# Updated 2022-02-15T12:23:42.311577 from git@github.com:JetBrains/swot.git@38c46e53

TLDS = frozenset(
    [
        "ac.bd",
        "ac.be",
        "ac.cr",
        "ac.cy",
        "ac.gg",
        "ac.gn",
        "ac.il",
        "ac.in",
        "ac.jp",
        "ac.ke",
        "ac.kr",
        "ac.ma",
        "ac.me",
        "ac.mw",
        "ac.mz",
        "ac.ni",
        "ac.om",
        "ac.pa",
        "ac.pg",
        "ac.pr",
        "ac.ru",
        "ac.rw",
        "ac.sz",
        "ac.uk",
        "ac.yu",
        "ac.za",
        "ac.zm",
        "ac.zw",
        "ed.ao",
        "ed.cr",
        "ed.jp",
        "edu",
        "edu.al",
        "edu.ar",
        "edu.az",
        "edu.ba",
        "edu.bb",
        "edu.bd",
        "edu.bh",
        "edu.bn",
        "edu.bs",
        "edu.bz",
        "edu.ck",
        "edu.cn",
        "edu.dz",
        "edu.ee",
        "edu.er",
        "edu.et",
        "edu.gh",
        "edu.gt",
        "edu.hn",
        "edu.in",
        "edu.jm",
        "edu.jo",
        "edu.kh",
        "edu.kn",
        "edu.kw",
        "edu.kz",
        "edu.lr",
        "edu.ly",
        "edu.me",
        "edu.mg",
        "edu.ml",
        "edu.mn",
        "edu.mo",
        "edu.mt",
        "edu.mv",
        "edu.mw",
        "edu.mx",
        "edu.ni",
        "edu.np",
        "edu.pa",
        "edu.pe",
        "edu.ph",
        "edu.pk",
        "edu.pr",
        "edu.pt",
        "edu.pw",
        "edu.py",
        "edu.qa",
        "edu.ru",
        "edu.sa",
        "edu.sc",
        "edu.sd",
        "edu.sh",
        "edu.sl",
        "edu.sv",
        "edu.sy",
        "edu.tt",
        "edu.ve",
        "edu.ws",
        "edu.ye",
        "edu.zm",
        "es.kr",
        "g12.br",
        "hs.kr",
        "ms.kr",
        "sc.kr",
        "sch.ae",
        "sch.gg",
        "sch.id",
        "sch.je",
        "sch.jo",
        "sch.lk",
        "sch.ly",
        "sch.my",
        "sch.om",
        "sch.ps",
        "sch.sa",
        "sch.uk",
        "school.za",
        "urfu.me",
        "vic.edu.au",
    ]
)
