# Updated 2022-02-15T12:23:43.011390 from git@github.com:JetBrains/swot.git@38c46e53

from typing import Dict, List, Optional

DOMAINS: Dict[str, List[Optional[str]]] = {
    ".daffodil.ac": ["Daffodil International Academy"],
    ".diu.ac": ["DIU", "Dhaka International University"],
    ".dpi.ac": [
        "Daffodil Polytechnic Institute",
        "Bangladesh Skill Development Institute",
    ],
    ".kcu.ac": ["SOONGSIL CYBER UNIVERSITY"],
    ".lsst.ac": ["London School of Science and Technology"],
    ".mdx.ac": ["Middlesex University Dubai"],
    ".ukh.ac": ["University of Kurdistan - Hawler"],
    ".unikam.ac": ["Université de Kamina"],
    ".unw.ac": ["University of NorthWest"],
    ".uod.ac": ["University of Dohuk (Kurdistan Region)"],
    ".upl-univ.ac": ["L'université protestante de Lubumbashi (UPL)"],
    ".yuhs.ac": ["Yonsei University Health System"],
    ".cti.za.ac": ["CTI Education Group"],
    ".campus.academy": ["Campus Academy"],
    ".chungkang.academy": ["청강문화산업대학교", "ChungKang College of Cultural Industries"],
    ".cloud-campus.academy": ["Cloud campus", "Cloud campus"],
    ".esoft.academy": ["ESOFT Metro Campus"],
    ".greta-sud-aquitaine.academy": ["GRETA Sud Aquitaine"],
    ".houghton.academy": ["Houghton Academy"],
    ".htk.academy": [
        "htk academy",
        "University of Applied Sciences Europe GmbH (ehem. BiTS/ btk) - Berlin, Hamburg, Iserlohn",
    ],
    ".itstep.academy": ["Компьютерная Академия ШАГ", "STEP IT Academy"],
    ".kenzie.academy": ["Kenzie Academy"],
    ".metis.academy": ["IT v kurze"],
    ".stevejobs.academy": [
        "Fondazione Istituto Tecnico Superiore per le Tecnologie dell'Informazione e della Comunicazione Steve Jobs"
    ],
    ".uview.academy": ["University View Academy"],
    ".educand.ad": ["Centre de Formació Professional d'Andorra"],
    ".uda.ad": ["University of Andorra"],
    ".aau.ac.ae": ["Al Ain university", "AAU"],
    ".adu.ac.ae": ["Abu Dhabi University"],
    ".ajman.ac.ae": ["Ajman University of Science &amp; Technology"],
    ".ajmanuni.ac.ae": ["Ajman University of Science & Technology"],
    ".alainuniversity.ac.ae": ["Alain University of Science and Technology"],
    ".aurak.ac.ae": ["American University of Ras Al Khaimah"],
    ".buid.ac.ae": ["British University in Dubai"],
    ".gmu.ac.ae": ["Gulf Medical University"],
    ".hbmsu.ac.ae": ["Hamdan Bin Mohammed Smart University"],
    ".hct.ac.ae": ["Higher Colleges of Technology"],
    ".ku.ac.ae": ["Khalifa University of Science, Technology and Research"],
    ".masdar.ac.ae": ["Masdar University Of Science And Technology"],
    ".mbzuai.ac.ae": ["Mohamed bin Zayed University of Artificial Intelligence"],
    ".pi.ac.ae": ["The Petroleum Institute"],
    ".psa.ac.ae": ["أكاديمية العلوم الشرطية", "Sharjah Police Science Academy"],
    ".sharjah.ac.ae": ["University of Sharjah"],
    ".uaeu.ac.ae": ["United Arab Emirates University"],
    ".ud.ac.ae": ["University Of Dubai"],
    ".uowdubai.ac.ae": ["University of Wollongong - Dubai Campus"],
    ".zu.ac.ae": ["Zayed University"],
    ".agu.ae": ["Al Ghurair University"],
    ".alhosnu.ae": ["Alhosn University"],
    ".aue.ae": ["American University in the Emirates"],
    ".auschool.ae": ["Arab Unity School"],
    ".aust.ae": ["Ajman University of Science & Technology"],
    ".biticrak.ae": ["Birla Institute of Technology, International Campus"],
    ".cranleigh.ae": ["Cranleigh Abu Dhabi"],
    ".cuca.ae": ["City University College of Ajman"],
    ".iiss.ae": ["India International School, Sharjah, UAE"],
    ".sorbonne.ae": ["Paris-Sorbonne University Abu Dhabi"],
    ".mstuca.aero": ["Moscow State Technical University of Civil Aviation"],
    ".auaf.edu.af": ["American University of Afghanistan"],
    ".bakhtar.edu.af": ["Bakhtar University"],
    ".dawat.edu.af": ["پوهنتون دعوت", "Dawat University"],
    ".dunya.edu.af": ["Dunya University"],
    ".kardan.edu.af": ["Kardan University"],
    ".kateb.edu.af": ["Kateb University"],
    ".ku.edu.af": ["Kabul University"],
    ".salam.edu.af": ["Salam University", "Salam University"],
    ".spingharuniversity.edu.af": ["Spinghar University"],
    ".uhsa.ag": ["University of Health Sciences Antigua"],
    ".beder.edu.al": ["University College Bedër"],
    ".epoka.edu.al": ["Epoka University"],
    ".fshn.edu.al": ["Faculty of Natural Sciences at University of Tirana"],
    ".fti.edu.al": ["Fakulteti i Teknologjisë she Informacionit."],
    ".uat.edu.al": ["American University of Tirana"],
    ".ubt.edu.al": ["Agricultural University of Tirane"],
    ".umb.edu.al": ["Marin Barleti University"],
    ".uniel.edu.al": ["University of Elbasan Aleksander Xhuvani"],
    ".unipavaresia.edu.al": ["University “Pavaresia” Vlore"],
    ".unishk.edu.al": ["University of Shkodra Luigj Gurakuqi"],
    ".unitir.edu.al": ["University of Tirana"],
    ".univlora.edu.al": ["University of Vlora Ismail Qemali"],
    ".unkorce.edu.al": ["University of Korca Fan Noli"],
    ".unyt.edu.al": ["University of New York Tirana"],
    ".uogj.edu.al": ["University of Gjirokstra Eqerem Cabej"],
    ".unizkm.al": ['Catholic University "Our Lady of Good Counsel"'],
    ".upt.al": ["Polytechnic University of Tirane"],
    ".armmed.am": ["Mehrabyan Medical Institute and Medical College"],
    ".aspu.am": ["Armenian State Pedagogical University"],
    ".asue.am": ["Armenian State University of Economics"],
    ".aua.am": ["American University of Armenia"],
    ".aybschool.am": ["Ayb School"],
    ".eiu.am": ["Eurasia International University"],
    ".eriicta.am": ["European Regional Educational Academy of Armenia"],
    ".fizmat.am": [
        "Արտաշես Շահինյանի անվան ֆիզիկամաթեմատիկական հատուկ դպրոց",
        "Physical-Mathematical School",
    ],
    ".isec.am": [
        "International Scientific-Educational Center of the National Academy of Sciences of Republic of Armenia (ISEC)"
    ],
    ".mskh.am": ["Mkhitar Sebastatsi Educational Complex"],
    ".msu.am": ["Филиал МГУ в Ереване", "Moscow State University Branch in Yerevan"],
    ".nuaca.am": ["NATIONAL UNIVERSITY OF ARCHITECTURE AND CONSTRUCTION OF ARMENIA"],
    ".polytechnic.am": ["National Polytechnic University of Armenia"],
    ".student.rau.am": [
        "Russian - Armenian University (RAU)",
        "Russian - Armenian University (RAU)",
    ],
    ".rau.am": ["Russian-Armenian University"],
    ".seua.am": ["State Engineering University of Armenia"],
    ".ufar.am": ["French University in Armenia (UFAR)"],
    ".yerphi.am": [
        "A. I. Alikhanian National Science Laboratory",
        "Yerevan Physics Institute",
    ],
    ".ysmu.am": ["Yerevan State Medical University"],
    ".ysu.am": ["Yerevan State University"],
    ".ysumail.am": ["Yerevan State University"],
    ".isptec.co.ao": ["Instituto Superior Politécnico de Tecnologias e Ciências"],
    ".uma.co.ao": ["Universidade Metodista de Angola"],
    ".utanga.co.ao": ["Universidade Tecnica de Angola"],
    ".uan.ao": ["Univesidade Agostinho Neto"],
    ".unia.ao": ["Universidade Independente de Angola"],
    ".ianca.com.ar": ["Instituto Argentino de Negociación, Conciliación y Arbitraje"],
    ".inaf27.com.ar": ["Instituto Nicolás Avellaneda F-27"],
    ".istea.com.ar": ["Instituto Superior Tecnológico Empresarial Argentino"],
    ".atlantida.edu.ar": ["Universidad Atlantida Argentina"],
    ".austral.edu.ar": ["Universidad Austral Buenos Aires"],
    ".caece.edu.ar": ["Universidad CAECE, Buenos Aires"],
    ".cema.edu.ar": ["Instituto Universitario CEMA"],
    ".ib.edu.ar": ["Instituto Balseiro", "Balseiro Institute"],
    ".iese.edu.ar": ["Instituto de Enseñanza Superior del Ejército"],
    ".ispi4038.edu.ar": ["Instituto Superior Particular Incorporado Nº 4038"],
    ".itba.edu.ar": ["Instituto Tecnológico de Buenos Aires"],
    ".iua.edu.ar": ["Instituto Universitario Aeronáutico"],
    ".iuna.edu.ar": ["Instituto Universitario Nacional del Arte"],
    ".kennedy.edu.ar": ["Universidad Argentina John F. Kennedy"],
    ".maimonides.edu.ar": ["Universidad Maimónides"],
    ".mdp.edu.ar": ["Universidad Nacional de Mar del Plata"],
    ".palermo.edu.ar": ["Universidad de Palermo"],
    ".salvador.edu.ar": ["Universidad del Salvador"],
    ".uade.edu.ar": ["Universidad Argentina de la Empresa"],
    ".uader.edu.ar": ["Universidad Autónoma de Entre Ríos"],
    ".alumnos.uai.edu.ar": ["Universidad Abierta Interamericana"],
    ".uai.edu.ar": ["Universidad Abierta Interamericana"],
    ".ub.edu.ar": ["Universidad de Belgrano"],
    ".ubp.edu.ar": ["Universidad Blas Pascal"],
    ".uca.edu.ar": ["Universidad Católica Argentina Santa Maria de los Buenos Aires"],
    ".ucaecemdp.edu.ar": ["Universidad CAECE, Mar del Plata"],
    ".ucalp.edu.ar": ["Universidad Católica de La Plata"],
    ".uccor.edu.ar": ["Universidad Católica de Córdoba"],
    ".uccuyo.edu.ar": ["Universidad Católica de Cuyo"],
    ".ucel.edu.ar": ["Universidad del Centro Educativo Latinoamericano Rosario"],
    ".ucema.edu.ar": ["Universidad del CEMA"],
    ".uces.edu.ar": ["Universidad de Ciencias Empresariales y Sociales"],
    ".uch.edu.ar": ["Universidad Champagnat"],
    ".ucine.edu.ar": ["Universidad del Cine - Buenos Aires"],
    ".ucp.edu.ar": ["Universidad de la Cuenca del Plata"],
    ".ucse.edu.ar": ["Universidad Católica de Santiago del Estero"],
    ".ucsf.edu.ar": ["Universidad Católica de Santa Fé"],
    ".ucu.edu.ar": ["Universidad de Concepción del Uruguay"],
    ".uda.edu.ar": ["Universidad del Aconcagua"],
    ".udemm.edu.ar": ["Universidad de la Marina Mercante"],
    ".udesa.edu.ar": ["Universidad de San Andres"],
    ".uesiglo21.edu.ar": ["Universidad Empresarial Siglio 21"],
    ".ufasta.edu.ar": [
        "Universidad de la Fraternidad de Agrupaciones Santo Tomas de Aquino (FASTA)"
    ],
    ".uflo.edu.ar": ["Universidad de Flores - Buenos Aires"],
    ".ulp.edu.ar": ["Universidad de La Punta"],
    ".um.edu.ar": ["Universidad de Mendoza"],
    ".umaza.edu.ar": ["Universidad Juan Agustín Maza"],
    ".umsa.edu.ar": ["Universidad del Museo Social Argentino"],
    ".unam.edu.ar": ["Universidad Nacional de Misiones"],
    ".unc.edu.ar": ["Universidad Nacional de Córdoba"],
    ".unca.edu.ar": ["Universidad Nacional de Catamarca"],
    ".uncoma.edu.ar": [
        "Instituto Universitario de Ciencias de la Salud - Buenos Aires",
        "Universidad Nacional del Comahue",
    ],
    ".uncu.edu.ar": ["Universidad Nacional de Cuyo"],
    ".undec.edu.ar": ["Universidad Nacional de Chilecito"],
    ".uner.edu.ar": ["Universidad Nacional de Entre Ríos"],
    ".unf.edu.ar": ["Universidad Nacional de Formosa"],
    ".ungs.edu.ar": ["Universidad Nacional de General Sarmiento"],
    ".unibo.edu.ar": ["Universidad de Bologna - Representación en Buenos Aires"],
    ".unicen.edu.ar": [
        "Universidad Nacional del Centro de la Provincia de Buenos Aires"
    ],
    ".unimoron.edu.ar": ["Universidad de Morón"],
    ".universidad-policial.edu.ar": ["Instituto Universitario de la Policia Federal"],
    ".universidadnotarial.edu.ar": ["Universidad Notarial Argentina"],
    ".unju.edu.ar": ["Universidad Nacional de Jujuy"],
    ".unl.edu.ar": ["Universidad Nacional del Littoral"],
    ".unla.edu.ar": ["Universidad Nacional de Lanus"],
    ".alumno.unlam.edu.ar": [
        "Departamento de Ingenieria - Universidad Nacional de la Matanza"
    ],
    ".unlam.edu.ar": ["Universidad Nacional de La Matanza"],
    ".unlar.edu.ar": ["Universidad Nacional de La Rioja"],
    ".unlp.edu.ar": ["Universidad Nacional de La Plata"],
    ".unlpam.edu.ar": ["Universidad Nacional de La Pampa"],
    ".unlu.edu.ar": [
        "Instituto Nacional de Educación Física General Manuel Belgrano",
        "Universidad Nacional de Luján",
    ],
    ".unlz.edu.ar": ["Universidad Nacional de Lomas de Zamora"],
    ".unne.edu.ar": ["Universidad Nacional del Nordeste"],
    ".unnoba.edu.ar": [
        "Universidad Nacional del Noroeste de la Provincia de Buenos Aires"
    ],
    ".unp.edu.ar": ["Universidad Nacional de la Patagonia San Juan Bosco"],
    ".unpa.edu.ar": ["Universidad Nacional de la Patagonia Austral"],
    ".unq.edu.ar": ["Universidad Nacional de Quilmes"],
    ".unr.edu.ar": ["Universidad Nacional de Rosario"],
    ".unrc.edu.ar": ["Universidad Nacional de Río Cuarto"],
    ".uns.edu.ar": ["Universidad Nacional del Sur"],
    ".exa.unsa.edu.ar": [
        "Facultad de Ciencias Exactas - Universidad Nacional de Salta"
    ],
    ".unsa.edu.ar": ["Universidad Nacional de Salta"],
    ".unsam.edu.ar": ["Universidad Nacional de General San Martín"],
    ".unse.edu.ar": ["Universidad Nacional de Santiago del Estero"],
    ".unsj.edu.ar": ["Universidad Nacional de San Juan"],
    ".unsl.edu.ar": ["Universidad Nacional de San Luis"],
    ".unsta.edu.ar": ["Universidad del Norte Santo Tomás de Aquino"],
    ".unt.edu.ar": ["Universidad Nacional de Tucumán"],
    ".untref.edu.ar": ["Universidad Nacional de Tres de Febrero"],
    ".usal.edu.ar": ["Universidad del Salvador"],
    ".frba.utn.edu.ar": [
        "Facultad Regional Buenos Aires - Universidad Tecnológica Nacional"
    ],
    ".frro.utn.edu.ar": [
        "Facultad Regional Rosario - Universidad Tecnológica Nacional"
    ],
    ".frsf.utn.edu.ar": [
        "Universidad Tecnológica Nacional - Facultad Regional Santa Fe",
        "National Technological University - Santa Fe Regional Faculty",
    ],
    ".utn.edu.ar": ["Universidad Tecnológica Nacional"],
    ".vaneduc.edu.ar": ["Universidad Abierta Interamericana"],
    ".igevet.gob.ar": [
        "Instituto de Genetica Veterinaria - Universidad nacional de la Plata",
        "Veterinary Genetics Institute - La Plata National University",
    ],
    ".irice-conicet.gov.ar": [
        "IRICE (CONICET/ UNR) - Instituto Rosario de Investigaciones en Ciencias de la Educación"
    ],
    ".itecriocuarto.org.ar": [
        "Instituto Tecnologico Rio Cuarto",
        "Rio Cuarto's Tech Institute",
    ],
    ".dc.uba.ar": [
        "Departamento de Computación - Facultad de Ciencias Exactas y Naturales. UBA"
    ],
    ".df.uba.ar": [
        "Departamento de Física - Facultad de Ciencias Exactas y Naturales. UBA"
    ],
    ".fi.uba.ar": ["Facultad de Ingenieria de la Universidad de Buenos Aires"],
    ".uba.ar": ["Universidad de Buenos Aires"],
    ".ait.asia": ["Asian Institute of Technology, Thailand"],
    ".mit.asia": ["Maharashtra institute of Technology, Aurangabad"],
    ".uap.asia": ["University of Asia and the Pacific"],
    ".vidyanikethan.asia": ["Sree Vidyanikethan Engineering College"],
    ".aau.at": ["Alpen-Adria-Universität Klagenfurt"],
    ".stud.aim.ac.at": ["Austrian Institute of Management - FH Burgenland"],
    ".akbild.ac.at": ["Akademie der bildenden Künste Wien"],
    ".boku.ac.at": ["Universität für Bodenkultur Wien"],
    ".borgstpoelten.ac.at": ["BRG/BORG"],
    ".bs-linz2.ac.at": ["Berufsschule Linz 2"],
    ".donau-uni.ac.at": ["Donau-Universität Krems"],
    ".fernfh.ac.at": ["Ferdinand Porsche FernFH"],
    ".fh-campuswien.ac.at": [
        "FH Campus Wien - Verein zur Förderung des Fachhochschul-, Entwicklungs- und Forschungszentrums im Süden Wiens",
        "FH Campus Wien - University of Applied Sciences",
    ],
    ".fh-kaernten.ac.at": ["Fachhochschule Kärnten"],
    ".fh-krems.ac.at": ["Fachhochschule Krems"],
    ".fh-kufstein.ac.at": ["Fachhochschule Kufstein (Tirol)"],
    ".fh-salzburg.ac.at": ["Fachhochschule Salzburg", "University of Applied Sciences"],
    ".fh-sbg.ac.at": ["Fachhochschule Salzburg"],
    ".fh-stpoelten.ac.at": ["Fachhochschule St. Pölten"],
    ".fh-vie.ac.at": ["Fachhochschule für Bank- und Finanzwirtschaft"],
    ".edu.fh-wien.ac.at": ["FHWien der WKW"],
    ".stud.fhgooe.ac.at": ["FH Gesundheitsberufe OÖ GmbH"],
    ".fhgooe.ac.at": ["FH Gesundheitsberufe OÖ GmbH"],
    ".fhstp.ac.at": [
        "Fachhochschule St. Pölten",
        "St.Pölten University of Applied Sciences",
    ],
    ".fhwn.ac.at": ["Fachhochschule Wiener Neustadt"],
    ".gym-hartberg.ac.at": [
        "Gymnasium Hartberg – BG/BRG/BORG",
        "High School Hartberg – BG/BRG/BORG",
    ],
    ".s.hakmistelbach.ac.at": ["Bundeshandelsakademie Mistelbach"],
    ".hakwr-neustadt.ac.at": [
        "Bundeshandelsakademie Wiener Neustadt",
        "College of Business Administration Wiener Neustadt",
    ],
    ".hblva17.ac.at": [
        "Höhere Bundes- Lehr- und Versuchsanstalt für chemische Industrie",
        "Federal College and research institute for chemical industry",
    ],
    ".htl-hl.ac.at": ["HTL Hollabrunn"],
    ".htl-kaindorf.ac.at": [
        "Höhere Technische Bundeslehranstalt Kaindorf",
        "Federal Higher Technical Institute Kaindorf",
    ],
    ".htl-leonding.ac.at": ["HTL Leonding"],
    ".htl-perg.ac.at": ["Höhere technische Bundeslehranstalt Perg"],
    ".htl-salzburg.ac.at": ["HTBLuVA Salzburg"],
    ".htl-steyr.ac.at": [
        "HTL Steyr",
        "HTBLA Steyr",
        "Hoehere technische Bundeslehranstalt Steyr",
    ],
    ".htlmistelbach.ac.at": [
        "Höhere technische Lehranstalt Mistelbach für Biomedizin und Gesundheitstechnik",
        "HTL Mistelbach for biomedical engineering",
    ],
    ".htlstp.ac.at": ["HTBLuVA St.Pölten"],
    ".htlwrn.ac.at": ["HTBLuVA Wiener Neustadt"],
    ".htlwy.ac.at": ["HTL-Waidhofen at the Ybbs"],
    ".i-med.ac.at": ["Medizinische Universität Innsbruck"],
    ".imc-krems.ac.at": ["Fachhochschulstudiengänge Krems IMC"],
    ".ist.ac.at": ["Institute of Science and Technology"],
    ".kfunigraz.ac.at": ["Universität Graz"],
    ".kug.ac.at": ["Universität für Musik und darstellende Kunst Graz"],
    ".litec.ac.at": ["Litec - Linzer Technikum"],
    ".mdw.ac.at": ["Universität für Musik und darstellende Kunst  Wien"],
    ".meduniwien.ac.at": ["Medizinische Universität Wien"],
    ".modul.ac.at": ["MODUL Private University Vienna"],
    ".moz.ac.at": ["Universität Mozarteum Salzburg"],
    ".ndu.ac.at": ["New Design University - Privatuniversität St. Pölten"],
    ".plus.ac.at": ["University of Salzburg"],
    ".rg18.ac.at": ["BRG 18"],
    ".sbg.ac.at": ["Universität Salzburg"],
    ".mail.sfu.ac.at": [
        "Sigmund Freud University Vienna",
        "Sigmund Freud University Vienna",
    ],
    ".sz-ybbs.ac.at": ["SZ-Ybbs"],
    ".tgm.ac.at": ["Technologisches Gewerbemuseum Wien"],
    ".tuwien.ac.at": ["Technische Universität Wien"],
    ".uibk.ac.at": ["Universität Innsbruck"],
    ".uni-ak.ac.at": ["Universität für angewandte Kunst Wien"],
    ".uni-klu.ac.at": ["Alpen-Adria-Universität Klagenfurt"],
    ".uni-linz.ac.at": ["Universität Linz"],
    ".unileoben.ac.at": ["Montanuniversität Leoben"],
    ".univie.ac.at": ["Universität Vienna"],
    ".vu-wien.ac.at": ["Veterinärmedizinische Universität Wien"],
    ".webster.ac.at": ["Webster University, Vienna"],
    ".wu-wien.ac.at": [
        "\ufeffWirtschaftsuniversität Wien",
        "Vienna University of Economics and Business",
    ],
    ".wu.ac.at": [None, "Vienna University of Economics and Business"],
    ".ais.at": ["American International School Vienna"],
    ".ams-wien.at": ["Albertus Magnus Schule"],
    ".antonkriegergasse.at": [" WMS/RG/ORG antonkriegergasse"],
    ".bbs-rohrbach.at": ["BBS-Rohrbach"],
    ".bgklosterneuburg.at": ["BG/BRG Klosterneuburg"],
    ".bhak-eisenerz.at": ["BHAK-Eisenerz Bundeshandelsakademie"],
    ".bhak.at": ["BHAK Fürstenfeld"],
    ".borg-kindberg.at": ["BORG Kindberg"],
    ".borg1.at": ["BORG Monsbergergasse", "BORG Monsberger"],
    ".brgwels.at": ["BRG Wels Wallererstraße"],
    ".edu.brucknergym.at": ["Brucknergymnasium Wels"],
    ".bulme.at": ["HTL BULME"],
    ".campus02.at": ["CAMPUS 02 Fachhochschule der Wirtschaft"],
    ".dachsberg.at": ["Gymnasium Dachsberg"],
    ".erlgasse.at": ["GRG XII Erlgasse"],
    ".europagym.at": ["Europagymnasium Auhof"],
    ".evgym.at": ["Evangelisches Gymnasium"],
    ".fadi.at": ["BRG Fadingerstraße Linz, Austria"],
    ".fbs-klagenfurt1.at": [
        "Fachberufsschule Klagenfurt1",
        "Vocational school Klagenfurt1",
        "https://www.fbs-klagenfurt1.at",
        "Long-term IT related Course: https://www.fbs-klagenfurt1.at/lehrberufe/applikationsentwicklung-coding/",
        "Students and Teachers are provided with an email address like firstname.lastname@fbs-klagenfurt1.at",
        "so my email is isolde.koelblinger@fbs-klagenfurt1.at (I'm the teacher for course 'Coding')",
    ],
    ".fh-burgenland.at": ["Fachhochschule Burgenland"],
    ".fh-hagenberg.at": ["Fachhochschulstudiengänge Hagenberg"],
    ".fh-joanneum.at": ["Fachhochschule JOANNEUM"],
    ".fh-kaernten.at": ["Fachhochschule Kärnten"],
    ".fh-steyr.at": ["Fachhochschulstudiengänge Steyr"],
    ".fh-wels.at": ["Fachhochschulstudiengänge Wels"],
    ".fhv.at": ["Fachhochschule Vorarlberg"],
    ".fhw.at": ["Fachhochschulstudiengänge der Wiener Wirtschaft"],
    ".forstschule.at": ["HBLA für Forstwirtschaft Bruck an der Mur"],
    ".gym-nd.at": ["Bundesgymnasium und Bundesrealgymnasium Neusiedl am See"],
    ".gymgmunden.at": ["BG und BRG Gmunden"],
    ".gymnasium-saalfelden.at": ["BG/Sport-RG Saalfelden"],
    ".hak-althofen.at": ["HAK Althofen"],
    ".hak-bregenz.at": ["HAK Bregenz"],
    ".hak-frk.at": ["Bundeshandelsakademie und Bundeshandelsschule Frauenkirchen"],
    ".hak-liezen.at": ["BHAK/BHAS Liezen"],
    ".hak-op.at": ["HAK Oberpullendorf", "Commercial High School Oberpullendorf"],
    ".hakneumarkt.at": [
        "Bundeshandelsakademie Neumarkt am Wallersee",
        "Commercial School in Neumarkt am Wallersee",
    ],
    ".hakspittal.at": ["HAK Spittal"],
    ".hakvb.at": ["Handelsakademie Vöcklabruck"],
    ".hakzell.at": ["BHAK/BHAS Zell am See"],
    ".hblfa-tirol.at": [
        "Höhere Bundeslehr- und Forschungsanstalt für Landwirtschaft und Ernährung, Lebensmittel- und Biotechnologie Tirol",
        "Higher Federal Education and Research Institute for Agriculture and Food, Food and Biotechnology Tyrol",
    ],
    ".hblw-saalfelden.at": ["HBLW Saalfelden"],
    ".hlw-freistadt.at": ["HLW Freistadt school"],
    ".hlw10.at": ["Höhere Bundeslehranstalt für wirtschaftliche Berufe"],
    ".holztechnikum.at": ["Holztechnikum Kuchl"],
    ".htl-braunau.at": ["HTBLA Braunau"],
    ".htl-donaustadt.at": ["HTL Donaustadt"],
    ".htl-grieskirchen.at": ["HTBLA Grieskirchen"],
    ".htl-hallein.at": ["HTBLA Hallein"],
    ".htl-kaindorf.at": [
        "Höhere Technische Bundeslehranstalt Kaindorf",
        "Federal Higher Technical Institute Kaindorf",
    ],
    ".htl-klu.at": ["HTL Mössingerstraße"],
    ".o365.htl-leoben.at": [
        "Höhere Technische Lehranstalt und Werkmeisterschule des Schulvereins der Berg- und Hüttenschule Leoben Privatschule mit Öffentlichkeitsrecht",
        "Higher Technical Education Institute Leoben, private school",
    ],
    ".htl-leoben.at": ["Higher Technical Education Institute Leoben, private school"],
    ".htl-neufelden.at": ["HTL Neufelden"],
    ".htl-ottakring.at": ["HTL Ottakring"],
    ".htl-saalfelden.at": [
        "Höhere Technische Bundeslehranstalt Saalfelden am Steinernen Meer"
    ],
    ".htl-villach.at": ["HTL Villach"],
    ".htl-wels.at": ["HTL Wels"],
    ".htl-wolfsberg.at": ["HTL Wolfsberg", "HTL Wolfsberg"],
    ".htldornbirn.at": ["HTL Dornbirn"],
    ".wi.htlhl.at": ["HTL Hollabrunn", "Higher Technical College Hollabrunn"],
    ".htlkrems.at": ["HTL Krems"],
    ".htlpinkafeld.at": ["HTL Pinkafeld"],
    ".htlstp.at": ["HTBLuVA St. Pölten"],
    ".htltraun.at": ["HTL Traun", "Higher technical college Traun"],
    ".htlvb.at": ["HTL Vöcklabruck"],
    ".htlweiz.at": ["HTL Weiz"],
    ".htlwienwest.at": ["Höhere Technische Lehranstalt Wien West"],
    ".htlwy.at": ["HTL-Waidhofen at the Ybbs"],
    ".isi-hagenberg.at": [
        "Universal Computing and Business - International School for Informatics"
    ],
    ".jku.at": ["Johannes Kepler University Linz"],
    ".johak.at": [
        "Bundeshandelsakademie St. Johann im Pongau",
        "Federal Business Academy St. Johann im Pongau",
    ],
    ".klostergasse.at": ["BG 18 Klostergasse"],
    ".kundmanngasse.at": ["GRg3 Kundmanngasse Bundesgymnasium und Bundesrealgymnasium"],
    ".lichtenfels.at": ["BG/BRG Lichtenfels Graz"],
    ".lyceefrancais.at": ["Lycée Français de Vienne"],
    ".mci4me.at": ["Management Center Innsbruck"],
    ".meduni-graz.at": ["Medizinische Universität Graz"],
    ".medunigraz.at": ["Medical University of Graz"],
    ".meduniwien.at": ["Medizinische Universität Wien"],
    ".htl.moedling.at": ["HTL Mödling"],
    ".nmms-mautern.at": ["Neuemusikmittelschule Mautern", "NMMS Mautern"],
    ".nms-gruenburg.at": ["NMS Grünburg", "(new) middle-school Gruenburg"],
    ".klg.or.at": ["Konrad Lorenz Gymnasium"],
    ".ph-linz.at": ["Private Pädagogische Hochschule der Diözese Linz"],
    ".phst.at": [
        "University College of Teacher Education Styria",
        "Pädagogische Hochschule Steiermark",
    ],
    ".popperschule.at": ["Sir Karl Popper Schule"],
    ".qualifizierung.at": [
        "Berufliches Bildungs- und Rehabilitationszentrum Österreich",
        "Austrian Center for Professional Education and Rehabilitation",
        "www.bbrz.at",
        "(The @qualifizierung.at is the domain used for all students in an Austrian qualification program.)",
        "My course for software development (24 months):",
        "https://www.bbrz.at/fileadmin/user_upload/Produkblaetter/Reha-Ausbildung/Steiermark/Kapfenberg_REHA_Ausbildung_CODERSBAY.pdf",
        "https://www.whois.com/whois/qualifizierung.at",
    ],
    ".raumberg-gumpenstein.at": ["HBLFA Raumberg-Gumpenstein"],
    ".htl.rennweg.at": ["HTL Rennweg"],
    ".hak-stjo.salzburg.at": [
        "Bundeshandelsakademie St. Johann im Pongau",
        "Federal Business Academy St. Johann im Pongau",
    ],
    ".lbs4.salzburg.at": ["Landesberufsschule 4"],
    ".schulzentrum-hall.at": ["NMS Schulzentrum Hall"],
    ".lbsfe1.snv.at": [
        "Landesberufsschule Feldkirch",
        "State Vocational School Feldkirch",
    ],
    ".spengergasse.at": ["HTL Spengergasse"],
    ".sti2.at": ["Semantic Technology Institute"],
    ".swale.at": ["The Sittingbourne School", "The Sittingbourne School"],
    ".szu.at": ["Schulzentrum HTL HAK Ungargasse"],
    ".technikum-wien.at": ["Technikum Wien"],
    ".tsn.at": [
        "Schulen des Tiroler Schulnetzes https://www.dvt.at/services/tsn-tiroler-schulnetz/"
    ],
    ".tugraz.at": ["Technische Universität Graz"],
    ".ufg.at": ["University of Art and Design Linz"],
    ".umit.at": ["Private Universität für Medizinische Informatik und Technik Tirol"],
    ".uni-graz.at": ["University of Graz"],
    ".edu.uni-seeburg.at": ["Pruvatuniversität Seeburg"],
    ".ursulinen.at": ["Schulverein der Grazer Ursulinen"],
    ".werkschulheim.at": ["Werkschulheim Felbertal"],
    ".wiednergymnasium.at": ["Wiedner Gymnasium (Sir-Karl-Popper-Schule)"],
    ".student.aiict.com.au": ["Australian Institute of ICT"],
    ".alkirasc.com.au": ["Alkira Secondary College"],
    ".churchie.com.au": ["Anglican Church Grammar School"],
    ".cqumail.com.au": ["CQUniversity [https://www.cqu.edu.au/]"],
    ".hotelschool.com.au": ["Blue Mountains Hotel School"],
    ".studentmail.academies.edu.au": ["Academies Australasia "],
    ".accm.edu.au": ["Australian College of Commerce and Management"],
    ".acs.edu.au": ["Australian Correspondence Schools"],
    ".cgs.act.edu.au": ["Canberra Grammar School"],
    ".ed.act.edu.au": ["Lake Tuggeranong College"],
    ".schoolsnet.act.edu.au": [
        "ACT Education Directorate",
        "Lake Tuggeranong College",
        ".group",
    ],
    ".acu.edu.au": ["Australian Catholic University"],
    ".adelaide.edu.au": ["University of Adelaide"],
    ".study.aib.edu.au": ["Australia Institute of Business"],
    ".aie.edu.au": ["The Academy of Interactive Entertainment"],
    ".albrightinstitute.edu.au": ["Albright Institute of Business and Language"],
    ".alc.edu.au": ["Australian Lutheran College"],
    ".amc.edu.au": ["Australian Maritime College"],
    ".angliss.edu.au": ["William Angliss Institute"],
    ".anu.edu.au": ["Australian National University"],
    ".apc.edu.au": ["Australian Pacific College"],
    ".atmc.edu.au": ["ATMC", "Australian Technical and Management College"],
    ".avondale.edu.au": ["Avondale College"],
    ".bond.edu.au": ["Bond University"],
    ".canberra.edu.au": ["University of Canberra"],
    ".cardijn.catholic.edu.au": ["Cardijn Collage"],
    ".parrastu.catholic.edu.au": ["St Luke's Catholic College"],
    ".sydstu.catholic.edu.au": ["De La Salle Catholic College"],
    ".cdu.edu.au": ["Charles Darwin University"],
    ".cem.edu.au": ["Melbourne Archdiocese Catholic Schools"],
    ".students.cit.edu.au": ["Canberra institute of technology"],
    ".coderacademy.edu.au": ["Coder Academy"],
    ".cqu.edu.au": ["Central Queensland University"],
    ".cs.edu.au": ["Education Services Australia"],
    ".csu.edu.au": ["Charles Sturt University"],
    ".curtin.edu.au": ["Curtin University of Technology"],
    ".danford.edu.au": ["Danford College "],
    ".deakin.edu.au": ["Deakin University"],
    ".ecu.edu.au": ["Edith Cowan University"],
    ".eit.edu.au": ["Engineering Institute of Technology"],
    ".eq.edu.au": [
        "Queensland Academy of Science, Mathematics and Technology",
        "Helensvale State High School",
        ".group",
    ],
    ".federation.edu.au": ["Federation University Australia"],
    ".flinders.edu.au": ["Flinders University of South Australia"],
    ".griffith.edu.au": ["Griffith University"],
    ".griffithuni.edu.au": ["Griffith University"],
    ".holmes.edu.au": ["Holmes Institute"],
    ".holmesglen.edu.au": ["Holmesglen Institute, Victoria, Australia"],
    ".student.ichm.edu.au": [
        "International College of Hotel Management",
        "International College of Hotel Management",
    ],
    ".iota.edu.au": ["Institute Of Technology, Australia"],
    ".jcu.edu.au": ["James Cook University of North Queensland"],
    ".jmc.edu.au": ["JMC Academy"],
    ".kaplanstudent.edu.au": ["Kaplan Business School", "KBS"],
    ".student.kent.edu.au": ["Kent Institute"],
    ".student.kii.edu.au": ["Kingsford international Institute (KII)"],
    ".kings.edu.au": ["kings.edu.au"],
    ".students.koi.edu.au": ["King’s Own Institute"],
    ".latrobe.edu.au": ["La Trobe University"],
    ".laureate.edu.au": ["Torrens University"],
    ".students.ltu.edu.au": ["La Trobe"],
    ".ltu.edu.au": ["La Trobe University"],
    ".mcri.edu.au": ["Murdoch Children's Research Institute"],
    ".mercurycolleges.edu.au": ["Mercury Colleges"],
    ".mit.edu.au": ["Melbourne Institute of Technology"],
    ".monash.edu.au": ["Monash University"],
    ".student.mp.edu.au": ["Melbourne Polytechnic"],
    ".mq.edu.au": ["Macquarie University"],
    ".murdoch.edu.au": ["Murdoch University"],
    ".myacu.edu.au": ["Australian Catholic University"],
    ".myangliss.edu.au": ["William Angliss Institute"],
    ".myune.edu.au": ["University of New England", "University of New England"],
    ".nd.edu.au": ["University of Notre Dame Australia"],
    ".newcastle.edu.au": ["University of Newcastle"],
    ".nortwest.edu.au": ["Nortwest Pty Ltd."],
    ".ait.nsw.edu.au": ["Academy of Information Technology"],
    ".covenant.nsw.edu.au": ["Covenant Christian School"],
    ".lindisfarne.nsw.edu.au": ["Lindisfarne Anglican Grammar School"],
    ".loreto.nsw.edu.au": ["Loreto Kirribilli"],
    ".mercurycolleges.nsw.edu.au": ["Mercury Colleges"],
    ".sec.nsw.edu.au": ["St Edward's College"],
    ".stgregs.nsw.edu.au": ["St Gregory's College"],
    ".sydgram.nsw.edu.au": ["Sydney Grammar School"],
    ".opencolleges.edu.au": ["Open Colleges"],
    ".pac.edu.au": ["Prince Alfred College"],
    ".citipointe.qld.edu.au": ["Citipointe Christian College"],
    ".clayfield.qld.edu.au": ["Clayfield College"],
    ".hillbrook.qld.edu.au": ["Hillbrook Anglican School"],
    ".jpc.qld.edu.au": ["John Paul College"],
    ".mta.qld.edu.au": ["Mount Alvernia College"],
    ".saac.qld.edu.au": ["St Andrews's Anglican College"],
    ".somerset.qld.edu.au": ["Somerset College"],
    ".stpauls.qld.edu.au": ["St Pauls School, Australia"],
    ".thelakes.qld.edu.au": ["The Lakes College"],
    ".qut.edu.au": ["Queensland University of Technology"],
    ".rmit.edu.au": ["Royal Melbourne Institute of Technology"],
    ".pedarecc.sa.edu.au": ["Pedare Christian College"],
    ".pembroke.sa.edu.au": ["Pembroke School"],
    ".rostrevor.sa.edu.au": ["Rostrevor College"],
    ".schools.sa.edu.au": [
        "Salisbury High School",
        "Department for Education | South Australia",
        ".group",
    ],
    ".smc.sa.edu.au": ["St Michaels College Adelaide"],
    ".sae.edu.au": ["SAE - Creative Media Institute"],
    ".scu.edu.au": ["Southern Cross University"],
    ".selc.edu.au": ["SELC Career College Australia"],
    ".studytafensw.edu.au": ["TAFE NSW"],
    ".swin.edu.au": ["Swinburne University of Technology"],
    ".sydney.edu.au": ["University of Sydney"],
    ".tafensw.edu.au": ["TAFE NSW"],
    ".tafeqld.edu.au": ["TAFE Queensland"],
    ".tafesa.edu.au": ["TAFE SA"],
    ".education.tas.edu.au": ["Department of Education Tasmania"],
    ".tascollege.edu.au": ["TasCollege"],
    ".tased.edu.au": ["Department of Education Tasmania"],
    ".top.edu.au": ["Top education Institute", "Top education Institute"],
    ".torrens.edu.au": ["Torrens University, Australia"],
    ".student.tua.edu.au": ["Torrens University Australia"],
    ".une.edu.au": ["University of New England"],
    ".unimelb.edu.au": ["University of Melbourne"],
    ".unisa.edu.au": ["University of South Australia"],
    ".unsw.edu.au": ["University of New South Wales"],
    ".uon.edu.au": ["University of Newcastle", "example@uon.edu.au"],
    ".uow.edu.au": ["University of Wollongong"],
    ".uowmail.edu.au": [
        "University of Wollongong",
        "Faculty of Engineering and Information Sciences",
    ],
    ".uq.edu.au": ["University of Queensland"],
    ".uqconnect.edu.au": [
        "The University of Queensland",
        "The University of Queensland",
    ],
    ".usc.edu.au": ["University of the Sunshine Coast"],
    ".usq.edu.au": ["University of Southern Queensland"],
    ".usyd.edu.au": ["University of Sydney"],
    ".utas.edu.au": ["University of Tasmania"],
    ".uts.edu.au": ["University of Technology Sydney"],
    ".uwa.edu.au": ["University of Western Australia"],
    ".uws.edu.au": ["University of Western Sydney"],
    ".genazzano.vic.edu.au": ["Genazzano FCJ College"],
    ".macs.vic.edu.au": ["Melbourne Archdiocese Catholic Schools"],
    ".marcusoldham.vic.edu.au": ["Marcus Oldham College"],
    ".student.vit.edu.au": ["Victoria Institute of Technology"],
    ".vu.edu.au": ["Victoria University"],
    ".carey.wa.edu.au": ["The Carey Baptist College"],
    ".cgs.wa.edu.au": ["Court Grammar School"],
    ".student.education.wa.edu.au": [
        "Warnbro community high school",
        "Warnbro community high school",
    ],
    ".gegs.wa.edu.au": ["Geraldton Grammar School, Geraldton, WA, Australia"],
    ".nmtafe.wa.edu.au": ["North Metropolitan TAFE, Australia"],
    ".tafe.wa.edu.au": ["North Metropolitan TAFE, Australia"],
    ".student.westernsydney.edu.au": ["Western Sydney University"],
    ".westernsydney.edu.au": ["Western Sydney University"],
    ".wic.edu.au": [
        "WELLS INTERNATIONAL COLLEGE PTY LTD",
        "WELLS INTERNATIONAL COLLEGE PTY LTD",
    ],
    ".education.nsw.gov.au": ["NSW Education"],
    ".student.education.nt.gov.au": ["Casuarina Senior College"],
    ".www.nt.gov.au": ["Batchelor Institute of Indigenous Tertiary Education"],
    ".education.tas.gov.au": ["Department of Education Tasmania"],
    ".education.vic.gov.au": [
        "Department of Education and Training, Victoria, Australia for Teacher's accounts"
    ],
    ".edumail.vic.gov.au": ["Williamstown High School"],
    ".tafensw.net.au": ["TAFE NSW"],
    ".uq.net.au": ["University of Queensland"],
    ".mu.oz.au": ["University of Melbourne"],
    ".ha.ax": ["Åland University of Applied Sciences"],
    ".elev.mariehamn.ax": ["Mariehamns Stad Grundskolor"],
    ".aztu.az": ["Azerbaijan Technical University"],
    ".bsu.az": ["Baku State University"],
    ".ada.edu.az": ["Azerbaijan Diplomatic Academy"],
    ".adu.edu.az": ["Azerbaijan University ol Languages"],
    ".amu.edu.az": ["Azerbaijan Medical University"],
    ".asoiu.edu.az": [
        "Azerbaijan State Oil and Industry University",
        "Azərbaycan Dövlət Neft və Sənaye Universiteti",
    ],
    ".au.edu.az": ["Azerbaijan University"],
    ".aztu.edu.az": ["Azerbaijan Technology University"],
    ".bbu.edu.az": ["Baki Business University"],
    ".dia.edu.az": ["Academy of Public Administration"],
    ".lsu.edu.az": ["Lankaran State University"],
    ".naa.edu.az": ["National Aviation Academy"],
    ".ndu.edu.az": ["Nakhchivan State University"],
    ".oyu.edu.az": ["Odlar Yurdu University"],
    ".pa.edu.az": ["Police Academy"],
    ".sdu.edu.az": ["Sumgait State University"],
    ".tourism.edu.az": ["Azerbaijan Toursim Institute"],
    ".wu.edu.az": ["Western University"],
    ".gsu.az": ["Ganja State University "],
    ".jis.az": ["Azerbaijan State Oil Academy"],
    ".ufaz.az": ["French-Azerbaijani University", "Azərbaycan-Fransız Universiteti"],
    ".ibu.edu.ba": ["International Burch University"],
    ".ius.edu.ba": ["International University of Sarajevo"],
    ".unvi.edu.ba": ["University Vitez In Travnik"],
    ".fet.ba": ["Faculty of Electrical Engineering Tuzla"],
    ".fit.ba": ['Univerzitet "Džemal Bijedić" Mostar'],
    ".student.fsre.ba": [
        "Faculty of mechanical engineering and computing, Mostar, Bosnia and Herzegowina",
        "Faculty of mechanical engineering and computing, Mostar, Bosnia and Herzegowina",
    ],
    ".unssa.rs.ba": ["University of East Srarajevo"],
    ".sfa.ba": ["Sarajevo Film Academy"],
    ".sinergija.ba": ["Univerzitet Sinergija", "Sinergija University"],
    ".size.ba": [
        "Politehnički fakultet Univerziteta u Zenici",
        "Faculty of Polytechnics - University of Zenica",
    ],
    ".spu.ba": ["Slobomir P Univerzitet"],
    ".fpmoz.sum.ba": ["Faculty of Science and Education"],
    ".sum.ba": ["University of Mostar"],
    ".sve-mo.ba": ["University of Mostar"],
    ".www.unbi.ba": ["University of Bihac"],
    ".unmo.ba": ["Univerzitet u Mostaru Dzemal Bijedic"],
    ".www.unsa.ba": ["University of Sarajevo"],
    ".unsa.ba": ["University of Sarajevo"],
    ".untz.ba": ["University of Tuzla"],
    ".unze.ba": ["University of Zenica"],
    ".uwichill.edu.bb": ["University of the West Indies, Cave Hill"],
    ".bracu.ac.bd": ["BRAC University"],
    ".brur.ac.bd": ["Begum Rokeya University, Rangpur"],
    ".buet.ac.bd": ["Bangladesh University of Engineering and Technology (BUET)"],
    ".cou.ac.bd": ["Comilla University"],
    ".cu.ac.bd": ["University of Chittagong"],
    ".cuet.ac.bd": ["Chittagong University of Engineering and Technology (CUET)"],
    ".du.ac.bd": ["University of Dhaka"],
    ".duet.ac.bd": ["Dhaka University of Engineering and Technology"],
    ".iiuc.ac.bd": [
        "International Islamic University Chittagong",
        "International Islamic University Chittagong(IIUC)",
    ],
    ".ku.ac.bd": ["Khulna University"],
    ".kuet.ac.bd": ["Khulna University of Engineering And Technology"],
    ".lus.ac.bd": ["Leading University"],
    ".mbstu.ac.bd": ["Mawlana Bhashani Science And Technology University"],
    ".mist.ac.bd": ["Military Institute of Science and Technology (MIST)"],
    ".nub.ac.bd": ["Northern University Bangladesh"],
    ".pstu.ac.bd": ["Patuakhali Science and Technology University"],
    ".pust.ac.bd": ["Pabna University of Science And Technology"],
    ".ru.ac.bd": ["University of Rajshahi"],
    ".ruet.ac.bd": ["Rajshahi University of Engineering And Technology"],
    ".sec.ac.bd": ["Sylhet Engineering College"],
    ".seu.ac.bd": ["Southeast University"],
    ".uiu.ac.bd": ["United International University (UIU)"],
    ".dcc.netpoint.com.bd": ["Dhaka City College"],
    ".asaub.edu.bd": ["Asa University Bangladesh"],
    ".bubt.edu.bd": ["Bangladesh University of Business &amp; Technology"],
    ".bup.edu.bd": ["Bangladesh University of Professionals"],
    ".cityuniversity.edu.bd": ["City University"],
    ".daffodilvarsity.edu.bd": ["Daffodil International University"],
    ".dis.edu.bd": ["Daffodil International School"],
    ".easternuni.edu.bd": ["Eastern University"],
    ".iub.edu.bd": ["Independent University, Bangladesh"],
    ".jkkniu.edu.bd": ["Jatiya Kabi Kazi Nazrul Islam University"],
    ".metrouni.edu.bd": ["Metropolitan University"],
    ".nstu.edu.bd": ["Noakhali University Of Science And Technology"],
    ".nu.edu.bd": ["National University"],
    ".portcity.edu.bd": ["Port City International University"],
    ".presidency.edu.bd": ["Presidency University"],
    ".primeuniversity.edu.bd": ["Prime University"],
    ".siu.edu.bd": ["Sylhet International University"],
    ".uits.edu.bd": ["University of Information Technology and Sciences"],
    ".ulab.edu.bd": ["University of Liberal Arts"],
    ".wub.edu.bd": ["World University of Bangladesh"],
    ".fpms.ac.be": ["Faculté Polytechnique de Mons"],
    ".fsagx.ac.be": ["Faculté Universitaire des Sciences Agronomiques de Gembloux"],
    ".fucam.ac.be": ["Facultés Universitaires Catholiques de Mons"],
    ".ful.ac.be": ["Fondation Universitaire Luxembourgeoise"],
    ".fundp.ac.be": ["Facultés Universitaires Notre-Dame de la Paix"],
    ".fusl.ac.be": ["Facultés Universitaires Saint-Louis"],
    ".kulak.ac.be": ["Katholieke Universiteit Leuven, Campus Kortrijk"],
    ".kuleuven.ac.be": ["Katholieke Universiteit Leuven"],
    ".rma.ac.be": ["Royal Military Academy"],
    ".ua.ac.be": ["Universiteit Antwerpen"],
    ".ucl.ac.be": ["Université Catholique de Louvain"],
    ".ufsia.ac.be": ["Universiteit Antwerpen, UFSIA"],
    ".ulb.ac.be": ["Université Libre de Bruxelles"],
    ".ulg.ac.be": ["Université de Liège"],
    ".umh.ac.be": ["Université de Mons-Hainaut"],
    ".umons.ac.be": ["University of Mons (merging of UMH and FPMS)."],
    ".vub.ac.be": ["Vrije Universiteit Brussel"],
    ".actournai.be": [
        "Official website : http://www.actournai.be/",
        "long term course on the official website (IT art, including game and web dev) : http://www.actournai.be/atelier/arts_numeriques",
    ],
    ".ap.be": ["AP Hogeschool Antwerpen"],
    ".ar-lessines.be": ["Athénée Royal René Magritte"],
    ".arteveldehs.be": ["Artevelde University College Ghent"],
    ".arvise.be": ["Athénée Royal de Visé"],
    ".assumpta.be": ["Lycée Maria Assumpta"],
    ".avondschool.be": ["CVO Panta Rhei"],
    ".bastassart.be": ["Busleyden Atheneum"],
    ".bazandpoort.be": ["Busleyden Atheneum"],
    ".bib-buellingen.be": ["Bischöfliches Institut Büllingen"],
    ".broeders.be": ["Broederscholen Hiëronymus"],
    ".campuskahalle.be": ["Atheneum Halle"],
    ".campussintursula.be": ["Campus Sint Ursula Lier"],
    ".cf2m.be": ["CF2m - Centre de Fomration TIC Bruxelles"],
    ".cidc.be": ["Centre IFAPME de Charleroi"],
    ".cnddinant.be": ["Collège Notre-Dame – Dinant"],
    ".cnldb.be": ["Haute Ecole Lucia de Brouckère"],
    ".condorcet.be": ["Haute Ecole Provinciale de Hainaut - Condorcet"],
    ".creo.be": ["Creo Secondary Adult Education Center"],
    ".cvo-step.be": ["CVO STEP"],
    ".cvoantwerpen.be": ["CVO Antwerpen"],
    ".cvosemper.be": ["CVO Semper"],
    ".dbhaacht.be": ["Don Bosco Haacht"],
    ".dbz.be": ["Don Boscocollege Zwijnaarde"],
    ".donboscosdw.be": ["Don Bosco Sint-Denijs-Westrem"],
    ".donboscoverviers.be": [
        "Institut Donbosco Verviers : Rue des Alliés 70, 4800 Verviers",
        "http://www.donboscoverviers.be/",
        "http://tqinfo.donboscoverviers.be/",
        "email adresse : XXX.XXXX@donboscoverviers.be",
    ],
    ".dvmhum.be": [
        "DvM Humaniora Aalst",
        "Mail domain for students.",
        'Main domain "dvmhumaniora.be"',
    ],
    ".dvmhumaniora.be": ["DvM Humaniora Aalst"],
    ".ecam.be": ["ECAM - Institut Supérieur Industriel"],
    ".efpl.be": ["Enseignement de la Province de Liège", ".group"],
    ".ehb.be": ["Erasmushogeschool Brussel"],
    ".ehsal.be": ["EHSAL - Europese Hogeschool Brussel"],
    ".elmarche.be": ["Institut Saint-Laurent (Marche-en-Famenne)"],
    ".ephec.be": ["Economics and Technics School"],
    ".erce.be": ["Regina Caeli"],
    ".esa-namur.be": ["Ecole Supérieure des Affaires - Namur"],
    ".esmol.be": ["European School of Mol"],
    ".groeipunt.be": ["CVO Groeipunt - Adult Education"],
    ".groept.be": ["Groep T Hogeschool Leuven"],
    ".gtibeveren.be": ["GTI Beveren"],
    ".ha.be": ["Hogeschool Antwerpen"],
    ".hainaut-promsoc.be": ["Haute Ecole Provinciale de Hainaut -promotion sociale"],
    ".he-spaak.be": ["Haute Ecole Paul-Henri Spaak"],
    ".he2b.be": ["Haute École Bruxelles-Brabant"],
    ".student.heaj.be": ["Haute Ecole Albert Jacquard"],
    ".heb.be": ["Haute Ecole de Bruxelles"],
    ".hecfh.be": ["Haute École en Hainaut"],
    ".heh.be": ["Haute École en Hainaut"],
    ".student.hel.be": [
        "Haute école de la ville de Liège",
        "High School of the City of Liège",
    ],
    ".helb-prigogine.be": ["HELB Iliya Prigogine"],
    ".helha.be": ["Haute École Louvain en Hainaut"],
    ".helmo.be": ["Haute Ecole Libre Mosane"],
    ".henallux.be": ["Haute ecole de namur-liege-luxembourg"],
    ".hepl.be": ["Haute Ecole de la Province de Liège"],
    ".hers.be": ["Haute École Robert Schuman"],
    ".hetkasteelpark.be": ["VIBO BuSO Het Kasteelpark"],
    ".hhscholen.be": ["Heilig Hartinstituut"],
    ".hik.be": ["hik - hogeschool der kempen"],
    ".hogent.be": ["University College Ghent"],
    ".howest.be": ["Hogeschool West-Vlaanderen (TU)"],
    ".hzs.be": ["Hogere Zeevaartschool - Maritime Academy"],
    ".etu.iad-arts.be": ["Institut des Arts de Diffusion"],
    ".ichec.be": ["Brussels Management School (ICHEC)"],
    ".icinstitute.be": ["IC Institute"],
    ".iepscf-uccle.be": ["IEPSCF Uccle"],
    ".iepsevere.be": ["IEPS Evere"],
    ".ifosupwavre.be": ["IFOSUP - Institute de Formation Superieure"],
    ".ikorn.be": ["IKORN NINOVE"],
    ".immalle.be": ["Immaculata Instituut Oostmalle"],
    ".indbg.be": ["Institut Notre-Dame de Beauraing"],
    ".intecbrussel.be": ["Intec Brussel (CVO)"],
    ".isagosselies.be": ["Institut Sainte-Anne"],
    ".isb.be": ["International School of Brussels"],
    ".isfce.be": ["Institut Superieur de Formation Continue d'Etterbeek"],
    ".isjlalouviere-ac.be": ["Institut Saint-Joseph"],
    ".isl-edu.be": ["Institut Saint-Laurent"],
    ".portail.itlg.be": ["Institut de Technologie de Liège"],
    ".itscm.be": ["Institut Technique supérieur Cardinal Mercier", "ITSCM"],
    ".ivobrugge.be": ["CVO Instituut voor volwassenenonderwijs Brugge"],
    ".katho.be": ["KATHO University of Applied Sciences"],
    ".kdg.be": ["Karel De Grote Hogeschool"],
    ".khbo.be": ["Catholic College Bruges-Ostend"],
    ".khk.be": ["Katholieke Hogeschool Kempen"],
    ".khleuven.be": ["Katholieke Hogeschool Leuven"],
    ".khlim.be": ["Katholieke Hogeschool Limburg"],
    ".kobos.be": ["KOBOS"],
    ".kogeka.be": ["Kogeka", "Kogeka"],
    ".min.ksleuven.be": ["Miniemeninstituut"],
    ".student.kta1-hasselt.be": ["GO! NEXT KTA1 Hasselt", "KTA1"],
    ".kuleuven.be": ["KU Leuven"],
    ".kvri.be": ["Kardinaal Van Roey-Instituut", "Cardinal Van Roey-Institute"],
    ".leielandscholen.be": ["Scholengroep Leielandscholen VZW"],
    ".luca-arts.be": ["Luca School of Arts"],
    ".lyceefrancais.be": ["IT option at the French Lycée Jean Monnet in Brussels"],
    ".mad-fac.be": [
        " Media, Arts and Design Faculty at University College of Limburg & Provincial University College Limburg"
    ],
    ".maerlantatheneum.be": ["Maerlant Atheneum"],
    ".stud.miniemeninstituut.be": ["Miniemeninstituut"],
    ".miras.be": ["CVO Miras"],
    ".mobyus.be": ["Mobyus"],
    ".montfort.be": ["Montfort College Rotselaar"],
    ".odisee.be": ["University College Odisee"],
    ".olvp.be": ["Scholen Onze-Lieve-Vrouw-Presentatie, Sint-Niklaas"],
    ".openuniversiteit.be": ["Open University Belgium"],
    ".schueler.pds-eupen.be": ["Pater-Damian-Sekundarschule"],
    ".petrusenpaulus.be": ["Petrus en Paulus vzw"],
    ".staff.promsoc-arlon.be": ["Promotion Sociale Arlon"],
    ".student.promsoc-arlon.be": ["Promotion Sociale Arlon"],
    ".provilion.be": ["Provinciaal Instituut Lommel"],
    ".pxl.be": ["Hogeschool PXL"],
    ".qrios.be": ["Qrios"],
    ".reginacaeli.be": ["Regina Caeli"],
    ".ritacollege.be": ["Sint-Ritacollege Kontich"],
    ".student.romerocollege.be": ["Oscar. Romero. College. Belgium."],
    ".s19.be": ["Ecole 19"],
    ".scheppers.be": [
        "Scheppersinstituut Deurne & Antwerpen",
        "Scheppersinstituut Antwerpen",
        "Scheppersinstituut Deurne",
    ],
    ".scheppersinstituut.be": [
        "Scheppersinstituut Deurne & Antwerpen",
        "Scheppersinstituut Antwerpen",
        "Scheppersinstituut Deurne",
    ],
    ".sgvw.be": ["College Veurne"],
    ".sibbo.be": ["SBSO SIBBO"],
    ".sint-michiel.be": ["Scholengroep Sint-Michiel"],
    ".sint-pietersinstituut.be": ["Sint-Pietersinstituut Turnhout"],
    ".sint-rembert.be": ["Sint-Rembert Scholengroep", ".group"],
    ".sintcordula.be": ["Sint-Cordula-instituut Schoten"],
    ".sintlievenscollege.be": [
        "Sint-Lievenscollege Business",
        "Website: slcb.be   ",
        "Location: Gent, Belgium",
        "Course: https://www.slcb.be/aanbod/niveau-5/it-en-netwerken",
        "We have students 17-18-19 years old who learn C#, Javascript, PHP, PowerShell, ... in two years at our school in the courses IT and Networking.",
        "Proof of @sintlievenscollege.be: https://www.slcb.be/contact",
        "Domains: @sintlievenscollege.be and @student.sintlievenscollege.be",
    ],
    ".sji.be": ["Sint-Jozef Instituut"],
    ".sjks.be": ["Sint-Jozef-Klein-Seminarie", "Sint-Jozef-Klein-Seminarie"],
    ".slcb.be": [
        "Sint-Lievenscollege Business",
        "Website: slcb.be   redirects to our old domain vhsj.be, we are creating at the moment a new website under our new name slcb.",
        "Location: Gent, Belgium",
        "Course: http://www.vhsj.be/sint-joris/index.php?p=130",
        "We have students 17-18-19 years old who learn C#, Javascript, PHP, PowerShell, ... in two years at our school in the courses IT and Networking.",
        "Proof of @slcb.be: http://www.vhsj.be/sint-joris/index.php?p=158",
    ],
    ".snt.be": ["SNT CVO Centrum voor Volwassenenonderwijs Brugge"],
    ".st-martinus.be": ["Sint-Martinusscholen Herk-de-Stad"],
    ".stben.be": ["Communauté scolaire Saint-Benoît"],
    ".steinerschoolleuven.be": ["Steinerschool Leuven"],
    ".syntrawest.be": ["SYNTRA West"],
    ".thomasmore.be": ["Thomas More"],
    ".tihf.be": ["Technisch Instituut de Heilige Familie Brugge"],
    ".uams.be": ["Universiteit Antwerpen Management School"],
    ".uantwerpen.be": ["University of Antwerp"],
    ".ucll.be": ["University College Leuven-Limburg"],
    ".uclouvain.be": ["Catholic University of Louvain"],
    ".ugent.be": ["Ghent University"],
    ".uhasselt.be": ["Hasselt University"],
    ".ulb.be": ["Université Libre de Bruxelles", "Free University of Brussels"],
    ".uliege.be": ["Université de Liège"],
    ".unamur.be": ["Université de Namur"],
    ".vinci.be": ["Haute École Léonard de Vinci"],
    ".virgosapiens.be": ["Virgo Sapiens Institute", "Virgo Sapiens Institute"],
    ".vitaetpax.be": ["Vita et Pax-college"],
    ".vives.be": ["Katholieke hogeschool VIVES"],
    ".student.viveshbo5.be": ["VIVES University College"],
    ".vlekho.be": ["Hogeschool voor Wetenschap en Kunst (VLEKHO), Brussel"],
    ".vlerick.be": ["Vlerick Leuven Gent Management School"],
    ".vspw.be": ["PCVO Vormingsleergang voor Sociaal en Pedagogisch Werk Gent"],
    ".vtideinze.be": ["VTI Deinze"],
    ".vub.be": ["Vrije Universiteit Brussel"],
    ".ifosup.wavre.be": ["IFOSUP"],
    ".wenk.be": ["Hogeschool voor Wetenschap &amp; Kunst"],
    ".xios.be": ["XIOS Hogeschool Limburg"],
    ".code.berlin": ["CODE University of Applied Sciences in Berlin"],
    ".gkbs.berlin": [
        "Integrierte Sekundarschule Georg-Klingenberg",
        "Georg-Klingenberg-School",
    ],
    ".edu.letteverein.berlin": ["Lette Verein Berlin"],
    ".ong.berlin": ["Otto-Nagel-Gymnasium"],
    ".esta.bf": ["Ecole Supérieure des Techniques Avancées (ESTA) "],
    ".univ-ouaga.bf": ["Université de Ouagadougou"],
    ".student.51school.bg": [
        '51 СРЕДНО УЧИЛИЩЕ "ЕЛИСАВЕТА БАГРЯНА", София, България',
        '51 High School "Elisaveta Bagryana", Sofia, Bulgaria',
    ],
    ".acad.bg": [
        "Technical University of Varna",
        "University of National and World Economy",
        "University of Rousse",
    ],
    ".au-plovdiv.bg": ["Agricultural University of Plovdiv"],
    ".aubg.bg": ["American University in Bulgaria"],
    ".bfu.bg": ["Bourgas Free University"],
    ".btu.bg": ["Bourgas University Prof. Assen Zlatarov"],
    ".hit.bg": ["Academy of Music, Dance and Fine Arts"],
    ".ibsedu.bg": [
        "Международно Висше Бизнес Училище",
        "International Business School",
    ],
    ".ltu.bg": ["University of Forestry Sofia"],
    ".meduniversity-plovdiv.bg": ["Medical University Plovdiv"],
    ".mg-babatonka.bg": [
        'Математическа гимназия "Баба Тонка"',
        "Baba Tonka High School of Mathematics",
    ],
    ".mgu.bg": ["University of Mining and Geology St. Ivan Rils"],
    ".edu.mon.bg": ["Ministry of Education and Science - Bulgaria"],
    ".mu-plovdiv.bg": ["Medical University Plovdiv", "Medical University Plovdiv"],
    ".mu-sofia.bg": ["Medical University of Sofia"],
    ".mu-varna.bg": ["Medical University Varna"],
    ".natfiz.bg": ["National Academy for Theatre and Film Arts Krustju Sarafov"],
    ".naval-acad.bg": [
        'Висше Военноморско Училище "Никола Йонков Вапцаров"',
        "Nicola Vaptsarov Naval Academy",
    ],
    ".nbu.bg": ["New Bulgarian University"],
    ".nma.bg": ["National Academy of Music Pantcho Vladigerov"],
    ".nsa.bg": ["National Sports Academy Sofia"],
    ".ntbg.bg": ["National Trade and Banking High School"],
    ".pv-ma.bg": ["Military University Shoumen"],
    ".shu.bg": ['Shumen University "Konstantin Preslavsky" (http://shu.bg)'],
    ".smg.bg": [
        'Софийска математическа гимназия "Паисий Хилендарски"',
        'Sofia Mathematics high school "Paisius of Hilendar"',
    ],
    ".softuni.bg": ["Software University", "Sofia", "Bulgaria"],
    ".swu.bg": ["South-West University Neofit Rilski"],
    ".trakia-uni.bg": ["Тракийски университет", "Trakia University"],
    ".tu-plovdiv.bg": [
        "Технически университет София - филиал Пловдив",
        "Technical University of Plovdiv",
    ],
    ".tu-sofia.bg": ["Technical University of Sofia"],
    ".tu-varna.bg": ["Technical University of Varna"],
    ".tugab.bg": ["Technical University of Gabrovo"],
    ".uacg.bg": ["University of Architecture, Civil Engineering and Geodesy"],
    ".ue-varna.bg": ["University of Economics Varna"],
    ".uft-plovdiv.bg": ["University of Food Technology"],
    ".uni-plovdiv.bg": ["University of Plovdiv"],
    ".uni-ruse.bg": ["University of Ruse"],
    ".uni-sofia.bg": ["Sofia University St. Kliment Ohridski"],
    ".uni-svishtov.bg": ["Academy of Economics Dimitur A. Tscenov"],
    ".uni-sz.bg": ["Trakia University Stara Zagora"],
    ".uni-vt.bg": ["Veliko Turnovo University Cyril and Methodius"],
    ".unibit.bg": ["University of Library Studies and Information Technologies"],
    ".unwe.bg": ["University of National and World Economy"],
    ".uwekind.bg": ["International School Uwekind "],
    ".vfu.bg": ["Varna Free University"],
    ".agu.edu.bh": ["Arabian Gulf University"],
    ".amaiu.edu.bh": ["Ama International University"],
    ".asu.edu.bh": ["Applied Science University"],
    ".ku.edu.bh": ["The Kingdom University"],
    ".nyit.edu.bh": ["New York Instiute of Technology"],
    ".ucb.edu.bh": ["University College Bahrain"],
    ".uob.edu.bh": ["University of Bahrain"],
    ".aou.org.bh": ["Arab Open University"],
    ".polytechnic.bh": ["Bahrain Polytechnic"],
    ".ub.edu.bi": ["University of Burundi"],
    ".uac.bj": ["Université d'Abomey-Calavi (UAC)"],
    ".unstim.bj": [
        "Université Nationale des Sciences Technologies Ingénieries et Mathématiques d'Abomey (UNSTIM)",
        "National University of Sciences, Engineering and Mathematics of Abomey",
    ],
    ".bercol.bm": ["Bermuda College"],
    ".ubd.edu.bn": ["University of Brunei Darussalam"],
    ".unissa.edu.bn": ["Universiti Islam Sultan Sharif Ali"],
    ".udivirtual.com.bo": ["Universidad para el Desarrollo y la Innovación"],
    ".emi.edu.bo": ["Escuela Militar de Ingeniería"],
    ".fcpn.edu.bo": [
        "Universidad Mayor de San Andres",
        "University Major of San Andres",
    ],
    ".fhumanidades-uagrm.edu.bo": ["Facultad de Humanidades, Gabriel Rene Moreno"],
    ".incos-santacruz.edu.bo": [
        "Solicitud Incos Santa Cruz",
        "Correo dominio: incos-santacruz.edu.bo",
        "pagina web: https://incos-santacruz.edu.bo/",
    ],
    ".industrialmurillo.edu.bo": ["Escuela Industrial Superior Pedro Domingo Murillo"],
    ".nur.edu.bo": ["Universidad Nur", "Nur University"],
    ".uab.edu.bo": ["Universidad Adventista de Bolivia"],
    ".uabjb.edu.bo": ["Universidad Autónoma del Beni José Ballivián"],
    ".uagrm.edu.bo": ["Universidad Autónoma Gabriel René Moreno"],
    ".uajms.edu.bo": [
        "Universidad Autónoma Juan Misael Saracho",
        "Universidad Juan Misael Saracho",
    ],
    ".uasb.edu.bo": ["Universidad Andina Simón Bolivar"],
    ".uatf.edu.bo": ["Universidad Autónoma Tomás Frías"],
    ".ubilapaz.edu.bo": [
        "Universidad Boliviana de Informatica",
        "Bolivian University of Informatica ",
    ],
    ".ucb.edu.bo": ["Universidad Católica Boliviana, La Paz"],
    ".ucbcba.edu.bo": ["Universidad Católica Boliviana, Cochabamba"],
    ".ucbscz.edu.bo": ["Universidad Católica Boliviana, Santa Cruz"],
    ".ucbtja.edu.bo": ["Universidad Católica Boliviana, Tarija"],
    ".udabol.edu.bo": ["Universidad de Aquino Bolivia"],
    ".udelosandes.edu.bo": ["Universidad Los Andes"],
    ".ulasalle.edu.bo": ["Universidad LaSalle Bolivia", "LaSalle Bolivia University"],
    ".umss.edu.bo": ["Universidad Mayor de San Simón"],
    ".unefco.edu.bo": [
        "Unidad Especializada de Formación Continua - UNEFCO",
        "Unidad Especializada de Formación Continua - UNEFCO",
    ],
    ".unicen.edu.bo": ["Universidad Central"],
    ".unifranz.edu.bo": ["Universidad Privada Franz Tamayo (UNIFRANZ)"],
    ".unslp.edu.bo": ["Universidad Nuestra Senora de La Paz"],
    ".unsxx.edu.bo": ["Universidad Nacional Siglo XX Llallagua"],
    ".upds.edu.bo": ["Universidad Domingo Savio"],
    ".upsa.edu.bo": ["Universidad Privada de Santa Cruz de la Sierra"],
    ".usalesiana.edu.bo": ["Universidad Salesiana de Bolivia"],
    ".usfx.edu.bo": ["Universidad San Francisco Xavier de Chuquisaca"],
    ".uto.edu.bo": ["Universidad Técnica de Oruro"],
    ".upds.net.bo": [
        "Universidad Privada Domingo Savio",
        "Domingo Savio Private University",
    ],
    ".umsa.bo": ["Universidad Mayor de San Andrés"],
    ".upea.bo": ["Universidad publica de El Alto", "Public University of El Alto"],
    ".usfx.bo": [
        "Universidad Mayor Real y Pontificia de San Francisco Xavier de Chuquisaca",
        "San Francisco Xavier University",
    ],
    ".aedb.br": ["Associação Educacional Dom Bosco"],
    ".aiec.br": ["Faculdade AIEC"],
    ".alfa.br": ["Faculdades Alves Faria"],
    ".anhembi.br": ["Universidade Anhembi Morumbi"],
    ".baraodemaua.br": ["Centro Universitário Barao de Maua"],
    ".brazcubas.br": ["Universidade Braz Cubas"],
    ".cairu.br": ["Fundação Visconde de Cairu", "Viscount of Cairu Foundation"],
    ".candidomendes.br": ["Universidade Candido Mendes"],
    ".castelobranco.br": ["Universidade Castelo Branco"],
    ".cbpf.br": ["Centro Brasileiro de Pesquisas Físicas"],
    ".cefet-rj.br": ["Centro Federal de Educação Tecnológica"],
    ".cefetmg.br": ["Centro Federal de Educação Tecnológica de Minas Gerais"],
    ".cesed.br": ["Centro de Ensino Superior e Desenvolvimento"],
    ".cesjf.br": ["Centro de Ensino Superior de Juiz de Fora"],
    ".cesuc.br": ["Centro de Ensino Superior de Catalão"],
    ".cesumar.br": ["Centro Universitário de Maringá"],
    ".aluno.cesupa.br": ["Centro Universitário do Estado do Pará"],
    ".cnec.br": ["Campanha Nacional de Escolas da Comunidade (CNEC)"],
    ".academicougb.com.br": ["Centro Universitário Geraldo Di Biase"],
    ".alfaunipac.com.br": ["AlfaUnipac", "AlfaUnipac"],
    ".alunofg.com.br": ["UNIFG - Centro Universitário dos Guararapes"],
    ".alunofpb.com.br": [
        "Faculdade Internacional da Paraiba",
        "International Faculty of Paraiba",
    ],
    ".alunoimpacta.com.br": ["FIT - Faculdade Impacta de Tecnologia"],
    ".alunosmaristas.com.br": ["Colégio Marista Arquidiocesano"],
    ".alunounyleya.com.br": ["Unyleya"],
    ".bandtec.com.br": ["Faculdade de Tecnologia Bandeirantes - BandTec"],
    ".bilac.com.br": ["Faculdade Bilac"],
    ".ceduphh.com.br": ["Centro de Educação Profissional Hermann Hering"],
    ".ceepcascavel.com.br": [
        "Centro Estadual de Educação Profissional Pedro Boaretto Neto",
        "CEEP - Pedro Boaretto Neto",
    ],
    ".colband.com.br": ["Colégio Bandeirantes"],
    ".colegioflama.com.br": ["Flama", "Flama"],
    ".colegiomercurio.com.br": ["Colégio Mercúrio"],
    ".colegiosantanh.com.br": ["Colégio Santa Catarina"],
    ".cotemig.com.br": ["Faculdade COTEMIG"],
    ".cscs.com.br": ["Colegio Santa Catarina de Sena"],
    ".descomplica.com.br": ["Faculdade Descomplica"],
    ".edumail.com.br": ["Faculdade Pitágoras Ipatinga", "Faculdade Pitágoras Ipatinga"],
    ".einsteinlimeira.com.br": ["Einstein Limeira"],
    ".escolamobile.com.br": ["Escola Móbile", "Móbile School"],
    ".etecdeguaianazes.com.br": ["Etec de Guaianazes"],
    ".facamp.com.br": ["Facamp:  http://www.facamp.com.br", "Facamp"],
    ".edu.faccar.com.br": ["FACCAR - Faculdade Paranaense"],
    ".aluno.facthus.com.br": [
        "Faculdade de Talentos Humanos",
        "FACTHUS - Faculdade de Talentos Humanos",
        "Facthus",
    ],
    ".aluno.faculdadeimpacta.com.br": ["Faculdade Impacta de Tecnologia"],
    ".faculdadeimpacta.com.br": ["IMPACTA TECNOLOGIA ELETRONICA LTDA"],
    ".faculdadeporto.com.br": ["Faculdade Porto"],
    ".faculdadeprominas.com.br": ["Faculdade PROMINAS"],
    ".faculdadesprominas.com.br": ["Faculdade PROMINAS"],
    ".faculdadeunica.com.br": ["Faculdade ÚNICA"],
    ".fadergs.com.br": ["Fadergs"],
    ".fai.com.br": [
        "Centro Universitário de Adamantina - UNIFAI",
        "University Center of Adamantina",
    ],
    ".fainor.com.br": ["Faculdade Independente do Nordeste"],
    ".fals.com.br": ["Faculdade do Litoral Sul Paulista - FALS"],
    ".fametro.com.br": ["Faculdade Metropolitana"],
    ".fap.com.br": ["FAP - Faculdade de Apucarana"],
    ".fasipe.com.br": ["Unifasipe Centro Educacional"],
    ".fecaf.com.br": ["Faculdade Capital Federal", "FECAF"],
    ".feituverava.com.br": ["Fundação Educacional de Ituverava"],
    ".fgp.com.br": ["Faculdade Genare & Peatre"],
    ".fia.com.br": ["FIA - Fundação Instituto de Administração"],
    ".fiap.com.br": ["Faculdade de Informatica e Administração Paulista"],
    ".ftec.com.br": ["Faculdade de Tecnologia TECBrasil"],
    ".grupoprominas.com.br": ["Grupo PROMINAS"],
    ".ienh.com.br": ["Faculdade IENH - Instituição Evangélica de Novo Hamburgo"],
    ".ises.com.br": ["Instituto Sumaré de Ensino Superior"],
    ".kroton.com.br": ["Universidade Pitágoras", "University Pitagoras"],
    ".liberato.com.br": ["Fundação Escola Técnica Liberato Salzano Vieira da Cunha"],
    ".mackenzista.com.br": ["Mackenzie Presbyterian University"],
    ".maisunifacisa.com.br": ["Unifacisa", "Unifacisa"],
    ".melies.com.br": [
        "Faculdade de Tecnologia Melies",
        "Website: https://www.melies.com ",
        "Email: melies.com.br",
    ],
    ".meuibgen.com.br": ["IBGEN Business School"],
    ".prover.com.br": ["Universidade de Itaúna"],
    ".sapiens.com.br": ["Collegium Sapiens"],
    ".sempreunama.com.br": [
        "Universidade da Amazônia",
        "UNAMA - Ser Educational Group",
    ],
    ".sempreung.com.br": ["UNIVERSIDADE GUARULHOS", "GUARULHOS UNIVERSITY"],
    ".sempreuninassau.com.br": ["UniNassau University"],
    ".sempreuninorte.com.br": [
        "Centro Universitário do Norte",
        "UniNorte - Ser Educational Group",
    ],
    ".setrem.com.br": ["Sociedade Educacional Três de Maio"],
    ".souenergia.com.br": ["FEAN - Faculdades Energia"],
    ".soulasalle.com.br": ["Centro Universitário La Salle do Rio de Janeiro"],
    ".sounidesc.com.br": [
        "CENTRO UNIVERSITÁRIO DE DESENVOLVIMENTO DO CENTRO-OESTE",
        "UNIVERSITY CENTER FOR WEST CENTER DEVELOPMENT",
    ],
    ".sounisuam.com.br": ["Universidade Augusto Motta"],
    ".souunigoias.com.br": [
        "UNIGOIÁS - Centro Universitário de Goiás",
        "UNIGOIÁS - University Center of Goiás",
    ],
    ".souunisuam.com.br": ["UNISUAM", "UNISUAM"],
    ".souunit.com.br": ["Universidade Tiradentes"],
    ".studiumensinofundamental.com.br": [
        "Studium Pequeno Príncipe | Educação Infantil, Fundamental I e II"
    ],
    ".technet.com.br": ["Universidade Federal de Roraima"],
    ".estudante.ufscar.com.br": ["universidade federal de são carlos"],
    ".unialfa.com.br": ["UNIALFA"],
    ".uniara.com.br": ["Centro Universitário de Araraquara"],
    ".uniasselvi.com.br": ["Sociedade Educacional Leonardo da Vinci - UNIASSELVI"],
    ".unibrasil.com.br": ["Faculdades Integradas do Brasil - UNIBRASIL"],
    ".unicaipatinga.com.br": ["Faculdade Única"],
    ".uniciv.com.br": ["UNICIV - POS GRADUAÇÂO EAD EM TI."],
    ".al.unieduk.com.br": ["Centro Universitário de Jaguariúna - UniFAJ"],
    ".unieuro.com.br": ["Centro Universitário UNIEURO"],
    ".unifametro.com.br": ["Unifametro"],
    ".unigranet.com.br": ["Universidade da Grande Dourados - UNIGRANET"],
    ".unijorge.com.br": ["UNIJORGE - Centro Universitário Jorge Amado"],
    ".unimes.com.br": ["Universidade Metropolitana de Santos"],
    ".unipacto.com.br": ["Faculdade Presidente Antônio Carlos"],
    ".unipli.com.br": ["Centro Universitário Plinio Leite"],
    ".unisalesiano.com.br": [
        "Centro Universitário Católico Salesiano Auxilium",
        "UniSALESIANO",
    ],
    ".unisantos.com.br": ["Universidade Católica de Santos"],
    ".uniseb.com.br": ["Centro Universitário Estácio UniSEB"],
    ".aluno.unisociesc.com.br": [
        "UniSociesc",
        "Sociedade Educacional de Santa Catarina",
        "Educational Society of Santa Catarina",
    ],
    ".unitau.com.br": ["Universidade de Taubaté"],
    ".univale.com.br": ["Faculdades Integradas do Vale do Ivaí"],
    ".univicosa.com.br": ["Centro Universitário de Viçosa - Univiçosa", "Univiçosa"],
    ".unopar.com.br": ["Universidade Norte do Paraná"],
    ".uscsonline.com.br": ["Universidade Municipal de São Caetano do Sul"],
    ".uvvnet.com.br": ["Universidade Vila Velha"],
    ".viannasempre.com.br": ["Instituto Vianna Júnior"],
    ".creupi.br": ["Centro Regional Universitário de Espiríto Santo do Pinhal"],
    ".ime.eb.br": ["Instituto Militar de Engenharia"],
    ".alunosatc.edu.br": [
        "SATC - Educação e Tecnologia",
        "SATC - Education and Technology",
    ],
    ".anhanguera.edu.br": [
        "UNIGOIÁS - Centro Universitário de Goiás",
        "UNIGOIÁS - University Center of Goiás",
    ],
    ".anhembimorumbi.edu.br": ["Universidade Anhembi Morumbi"],
    ".auden.edu.br": ["Auden Educação", "Auden MFA"],
    ".catolica.edu.br": ["Universidade Catolica de Brasilia"],
    ".catolicasc.edu.br": ["Católica de Santa Catarina"],
    ".ftt.cefsa.edu.br": ["Faculdade de Tecnologia Termomecânica"],
    ".celsolisboa.edu.br": ["Centro Universitário Celso Lisboa"],
    ".academico.cesmac.edu.br": [
        "Centro Universitário CESMAC",
        "CESMAC University Center",
    ],
    ".cesumar.edu.br": ["Centro Universitário Cesumar"],
    ".ceub.edu.br": ["Centro Universitário de Brasília"],
    ".claretiano.edu.br": ["Centro Universitário Claretiano"],
    ".cruzeirodosul.edu.br": ["Universidade Cruzeiro do Sul"],
    ".doctum.edu.br": ["Doctum"],
    ".einstein.edu.br": ["Instituto Israelita de Ensino e Pesquisa Albert Einstein"],
    ".academico.emge.edu.br": [
        "Escola de Engenharia de Minas Gerais - EMGE",
        " Engineering School of Minas Gerais",
    ],
    ".emge.edu.br": ["Escola de Engenharia de Minas Gerais"],
    ".eniac.edu.br": ["Centro Universitário de Excelência Eniac - ENIAC"],
    ".esuda.edu.br": ["Faculdade de Ciências Humanas ESUDA"],
    ".bsi.facet.edu.br": [
        "Facet - Faculdade de Ciencias e Tecnologia do Paraná",
        "Science and Technology College of Paraná",
    ],
    ".facimp.edu.br": ["Faculdade Facimp ", "Facimp School"],
    ".faculdadecesusc.edu.br": ["Faculdade CESUSC"],
    ".faculdadefacec.edu.br": [
        "Faculdade de Administração e Ciências Econômicas, Facec"
    ],
    ".faculdadefamart.edu.br": ["Faculdade Famart"],
    ".faculdadefia.edu.br": [
        "Fundação Instituto de Administração",
        "Administration Institute Foundation",
    ],
    ".faculdadescearenses.edu.br": ["Faculdade Cearense", "Cearense Faculty"],
    ".fadam.edu.br": ["Faculdade das Américas - FADAM"],
    ".fadergs.edu.br": ["FADERGS"],
    ".fael.edu.br": ["FAEL – Faculdade Educacional da Lapa"],
    ".faeterj-rio.edu.br": [
        "Resultados da pesquisa Resultados da Web  Faeterj-Rio - Faculdade de Educação Tecnológica do Estado do Rio de Janeiro"
    ],
    ".faex.edu.br": ["Faculdade de Ciências Sociais Aplicadas de extrema", "FAEX"],
    ".minha.fag.edu.br": ["Centro Universitário da Fundação Assis Gurgacz"],
    ".fagammon.edu.br": ["Fagammon", "Faculdade Presbiteriana Gammon"],
    ".fam.edu.br": ["FAM - Faculdade de Americana"],
    ".aluno.famper.edu.br": ["Famper Faculdade de Ampére "],
    ".acad.fanese.edu.br": [
        "Faculdade de Administração e Negócios de Sergipe",
        " Sergipe School of Business and Administration",
    ],
    ".faosc.edu.br": ["FACULDADE DO OESTE DE SANTA CATARIA – FAOSC"],
    ".fapce.edu.br": [
        "Centro Universitário Paraíso, Brasil",
        "Faculdade Paraíso do Ceará, Brasil",
        "FAPCE",
    ],
    ".fapi-pi.edu.br": ["FAPI - Centro Universitario do Piaui"],
    ".fasec.edu.br": ["Faculdade Serra do Carmo", "Serra do Carmo College"],
    ".fat-al.edu.br": [
        "Centro Universitário Mário Pontes Jucá",
        "Faculdade de Tecnologia de Alagoas",
    ],
    ".fatecie.edu.br": ["UniFatecie Centro Universitário"],
    ".fatecourinhos.edu.br": ["Faculdade de Tecnologia de Ourinhos"],
    ".fatecrl.edu.br": [
        "Fatec Rubens Lara",
        "Fatec Baixada Santista - Rubens Lara",
        "Fatec Rubens Lara - Baixada Santista (SP)",
        ".group",
    ],
    ".fcarp.edu.br": ["Faculdade Católica Rainha da Paz"],
    ".fdvmg.edu.br": ["Faculdade de Viçosa - FDV"],
    ".fei.edu.br": ["Centro Universitário FEI", "University Center FEI"],
    ".feitep.edu.br": ["Faculdade de Engenharia e Inovação Técnico Profissional"],
    ".fema.edu.br": ["FEMA - Fundação Educacional do Município de Assis"],
    ".fgp.edu.br": ["Faculdade Gennari & Peartree"],
    ".fgv.edu.br": ["Fundação Getúlio Vargas", "Getulio Vargas Foundation", "FGV"],
    ".alunos.fho.edu.br": ["Fundação Hermínio Ometto"],
    ".fho.edu.br": ["Centro Universitário da Fundação Hermínio Ometto"],
    ".a.ficr.edu.br": ["Faculdade Imaculada Conceição do Recife"],
    ".fieb.edu.br": ["Fundação Instituto de Educação de Barueri"],
    ".fiec.edu.br": [
        "Fundação Indaiatubana de Educação e Cultura",
        "Culture and Education Indaiatuban Fundation",
    ],
    ".si.fiponline.edu.br": ["Unifip", "Unifip"],
    ".flf.edu.br": ["Faculdade Lourenço Filho"],
    ".fmu.edu.br": ["Centro Universitário FMU", "FMU University Center"],
    ".fortec.edu.br": [
        "Escola e Faculdade Fortec",
        "Fortec School and College",
        "FATEF - Faculdade de Tecnologia de São Vicente",
        "FATEF - Faculty of Technology of São Vicente",
        ".group",
    ],
    ".fpp.edu.br": ["Faculdades Pequeno Príncipe"],
    ".ftc.edu.br": ["Faculdade de Tecnologia e Ciência"],
    ".fumec.edu.br": ["Universidade FUMEC", "FUMEC University"],
    ".funecsantafe.edu.br": [
        "Centro Universitário de Santa Fé do Sul",
        "University Centre of Santa Fe do Sul",
        "UNIFUNEC",
    ],
    ".iesb.edu.br": ["IESB - Centro Universitário", "IESB University Center"],
    ".iesp.edu.br": ["Centro Universitário UNIESP", "University Center UNIESP"],
    ".ifal.edu.br": ["Instituto Federal de Alagoas", "Federal Institute of Alagoas"],
    ".ifam.edu.br": ["Instituto Federal de Educação, Ciência e Tecnologia do Amazonas"],
    ".ifap.edu.br": ["Instituto Federal de Educação, Ciência e Tecnologia do Amapá"],
    ".ifb.edu.br": ["Instituto Federal de Educação, Ciência e Tecnologia de Brasília"],
    ".ifba.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia da Bahia",
        "Federal Institute of Education, Science and Technology of Bahia",
    ],
    ".ifbaiano.edu.br": ["Instituto Federal de Educação, Ciência e Tecnologia Baiano"],
    ".ifc.edu.br": ["Instituto Federal Catarinense"],
    ".aluno.ifce.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Ceará"
    ],
    ".lds.ifce.edu.br": [
        "Laboratório de Desenvolvimento de Software - Instituto Federal de Educação, Ciência e Tecnologia do Ceará"
    ],
    ".ifce.edu.br": ["Instituto Federal do Ceará"],
    ".ifes.edu.br": ["Instituto Federal do Espírito Santo"],
    ".iff.edu.br": ["Instituto Federal de Educação, Ciência e Tecnologia Fluminense"],
    ".aluno.iffar.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia Farroupilha"
    ],
    ".iffarroupilha.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia Farroupilha - IF Farroupilha"
    ],
    ".ifg.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia de Goiás",
        "Instituto Federal de Goiás",
        "IFG",
    ],
    ".estudante.ifgoiano.edu.br": ["Instituto Federal Goiano"],
    ".ifgoiano.edu.br": ["Instituto Federal Goiano"],
    ".acad.ifma.edu.br": [
        "Instituto Federal de Educação Ciência e Tecnologia do Maranhão"
    ],
    ".ifma.edu.br": ["Instituto Federal do Maranhão", "Federal Institute of Maranhão"],
    ".ifmg.edu.br": ["Instituto Federal de Minas Gerais"],
    ".ifms.edu.br": ["Federal Institute of Mato Grosso do Sul (IFMS)"],
    ".ifmt.edu.br": ["Instituto Federal de Mato Grosso"],
    ".ifnmg.edu.br": ["Instituto Federal do Norte de Minas Gerais"],
    ".ifpa.edu.br": ["Instituto Federal do Pará"],
    ".ifpb.edu.br": ["Instituto Federal de Educação, Ciência e Tecnologia da Paraíba"],
    ".ifpe.edu.br": ["Instituto Federal de Pernambuco"],
    ".ifpi.edu.br": ["Instituto Federal do Piauí"],
    ".ifpr.edu.br": ["Instituto Federal de Instituto Federal do Paraná"],
    ".ifrj.edu.br": [
        "Instituto Federal do Rio de Janeiro",
        "Federal institute of Rio de Janerio",
    ],
    ".ifrn.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Rio Grande do Norte"
    ],
    ".aluno.ifro.edu.br": [" Instituto Federal de Rondônia - Campus Vilhena"],
    ".ifro.edu.br": ["Instituto Federal de Educação, Ciência e Tecnologia de Rondônia"],
    ".ifrr.edu.br": ["Instituto Federal de Roraima", "Federal Institute of Roraima"],
    ".aluno.canoas.ifrs.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Rio Grande do Sul - Campus Canoas",
        "Federal Institute of Rio Grande do Sul Canoas Campus",
    ],
    ".canoas.ifrs.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Rio Grande do Sul - Campus Canoas",
        "Federal Institute of Rio Grande do Sul Canoas Campus",
    ],
    ".farroupilha.ifrs.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Rio Grande do Sul - Campus Farroupilha"
    ],
    ".aluno.feliz.ifrs.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Rio Grande do Sul - Campus Feliz"
    ],
    ".feliz.ifrs.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Rio Grande do Sul - Campus de Feliz"
    ],
    ".ibiruba.ifrs.edu.br": [
        "Instituto Federal do Rio Grande do Sul - Campus Ibiruba",
        "Federal Institute of Rio Grande do Sul - Campus Ibiruba",
    ],
    ".restinga.ifrs.edu.br": [
        "Instituto Federal do Rio Grande do Sul Campus Restinga",
        "Federal Institute of Rio Grande do Sul Restinga Campus",
    ],
    ".riogrande.ifrs.edu.br": [
        "Instituto Federal do Rio Grande do Sul - Campus Rio Grande"
    ],
    ".vacaria.ifrs.edu.br": [
        "Instituto Federal do Rio Grande do Sul - Campus Vacaria",
        "Federal Institute of Rio Grande do Sul - Campus Vacaria",
    ],
    ".ifs.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia de Sergipe",
        "Federal Institute of Education, Science and Technology of Sergipe",
    ],
    ".ifsc.edu.br": ["Federal Institute of Santa Catarina"],
    ".aluno.ifsertao-pe.edu.br": ["IF Sertão-PE Campus Petrolina"],
    ".ifsertao-pe.edu.br": ["Instituto Federal do Sertão Pernambucano"],
    ".ifsp.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia de São Paulo"
    ],
    ".ifsudestemg.edu.br": ["Instituto Federal Sudeste de Minas Gerais"],
    ".ifsul.edu.br": ["Instituto Federal Sul-Rio-Grandense "],
    ".ifsuldeminas.edu.br": ["Instituto Federal do Sul de Minas Gerais"],
    ".iftm.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Triângulo Mineiro"
    ],
    ".ifto.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Tocantins",
        "Federal Institute of Tocantins",
    ],
    ".imed.edu.br": ["Faculdade Meridional - IMED"],
    ".imepac.edu.br": [
        "Centro Universitário Imepac Araguari",
        "Imepac Araguari University Center",
    ],
    ".infnet.edu.br": ["Instituto Infnet"],
    ".insper.edu.br": ["Insper", "Institute of Education and Research"],
    ".insted.edu.br": ["Insted"],
    ".iscon.edu.br": ["Faculdade ISCON"],
    ".iscp.edu.br": ["Instituto Superior de Ciências Policiais - PMDF"],
    ".libertas.edu.br": [
        "Libertas Faculdades Integradas",
        "Libertas Integrated Faculties",
    ],
    ".logatti.edu.br": ["Faculdades Logatti Araraquara"],
    ".ls.edu.br": ["Faculdade LS"],
    ".materdei.edu.br": ["Faculdade Mater Dei"],
    ".meta.edu.br": ["Grupo Meta"],
    ".aluno.multivix.edu.br": ["Faculdade Multivix"],
    ".opet.edu.br": ["Centro Universitário OPET", "OPET University Center"],
    ".piodecimo.edu.br": ["Piodecimo Group"],
    ".pitagoras.edu.br": ["Faculdade Pitágoras", "Pitagoras College"],
    ".aluno.positivo.edu.br": ["Universidade Positivo"],
    ".projecao.edu.br": [
        "Centro Universitario e Faculdade Projeção",
        " University Center and College Projection",
    ],
    ".puccampinas.edu.br": [
        "Pontifícia Universidade Católica de Campinas",
        "Pontifical Catholic University of Campinas",
        "PUC Campinas",
        "PCU Campinas",
        "PUCC",
    ],
    ".pucgo.edu.br": ["Pontifícia Universidade Católica de Goiás"],
    ".pucgoias.edu.br": [
        "Pontifícia Universidade Católica de Goias",
        "Pontifical Catholic University of Goiás",
    ],
    ".pucpr.edu.br": [
        "Pontifícia Universidade Católica do Paraná",
        "Pontifical Catholic University of Paraná",
    ],
    ".pucsp.edu.br": ["Pontifícia Universidade Católica"],
    ".redentor.edu.br": ["Centro Universitário Redentor", "Redentor University Center"],
    ".senacsp.edu.br": ["Centro Universitario Senac"],
    ".senaimt.edu.br": ["FATEC SENAI MT", "FATEC SENAI MT"],
    ".senaisp.edu.br": [
        "Escola e Faculdade de Tecnologia Senai Anchieta",
        "Senai Anchieta School and College of Technology",
        "Faculdade Senai de Tecnologia",
        ".group",
    ],
    ".sumare.edu.br": ["Faculdade Sumaré "],
    ".toledoprudente.edu.br": ["Toledo Prudente Centro Universitário"],
    ".ubec.edu.br": ["União Brasileira de Educação Católica"],
    ".uca.edu.br": ["Faculdade Católica Paulista"],
    ".uceff.edu.br": ["UCEFF- UNIDADE CENTRAL DE EDUCAÇÃO FAI FACULDADES LTDA"],
    ".ucpel.edu.br": [
        "Universidade Católica de Pelotas",
        "Catholic University of Pelotas",
    ],
    ".ucsal.edu.br": [
        "Universidade Católica de Salvador",
        "Salvador Catholic University",
    ],
    ".udc.edu.br": ["Centro Universitário Dinâmica Cataratas"],
    ".udf.edu.br": ["Centro de Ensino Unificado do Distrito Federal"],
    ".uea.edu.br": ["Universidade do Estado do Amazonas", "Amazonas State University"],
    ".uepb.edu.br": ["Universidade Estadual da Paraíba"],
    ".uergs.edu.br": ["Universidade Estadual do Rio Grande do Sul"],
    ".uerr.edu.br": ["Universidade Estadual de Roraima"],
    ".uesb.edu.br": [
        "Universidade Estadual do Sudoeste da Bahia",
        "State University of Southwest Bahia",
    ],
    ".uezo.edu.br": ["Fundação Centro Universitário da Zona Oeste do Rio de Janeiro"],
    ".ufabc.edu.br": ["Universidade Federal do ABC"],
    ".ufam.edu.br": ["UNIVERSIDADE FEDERAL DO AMAZONAS"],
    ".ufape.edu.br": ["Universidade Federal do Agreste de Pernambuco"],
    ".ufca.edu.br": ["Universidade Federal do Cariri"],
    ".discente.ufcat.edu.br": ["Universidade Federal de Catalão"],
    ".ufcg.edu.br": ["Universidade Federal de Campina Grande"],
    ".ufcspa.edu.br": ["Universidade Federal de Ciências da Saúde de Porto Alegre"],
    ".ufersa.edu.br": [
        "Universidade Federal Rural do Semi-Árido",
        "Federal Rural University of the Semi-Arid",
    ],
    ".uffs.edu.br": [
        "Universidade Federal da Fronteira Sul",
        "Federal University of Fronteira Sul",
    ],
    ".ufgd.edu.br": ["Universidade Federal da Grande Dourados"],
    ".ufjf.edu.br": [
        "Universidade Federal de Juiz de Fora",
        "Federal University of Juiz de Fora",
    ],
    ".ufn.edu.br": ["Universidade Franciscana", "Franciscan University"],
    ".ufop.edu.br": [
        "Universidade Federal de Ouro Preto",
        "Federal University of Ouro Preto",
    ],
    ".discente.ufopa.edu.br": ["Universidade Federal do Oeste do Pará"],
    ".ufopa.edu.br": [
        "Universidade Federal do Oeste do Pará (UFOPA)",
        "Federal University of Western Pará",
    ],
    ".ufpel.edu.br": ["Universidade Federal de Pelotas"],
    ".ufpi.edu.br": ["Universidade Federal do Piauí", "Federal University of Piaui"],
    ".ufr.edu.br": [
        "Universidade Federal de Rondonópolis",
        "Federal University of Rondonópolis",
    ],
    ".aluno.ufrb.edu.br": [
        "Universidade Federal do Recôncavo da Bahia",
        "Federal University of Recôncavo da Bahia",
    ],
    ".ufrn.edu.br": ["Universidade Federal do Rio Grande do Norte"],
    ".ufsb.edu.br": [
        "Universidade Federal do Sul da Bahia",
        "Federal University of Southern Bahia",
    ],
    ".aluno.ufsj.edu.br": ["Universidade Federal de São João del-Rei"],
    ".ufsj.edu.br": [
        "Universidade Federal de São João del-Rei",
        "Federal University of São João del-Rei",
    ],
    ".uft.edu.br": [
        "Universidade Federal do Tocantins",
        "Federal University of Tocantins",
    ],
    ".uftm.edu.br": [
        "Universidade Federal do Triângulo Mineiro",
        "Federal University of Triângulo Mineiro",
    ],
    ".ufvjm.edu.br": ["Universidade Federal dos Vales do Jequitinhonha e Mucuri"],
    ".ulbra.edu.br": ["Universidade Luterana do Brasil"],
    ".sou.unaerp.edu.br": [
        "UNAERP - Universidade de Ribeirão Preto",
        "UNAERP - University of Ribeirão Preto",
    ],
    ".unasp.edu.br": ["UNASP", "UNASP"],
    ".undb.edu.br": ["UNDB"],
    ".uni7.edu.br": [
        "Centro Universitário 7 de Setembro",
        "University Center September 7",
    ],
    ".uni9.edu.br": ["Universidade Nove de Julho"],
    ".uniabeu.edu.br": [
        "uniabeu",
        "https://www.uniabeu.edu.br",
        "https://www.uniabeu.edu.br/cursos/analise-de-sistemas",
    ],
    ".uniacademia.edu.br": ["UniAcademia Centro Universitário"],
    ".uniaeso.edu.br": ["UNIAESO", "Centro Universitário AESO-Barros Melo"],
    ".uniara.edu.br": ["Uniara - Universidade de Araraquara"],
    ".uniasselvi.edu.br": ["Sociedade Educacional Leonardo da Vinci - UNIASSELVI"],
    ".aluno.uniateneu.edu.br": [
        "Centro Universitário UniAteneu",
        "UniAteneu University Center",
    ],
    ".uniavan.edu.br": ["Centro Universitário Avantis", "Avantis University"],
    ".unibagozzi.edu.br": ["\ufeffCentro Universitário UniBagozzi"],
    ".aluno.unicarioca.edu.br": ["CENTRO UNIVERSITÁRIO CARIOCA", "UNICARIOCA"],
    ".unicesumar.edu.br": ["Centro de Ensino Superior de Maringá"],
    ".unichristus.edu.br": ["Centro Universitário Christus - Unichristus"],
    ".unicid.edu.br": ["Universidade Cidade de São Paulo"],
    ".unidavi.edu.br": ["Unidavi"],
    ".unidesc.edu.br": ["Centro Universitário de Desenvolvimento do Centro-Oeste"],
    ".unidombosco.edu.br": [
        "Centro Universitário Dom Bosco",
        "Dom Bosco University Center",
    ],
    ".unievangelica.edu.br": [
        "Centro Universitário de Anápolis - UniEVANGÉLICA",
        "University Center of Anápolis - UniEVANGÉLICA",
    ],
    ".unifacef.edu.br": ["Uni-FACEF Centro Universitário Municipal de Franca"],
    ".sempre.unifacig.edu.br": ["Centro Universitário UNIFACIG"],
    ".unifacisa.edu.br": ["Faculdade de Ciências Sociais Aplicadas"],
    ".unifacs.edu.br": ["UNIFACS"],
    ".unifacvest.edu.br": ["centro universitário unifacvest"],
    ".aluno.unifafibe.edu.br": ["UNIFAFIBE UNIVERSITY CENTER"],
    ".unifagoc.edu.br": [
        "Centro Universitário Governador Ozanan Coelho - UniFagoc",
        "Governor Ozanam Coelho University Center - UniFagoc",
    ],
    ".bcc.unifal-mg.edu.br": ["Universidade Federal de Alfenas"],
    ".sou.unifal-mg.edu.br": ["Universidade Federal de Alfenas"],
    ".aluno.unifametro.edu.br": ["Unifametro"],
    ".alunos.unifavip.edu.br": ["UniFavip Wyden", "UniFavip Wyden"],
    ".alunos.unifbv.edu.br": ["Unifbv", "Wyden"],
    ".unifcv.edu.br": ["Centro Universitário Cidade Verde"],
    ".unifebe.edu.br": ["Centro Universitário de Brusque - UNIFEBE"],
    ".unifei.edu.br": ["Universidade Federal de Itajubá"],
    ".unifemm.edu.br": ["UNIFEMM - Centro Universitário de Sete Lagoas"],
    ".sou.unifeob.edu.br": [
        " UNIFEOB - Centro Universitário Fundação de Ensino Octávio Bastos"
    ],
    ".unifesspa.edu.br": ["Universidade Federal do Sul e Sudeste do Pará"],
    ".unifev.edu.br": ["Unifev - Centro Universitário de Votuporanga"],
    ".unifio.edu.br": ["Centro Universitário das Faculdades Integradas de Ourinhos"],
    ".unifoa.edu.br": ["Centro Universitário de Volta Redonda - UniFOA"],
    ".unifran.edu.br": ["Universidade de Franca"],
    ".unigran.edu.br": ["Centro Universitário da Grande Dourados"],
    ".unigranrio.edu.br": ["Universidade Unigranrio"],
    ".aluno.unijuazeiro.edu.br": [
        "CENTRO UNIVERSITÁRIO DE JUAZEIRO DO NORTE",
        "UNIJUAZEIRO",
    ],
    ".sou.unijui.edu.br": [
        "Universidade Regional do Noroeste do Estado do Rio Grande do Sul"
    ],
    ".unila.edu.br": [
        "Universidade Federal da Integração Latino-Americana",
        "Federal University for Latin American",
    ],
    ".unilasalle.edu.br": ["Universidade La Salle"],
    ".a.unileste.edu.br": ["Centro Universitário Católica do Leste de Minas Gerais"],
    ".aluno.unilins.edu.br": ["UNILINS"],
    ".aluno.unimeta.edu.br": ["Unimeta"],
    ".unimetrocamp.edu.br": ["Centro Universitário UniMetrocamp"],
    ".unina.edu.br": ["Unina", "Unina"],
    ".aluno.unincor.edu.br": ["UNIVERSIDADE VALE DO RIO VERDE - UNINCOR"],
    ".uninorteac.edu.br": ["Centro Universitário Uninorte"],
    ".uninove.edu.br": ["Universidade Nove de Julho"],
    ".uninta.edu.br": [
        "Centro Universitário Inta - Uninta",
        "Inta University Center - Uninta",
    ],
    ".unipam.edu.br": [
        "Centro Universitário de Patos de Minas",
        "University Center of Patos de Minas",
    ],
    ".unipampa.edu.br": [
        "Fundação Universidade Federal do Pampa",
        "Federal University of Pampa Foundation",
    ],
    ".unipinterativa.edu.br": ["Universidade Paulista"],
    ".uniplaclages.edu.br": [
        "Universidade do Planalto Catarinense",
        "University of Planalto Catarinense",
    ],
    ".aluno.unirb.edu.br": ["Centro Universitário UNIRB"],
    ".unirg.edu.br": ["Universidade Regional de Gurupi"],
    ".unirios.edu.br": [
        "Centro Universitário do Rio São Francisco",
        "University Center of São Francisco's River (UNIRIOS)",
    ],
    ".uniritter.edu.br": ["Uniritter University"],
    ".unirn.edu.br": ["Centro Universitário do Rio Grande do Norte"],
    ".alunos.uniruy.edu.br": [
        "Centro Universitário Ruy Barbosa",
        "University Center Ruy Barbosa",
    ],
    ".unirv.edu.br": [
        "Register of Universidade de Rio Verde",
        "http://www.unirv.edu.br/",
        "http://www.unirv.edu.br/graduacao_curso.php?id=42",
    ],
    ".alunos.unis.edu.br": ["CENTRO UNIVERSITÁRIO DO SUL DE MINAS - UNIS"],
    ".unis.edu.br": ["CENTRO UNIVERSITÁRIO DO SUL DE MINAS - UNIS"],
    ".alunos.unisagrado.edu.br": ["Unisagrado"],
    ".unisecal.edu.br": ["SOCIEDADE EDUCATIVA E CULTURAL AMELIA S/C LTDA"],
    ".unisepe.edu.br": ["Unisepe Educacional", "Unisepe Educational University"],
    ".unisuam.edu.br": [
        "Centro Universitário Augusto Motta",
        "Augusto Motta University Center",
    ],
    ".unitri.edu.br": ["Unitri - Centro Universitário do Triângulo"],
    ".uniuv.edu.br": ["UNIUV - Centro Universitário da Cidade de União da Vitória"],
    ".univag.edu.br": ["Univag Centro Universitário"],
    ".univas.edu.br": ["\ufeffUniversidade do Vale do Sapucaí"],
    ".univasf.edu.br": ["Universidade Federal do Vale do São Francisco"],
    ".univem.edu.br": ["Centro Universitário Eurípides de Marília"],
    ".universidadedevassouras.edu.br": ["Universidade de Vassouras"],
    ".bh.universo.edu.br": [
        "Universidade Salgado de Oliveira",
        "University Salgado de Oliveira",
    ],
    ".univille.edu.br": ["Universidade da Região de Joinville - UNIVILLE(c)"],
    ".univisa.edu.br": ["CENTRO UNIVERSITÁRIO DA VITÓRIA DE SANTO ANTÃO - UNIVISA"],
    ".unochapeco.edu.br": [
        "Universidade Comunitária da Região de Chapecó - Unochapecó",
        "Community University of Chapecó Region - Unochapecó",
    ],
    ".unoesc.edu.br": ["Universidade do Oeste de Santa Catarina"],
    ".unp.edu.br": ["Universidade Potiguar"],
    ".aluno.up.edu.br": ["Universidade Positivo", "Positivo University"],
    ".urcamp.edu.br": ["Centro Universitário da Região da Campanha - URCAMP"],
    ".aluno.uricer.edu.br": [
        "Universidade Regional Integrada do Alto Uruguai e das Missões",
        "URI ERECHIM",
    ],
    ".uscs.edu.br": ["Universidade Municipal de São Caetano do Sul"],
    ".mail.usf.edu.br": ["Universidade São Francisco"],
    ".utfpr.edu.br": ["Universidade Tecnológica Federal do Paraná"],
    ".utp.edu.br": ["Universidade Tuiuti do Paraná"],
    ".veigadealmeida.edu.br": ["Universidade Veiga de Almeida"],
    ".vianna.edu.br": ["Instituto Vianna Júnior", "Vianna Júnior Institute"],
    ".eep.br": ["Escola de Engenharia de Piracicaba"],
    ".emescam.br": [
        "EMESCAM - Escola Superior de Ciências da Santa Casa de Misericórdia de Vitória"
    ],
    ".epm.br": ["Universidade Federal de São Paulo"],
    ".esamc.br": ["Escola Superior de Administração, Marketing e Comunicação"],
    ".acad.espm.br": ["Escola Superior de Propaganda e Marketing"],
    ".espm.br": ["Escola Superior de Propaganda e Marketing"],
    ".alunos.estacio.br": ["Faculdade Estácio de Sá"],
    ".estacio.br": ["Universidade Estácio de Sá"],
    ".faap.br": ["FAAP - Fundação Armando Alvares Penteado"],
    ".facape.br": ["Faculdade de Ciências Aplicadas e Sociais de Petrolina"],
    ".faccat.br": ["Faculdades Integradas de Taquara"],
    ".facens.br": ["Engineering College of Sorocaba"],
    ".facol.br": ["Facol Faculdade Orígenes Lessa - Lençóis Paulista / São Paulo"],
    ".aluno.faculdadecotemig.br": ["Faculdade COTEMIG"],
    ".faculdadescuritiba.br": ["Faculdades Integradas Curitiba"],
    ".sou.fae.br": [
        "UNIFAE - Centro Universitário das Faculdades Associadas de Ensino - FAE"
    ],
    ".faesa.br": ["FAESA Centro Universitário"],
    ".fagoc.br": ["Faculdade Governador Ozanam Coelho"],
    ".fai-mg.br": ["\ufeffCentro de Ensino Superior em Gestão, Tecnologia e Educação"],
    ".faj.br": ["Universidade de Jaguaríuna"],
    ".falec.br": ["Faculdade Doutor Leocádio José Correia"],
    ".famerp.br": ["Faculdade de Medicina de São José do Rio Preto"],
    ".fasp.br": ["FASP - Faculdades Associadas de Sao Paulo"],
    ".faspmail.br": ["FASP - Faculdades Associadas de Sao Paulo"],
    ".edu.fecap.br": ["Fundação Escola de Comércio Álvares Penteado (FECAP)", "FECAP"],
    ".fecap.br": ["Fundação Escola de Comércio Álvares Penteado (FECAP)", "FECAP"],
    ".feevale.br": ["Universidade Feevale"],
    ".fgv.br": ["Getulio Vargas Foundation"],
    ".fmu.br": ["Centro Universitário FMU", "FMU University Center"],
    ".fsa.br": ["Centro Universitário Fundação Santo André"],
    ".fsg.br": ["Faculdade da Serra Gaúcha"],
    ".fua.br": ["Universidade do Amazonas"],
    ".fucapi.br": ["Faculdade FUCAPI"],
    ".fumec.br": ["Universidade FUMEC", "FUMEC University"],
    ".funcesi.br": ["Fundacao Comunitaria de Ensino Superior de Itabira"],
    ".inf.furb.br": [
        "Fundação Universidade Regional de Blumenau - http://www.furb.br",
        "DSC - Departamento de Sistemas e Computação - http://dsc.inf.furb.br/",
        "Domain: user@inf.furb.br",
    ],
    ".furb.br": ["Fundação Universidade Regional de Blumenau"],
    ".furg.br": ["Universidade do Rio Grande"],
    ".aluno.enova.educacao.ba.gov.br": [
        "e-Nova Educacao Project by the Government of the State of Bahia, Brazil"
    ],
    ".escola.ce.gov.br": ["EEEP Professora Luíza De Teodoro Vieira"],
    ".tc.df.gov.br": ["Escola de Contas do Tribunal de Contas do Distrito Federal"],
    ".enap.gov.br": ["Escola Nacional de Administração Pública"],
    ".escola.pr.gov.br": ["Pedro Macedo High School", "Colégio Estadual Pedro Macedo"],
    ".aluno.educa.rj.gov.br": ["Colégio Estadual Paulino Barbosa"],
    ".aluno.faeterj-prc.faetec.rj.gov.br": [
        "Faculdade de Educação Tecnológica do Estado do Rio de Janeiro (FAETERJ-Paracambi)"
    ],
    ".educar.rs.gov.br": [
        "Escola Técnica Estadual Monteiro Lobato",
        "Monteiro Lobato State Technical School",
    ],
    ".estudante.sed.sc.gov.br": [
        "Governo de Santa Catarina | Secretaria de Estado da Educação - Novos Caminhos EAD"
    ],
    ".alunosjc.sp.gov.br": ["EMEF. ILDETE M. BARBOSA"],
    ".cpspos.sp.gov.br": [
        "Unidade de Pós Graduação, Extensão e Pesquisa do Centro Paula Souza"
    ],
    ".etec.sp.gov.br": [
        "Escolas Técnicas Estaduais de São Paulo - Centro Estadual de Educação Tecnológica Paula Souza"
    ],
    ".fatec.sp.gov.br": ["Faculdade de Tecnologia de Sorocaba"],
    ".edu.santoandre.sp.gov.br": [
        "Escola Municipal Professora Esther Moura Barreto",
        "County School Professor Esther Moura Barreto",
    ],
    ".grupointegrado.br": ["Faculdade Integrado de Campo Mourão"],
    ".ielusc.br": ["Associação Educacional Luterana Bom Jesus - IELUSC"],
    ".iesb.br": [
        "Instituto de Educação Superior de Brasília",
        "Superior Education Institute of Brasília",
    ],
    ".impa.br": ["Instituto Nacional de Matemática Pura e Aplicada - IMPA"],
    ".inatel.br": ["Instituto Nacional de Telecomunicações"],
    ".ulbra.inf.br": [
        "Universidade Luterana do Brasil - Computação",
        "Lutheran University of Brazil - Computing",
    ],
    ".inpe.br": [
        "Instituto Nacional de Pesquisas Espaciais",
        "National Institute for Space Research",
    ],
    ".ita.br": ["Instituto Tecnológico de Aeronáutica"],
    ".italo.br": ["Faculdade Italo Brasileira"],
    ".itpac.br": ["ITPAC"],
    ".lncc.br": ["Laboratório Nacional de Computação Científica"],
    ".mackenzie.br": ["Universidade Mackenzie"],
    ".maua.br": ["Instituto Maua de Tecnologia"],
    ".metodista.br": ["Universidade Metodista de Sao Paulo"],
    ".newtonpaiva.br": ["Centro Universitário Newton Paiva"],
    ".on.br": ["Observatório Nacional", "National Observatory of Brazil"],
    ".catolicasc.org.br": ["Centro Universitário - Católica de Santa Catarina"],
    ".faculdadedaindustriaiel.org.br": [
        "Faculdade da Indústria - Campus Afonso Pena",
        "faculdade da Indústria",
        "instituto euvaldo lodi - IEL",
    ],
    ".fieb.org.br": ["Federação das Indústrias do Estado da Bahia - Senai"],
    ".fundacaofemar.org.br": ["Fundação de Estudos do Mar"],
    ".ibfc.org.br": [
        "Instituto Brasileiro de Formação e Capacitação",
        "Brazilian Institute of Training and Capacity Building",
    ],
    ".edu.isd.org.br": [
        "Instituto Internacional de Neurociências Edmond e Lily Safra",
        "Edmond and Lily Safra International Institute of Neurosciences",
    ],
    ".lasalle.org.br": ["Centro Universitário Unilasalle do Rio de Janeiro"],
    ".senairs.org.br": ["Faculdade de Tecnologia Senai Porto Alegre "],
    ".estudante.sesisenai.org.br": [
        "Industry Social Service - SESI",
        "National Learning Service - SENAI",
    ],
    ".sesisenaipr.org.br": ["Faculdade da Industria Senai Parana"],
    ".sistemafieg.org.br": ["Faculdade SENAI Fatesg", "SENAI Fatesg College"],
    ".sistemafiep.org.br": [
        "Faculdades da Indústria - Sistema FIEP",
        "Industry College - FIEP System",
    ],
    ".sociesc.org.br": [
        "Centro Universitário - Sociedade Educacional de Santa Catarina"
    ],
    ".ecomp.poli.br": ["Escola politécnica de Pernambuco"],
    ".poli.br": ["Escola Politécnica de Pernambuco"],
    ".portovelho.br": ["Faculdade Porto"],
    ".uni9.pro.br": ["Universidade Nove de Julho"],
    ".puc-rio.br": ["Pontifícia Universidade Católica do Rio de Janeiro"],
    ".puccamp.br": ["Pontifícia Universidade Católica de Campinas"],
    ".pucminas.br": ["Pontifícia Universidade Católica de Minas Gerais"],
    ".pucpr.br": ["Pontificia Universidade Católica do Paraná"],
    ".pucrs.br": ["Pontifícia Universidade Católica do Rio Grande do Sul"],
    ".pucsp.br": ["Pontifícia Universidade Católica de São Paulo"],
    ".rct-sc.br": [
        "Universidade do Extremo Sul Catarinense",
        "Universidade do Vale do Itajaí",
        "Universidade para o Desenvolvimento do Alto Vale do Itajaí",
        "Universidade Regional de Blumenau",
    ],
    ".rnp.br": ["Universidade de Tocantins"],
    ".aluno.etip.santoandre.br": ["Centro Educacional ETIP"],
    ".etip.santoandre.br": ["Centro Educacional ETIP"],
    ".saocamilo-sp.br": ["Centro Universitário São Camilo"],
    ".aluno.saojose.br": [
        "Centro Universitário São José",
        " São José University Center",
    ],
    ".saojose.br": ["UniSãoJosé", "UniSãoJosé"],
    ".saojudas.br": ["Universidade São Judas Tadeu"],
    ".senac.br": ["Centro Universitário Senac"],
    ".aluno.senai.br": ["Senai - DF"],
    ".ba.estudante.senai.br": ["SENAI"],
    ".df.estudante.senai.br": ["SENAI"],
    ".sc.estudante.senai.br": ["SENAI"],
    ".pe.senai.br": ["Serviço Nacional de Aprendizagem Industrial - SENAI"],
    ".sc.senai.br": ["Serviço Nacional de Aprendizagem Industrial"],
    ".sp.senai.br": ["Serviço Nacional de Aprendizagem Industrial - São Paulo"],
    ".simonsen.br": ["Faculdades Integradas Simonsen"],
    ".smarcos.br": ["Universidade São Marcos"],
    ".souzamarques.br": ["Faculdade Tecnico-Educacional Souza Marques"],
    ".stcecilia.br": ["Universidade Santa Cecília dos Bandeirantes"],
    ".tcero.tc.br": ["Escola de Contas do Tribunal de Contas de Rondônia"],
    ".tche.br": [
        "Universidade Católica de Pelotas",
        "Universidade da Região da Campanha",
        "Universidade de Caxias do Sul",
        "Universidade de Cruz Alta",
        "Universidade de Passo Fundo",
        "Universidade Federal de Pelotas",
        "Universidade Regional do Noroeste do Estado do Rio Grande do Sul",
    ],
    ".toledo.br": ["Faculdades Integradas Toledo"],
    ".ucam-campos.br": ["Universidade Candido Mendes - Campos dos Goytacazes"],
    ".ucb.br": ["Universidade Católica de Brasília"],
    ".ucdb.br": ["Universidade Catolica Dom Bosco"],
    ".ucl.br": ["Faculdade UCL"],
    ".ucp.br": ["Universidade Católica de Petrópolis"],
    ".ucs.br": ["Universidade de Caxias do Sul"],
    ".ucsal.br": ["Universidade Católica de Salvador"],
    ".udesc.br": ["Universidade do Estado de Santa Catarina"],
    ".uece.br": ["Universidade Estadual do Ceará"],
    ".uefs.br": ["Universidade Estadual de Feira de Santana"],
    ".ueg.br": ["Universidade Estadual de Goiás"],
    ".uel.br": ["Universidade Estadual de Londrina"],
    ".uem.br": ["Universidade Estadual de Maringá"],
    ".uema.br": ["Universidade Estadual do Maranhão"],
    ".discente.uemg.br": ["Universidade do Estado de Minas Gerais"],
    ".comp.uems.br": [
        "Universidade Estadual de Mato Grosso do Sul - Ciência da Computação"
    ],
    ".uems.br": ["Universidade Estadual de Mato Grosso do Sul"],
    ".uenf.br": ["Universidade Estadual do Norte Fluminense"],
    ".uepa.br": ["UEPa - Universidade do Estado do Para"],
    ".uepg.br": ["Universidade Estadual de Ponta Grossa"],
    ".uerj.br": ["Universidade do Estado do Rio de Janeiro"],
    ".uern.br": ["Universidade do Estado do Rio Grande do Norte"],
    ".uesb.br": ["Universidade Estadual Sudoeste da Bahia"],
    ".uesc.br": ["Universidade Estadual de Santa Cruz"],
    ".uespi.br": ["Universidade Estadual do Piauí"],
    ".ufac.br": ["Universidade Federal do Acre"],
    ".ufal.br": ["Universidade Federal de Alagoas"],
    ".ufba.br": ["Universidade Federal da Bahia"],
    ".ufc.br": ["Universidade Federal do Ceará"],
    ".ufes.br": ["Universidade Federal do Espírito Santo"],
    ".uff.br": ["Universidade Federal Fluminense"],
    ".ufg.br": ["Universidade Federal de Goiás"],
    ".ufjf.br": ["Universidade Federal de Juiz de Fora"],
    ".ufla.br": ["Universidade Federal de Lavras"],
    ".ufma.br": ["Universidade Federal do Maranhão"],
    ".ufmg.br": ["Universidade Federal de Minas Gerais"],
    ".ufms.br": ["Universidade Federal de Mato Grosso do Sul"],
    ".ufmt.br": ["Universidade Federal de Mato Grosso"],
    ".decom.ufop.br": [
        "Universidade Federal de Ouro Preto",
        "Departamento de Computação",
    ],
    ".ufop.br": ["Universidade Federal de Ouro Preto"],
    ".ufpa.br": ["Universidade Federal do Pará"],
    ".ufpb.br": ["Universidade Federal da Paraíba"],
    ".ufpe.br": ["Universidade Federal de Pernambuco"],
    ".ufpi.br": ["Universidade Federal do Piauí"],
    ".ufpr.br": ["Universidade Federal do Paraná"],
    ".ufrgs.br": ["Universidade Federal do Rio Grande do Sul"],
    ".ufrj.br": ["Universidade Federal do Rio de Janeiro"],
    ".ufrn.br": ["Universidade Federal do Rio Grande do Norte"],
    ".ufrpe.br": ["Universidade Federal Rural de Pernambuco"],
    ".ufrr.br": ["Universidade Federal de Roraima"],
    ".ufrrj.br": ["Universidade Federal Rural do Rio de Janeiro"],
    ".ufs.br": ["Universidade Federal de Sergipe"],
    ".ufsc.br": ["Universidade Federal de Santa Catarina"],
    ".ufscar.br": ["Universidade Federal de São Carlos"],
    ".ufsm.br": ["Universidade Federal de Santa Maria"],
    ".ufu.br": ["Universidade Federal de Uberlândia"],
    ".ufv.br": ["Universidade Federal de Viçosa"],
    ".uit.br": ["Universidade de Itaúna", "Itaúna University"],
    ".ulbra.br": ["Universidade Luterana do Brasil"],
    ".umc.br": ["Universidade de Mogi das Cruzes"],
    ".una.br": ["Centro Universitário UNA"],
    ".unaerp.br": ["Universidade de Ribeirão Preto"],
    ".unama.br": ["Universidade da Amazônia"],
    ".unb.br": ["Universidade de Brasília"],
    ".unc.br": ["Universidade do Contestado - UnC"],
    ".uneb.br": ["Universidade do Estado da Bahia"],
    ".unemat.br": ["Universidade do Estado de Mato Grosso"],
    ".unescnet.br": ["UNESC – Faculdades Integradas de Cacoal"],
    ".unesp.br": ["Universidade Estadual Paulista"],
    ".ung.br": ["Universidade de Guarulhos"],
    ".uniamerica.br": ["Uniamérica Centro Universitário"],
    ".uniararas.br": ["Uniararas - Fundação Hermínio Ometto"],
    ".unib.br": ["Universidade Ibirapuera"],
    ".uniban.br": ["Universidade Bandeirante de São Paulo"],
    ".unibh.br": ["Centro Universitário de Belo Horizonte"],
    ".unibosco.br": ["Universidade Católica Dom Bosco"],
    ".unicamp.br": ["Universidade Estadual de Campinas"],
    ".unicap.br": ["Universidade Católica de Pernambuco"],
    ".unicastelo.br": ["Universidade Camilo Castelo Branco"],
    ".unicentro.br": ["Universidade Estadual do Centro-Oeste"],
    ".uniceub.br": ["Centro Universitário de Brasília"],
    ".unicid.br": ["Universidade Cidade de São Paulo"],
    ".unicsul.br": ["Universidade Cruzeiro do Sul"],
    ".uniderp.br": [
        "Universidade para o Desenvolvimento do Estado e da Região do Pantanal"
    ],
    ".unifacs.br": ["Universidade Salvador"],
    ".unifap.br": ["Universidade Federal do Amapá"],
    ".unifenas.br": ["Universidade de Alfenas"],
    ".unifesp.br": ["Universidade Federal de São Paulo"],
    ".unifieo.br": ["CENTRO UNIVERSITÁRIO FIEO"],
    ".edu.unifil.br": ["UniFil - Centro Universitário Filadélfia "],
    ".unifil.br": ["Centro Universitário Filadélfia", "UniFil"],
    ".unifor.br": ["Universidade de Fortaleza"],
    ".unifran.br": ["Universidade de Franca"],
    ".unig.br": ["Universidade de Nova Iguaçu"],
    ".alunos.unigran.br": [
        "UNIGRAN - Centro Universitário da Grande Dourados",
        "UNIGRAN - University Centre of the Grande Dourados Region",
    ],
    ".unigranrio.br": ["Universidade do Grande Rio"],
    ".unimar.br": ["Universidade de Marília"],
    ".unimep.br": ["Universidade Metodista de Piracicaba"],
    ".unimes.br": ["Universidade Metropolitana de Santos"],
    ".unimonte.br": ["Centro Universitário Monte Serrat"],
    ".unimontes.br": ["Universidade Estadual de Montes Claros"],
    ".uninga.br": ["Centro Universitário Ingá"],
    ".unioeste.br": ["Universidade Estadual do Oeste do Paraná"],
    ".unip-objetivo.br": ["Universidade Paulista"],
    ".unip.br": ["Universidade Paulista - UNIP"],
    ".aluno.unipac.br": [
        "UNIPAC Barbacena - Centro Universitário Presidente Antônio Carlos",
        "UNIPAC Barbacena - University President Antônio Carlos",
    ],
    ".unipar.br": ["Universidade Paranaense"],
    ".unipe.br": ["Centro Universitário de João Pessoa"],
    ".unir.br": ["Universidade Federal de Rondônia"],
    ".unirio.br": ["Universidade Federal do Estado do Rio de Janeiro"],
    ".uniriotec.br": ["Universidade Federal do Estado do Rio de Janeiro"],
    ".unirondon.br": ["Centro Universitario Candido Rondon"],
    ".unisa.br": ["Universidade de Santo Amaro"],
    ".lo.unisal.br": [
        "UNISAL - Centro Universitário Salesiano de São Paulo - Unidade Lorena"
    ],
    ".sj.unisal.br": [
        "UNISAL - Centro Universitário Salesiano de São Paulo - Unidade Campinas São José"
    ],
    ".alunos.unisanta.br": ["Universidade Santa Cecilia"],
    ".unisantos.br": ["Universidade Católica de Santos"],
    ".unisc.br": ["Universidade de Santa Cruz do Sul"],
    ".unisinos.br": ["Universidade Vale do Rio dos Sinos"],
    ".edu.uniso.br": ["Universidade de Sorocaba - UNISO"],
    ".uniso.br": ["Universidade de Sorocaba - Uniso"],
    ".unisul.br": ["Universidade do Sul de Santa Catarina"],
    ".unit.br": ["Universidade Tiradentes"],
    ".unitau.br": ["Universidade de Taubaté"],
    ".unitins.br": ["Fundação Universidade do Tocantins"],
    ".unitoledo.br": ["UniToledo"],
    ".uniube.br": ["Universidade de Uberaba"],
    ".univale.br": ["Universidade Vale do Rio Doce"],
    ".univali.br": ["Univali"],
    ".univap.br": ["Universidade Vale do Paraiba"],
    ".univates.br": ["Universidade do Vale do Taquari"],
    ".univel.br": ["Univel - União Educacional de Cascavel"],
    ".universo.br": ["Universidade Salgado de Oliveira"],
    ".univesp.br": ["Universidade Virtual do Estado de São Paulo"],
    ".univille.br": ["Universidade da Região de Joinville"],
    ".unoeste.br": ["Universidade do Oeste Paulista"],
    ".unopar.br": ["Universidade Norte do Paraná"],
    ".unorp.br": ["Centro Universitário do Norte Paulista", "UNORP"],
    ".unp.br": ["Universidade Potiguar"],
    ".upe.br": ["Universidade de Pernambuco"],
    ".upf.br": ["Universidade de Passo Fundo"],
    ".upis.br": ["Faculdades Integradas UPIS"],
    ".urca.br": ["Universidade Regional do Cariri"],
    ".uri.br": ["Universidade Regional Integrada do Alto Uruguai e das Missões"],
    ".usc.br": ["Universidade do Sagrado Coração"],
    ".usf.br": ["Universidade São Francisco"],
    ".usjt.br": ["Universidade São Judas Tadeu"],
    ".usp.br": ["Universidade de São Paulo"],
    ".uss.br": ["Universidade Severino Sombra"],
    ".usu.br": ["Universidade Santa Úrsula"],
    ".utp.br": ["Universidade Tuiuti do Paraná"],
    ".uva.br": ["Universidade Veiga de Almeida"],
    ".uvanet.br": ["Universidade Estadual do Vale do Acaraú"],
    ".uvv.br": ["Universidade Vila Velha"],
    ".ub.edu.bs": ["University of The Bahamas"],
    ".jnec.edu.bt": ["Jigme Namgyel Engineering College"],
    ".rub.edu.bt": ["Royal University of Bhutan"],
    ".bac.ac.bw": ["Botswana Accountancy College"],
    ".biust.ac.bw": ["Botswana  International University of Science & Technology"],
    ".mybac.ac.bw": ["Botswana Accountancy College"],
    ".ub.ac.bw": ["University of Botswana"],
    ".bca.bw": ["Botswana College of Agriculture"],
    ".mopipi.ub.bw": ["University of Botswana"],
    ".ub.bw": ["University of Botswana"],
    ".baa.by": ["Belarusian State Agricultural Academy"],
    ".belstu.by": ["Belarusian State Technological University"],
    ".bgam.by": [
        "Белорусская Государственная Академия Музыки",
        "Belarusian State Academy of Music",
    ],
    ".bkatk.by": ["Буда-Кошелевский аграрно-технический колледж"],
    ".bntu.by": ["Belarusian National Technical University"],
    ".brest.by": ["Brest State University"],
    ".brsu.by": ["\ufeffБрестский государственный университет имени А.С. Пушкина"],
    ".bru.by": ["Belarusian-Russian University"],
    ".bsac.by": ["Belarusian State Academy of Telecommunications"],
    ".bseu.by": ["Belarusian State Economic University"],
    ".bsmu.by": ["Belarusian State Medical University"],
    ".bspu.by": [
        "Белорусский Государственный Педагогический Университет им. Максима Танка",
        " Belarusian State Pedagogical University Named After Maxim Tank",
    ],
    ".bstu.by": ["Brest State Technical University"],
    ".bsu.by": ["Belarusian State University"],
    ".bsuir.by": ["Belarusian State University of Informatics and Radioelectronics"],
    ".bsut.by": [
        "Белорусский государственный университет транспорта",
        "Belarusian State University of Transport",
    ],
    ".buk.by": ["Belarusian State University of Culture and Arts"],
    ".edu.by": [
        "Belarusian State Academy of Music",
        "Belarusian State Agrarian Technical University",
    ],
    ".fksis.by": [
        "Faculty of Computer Systems and Networks (Belarusian State University of Informatics and Radioelectronics)"
    ],
    ".ggkttd.by": [
        "Гродненский государственный колледж техники, технологий и дизайна",
        "Hrodno state college of technic, technologies and design",
    ],
    ".ggplp.by": ["Gomel State Professional Lyceum of Instrumentation"],
    ".gomel.by": [
        "Belarusian State University of Transport",
        "Gomel State Medical University",
        "Gomel State Technical University Pavel Sukhoi",
        "Mozyr State Pedagogical Institute",
    ],
    ".kii.gov.by": [
        "Institute for Command Engineers of The Ministry for Emergency Situations"
    ],
    ".grodno.by": ["Grodno State Agrarian University"],
    ".grsmu.by": ["Grodno State Medical University"],
    ".grsu.by": ["Grodno State University Yanka Kupaly"],
    ".gstu.by": ["Gomel State Technical University Pavel Sukhoi"],
    ".gsu.by": ["Francisk Skorina Gomel State University"],
    ".iseu.by": ["International Sakharov Environmental University"],
    ".lyceum.by": ["Lyceum of Belarusian State University"],
    ".mcb.by": ["Минский колледж предпринимательства", "Minsk college of business"],
    ".mia.by": [
        "Academy of the Ministry of Internal Affairs of the Republic of Belarus"
    ],
    ".minsk.by": ["European Humanities University"],
    ".mitso.by": [
        'Международный Университет "МИТСО"',
        'International University "MITSO"',
    ],
    ".miu.by": ["Minsk Institute of Management"],
    ".mogilev.by": [
        "Belarusian-Russian University",
        "Mogilev State University A.A. Kuleshov",
    ],
    ".mrk-bsuir.by": [
        '"Belarusian State University of Informatics and Radio Electronics" Affiliate "Minsk Radio Engineering College"'
    ],
    ".mslu.by": ["Minsk State Linguistic University"],
    ".mspu.by": [
        "Мозырьский государственный универстит имени И.П. Шамякина",
        "Mozyr State Pedagogical University named after I.P.Shamyakin",
    ],
    ".msu.by": ["Mogilev State University A.A. Kuleshov"],
    ".mtp.by": ["Минский Колледж Предпринимательства", "Minsk College Of Bisenes"],
    ".pac.by": [
        "The Academy of Public Administration under the aegis of the President of the Republic of Belarus",
        "Академия управления при Президенте Республики Беларусь",
        "http://www.pac.by/en",
        "http://www.pac.by/ru/general-information/structure/institut-upr-kadrov/fakultet-innovacionnoi-podgotovki/1-stupen/",
        "http://oi67.tinypic.com/2zeb0n8.jpg",
    ],
    ".pdu.by": ["Polotsk State University"],
    ".polessu.by": ["Polessky State University"],
    ".psu.by": ["Polotsk State University"],
    ".reu.by": [
        "Российский экономический УНИВЕРСИТЕТ имени Г.В. Плеханова",
        "PLEKHANOV Russian University of Economics",
    ],
    ".unibel.by": [
        "Belarusian State Pedagogical University M. Tanka",
        "Belarusian State Polytechnical Academy",
        "Belarusian State Technological University",
        "Gomel State University Francisk Scarnia",
    ],
    ".uoggmk.by": [
        "Gomel State Machine-Building College",
        "Учреждение образования «Гомельский государственный машиностроительный колледж»",
    ],
    ".vfbsac.by": [
        'Витебский филиал УО "Белорусская государственная академия связи"',
        'Vitebsk branch of the educational establishment "Belarusian State Academy of Telecommunications"',
    ],
    ".vitebsk.by": [
        "Vitebsk State Medical University",
        "Vitebsk State Technological University",
    ],
    ".vstu.by": ["Vitebsk State Technological Univercity"],
    ".vsu.by": ["Vitebsk State University"],
    ".ub.edu.bz": ["University of Belize"],
    ".5565.ca": ["St. Albert Public Schools", ".group", "http://www.spschools.org/"],
    ".augustana.ab.ca": ["Augustana University College"],
    ".concordia.ab.ca": ["Concordia University College of Alberta"],
    ".gprc.ab.ca": ["Grande Prairie Regional College"],
    ".mtroyal.ab.ca": ["Mount Royal University"],
    ".rvschools.ab.ca": ["Springbank Community High School"],
    ".acadiau.ca": ["Acadia University"],
    ".algomau.ca": ["Algoma University"],
    ".arsdayschool.ca": ["ARS Armenian Private School", "ARS Armenian Private School"],
    ".ashbury.ca": ["Ashbury"],
    ".assumptionu.ca": ["Assumption University"],
    ".athabascau.ca": ["Athabasca University"],
    ".bart.ca": ["Collège Bart", "Bart College"],
    ".bayviewglen.ca": ["Bayview Glen Independent School"],
    ".camosun.bc.ca": ["Camosun College"],
    ".capcollege.bc.ca": ["Capilano College"],
    ".cnc.bc.ca": ["College of New Caledonia"],
    ".cotr.bc.ca": ["College of the Rockies"],
    ".csf.bc.ca": ["Conseil scolaire francophone de la C.-B."],
    ".douglas.bc.ca": ["Douglas College"],
    ".kwantlen.bc.ca": ["Kwantleen University College"],
    ".langara.bc.ca": ["Langara College"],
    ".mala.bc.ca": ["Malaspina University College"],
    ".meadowridge.bc.ca": ["Meadowridge School"],
    ".mylangara.bc.ca": ["Langara College"],
    ".myokanagan.bc.ca": ["Okanagan College"],
    ".nic.bc.ca": ["North Island College"],
    ".nlc.bc.ca": ["Northern Lights College"],
    ".nvit.bc.ca": ["Nicola Valley Institute of Technology"],
    ".okanagan.bc.ca": ["Okanagan University College"],
    ".sd23.bc.ca": ["Central Okanagan School District 23"],
    ".sd33.bc.ca": ["School District 33"],
    ".sd36.bc.ca": ["Surrey School District 36"],
    ".sd38.bc.ca": ["Steveston-London Secondary School"],
    ".sd43.bc.ca": ["Coquitlam School District 43"],
    ".sd45.bc.ca": ["West Vancouver School District 45"],
    ".sd57.bc.ca": ["School District #57 Prince George"],
    ".sd61.bc.ca": ["Greater Victoria School District #61"],
    ".sd63.bc.ca": ["Saanich School District #63"],
    ".sd64.bc.ca": ["Gulf Islands Secondary School"],
    ".sd72.bc.ca": ["School District No 72 (Campbell River)"],
    ".southridge.bc.ca": ["Southridge School"],
    ".stgeorges.bc.ca": ["St. George's School"],
    ".vsb.bc.ca": ["School District 39 (Vancouver)"],
    ".bcit.ca": ["British Columbia Institute of Technology"],
    ".bialik.ca": ["Bialik Hebrew Day School"],
    ".boothcollege.ca": ["William and Catherine Booth College"],
    ".bowvalleycollege.ca": ["Bow Valley College"],
    ".brandonu.ca": ["Brandon University"],
    ".brocku.ca": ["Brock University"],
    ".edu.burnabyschools.ca": ["Burnaby North Secondary School"],
    ".cambriancollege.ca": ["Cambrian College of Applied Arts and Technology"],
    ".online.camosun.ca": ["Camosun College"],
    ".capilanou.ca": ["Capilano University"],
    ".carleton.ca": ["Carleton University"],
    ".cbu.ca": ["Cape Breton University"],
    ".ccbc.ca": ["Canadian College of Business &amp; Computers"],
    ".etu.cchic.ca": ["Cégep de Chicoutimi"],
    ".cegepdrummond.ca": ["Cégep de Drummondville"],
    ".edu.cegepgarneau.ca": ["Cégep Garneau"],
    ".cegepgarneau.ca": ["Cégep Garneau"],
    ".cegepgim.ca": ["Cégep de la Gaspésie et des Îles"],
    ".cegepjonquiere.ca": ["Cégep de Jonquière"],
    ".etudiant.cegeplimoilou.ca": ["Cégep de Limoilou"],
    ".cegeplimoilou.ca": ["Cégep Limoilou"],
    ".cegepmontpetit.ca": ["Cégep Édouard-Montpetit"],
    ".cegepsi.ca": ["Cégep de Sept-Îles"],
    ".cegepvicto.ca": ["Cégep de Victoriaville"],
    ".centennialcollege.ca": ["Centennial College"],
    ".cimf.ca": ["Collège international Marie de France"],
    ".cmu.ca": ["Canadian Mennonite University"],
    ".collegealma.ca": ["Collège d'Alma"],
    ".collegeboreal.ca": ["Collège Boréal"],
    ".collegecdi.ca": ["College CDI"],
    ".edu.collegelacite.ca": ["La cité collégial"],
    ".collegelacite.ca": ["Collège La Cité"],
    ".collegeshawinigan.ca": ["Collège Shawinigan"],
    ".columbiacollege.ca": ["Columbia College"],
    ".concordia.ca": ["Concordia University"],
    ".confederationcollege.ca": ["Confederation College"],
    ".csda.ca": ["Centre de services scolaire des Affluents"],
    ".csfoy.ca": ["Cégep de Sainte-Foy"],
    ".cshawi.ca": ["CEGEP Shawinigan"],
    ".ele.cssda.ca": ["Centre de services scolaire des Affluents"],
    ".cus.ca": ["University of Moncton, Shippagan"],
    ".cuslm.ca": ["University of Moncton, Edmundston"],
    ".dal.ca": ["Dalhousie University"],
    ".dcmail.ca": ["Durham College"],
    ".ddsbstudent.ca": ["Durham District School Board"],
    ".devry.ca": ["DeVry Institute of Technology"],
    ".douglascollege.ca": ["Douglas College"],
    ".durhamcollege.ca": ["Durham College", "https://durhamcollege.ca/"],
    ".easternstudent.ca": ["Eastern College", "Eastern College"],
    ".ecolecatholique.ca": ["Franco-Cité", "Franco-Cite"],
    ".ecuad.ca": ["Emily Carr University of Art and Design"],
    ".educbe.ca": ["Sir John A. MacDonald Junior High"],
    ".enap.ca": ["Ecole Nationale d'Administration Publique"],
    ".etsmtl.ca": ["École de technologie supérieure, Université du Québec"],
    ".fanshawec.ca": ["Fanshawe College"],
    ".fanshaweonline.ca": ["Fanshawe College"],
    ".firstnationsuniversity.ca": ["First Nations University of Canada"],
    ".flemingcollege.ca": ["Fleming College"],
    ".learning.fraseric.ca": ["Simon Fraser University"],
    ".georgebrown.ca": ["George Brown College"],
    ".georgiancollege.ca": ["Georgian College"],
    ".gnspes.ca": ["Nova Scotia English School Board"],
    ".hdsb.ca": ["Halton District School Board"],
    ".hec.ca": ["École des Hautes Études Commerciales"],
    ".mtl.herzing.ca": ["Herzing College Montreal"],
    ".humber.ca": ["Humber College"],
    ".humbermail.ca": ["Humber College"],
    ".learning.icmanitoba.ca": ["International College Of Manitoba"],
    ".inrs.ca": ["Institut Armand-Frappier, Université du Québec"],
    ".itas.ca": [
        "Vancouver Island University - Information Technology Applied Systems"
    ],
    ".itdcanada.ca": ["Institute of Technology Development of Canada"],
    ".ivey.ca": ["Ivey Busines School"],
    ".keyanomail.ca": ["Keyano College"],
    ".kingsu.ca": ["The Kings University"],
    ".kpu.ca": ["Kwantlen Polytechnic University"],
    ".kwantlen.ca": ["Kwantlen Polytechnic University"],
    ".lakeheadu.ca": ["Lakehead University"],
    ".lambtoncollege.ca": ["Lambton College"],
    ".langara.ca": ["Langara College"],
    ".langleyschools.ca": ["Langley School District 35"],
    ".laurentian.ca": ["Laurentian University of Sudbury"],
    ".lethbridgecollege.ca": ["Lethbridge College"],
    ".macewan.ca": ["MacEwan University"],
    ".ustboniface.mb.ca": ["University College of Saint-Boniface"],
    ".mcgill.ca": ["McGill University"],
    ".mcmaster.ca": ["McMaster University"],
    ".meadowridge.ca": ["Meadowridge School"],
    ".mitt.ca": ["Manitoba Institute of Trades and Technology"],
    ".mohawkcollege.ca": ["Mohawk College"],
    ".monboreal.ca": ["Collège Boréal"],
    ".monccnb.ca": ["CCNB", "Community College of New Brunswick"],
    ".montrealcollege.ca": [
        "Montreal College of Information Technology",
        "Montreal College of Information Technology",
    ],
    ".monusb.ca": ["Université de Saint Boniface"],
    ".msvu.ca": ["Mount Saint Vincent University"],
    ".mta.ca": ["Mount Allison University"],
    ".mtroyal.ca": ["Mount Royal University"],
    ".mun.ca": ["Memorial University of Newfoundland"],
    ".mybvc.ca": ["Bow Valley College"],
    ".mycambrian.ca": ["Cambrian College"],
    ".mycdi.ca": ["College CDI"],
    ".mygeorgian.ca": ["Georgian College"],
    ".mylambton.ca": ["Lambton College"],
    ".mylangara.ca": ["Langara College"],
    ".mylaurier.ca": ["Wilfrid Laurier University"],
    ".mymacewan.ca": ["MacEwan University"],
    ".mynbcc.ca": ["New Brunswick Community College"],
    ".mynorquest.ca": ["Norquest College"],
    ".myscc.ca": [
        "St. Clair College",
        "official website URL: http://www.stclaircollege.ca/",
        "long-term IT related course: https://scweb.ca/ &&  http://www.stclaircollege.ca/programs/postsec/mobile_app_dev/",
    ],
    ".myseneca.ca": ["Seneca College"],
    ".mytru.ca": ["Thomson Rivers University"],
    ".mytwu.ca": ["Trinity Western University"],
    ".mytyndale.ca": ["Tyndale University College & Seminary"],
    ".myucw.ca": ["University Canada West"],
    ".myucwest.ca": ["University Canada West"],
    ".myumanitoba.ca": ["University of Manitoba"],
    ".nait.ca": ["Northern Alberta Institute of Technology"],
    ".nbcc.ca": ["New Brunswick Community College"],
    ".niagaracollege.ca": ["Niagara College"],
    ".nipissingu.ca": ["Nipissing University"],
    ".cna.nl.ca": ["College of the North Atlantic"],
    ".nlesd.ca": ["Gander Collegiate"],
    ".norquest.ca": ["NorQuest College"],
    ".ednet.ns.ca": ["St. Anne University"],
    ".nscad.ns.ca": ["Nova Scotia College of Art and Design"],
    ".uccb.ns.ca": ["University College of Cape Breton"],
    ".ukings.ns.ca": ["University of King's College"],
    ".nscc.ca": ["Nova Scotia Community College"],
    ".ocad.ca": ["Ontario College of Art and Design"],
    ".ocadu.ca": ["OCAD(Ontario College of Art and Design) University"],
    ".ocdsb.ca": ["Ottawa-Carleton District School Board"],
    ".ocsb.ca": ["Ottawa Catholic School Board Staff"],
    ".ocsbconted.ca": ["St Patrick School ", "St Patrick School - Ottawa"],
    ".ocsbstudent.ca": ["Ottawa Catholic School Board"],
    ".oldsuncollege.ca": ["Old Sun Community College"],
    ".borealc.on.ca": ["Collège Boréal"],
    ".conestogac.on.ca": ["Conestoga College"],
    ".confederationc.on.ca": ["Confederation College"],
    ".durhamc.on.ca": ["Durham College"],
    ".georgianc.on.ca": ["Georgian College"],
    ".hsc.on.ca": ["Hillfield Strathallan College"],
    ".huronuc.on.ca": ["Huron University College"],
    ".hwdsb.on.ca": ["Hamilton-Wentworth District School Board"],
    ".lacitec.on.ca": ["la cité collégiale - college Ottawa"],
    ".lambton.on.ca": ["Lambton College"],
    ".limestone.on.ca": ["Limestone district school board"],
    ".loyalistc.on.ca": ["Loyalist College"],
    ".student.rcdsb.on.ca": ["renfrew county district school board student emails"],
    ".rcdsb.on.ca": ["renfrew county district school board"],
    ".rsgc.on.ca": ["Royal St. George's College"],
    ".scdsb.on.ca": ["Banting Memorial High School"],
    ".senecac.on.ca": ["Seneca College"],
    ".sheridanc.on.ca": ["Sheridan College"],
    ".sl.on.ca": ["St. Lawrence College"],
    ".smcdsb.on.ca": ["Simcoe Muskoka Catholic District School Board"],
    ".tdsb.on.ca": ["Toronto District School Board"],
    ".ucc.on.ca": ["Upper Canada College"],
    ".wrdsb.on.ca": ["Waterloo Region District School Board"],
    ".cloud.edu.pe.ca": ["Three Oaks High School"],
    ".netmail.edu.pe.ca": ["Three Oaks High School"],
    ".perimeterinstitute.ca": [
        "Perimeter Institute for Theoretical Physics",
        "Perimeter Institute for Theoretical Physics",
    ],
    ".petrelcollege.ca": ["Petrel College of Technology"],
    ".polymtl.ca": ["École Polytechnique de Montréal, Université de Montréal"],
    ".publicboard.ca": ["Greater Essex County District School Board"],
    ".bdeb.qc.ca": ["Collège de Bois-de-Boulogne"],
    ".brebeuf.qc.ca": ["Collège Jean-De-Brébeuf "],
    ".cegep-chicoutimi.qc.ca": ["Cégep de Chicoutimi"],
    ".cegep-heritage.qc.ca": ["Cegep Heritage"],
    ".etu.cegep-lanaudiere.qc.ca": [
        "Cégep régional de Lanaudière à Joliette",
        "Cegep of Lanaudière at Joliette",
    ],
    ".cegep-rimouski.qc.ca": ["\ufeffCégep de Rimouski"],
    ".cegep-ste-foy.qc.ca": ["Cégep de Sainte-Foy"],
    ".cegepba.qc.ca": ["CÉGEP Beauce-Appalaches"],
    ".cegepgranby.qc.ca": ["Cégep de Granby"],
    ".cegeplapocatiere.qc.ca": ["Cegep de la Pocatière "],
    ".cegepoutaouais.qc.ca": ["Cégep de l'Outaouais"],
    ".cegepsherbrooke.qc.ca": ["Le Cégep de Sherbrooke"],
    ".cegepst.qc.ca": ["Cégep de Sorel-Tracy"],
    ".cegepsth.qc.ca": ["Cégep de Saint-Hyacinthe"],
    ".cegeptr.qc.ca": ["Cégep de Trois-Rivières"],
    ".cgmatane.qc.ca": ["Cégep de Matane"],
    ".cgodin.qc.ca": ["Cégep Gérald-Godin"],
    ".champlaincollege.qc.ca": ["Champlain Regional College"],
    ".claurendeau.qc.ca": ["Cégep André-Laurendeau"],
    ".clg.qc.ca": ["Collège Lionel-Groulx"],
    ".cll.qc.ca": ["Cégep de Lévis-Lauzon"],
    ".cmaisonneuve.qc.ca": ["Collège de Maisonneuve"],
    ".cmontmorency.qc.ca": ["Collège Montmorency"],
    ".college-em.qc.ca": ["Cégep Édouardp-Montpetit"],
    ".collegeahuntsic.qc.ca": ["Collège Ahuntsic"],
    ".collegemv.qc.ca": ["\ufeffCégep Marie-Victorin college"],
    ".collegeshawinigan.qc.ca": ["Collège Shawinigan", "Shawinigan College"],
    ".colval.qc.ca": ["Collège de Valleyfield"],
    ".crosemont.qc.ca": ["Collège de Rosemont", "College of Rosemont"],
    ".edu.csdraveurs.qc.ca": ["École polyvalente De l'Érablière"],
    ".csmb.qc.ca": ["Commission scolaire Marguerite-Bourgeoys"],
    ".csnavigateurs.qc.ca": ["\ufeffÉcole Secondaire Les Etchemins"],
    ".cstj.qc.ca": ["Cégep de Saint-Jérôme"],
    ".cstjean.qc.ca": ["Cégep Saint-Jean-sur-Richelieu"],
    ".etu.cvm.qc.ca": ["Cégep du Vieux-Montréal"],
    ".cvm.qc.ca": ["Cégep du Vieux-Montréal"],
    ".dawsoncollege.qc.ca": ["Dawson College CEGEP"],
    ".johnabbott.qc.ca": ["John Abbott College"],
    ".osullivan-quebec.qc.ca": ["Collège O'Sullivan de Québec"],
    ".psnm.qc.ca": [
        "Pensionnat du Saint-Nom-de-Marie",
        "Boarding School Du Saint-nom-de-Marie",
    ],
    ".rsb.qc.ca": ["Riverside School Board"],
    ".slc.qc.ca": ["Cegep Champlain St. Lawrence"],
    ".teccart.qc.ca": [
        "institut teccart",
        "https://www.teccart.qc.ca/",
        "https://www.teccart.qc.ca/it-management-dec.php",
    ],
    ".vaniercollege.qc.ca": ["Vanier College"],
    ".queensu.ca": ["Queen's University"],
    ".questu.ca": ["Quest University"],
    ".rcsd.ca": ["Regina Catholic Schools"],
    ".redeemer.ca": ["Redeemer College"],
    ".retsdstudent.ca": ["River East Collegiate"],
    ".rmc.ca": ["Royal Military College of Canada"],
    ".royalroads.ca": ["Royal Roads University"],
    ".rrc.ca": ["Red River College"],
    ".ryerson.ca": ["Ryerson Polytechnic University"],
    ".sait.ca": ["Southern Alberta Institute of Technology"],
    ".saskpolytech.ca": ["Saskatchewan Polytechnic"],
    ".saultcollege.ca": ["Sault College of Applied Arts & Technology"],
    ".selkirk.ca": ["Selkirk College"],
    ".selwyn.ca": ["Selwyn House School"],
    ".senecacollege.ca": ["Seneca College"],
    ".sfu.ca": ["Simon Fraser University"],
    ".shawnigan.ca": ["Shawnigan Lake School"],
    ".sheridancollege.ca": ["Sheridan College"],
    ".smu.ca": ["Saint Mary's University"],
    ".stclaircollege.ca": ["St.Clair College"],
    ".stclairconnect.ca": ["St.Clair College"],
    ".stfx.ca": ["St. Francis Xavier University"],
    ".stmarys.ca": ["St. Mary's University"],
    ".stmu.ca": ["St Mary's University"],
    ".stthomasu.ca": ["St. Thomas University"],
    ".surreyschools.ca": ["Surrey School District 36"],
    ".tav.ca": ["Tav College"],
    ".tcdsb.ca": ["Toronto Catholic District School Board"],
    ".teluq.ca": ["TÉLUQ"],
    ".tfs.ca": ["Toronto French School"],
    ".thecdm.ca": ["Centre for Digital Media"],
    ".thecea.ca": ["Langara Centre for Entertainment Arts"],
    ".torontofilmschool.ca": ["Toronto Film School"],
    ".trentu.ca": ["Trent University"],
    ".tru.ca": ["Thompson Rivers University"],
    ".tvdsb.ca": ["Thames Valley District School Board"],
    ".twu.ca": ["Trinity Western University"],
    ".tyndale.ca": ["Tyndale University College & Seminary"],
    ".ualberta.ca": ["University of Alberta"],
    ".ubc.ca": ["Sauder School of Business", "University of British Columbia"],
    ".ubishops.ca": ["Bishop's University"],
    ".ucalgary.ca": ["University of Calgary"],
    ".ufv.ca": ["University of the Fraser Valley"],
    ".ugcloud.ca": ["Center Wellington District High School"],
    ".ulaval.ca": ["Université Laval"],
    ".uleth.ca": ["University of Lethbridge"],
    ".umanitoba.ca": ["University of Manitoba"],
    ".umoncton.ca": ["University of Moncton"],
    ".umontreal.ca": ["Université de Montréal"],
    ".unb.ca": ["University of New Brunswick"],
    ".unbc.ca": ["University of Northern British Columbia"],
    ".unbsj.ca": ["University of New Brunswick, Saint John"],
    ".uofguelph.ca": ["University of Guelph (Ontario, Canada)"],
    ".uoguelph.ca": ["University of Guelph"],
    ".uoit.ca": ["University of Ontario Institute of Technology"],
    ".uottawa.ca": ["University of Ottawa"],
    ".upei.ca": ["University of Prince Edward Island"],
    ".uqac.ca": ["Université du Québec à Chicoutimi"],
    ".uqam.ca": ["Université du Québec à Montréal"],
    ".uqar.ca": ["Université du Québec à Rimouski"],
    ".uqat.ca": ["Université du Québec en Abitibi-Témiscamingue"],
    ".uqo.ca": ["Université du Québec en Outaouais"],
    ".uqtr.ca": ["Université du Québec à Trois-Rivières"],
    ".uquebec.ca": [
        "École nationale d'administration publique, Université du Québec",
        "Institut National de la Recherche Scientifique, Université du Québec",
        "Télé-université, Université du Québec",
        "Université du Québec à Rimouski",
        "Université du Québec à Trois-Rivières",
        "Université du Québec en Abitibi-Témiscamingue",
        "University of Québec",
    ],
    ".uregina.ca": ["Campion College", "University of Regina"],
    ".usask.ca": ["University of Saskatchewan"],
    ".usherb.ca": ["Université de Sherbrooke"],
    ".usherbrooke.ca": ["Université de Sherbrooke"],
    ".ustboniface.ca": ["Université de Saint-Boniface"],
    ".ustpaul.ca": ["St. Paul University"],
    ".utoronto.ca": [
        "University of St. Michael's College",
        "University of Toronto",
        "University of Toronto, Mississauga",
        "University of Toronto, Scarborough",
        "University of Trinity College",
        "Victoria University Toronto, University of Toronto",
    ],
    ".utschools.ca": ["University of Toronto Schools"],
    ".uvic.ca": ["University of Victoria"],
    ".edu.uwaterloo.ca": [
        "University of St. Jerome's College",
        "University of Waterloo",
    ],
    ".uwaterloo.ca": ["University of St. Jerome's College", "University of Waterloo"],
    ".uwindsor.ca": ["University of Windsor"],
    ".uwinnipeg.ca": ["University of Winnipeg"],
    ".uwo.ca": ["Brescia College", "King's College", "University of Western Ontario"],
    ".vanas.ca": ["Vancouver Animation School"],
    ".vcc.ca": ["Vancouver Community College"],
    ".viu.ca": ["Vancouver Island University"],
    ".wicmtl.ca": ["West Island College (Montreal)"],
    ".wlu.ca": ["Wilfrid Laurier University"],
    ".workschool.ca": ["Manitoba Institute Of Trades and Technology"],
    ".googleapps.wrdsb.ca": ["Waterloo Region District School Board"],
    ".wrdsb.ca": ["Waterloo Region District School Board"],
    ".ycdsbk12.ca": ["York Catholic District School Board"],
    ".yukoncollege.yk.ca": ["Yukon College"],
    ".yorku.ca": ["York University"],
    ".yorkvilleu.ca": ["Yorkville University in Canada"],
    ".yrdsb.ca": ["York Region District School Board"],
    ".bemen3.cat": ["Bemen 3"],
    ".boscdelacoma.cat": ["INS Bosc de la Coma"],
    ".cingle.cat": ["Escola Cingle"],
    ".cirvianum.cat": [None],
    ".enti.cat": ["Escola de Noves Tecnologies Interactives"],
    ".epiaedu.cat": ["Escola Pia de Catalunya"],
    ".escolesnuria.cat": ["CEFP Núria"],
    ".fedac.cat": ["Escoles FEDAC"],
    ".ibadia.cat": ["INS Badia del Vallès"],
    ".ies-sabadell.cat": ["Institut Sabadell"],
    ".iescarlesvallbona.cat": ["IES CARLES VALLBONA", "IES CARLES VALLBONA"],
    ".iesesteveterradas.cat": ["IES Esteve Terradas i Illa"],
    ".ieslaroca.cat": ["IES La Roca"],
    ".iessablancadona.cat": ["IES Sa Blanca Dona"],
    ".insabatoliba.cat": ["Institut Abat Oliba"],
    ".insbaixcamp.cat": ["Ins Baxi Camp"],
    ".inscamidemar.cat": ["Institut Públic Camí De Mar"],
    ".insgabrielamistral.cat": ["Institut Gabriela Mistral"],
    ".inslaguineueta.cat": ["INS La Guineueta"],
    ".inslapineda.cat": ["Institut La Pineda"],
    ".inspauvila.cat": ["Institut Pau Vila"],
    ".inspedralbes.cat": ["Institut Pedralbes"],
    ".inspladelestany.cat": ["Institut Pla de l'Estany"],
    ".institutjaumehuguet.cat": ["Institut Jaume Huguet"],
    ".institutlasegarra.cat": ["Institut La Segarra"],
    ".institutvidreres.cat": ["Institut Vidreres"],
    ".itb.cat": [
        "Institut Tecnològic de Barcelona",
        "Technological Institute of Barcelona",
    ],
    ".gracia.lasalle.cat": ["LaSalle Gràcia"],
    ".palcam.cat": ["Escola Palcam"],
    ".paucasesnovescifp.cat": ["CIFP Pau Casesnoves"],
    ".salesians.cat": ["Salesians"],
    ".sapalomera.cat": ["Institut Sa Palomera (polytechnic High School)"],
    ".tecnocampus.cat": ["TecnoCampus"],
    ".teknos.cat": ["Teknós"],
    ".uab.cat": [
        "Universitat Autónoma de Barcelona",
        "Autonomous University of Barcelona",
    ],
    ".udl.cat": ["University of Lleida"],
    ".uib.cat": ["Universitat de les Illes Balears"],
    ".uoc.cat": ["Universitat oberta de Catalunya"],
    ".urv.cat": ["Universitat Rovira i Virgili"],
    ".uvic.cat": ["University of Vic - Central University of Catalonia"],
    ".xtec.cat": ["Departament d'Ensenyament de la Generalitat de Catalunya"],
    ".cwidaho.cc": ["College of Western Idaho"],
    ".mycwi.cc": ["College of Western Idaho"],
    ".rns.cc": ["Rothesay Netherwood School"],
    ".tvcc.cc": ["Treasure Valley Community College"],
    ".ac.cd": ["Université de Lubumbashi"],
    ".unikin.cd": ["Université de Kinshasa"],
    ".abbts.ch": ["ABB Technikerschule"],
    ".stud.altekanti.ch": ["Alte Kantonsschule Aarau "],
    ".arches.ch": ["Ecole des Arches, Lausanne"],
    ".stud.bbbaden.ch": ["Berufsfachschule BBB"],
    ".bbbaden.ch": ["Berufsfachschule BBB"],
    ".bbcag.ch": ["ICT Berufsbildungscenter AG "],
    ".bbw.ch": ["Berufsbildungsschule Winterthur"],
    ".bbzsogr.ch": ["Berufsbildungszentrum Solothurn-Grenchen"],
    ".bene-edu.ch": ["Benedict Schule Luzern"],
    ".bfh.ch": ["Bern University of Applied Sciences"],
    ".bhms.ch": ["Business and Hotel Management School"],
    ".bict.ch": ["BiCT AG, Die Berufsbildner"],
    ".bks-campus.ch": ["Bündner Kantonschule Chur"],
    ".stud.bms-zuerich.ch": ["BMZ - Berufsmaturitätsschule Zürich"],
    ".bsl-lausanne.ch": ["Business School Lausanne (BSL)"],
    ".bwdbern.ch": ["Bildungszentrum für Wirtschaft und Dienstleistung"],
    ".bwz-rappi.ch": ["Berufs- und Weiterbildungszentrum Rapperswil-Jona"],
    ".bzbuchs.ch": ["Berufs- und Weiterbildungszentrum Buchs"],
    ".bztf.ch": [None],
    ".stud.bzu.ch": ["Berufsfachschule Uster"],
    ".bzwu.ch": ["Berufs- und Weiterbildungszentrum Wil-Uzwil"],
    ".bzz.ch": ["Bildungszentrum Zürichsee"],
    ".ceff.ch": ["CENTRE DE FORMATION PROFESSIONNELLE BERNE FRANCOPHONE"],
    ".cifom.ch": ["Centre interrégional des montagnes neuchâteloises"],
    ".cpnv.ch": ["Centre professionnel du Nord vaudois"],
    ".csbe.ch": ["Computerschule Bern"],
    ".dct.ch": ["DCT International Hotel &amp; Business Management School"],
    ".divart.ch": ["Division Artisanale du CEJEF"],
    ".divcom.ch": ["Ecole professionnelle commerciale du canton du Jura"],
    ".divlyc.ch": ["Lycée cantonal Porrentruy"],
    ".divtec.ch": ["Ecole des Métiers Techniques de Porrentruy"],
    ".dsgenf.ch": ["Deutsche Schule Genf", "German School of Geneva"],
    ".ecal.ch": ["Ecole cantonale d'art de Lausanne ECAL"],
    ".ecolint.ch": ["International School of Geneva"],
    ".edubs.ch": ["Basler Bildungsserver"],
    ".edueptm.ch": ["Ecole professionnelle technique des métiers"],
    ".edufr.ch": ["Education et formation dans le canton de Fribourg"],
    ".eduge.ch": ["Département de l'Instruction Publique du Canton de Genève"],
    ".edulu.ch": [
        "Berufsbildungszentrum Wirtschaft, Informatik und Technik (Kanton Luzern)"
    ],
    ".eduvaud.ch": [
        "Toutes les personnes en formation, ainsi que le personnel enseignant du Département de la formation, de la jeunesse et de la culture.",
        "All trainees, as well as the teaching staff of the Department of Training, Youth and Culture.",
        ".group",
    ],
    ".eduvs.ch": [
        "Colleges in Switzerland, including Lycée-Collège des Creusets de Sion",
        ".group",
    ],
    ".ehl.ch": ["Lausanne Hotel School (EHL)"],
    ".epfl.ch": ["Swiss Federal Institute of Technology, Lausanne"],
    ".epsic.ch": ["EPSIC - Ecole Professionnelle Lausanne"],
    ".eptsion.ch": ["Ecole professionnelle technique de Sion"],
    ".eracom.ch": ["Eracom - Ecole romande d'arts et communication, Lausanne"],
    ".ethz.ch": ["Swiss Federal Institute of Technology, Zurich"],
    ".etml-es.ch": [
        "Ecole supérieure - Ecole technique - Ecole des métiers - Lausanne"
    ],
    ".fernfachhochschule.ch": ["Fernfachhochschule Schweiz"],
    ".fernuni.ch": [
        "Universitare Fernstudien Schweiz",
        "Distance learning University Switzerland",
    ],
    ".ffhs.ch": ["Fernfachhochschule Switzerland"],
    ".fh-aargau.ch": ["University of Applied Sciences Aargau"],
    ".fh-htachur.ch": ["University of Applied Sciences Chur"],
    ".fh-hwz.ch": ["Hochschule für Wirtschaft Zürich"],
    ".fhbb.ch": ["University of Applied Sciences Basel (FHBB )"],
    ".fhgr.ch": ["University of Applied Sciences of the Grisons"],
    ".fhnw.ch": ["University of Applied Sciences and Arts Northwestern Switzerland"],
    ".fhso.ch": ["University of Applied Sciences Solothurn Northwestern Switzerland"],
    ".fhsstudents.ch": ["University of Applied Sciences St.Gallen"],
    ".fmi.ch": ["Friedrich Miescher Institute for Biomedical Research"],
    ".gbchur.ch": ["Gewerbliche Berufsschule Chur (GBC)"],
    ".gbs-ge.ch": ["Geneva Business School"],
    ".gbssg.ch": ["Gewerbliches Berufs- und Weiterbildungszentrum St. Gallen"],
    ".edu.ge.ch": ["Département de l'Instruction Publique du Canton de Genève"],
    ".edu.gfbienne.ch": ["Gymnase Français de Bienne"],
    ".gibb.ch": ["Gewerblich-Industrielle Berufsschule Bern"],
    ".gibmit.ch": ["GIBM IT Pratteln"],
    ".gibz.ch": ["Gewerblich-industrielle Bildungszentrum Zug"],
    ".graduateinstitute.ch": [
        "Graduate Institute of international and development studies",
        "Institut de hautes études internationales et du développement",
    ],
    ".gymburgdorf.ch": ["Gymnasium Burgdorf, Switzerland"],
    ".gymo.ch": ["Gymnasium Oberaargau, Switzerland"],
    ".stud.gymthun.ch": ["Gymnasium Thun, Switzerland"],
    ".he-arc.ch": ["Haute Ecole Arc"],
    ".hefr.ch": [
        "University of Applied Sciences and Arts Western Switzerland // Fribourg"
    ],
    ".heig-vd.ch": ["The School of Engineering and Business Vaud"],
    ".hes-so.ch": ["University of Applied Sciences and Arts Western Switzerland"],
    ".hesge.ch": ["University of Applied Sciences (HES-SO)"],
    ".hevs.ch": [
        "University of Applied Sciences and Arts Western Switzerland // Valais"
    ],
    ".hf-ict.ch": ["Höhere Fachschule für Informations- und Kommunikationstechnologie"],
    ".hftm.ch": [
        "Höhere Fachschule für Technik Mittelland",
        "école supérieure technique Mittelland",
    ],
    ".hfu.ch": ["Höhere Fachschule Uster"],
    ".hgkz.ch": ["Hochschule für Gestaltung und Kunst Zürich"],
    ".hslu.ch": ["Lucerne University of Applied Sciences and Arts "],
    ".hsr.ch": ["University of Applied Sciences Rapperswil"],
    ".htwchur.ch": ["University of Applied Sciences (HTW) Chur"],
    ".ibw-schule.ch": ["Hohere Fachschule Sudostschweiz"],
    ".ibw.ch": ["Hohere Fachschule Sudostschweiz"],
    ".iet-gibb.ch": ["Gewerblich-Industrielle Berufsschule Bern Abteilung IET"],
    ".ifa.ch": ["IFA - Höhere Fachschule für Wirtschaft und Informatik"],
    ".informatikschuleolten.ch": ["Informatikschule Olten"],
    ".ini.ch": ["Institute of Neuroinformatics"],
    ".ipso.ch": ["ipso Bildung AG"],
    ".isb-sib.ch": ["SIB Swiss Institute of Bioinformatics"],
    ".iun.ch": ["International University in Geneva"],
    ".kantisargans.ch": ["Kantonsschule Sargans"],
    ".kantiwattwil.ch": ["Kantonsschule Wattwil"],
    ".kbw.ch": ["Kantonsschule Büelrain Winterthur"],
    ".kbzsg.ch": ["KBZ", "KBZSG", "St.Gallen 9000"],
    ".stud.kefikon.ch": ["Schule Schloss Kefikon"],
    ".ken.ch": ["Kantonsschule Enge Zurich"],
    ".kftg.ch": ["Kantonsschule Frauenfeld"],
    ".stud.kks.ch": ["Kantonsschule Kollegium Schwyz"],
    ".kme.ch": ["Kantonale Maturitätsschule für Erwachsene Zürich"],
    ".kollegistans.ch": ["Kollegium St. Fidelis"],
    ".ksb-sg.ch": ["Kantonsschule am Brühl"],
    ".ksbg.ch": ["Kantonsschule am Burggraben St. Gallen"],
    ".kshp.ch": ["Kantonsschule Hohe Promenade"],
    ".stud.ksimlee.ch": ["Kantonsschule Im Lee Winterthur"],
    ".ksk.ch": [
        "Kantonsschule Kreuzlingen",
        "state college of higher educations",
        "ksk.ch",
    ],
    ".ksobwalden.ch": ["Kantonsschule Obwalden"],
    ".ksuster.ch": ["Kantonsschule Uster"],
    ".kswe.ch": ["Kantonsschule Wettingen"],
    ".kvbl.ch": ["Schulen kvBL"],
    ".kzn.ch": ["Kantonsschule Zürich Nord"],
    ".kzo.ch": ["Kantonsschule Zurcher Oberland"],
    ".kzu.ch": ["Kantonsschule Zurcher Unterland"],
    ".stud.lgr.ch": ["Literargymnasium Rämibühl", "literary high school rämibühl"],
    ".liceolugano.ch": ["Liceo di Lugano 1"],
    ".lilu2.ch": ["Liceo di Lugano 2, Savosa"],
    ".lrguas.ch": ["Les Roches Gruyère University of Applied Sciences"],
    ".mng.ch": ["Mathematisch-Naturwissenschaftliches Gymnasium Rämibühl Zürich"],
    ".ntb.ch": ["NTB Interstate University of Applied Sciences of Technology"],
    ".orif.ch": [
        "Organisation romande pour la formation et l'intégration professionnelle (Orif)",
        "Orif",
    ],
    ".ost.ch": ["OST Ostschweizer Fachhochschule"],
    ".phbern.ch": [
        "Pädagogische Hochschule Bern (University of Teacher Education Bern)"
    ],
    ".phgr.ch": ["Padagogischen Hochschule Graubunden"],
    ".phlu.ch": ["PH Luzern - University of Teacher Education Lucerne"],
    ".phsg.ch": ["Pädagogische Hochschule St.Gallen"],
    ".phtg.ch": ["Pädagogische Hochschule Thurgau (Thurgau School of Education)"],
    ".phzh.ch": ["Pädagogische Hochschule Zürich (Zurich School of Education)"],
    ".psi.ch": ["Paul Scherrer Institute"],
    ".rpn.ch": ["Réseau pédagogique neuchâtelois"],
    ".samtrevano.ch": ["Scuola Arti e Mestieri di Trevano"],
    ".sbl.ch": ["gymnasium liestal"],
    ".schule-eschenbach.ch": ["Schule Eschenbach"],
    ".schulegl.ch": ["Kantonsschule Glarus"],
    ".shms-mail.ch": ["Swiss Hotel Management School"],
    ".sluz.ch": [
        "Berufsbildungszentrum Wirtschaft, Informatik und Technik (Kanton Luzern)"
    ],
    ".ssseco.ch": [
        "Scuola specializzata superiore di economia",
        "State School of Applied Computer Sciences and Economics",
        "https://www.ssseco.ch/",
    ],
    ".stiftsschule-engelberg.ch": ["Stiftsschule Engelberg"],
    ".studentfr.ch": ["Education et formation dans le canton de Fribourg"],
    ".supsi.ch": ["University of Applied Sciences and Arts of Southern Switzerland"],
    ".swissinternationalschool.ch": ["SIS Swiss International Schools Schweiz AG"],
    ".swissmc.ch": ["Swiss Management Center"],
    ".tbz.ch": ["Technische Berufsschule Zürich"],
    ".teko.ch": ["Schweizerische Fachschule TEKO"],
    ".tfbern.ch": ["Technische Fachschule Bern"],
    ".edu.ti.ch": [
        "TI-EDU è il nome della rete d'attività di insegnamento superiore e di ricerca scientifica nella Svizzera italiana (Cantone Ticino)"
    ],
    ".unibas.ch": ["University of Basel"],
    ".unibe.ch": ["University of Berne"],
    ".etu.unidistance.ch": ["Unidistance / FernUni", "Unidistance"],
    ".unifr.ch": ["University of Fribourg"],
    ".unige.ch": ["University of Geneva"],
    ".unil.ch": ["University of Lausanne"],
    ".unilu.ch": ["University of Lucerne"],
    ".uniludes.ch": ["Libera Università degli Studi di Scienze Umane e Tecnologiche"],
    ".unine.ch": ["University of Neuchatel"],
    ".unisg.ch": ["University of St. Gallen"],
    ".unisi.ch": ["University of the Italian-speaking Part of Switzerland"],
    ".unizh.ch": ["University of Zürich"],
    ".usb.ch": ["Universitätsspital Basel"],
    ".usi.ch": ["Università della Svizzera italiana"],
    ".uzh.ch": ["University of Zurich"],
    ".webster.ch": ["Webster University Geneva"],
    ".wsl.ch": ["Swiss Federal Institute for Forest, Snow and Landscape Research WSL"],
    ".zbw-online.ch": ["Zentrum für Berufliche Weiterbildung"],
    ".zhaw.ch": ["Zurich University of Applied Sciences"],
    ".zhdk.ch": ["Zurich University of Arts"],
    ".zis.ch": ["Zurich International School"],
    ".iugb.edu.ci": ["International University of Grand Bassam"],
    ".ujlg.edu.ci": ["Université Jean Lourougnon Guédé"],
    ".uvci.edu.ci": ["Université Virtuelle de Côte d'Ivoire"],
    ".esatic.ci": ["ESATIC", "ESATIC"],
    ".inphb.ci": ["INP-HB (Institut National Polytechnique Félix Houphouët-Boigny)"],
    ".ita-education.ci": ["ITA Ingenierie SA", "Abidjan Institute of Technology"],
    ".nan.ci": ["NaN"],
    ".uabobo.ci": ["Université d'Abobo-Adjamé"],
    ".ubouake.ci": ["Université de Bouaké"],
    ".univ-cocody.ci": ["Université de Cocody"],
    ".univmetiers.ci": [
        "School actual website is http://www.pigierci.com/, Mails are hosted by microsoft but via http://univmetiers.onmicrosoft.com/."
    ],
    ".academia.cl": ["Universidad Academia de Humanismo Cristiano"],
    ".aiep.cl": ["Instituto Profesional AIEP (Administrativos)"],
    ".alperit.cl": ["Alperit"],
    ".alumnosuls.cl": ["Universidad de La Serena"],
    ".arquitecturaucv.cl": ["Escuela de Arquitectura y Diseño"],
    ".ciisa.cl": ["Instituto de Ciencias Tecnológicas CIISA"],
    ".cinv.cl": [
        "Centro Interdisciplinario de Neurociencia (Universidad de Valparaiso)"
    ],
    ".correoaiep.cl": ["Instituto Profesional AIEP (Estudiantes)"],
    ".duoc.cl": ["Fundación Instituto Profesional Duoc UC"],
    ".duocuc.cl": ["Duoc UC"],
    ".estudiantes.iacc.cl": [
        "Instituto Profesional IACC",
        "IACC Professional Institute",
    ],
    ".inacapmail.cl": ["Universidad Tecnologica de Chile - INACAP"],
    ".ipchile.cl": ["instituto profesional de chile"],
    ".ipciisa.cl": ["Instituto de Ciencias Tecnológicas IP CIISA"],
    ".irfe.cl": ["Instituto Regional Federico Errazuriz"],
    ".itcalumnos.cl": ["Instituto Tecnologico de Chile"],
    ".mayor.cl": ["Universidad Mayor Temuco"],
    ".miuandes.cl": ["Universidad de los Andes"],
    ".puc.cl": ["Pontificia Universidad Catolica de Chile"],
    ".pucv.cl": ["Pontificia Universidad Católica de Valparaíso"],
    ".santotomas.cl": ["Universidad Santo Tomás"],
    ".twk.cl": ["CFT Teodoro Wickel K."],
    ".ua.cl": ["Universidad de Antofagasta"],
    ".uach.cl": ["Universidad Austral de Chile"],
    ".uaconcagua.cl": ["Universidad de Aconcagua"],
    ".uahurtado.cl": ["Universidad Alberto Hurtado"],
    ".uai.cl": ["Universidad Adolfo Ibañez", "Universidad Adolfo Ibáñez"],
    ".uamericas.cl": ["Universidad de Las Américas"],
    ".uandes.cl": ["Universidad de Los Andes"],
    ".uantof.cl": ["Universidad de Antofagasta"],
    ".uas.cl": ["Universidad Autonoma del Sur"],
    ".uautonoma.cl": ["Universidad Autonoma de Chile"],
    ".ubiobio.cl": ["Universidad del Bío-Bío"],
    ".pregrado.ubo.cl": ["Universidad Bernardo O'Higgins"],
    ".ubohiggins.cl": ["Universidad Bernardo O'Higgins"],
    ".ubolivariana.cl": ["Universidad Bolivariana"],
    ".ubritanica.cl": ["Universidad Chileno Britanica de Cultura"],
    ".uc.cl": ["Pontificia Universidad Católica de Chile"],
    ".ucentral.cl": ["Universidad Central"],
    ".dcc.uchile.cl": [
        "Departamento de Ciencias de la Computación",
        "Universidad de Chile",
    ],
    ".u.uchile.cl": ["Universidad de Chile"],
    ".ug.uchile.cl": ["Universidad de Chile"],
    ".uchile.cl": ["Universidad de Chile"],
    ".ucinf.cl": ["Universidad de Ciencias de la Informatica"],
    ".ucm.cl": ["Universidad Catolica del Maule"],
    ".ucn.cl": ["Universidad Catolica del Norte"],
    ".ucsc.cl": ["Universidad Catolica de La Santísima Concepción"],
    ".ucsh.cl": ["Universidad Católica Cardenal Raúl Silva Henríquez"],
    ".uct.cl": ["Universidad Catolica de Temuco"],
    ".uctemuco.cl": ["Universidad Católica de Temuco"],
    ".ucv.cl": ["Universidad Catolica de Valparaiso"],
    ".uda.cl": ["Universidad de Atacama"],
    ".ingenieros.udd.cl": ["Universidad del Desarrollo"],
    ".udd.cl": ["Universidad del Desarrollo"],
    ".udec.cl": ["Universidad de Concepcion"],
    ".udelmar.cl": ["Universidad del Mar"],
    ".udesarrollo.cl": ["Universidad del Desarrollo"],
    ".edu.udla.cl": ["Universidad de Las Américas"],
    ".udla.cl": ["Universidad de Las Américas"],
    ".udp.cl": ["Universidad Diego Portales"],
    ".ufinis.cl": ["Universidad Finis Terrae"],
    ".ufromail.cl": ["Universidad de La Frontera"],
    ".ufrontera.cl": ["Universidad de La Frontera"],
    ".ugm.cl": ["Universidad Gabriela Mistral"],
    ".uisek.cl": ["Universidad International SEK, Santiago"],
    ".ulagos.cl": ["Universidad de Los Lagos"],
    ".ulare.cl": ["Universidad La Republica"],
    ".umag.cl": ["Universidad de Magallanes"],
    ".umaritima.cl": ["Universidad Maritima de Chile"],
    ".umayor.cl": ["Universidad Mayor"],
    ".umce.cl": ["Universidad Metropolitana de Ciencias de la Educación"],
    ".ume.cl": ["Universidad Mariano Egaña"],
    ".unab.cl": ["Universidad Andrés Bello"],
    ".unach.cl": ["Universidad Adventista de Chile"],
    ".unap.cl": ["Universidad Arturo Prat"],
    ".unfa.cl": ["Universidad Francisco de Aguirre"],
    ".uniacc.cl": ["Universidad de Artes, Ciencias y Comunicación"],
    ".unicit.cl": ["Universidad Iberoamericana de Ciencias y Tecnologia"],
    ".universidadarcis.cl": ["Universidad Arcis"],
    ".uoh.cl": ["Universidad de O'Higgins"],
    ".upa.cl": ["Universidad de Playa Ancha de Ciencias de la Educacion"],
    ".upla.cl": ["Universidad de Playa Ancha"],
    ".usach.cl": ["Universidad de Santiago de Chile"],
    ".usanandres.cl": ["Universidad de San Andres"],
    ".userena.cl": ["Universidad de La Serena"],
    ".usm.cl": ["Federico Santa María Technical University"],
    ".uss.cl": ["Universidad San Sebastian"],
    ".ust.cl": ["Universidad Santo Tomás"],
    ".uta.cl": ["Universidad de Tarapacá"],
    ".utalca.cl": ["Universidad de Talca"],
    ".utem.cl": ["Universidad Tecnológica Metropolitana"],
    ".utfsm.cl": ["Universidad Técnica Federico Santa María"],
    ".uv.cl": ["Universidad de Valparaiso"],
    ".uvm.cl": ["Universidad de Viña del Mar"],
    ".virginiogomez.cl": ["Instituto Profesional Virginio Gómez"],
    ".tsbw.cloud": [
        "Theodor-Schäfer-Berufsbildungswerk",
        "Theodor-Schäfer-Berufsbildungswerk Husum",
    ],
    ".enspd-udo.cm": [
        "Ecole Nationale Supérieure Polytechnique de Douala (ENSPD)",
        "National Higher Polytechnic School of Douala",
    ],
    ".iut-douala.cm": [
        "Institut Universitaire des Technologies",
        "Univesity Institute Of Technologies",
    ],
    ".polytechnique.cm": ["Ecole National Supérieure Polytechnique de Yaounde"],
    ".ubuea.cm": ["University of Buea"],
    ".udm.cm": ["\ufeffUniversité des Montagnes"],
    ".uninet.cm": ["Université de Yaoundé I"],
    ".univ-maroua.cm": ["The University of Maroua"],
    ".univ-ndere.cm": [
        "ENSAI Ngaoundéré",
        "Higher National Agro-Industrial science college Ngaoundéré",
    ],
    ".aircas.ac.cn": [
        "中国科学院空天信息创新研究院",
        "Aerospace Information Research Institute,Chinese Academy of Sciences",
    ],
    ".big.ac.cn": [
        "中国科学院北京基因组研究所",
        "Beijing Institute of Genomics, Chinse Academy of Sciences",
    ],
    ".genetics.ac.cn": [
        "Institute of Genetics and Developmental Biology, Chinese Academy of Sciences",
        "Institute of Genetics and Developmental Biology, Chinese Academy of Sciences",
    ],
    ".gscaep.ac.cn": [
        "中国工程物理研究院研究生院",
        "Graduate School of China Academy of Engineering Physics",
    ],
    ".ia.ac.cn": [
        "中国科学院大学，中国科学院自动化研究所",
        "University of Chinese Academy of Sciences，Institute of Automation Chinese Academy of Sciences",
    ],
    ".ibp.ac.cn": ["Institute of Biophysics Academia Sinica"],
    ".iccas.ac.cn": [
        "中国科学院化学研究所",
        "Institute of Chemistry Chinese Academy of Sciences",
    ],
    ".ict.ac.cn": [
        "中国科学院计算技术研究所",
        "Institute of Computing Technology, Chinese Academy of Sciences",
    ],
    ".igsnrr.ac.cn": [
        "中国科学院地理科学与资源研究所",
        "INSTITUTE OF GEOGRAPHIC SCIENCES AND NATURAL RESOURCES RESEARCH",
    ],
    ".ihep.ac.cn": [
        "\ufeff中国科学院高能物理研究所",
        "The Institute of High Energy Physics of the Chinese Academy of Sciences",
    ],
    ".iie.ac.cn": ["中国科学院大学", "University of Chinese Academy of Sciences"],
    ".ime.ac.cn": [
        "中国科学院微电子研究所",
        "Institute of Microelectronics，Chinese Academy of Sciences",
    ],
    ".imicams.ac.cn": [
        "\ufeff中国医学科学院/北京协和医学院医学信息研究所/图书馆",
        "The Institute of Medical Information (IMI) & Library, Chinese Academy of Medical Sciences and Peking Union Medical College (CAMS & PUMC)",
    ],
    ".mail.ioa.ac.cn": [
        "中国科学院大学",
        "Institute of Acoustics, Chinese Academy of Sciences",
    ],
    ".iphy.ac.cn": [
        "中国科学院物理研究所, 中国科学院",
        "Institute of Physics, Chinese Academy of Sciences",
    ],
    ".iscas.ac.cn": [
        "中国科学院软件研究所，中国科学院大学",
        "Institute of Software, Chinese Academy of Sciences/University of Chinese Academy of Sciences",
    ],
    ".nibs.ac.cn": ["北京生命科学研究所", "National Institute of Biological Sciences, Beijing"],
    ".nssc.ac.cn": [
        "中国科学院国家空间科学中心",
        "National Space Science Center, Chinese Academy of Sciences",
    ],
    ".picb.ac.cn": [
        "中国科学院-马普学会计算生物学伙伴研究院",
        "CAS-MPG Partner Institute for Computational Biology (PICB)",
    ],
    ".siat.ac.cn": [
        "中国科学院大学深圳先进技术研究院",
        "Shenzhen Institutes of Advanced Technology，Chinese Academy of Sciences",
    ],
    ".sict.ac.cn": [
        "中国科学院沈阳计算技术研究所",
        "Shenyang institute of computing technology, Chinese Academy of Sciences",
    ],
    ".simm.ac.cn": [
        "中国科学院上海药物研究所",
        "Shanghai Institute of Metria and Medica, Chinese Academy of Sciences",
    ],
    ".tfswufe.ac.cn": [
        "西南财经大学天府学院",
        "Tianfu Southwest University of Finance and Economics",
    ],
    ".ucas.ac.cn": ["University of Chinese Academy of Sciences"],
    ".wipm.ac.cn": [
        "中国科学院武汉物理与数学研究所",
        "Wuhan Institute of Physics and Mathematics Chinese Academy of Science",
    ],
    ".mails.ucas.as.cn": ["中国科学院大学", "University of Chinese Academy of Sciences"],
    ".stu.aurora-college.cn": ["上海震旦职业技术学院", "Shanghai Aurora Vocational College"],
    ".bcis.cn": ["Beijing City International School"],
    ".bupt.cn": ["北京邮电大学"],
    ".ccbupt.cn": [
        "北京邮电大学世纪学院",
        "Century College,Beijing University of Posts and Telecommunications",
    ],
    ".alevel.com.cn": ["Shenzhen College of International Education"],
    ".beijing101.com.cn": ["Beijing 101 Middle School"],
    ".bibs.com.cn": [
        "Beanstalk International Bilingual School in China (Chengdu campus)"
    ],
    ".cvit.com.cn": ["Changchun Vocational Institute Of Technology"],
    ".jxhlxy.com.cn": ["江西卫生职业学院", "jiangxi health vocational college"],
    ".njude.com.cn": ["南京大学网络教育学院", "NANJING UNIVERSITY School of Distance Education"],
    ".nou.com.cn": ["Dalian Neusoft University of Information"],
    ".qypt.com.cn": ["Qingyuan Polytechnic"],
    ".schxmvc.com.cn": ["四川华新现代职业学院", "Sichuan Huaxin Modern Vocational College"],
    ".scie.com.cn": [
        "Shenzhen College of Internation Education",
        "深圳国际交流学院",
        "URL: http://www.alevel.com.cn/",
    ],
    ".scse.com.cn": [
        "South China Institute Of Software Engineering, Guangzhou University"
    ],
    ".sise.com.cn": [
        "South China Institute of Software Engineering of Guangzhou University"
    ],
    ".wy.suis.com.cn": [
        "上海市民办万源城协和双语学校",
        "Shanghai United International School, Wanyuan Campus",
    ],
    ".czu.cn": ["Changzhou Institute of Technology"],
    ".dulwich-suzhou.cn": ["Dulwich College Suzhou", "苏州德威学校"],
    ".dwlxs.cn": ["Dalian University Of Foreign Languages"],
    ".ecnu.cn": ["East China Normal University"],
    ".ah.edu.cn": [
        "Anhui Technical College of Water Resources and Hydroelectric Power"
    ],
    ".ahau.edu.cn": ["Anhui Agriculture University"],
    ".ahjzu.edu.cn": ["Anhui JianZhu University", "安徽建筑大学"],
    ".ahmu.edu.cn": ["Anhui Medical University"],
    ".ahnu.edu.cn": ["Anhui Normal University"],
    ".ahtcm.edu.cn": ["Anhui University of Traditional Chinese Medicine"],
    ".ahu.edu.cn": ["Anhui University"],
    ".ahut.edu.cn": ["Anhui University of Technology"],
    ".ayit.edu.cn": ["Anyang Institute of Technology", "安阳工学院"],
    ".bac.edu.cn": ["Beijing University of Agriculture"],
    ".bbc.edu.cn": ["Bengbu University"],
    ".bfa.edu.cn": ["Beijing Film Academy"],
    ".bfsu.edu.cn": ["Beijing Foreign Studies University"],
    ".bhu.edu.cn": ["Bohai University"],
    ".bistu.edu.cn": ["Beijing Information Science & Technology University"],
    ".bit.edu.cn": ["Beijing Institute of Technology"],
    ".bj.edu.cn": ["Beijing New Asia University"],
    ".bjfu.edu.cn": ["Beijing Forestry University"],
    ".bjmu.edu.cn": ["Beijing Medical University"],
    ".bjtu.edu.cn": ["Beijing Jiaotong University"],
    ".emails.bjut.edu.cn": ["Beijing University of Technology"],
    ".bjut.edu.cn": ["Beijing University of Technology"],
    ".blcu.edu.cn": ["Beijing Language and Culture University"],
    ".bnu.edu.cn": ["Beijing Normal University"],
    ".bnuz.edu.cn": ["BEIJING NORMAL UNIVERSITY ZHUHAI"],
    ".btbu.edu.cn": ["Beijing Technology and Business University"],
    ".buaa.edu.cn": ["Beihang University"],
    ".stu.bucea.edu.cn": ["BEIJING UNIVERSITY OF CIVITL ENGINEERING AND ARCHITECTURE"],
    ".buct.edu.cn": ["Beijing University of Chemical Technology"],
    ".bupt.edu.cn": ["Beijing University of Posts and Telecommunications"],
    ".buu.edu.cn": ["Beijing Union University", "北京联合大学"],
    ".cafa.edu.cn": ["Central Academy of  Fine Art"],
    ".cafuc.edu.cn": ["中国民用航空飞行学院", "Civil Aviation Flight University of China"],
    ".cau.edu.cn": ["China Agricultural University"],
    ".ccdgut.edu.cn": ["City College of Dongguan University of Technology"],
    ".ccmu.edu.cn": ["Capital Medical University", "首都医科大学"],
    ".ccnu.edu.cn": ["Central China Normal University"],
    ".ccsu.edu.cn": ["Changsha Unversity"],
    ".mails.ccu.edu.cn": ["Changchun University"],
    ".ccu.edu.cn": ["Changchun University"],
    ".ccut.edu.cn": ["Changchun University of Technology"],
    ".smail.cczu.edu.cn": ["Changzhou University"],
    ".cdmc.edu.cn": ["Chengde Medical University", "承德医学院"],
    ".cdu.edu.cn": ["Chengdu University"],
    ".cduestc.edu.cn": [
        "Chengdu College of University of Electronic Science and Technology"
    ],
    ".cdut.edu.cn": ["Chengdu University of Technology"],
    ".chd.edu.cn": ["Chang'an University"],
    ".chu.edu.cn": [
        "Official website: http://www.chu.edu.cn/",
        "Student mailbox login page: http://mail.chu.edu.cn/",
    ],
    ".stu.cjlu.edu.cn": ["China Jiliang University", "中国计量大学(学生邮箱)"],
    ".cjlu.edu.cn": ["China Jiliang University", "中国计量大学"],
    ".cmu.edu.cn": ["China Medical University Shenyang"],
    ".cncnc.edu.cn": ["Changchun Teachers College"],
    ".cnu.edu.cn": ["Capital Normal University"],
    ".cpu.edu.cn": ["China Pharmaceutical University Nanjing"],
    ".cqnu.edu.cn": ["Chongqing Normal University"],
    ".cqu.edu.cn": ["Chongqing University"],
    ".stu.cque.edu.cn": ["重庆第二师范学院", "ChongQing Unversity Of Education"],
    ".cqupt.edu.cn": ["Chongqing University of Post and Telecommunications"],
    ".cqust.edu.cn": ["Chongqing University Of Science and Technology"],
    ".2014.cqut.edu.cn": ["Chongqing University of Technology"],
    ".crtvu.edu.cn": ["Central Radio and TV University"],
    ".cslg.edu.cn": ["ChangShu Institute of Technology "],
    ".csu.edu.cn": ["Central South University"],
    ".csuft.edu.cn": ["Central South University of Forestry and Technology"],
    ".stu.csust.edu.cn": ["Changsha University of Science and Technology"],
    ".csust.edu.cn": ["Changsha University of Science & Technology"],
    ".ctbu.edu.cn": ["Chongqing Technology and Business University"],
    ".ctgu.edu.cn": ["China Three Gorges University"],
    ".cuc.edu.cn": ["Communication University of China"],
    ".cueb.edu.cn": ["Capital University of Economics and Business"],
    ".cufe.edu.cn": ["Central University of Finance and Economics"],
    ".cug.edu.cn": ["China University of Geosciences Wuhan"],
    ".cugb.edu.cn": ["China University of Geoscience Beijing"],
    ".link.cuhk.edu.cn": ["The Chinese University of Hong Kong, Shenzhen"],
    ".cuhk.edu.cn": ["The Chinese University of Hong Kong, Shenzhen"],
    ".cuit.edu.cn": ["Chengdu University of Information Technology"],
    ".cumt.edu.cn": ["China University of Mining Technology - Xuzhou"],
    ".cumtb.edu.cn": ["China University of Mining Technology - Beijing"],
    ".student.cup.edu.cn": ["China University of Petroleum-Beijing"],
    ".cup.edu.cn": ["China University of Petroleum-Beijing"],
    ".cupk.edu.cn": [
        "China University of Petroleum-Beijing at Karamay",
        "中国石油大学（北京）克拉玛依校区",
    ],
    ".cupl.edu.cn": ["China University of Political Science and Law"],
    ".cust.edu.cn": ["Changchun University of Science and Technology"],
    ".email.cwu.edu.cn": ["CHINA WOMEN'S UNIVERSITY", "中华女子学院"],
    ".cyc.edu.cn": ["China youth college for political science"],
    ".dgut.edu.cn": ["Dongguan University Of Technology"],
    ".dhu.edu.cn": ["Donghua University, Shanghai"],
    ".dlmedu.edu.cn": ["Dalian Medical University"],
    ".dlmu.edu.cn": ["Dalian Martime University"],
    ".dlpu.edu.cn": ["大连工业大学", "Dalian Polytechnic University"],
    ".dlu.edu.cn": ["Dalian University"],
    ".student.dlufl.edu.cn": ["Dalian University Of Foreign Languages"],
    ".dlufl.edu.cn": ["Dalian University Of Foreign Languages"],
    ".dlut.edu.cn": ["Dalian University of Technology"],
    ".dufe.edu.cn": ["Dongbei University of Finance And Economics"],
    ".student.ecnu.edu.cn": ["East China Normal University"],
    ".ecnu.edu.cn": ["East China Normal University"],
    ".ecupl.edu.cn": ["华东政法大学", "East China University of Political Science and Law"],
    ".ecust.edu.cn": ["East China University of Science and Technology"],
    ".ecut.edu.cn": ["East China University of Technology"],
    ".fjau.edu.cn": ["Fujian Agricultural University"],
    ".fjmu.edu.cn": ["Fujian Medical University"],
    ".fjnu.edu.cn": ["Fujian Normal University"],
    ".fjtcm.edu.cn": ["Fujian University of Traditional Chinese Medicine"],
    ".fjut.edu.cn": ["Fujian University of Technology"],
    ".fmmu.edu.cn": ["4th Military Medical University"],
    ".fosu.edu.cn": ["Foshan University"],
    ".fudan.edu.cn": ["Fudan University"],
    ".fzfu.edu.cn": ["fuzhou university of international studies and trade"],
    ".fzu.edu.cn": ["Fuzhou University"],
    ".stu.gdgm.edu.cn": [
        "广东工贸职业技术学院",
        "Guangdong Polytechnic of Industry and Commerce",
        "the university official website URL: https://www.gdgm.edu.cn/",
    ],
    ".gdou.edu.cn": ["Guangdong Ocean University"],
    ".gdpu.edu.cn": ["Guangdong Pharmaceutical University"],
    ".gdrtvu.edu.cn": ["Guangdong Radio &amp; TV University"],
    ".gduf.edu.cn": ["Guangdong University Of Finance"],
    ".gdufs.edu.cn": ["Guangdong University of Foreign Studies"],
    ".gdut.edu.cn": ["Guangdong University of Technology"],
    ".gench.edu.cn": ["Shanghai Jian Qiao University"],
    ".glmc.edu.cn": ["Guilin Medical University"],
    ".glut.edu.cn": ["Guilin university of technology"],
    ".gpnu.edu.cn": ["Guangdong Polytechnic Normal University", "广东技术师范大学"],
    ".gsau.edu.cn": ["Gansu Agricultural University"],
    ".gsli.edu.cn": [" GanSu Political Science And Law Institute"],
    ".gsut.edu.cn": ["Gansu University of Technology"],
    ".mails.guet.edu.cn": ["Guilin University Of Electronic Technology"],
    ".gxnu.edu.cn": ["Guangxi Normal University"],
    ".gxtcmu.edu.cn": ["Guangxi Traditional Chinese Medical University"],
    ".xingjian.gxu.edu.cn": [
        "Guangxi University Xingjian College of Science and Liberal Arts"
    ],
    ".gxu.edu.cn": ["Guangxi University"],
    ".gxun.edu.cn": ["Guangxi University for Nationalities"],
    ".gzhu.edu.cn": ["Guangzhou University"],
    ".gznu.edu.cn": ["Guizhou Normal University"],
    ".gzu.edu.cn": ["Guizhou University"],
    ".stu.gzucm.edu.cn": ["Guangzhou University of Chinese Medicine"],
    ".hainnu.edu.cn": ["Hainan Normal University"],
    ".hainu.edu.cn": ["Hainan University"],
    ".haue.edu.cn": ["add Henan University of Engineering"],
    ".haust.edu.cn": ["Henan University of Science and Technology"],
    ".haut.edu.cn": ["Henan University of Technology"],
    ".hbu.edu.cn": ["Hebei University"],
    ".hbuas.edu.cn": ["HUBEI UNIVERSITY OF ARTS AND SCIENCE", "湖北文理学院"],
    ".hbut.edu.cn": ["Hubei University of Technology"],
    ".hdu.edu.cn": ["Hangzhou Dianzi University"],
    ".hebau.edu.cn": ["Hebei Agricultural University"],
    ".hebmu.edu.cn": ["Hebei Medical University"],
    ".hebnu.edu.cn": ["Hebei Normal University"],
    ".hebust.edu.cn": ["Hebei University of Science and Technology"],
    ".hebut.edu.cn": ["Hebei University of Technology"],
    ".henannu.edu.cn": ["Henan Normal University"],
    ".henau.edu.cn": ["Henan Agriculture University"],
    ".henu.edu.cn": ["Henan Univeristy"],
    ".heuet.edu.cn": ["Hebei University of Economics and Trade"],
    ".hfut.edu.cn": ["Hefei University of Technology"],
    ".hhit.edu.cn": ["HuaiHai Institute of Technology"],
    ".hhstu.edu.cn": ["Huanghe Science &amp; Technology University"],
    ".hhtc.edu.cn": ["Huaihua University"],
    ".hhu.edu.cn": ["Hehai University"],
    ".hhuc.edu.cn": ["Hohai University Changzhou"],
    ".hit.edu.cn": ["Harbin Institute of Technology"],
    ".stmail.hitsz.edu.cn": ["Harbin Institute of Technology, Shenzhen"],
    ".hlju.edu.cn": ["Heilongjiang University"],
    ".hnu.edu.cn": ["Hunan University"],
    ".hnuahe.edu.cn": ["Henan University of Animal Husbandry and Economy"],
    ".hnust.edu.cn": ["Hunan University of Science and Technology"],
    ".hpu.edu.cn": ["Henan Polytechnic University"],
    ".hqu.edu.cn": ["Huaqiao University Quanzhuo"],
    ".hrbeu.edu.cn": ["Harbin Engineering University"],
    ".hrbmu.edu.cn": ["Harbin Medical University"],
    ".hrbnu.edu.cn": ["Harbin Normal University"],
    ".hrbust.edu.cn": ["Harbin University of Science and Technology"],
    ".hsu.edu.cn": ["Huang Shan University"],
    ".huat.edu.cn": ["Hubei University of Automotive Industry"],
    ".hubu.edu.cn": ["Hubei University"],
    ".hunau.edu.cn": ["Hunan Agricultural University"],
    ".hunnu.edu.cn": ["Hunan Normal University"],
    ".hust.edu.cn": ["Huazhong University of Science and Technology"],
    ".hut.edu.cn": ["HuNan University of Technology"],
    ".hyit.edu.cn": ["Huaiyin Institute Of Technology"],
    ".hzau.edu.cn": ["Huazhong Agricultural University"],
    ".hznu.edu.cn": ["Hangzhou Normal University"],
    ".hzu.edu.cn": ["Huizhou University"],
    ".imau.edu.cn": ["Inner Mongolia Agricultural University"],
    ".imnu.edu.cn": ["Inner Mongolia Normal University"],
    ".imu.edu.cn": ["Inner Mongolia University"],
    ".jiangnan.edu.cn": ["Jiangnan University"],
    ".stu.jit.edu.cn": ["Jinling Institute Of Technology (Student Used)"],
    ".jit.edu.cn": ["Jinling Institute of Technology"],
    ".jlau.edu.cn": ["Jilin Agricultural University"],
    ".jlnu.edu.cn": ["Jilin Normal University"],
    ".jlu.edu.cn": ["Jilin University"],
    ".jmu.edu.cn": ["Jimei University"],
    ".jnu.edu.cn": ["Jinan University"],
    ".jou.edu.cn": ["Jiangsu Ocean University", "江苏海洋大学"],
    ".jsu.edu.cn": ["Jishou University"],
    ".jsust.edu.cn": ["Jiangsu University of Science and Technology"],
    ".stu.just.edu.cn": ["Jiangsu University of Science and Technology"],
    ".jxau.edu.cn": ["Jiangxi Agricultural University"],
    ".jxnu.edu.cn": ["Jiangxi Normal University"],
    ".jxufe.edu.cn": ["Jiangxi University of Finance and Economics"],
    ".mail.jxust.edu.cn": ["JiangXi University of Science and Technology"],
    ".jyu.edu.cn": ["Jiaying University"],
    ".kfu.edu.cn": ["Kaifeng University"],
    ".kmust.edu.cn": ["Kunmimg University of Science and Technology"],
    ".lcu.edu.cn": ["Liaocheng University", "聊城大学"],
    ".lixin.edu.cn": ["Shanghai Lixin University of Accounting and Finance"],
    ".lnnu.edu.cn": ["Liaoning Normal University"],
    ".stu.lnpu.edu.cn": [
        "辽宁石油化工大学",
        "Liaoning University of Petroleum and Chemical Technology",
    ],
    ".lntu.edu.cn": ["Liaoning Technical University"],
    ".lnu.edu.cn": ["Liaoning University"],
    ".lzjtu.edu.cn": ["Lanzhou Jiaotong University", "兰州交通大学"],
    ".lzu.edu.cn": ["Lanzhou University"],
    ".mail.nankai.edu.cn": ["Nankai University"],
    ".nankai.edu.cn": ["Nankai University"],
    ".nanshan.edu.cn": ["Yantai Nanshan University"],
    ".nau.edu.cn": ["Nanjing Audit University"],
    ".nbpt.edu.cn": ["Ningbo Polytechnic"],
    ".nbu.edu.cn": ["Ningbo University"],
    ".nchu.edu.cn": ["Nanchang Hangkong University"],
    ".nciae.edu.cn": ["North China Institute of Aerospace Engineering"],
    ".ncist.edu.cn": ["North China Institute of Science and Technology"],
    ".ncst.edu.cn": ["North China University of Science and Technology", "华北理工大学"],
    ".ncu.edu.cn": ["Nanchang University"],
    ".ncut.edu.cn": ["North China University of Technology"],
    ".neau.edu.cn": ["Northeast Agricultural University"],
    ".nenu.edu.cn": ["Northeast Normal University"],
    ".neu.edu.cn": ["Northeastern University"],
    ".neuq.edu.cn": ["Northeast University at Qinhuangdao Campus"],
    ".neusoft.edu.cn": ["Dalian Neusoft Institute Of Information"],
    ".nit.edu.cn": ["Nanchang Institute Of Technology"],
    ".njau.edu.cn": ["Nanjing Agricultural University"],
    ".njfu.edu.cn": ["Nanjing Forestry University"],
    ".njit.edu.cn": ["Nanjing Institute of Technology"],
    ".njmu.edu.cn": ["Nanjing Medical University"],
    ".njnu.edu.cn": ["Nanjing Normal University"],
    ".njtech.edu.cn": ["Nanjing Tech University"],
    ".njtu.edu.cn": ["Northern Jiaotong University"],
    ".nju.edu.cn": ["Nanjing University"],
    ".njupt.edu.cn": ["Nanjing University of Posts and Telecommunications"],
    ".njust.edu.cn": ["Nanjing University of Science and Technology"],
    ".njutcm.edu.cn": ["Nanjing University of Traditional Chinese Medicine"],
    ".st.njxzc.edu.cn": ["Nanjing Xiaozhuang University"],
    ".njxzc.edu.cn": ["Nanjing Xiaozhuang University"],
    ".nottingham.edu.cn": ["University of Nottingham Ningbo China"],
    ".ntu.edu.cn": ["nantong university"],
    ".nuaa.edu.cn": ["Nanjing University of Aeronautics and Astronautics"],
    ".nuc.edu.cn": ["North University of China"],
    ".nudt.edu.cn": ["National University of Defense Technology"],
    ".nufe.edu.cn": ["Nanjing University of Finance and Economics", "南京财经大学"],
    ".nuist.edu.cn": ["Nanjing University of Information Science and Technology"],
    ".nuit.edu.cn": ["Neusoft Institute Guangdong"],
    ".stu.nun.edu.cn": ["北方民族大学", "North Minzu University"],
    ".nwafu.edu.cn": ["Northwest A&F University"],
    ".nwnu.edu.cn": ["Northwest Normal University Lanzhou"],
    ".mail.nwpu.edu.cn": ["西北工业大学", "Northwestern Polytechnical University"],
    ".nwpu.edu.cn": ["Northwest Polytechnical University Xi'an"],
    ".nwsuaf.edu.cn": ["Northwest A&F University"],
    ".nwu.edu.cn": ["Northwest University Xi'an"],
    ".nxu.edu.cn": ["Ningxia University"],
    ".ouc.edu.cn": ["Ocean University of China"],
    ".pku.edu.cn": ["Peking University"],
    ".qau.edu.cn": ["Qingdao Agricultural University"],
    ".qdu.edu.cn": ["Qingdao University"],
    ".qfnu.edu.cn": ["Qufu Normal University"],
    ".qhnu.edu.cn": ["Qinghai Normal University"],
    ".qhu.edu.cn": ["Qinghai University"],
    ".qlu.edu.cn": ["Qilu university of Technology"],
    ".qust.edu.cn": ["Qingdao University of Science and Technology"],
    ".ruc.edu.cn": ["Renmin University of China"],
    ".sandau.edu.cn": ["Shanghai Sanda University"],
    ".sbs.edu.cn": ["Shanghai Business School"],
    ".scau.edu.cn": ["South China Agricultural University"],
    ".scnu.edu.cn": ["South China Normal University"],
    ".scu.edu.cn": ["Sichuan University"],
    ".scuec.edu.cn": ["South-Central University for Nationalities"],
    ".mail.scut.edu.cn": ["华南理工大学", "South China University of Technology"],
    ".scut.edu.cn": ["South China University of Technology"],
    ".sdau.edu.cn": ["Shandong Agricultural University"],
    ".sdcit.edu.cn": ["Shandong College of Information Technology", "山东信息职业技术学院"],
    ".sdjtu.edu.cn": ["Shandong Jiaotong University"],
    ".sdju.edu.cn": ["Shanghai Dainji University"],
    ".sdmu.edu.cn": ["Shandong Medical University"],
    ".sdnu.edu.cn": ["Shandong Normal University"],
    ".sdpt.edu.cn": ["顺德职业技术学院", "ShundePolyTechnic"],
    ".sdu.edu.cn": ["Shandong University"],
    ".sdust.edu.cn": ["Shandong University of Science and Technology", "山东科技大学"],
    ".sdut.edu.cn": ["Shandong University of Technology"],
    ".sdutcm.edu.cn": ["Shandong University of Triaditional Chinese Medicine"],
    ".sdyu.edu.cn": ["SHANDONG YOUTH UNIVERITY OF POLITICAL SCIENCE"],
    ".seu.edu.cn": ["Southeast University"],
    ".sgu.edu.cn": ["Shaoguan University"],
    ".shanghaitech.edu.cn": ["ShanghaiTech University"],
    ".shcc.edu.cn": ["上海海关学院", "Shanghai Customs College"],
    ".shfu.edu.cn": ["Shanghai Fisheries University"],
    ".shiep.edu.cn": ["Shanghai University of Electric Power"],
    ".shisu.edu.cn": ["Shanghai International Studies University"],
    ".shmtu.edu.cn": ["Shanghai Maritime University"],
    ".shmu.edu.cn": ["Shanghai Medical University"],
    ".smail.shnu.edu.cn": ["Shanghai Normal University"],
    ".shou.edu.cn": ["ShangHai Ocean University"],
    ".shsmu.edu.cn": ["Shanghai Second Medical University"],
    ".shtu.edu.cn": ["Shanghai Normal University"],
    ".shtvu.edu.cn": ["Shanghai Television University"],
    ".shu.edu.cn": ["Shanghai University"],
    ".shufe.edu.cn": ["Shanghai University of Finance and Economics"],
    ".shupl.edu.cn": ["Shanghai University of Political Science and Law"],
    ".shutcm.edu.cn": [
        "Shanghai University of Traditional Chinese Medicine and Pharmacology"
    ],
    ".sicau.edu.cn": ["Sichuan Agricultural University"],
    ".sicnu.edu.cn": ["Sichuan Normal University"],
    ".sisu.edu.cn": ["Sichuan International Studies University"],
    ".sjtu.edu.cn": ["Shanghai Jiaotong University"],
    ".sjzu.edu.cn": ["Shenyang Jianzhu University"],
    ".smbu.edu.cn": ["ShenZhen MSU-BIT University", "深圳北理莫斯科大学"],
    ".smmu.edu.cn": ["2nd Military Medical University"],
    ".smu.edu.cn": [
        "Official website: http://www.smu.edu.cn/",
        "Student mailbox login page: http://mail.smu.edu.cn/",
    ],
    ".snnu.edu.cn": ["Shaanxi Normal University", "Shanxi Normal University"],
    ".stu.sspu.edu.cn": ["Shanghai Second Polytechnic University"],
    ".stu.edu.cn": ["Shantou University"],
    ".suda.edu.cn": ["Suzhou University"],
    ".sues.edu.cn": ["Shanghai University of Engineering Science"],
    ".163.sufe.edu.cn": ["Shanghai University of Finance and Economics"],
    ".live.sufe.edu.cn": ["Shanghai University of Finance and Economics"],
    ".suibe.edu.cn": ["Shanghai University of International Business and Economics"],
    ".sustc.edu.cn": [
        "南方科技大学",
        "Southern University of Science and Technology",
        "SUSTech",
        "South University of Science and Technology of China",
    ],
    ".sustech.edu.cn": [
        "南方科技大学",
        "Southern University of Science and Technology",
        "SUSTech",
        "South University of Science and Technology of China",
    ],
    ".swjtu.edu.cn": ["Southwest Jiaotong University"],
    ".swpu.edu.cn": ["Southwest Petroleum University"],
    ".swu.edu.cn": ["Southwest University"],
    ".swufe.edu.cn": ["Southwest University of Finance and Economics"],
    ".swupl.edu.cn": ["Southwest University of Political Science and Law"],
    ".swust.edu.cn": ["Southwest University of Science and Technology"],
    ".sxau.edu.cn": ["Shanxi Agricultural University"],
    ".sxie.edu.cn": ["山西能源学院", "Shanxi Institute of Energy"],
    ".sxu.edu.cn": ["Shanxi University"],
    ".syphu.edu.cn": ["Shenyang Pharmaceutical University"],
    ".mail2.sysu.edu.cn": ["Sun Yat-sen University"],
    ".mail3.sysu.edu.cn": ["Sun Yat-Sen University"],
    ".sysu.edu.cn": ["Sun Yat-Sen University"],
    ".syu.edu.cn": ["Shenyang University"],
    ".st.sziit.edu.cn": ["Shenzhen Institute of Information Technology"],
    ".mail.szpt.edu.cn": ["Shenzhen Polytechnic"],
    ".szu.edu.cn": ["Shenzhen University"],
    ".tijmu.edu.cn": ["Tianjin Medical University"],
    ".tjcu.edu.cn": ["Tianjin University of Commerce"],
    ".tjmu.edu.cn": ["Tongji Medical University"],
    ".tjnu.edu.cn": ["Tianjin Normal University"],
    ".tjpu.edu.cn": ["Tianjin Polytechnic University"],
    ".tjrtvu.edu.cn": ["Tianjin Open University"],
    ".tju.edu.cn": ["Tianjin University"],
    ".tjufe.edu.cn": ["Tianjin University of Finance &amp; Economics"],
    ".tjut.edu.cn": ["Tianjin University of Technology"],
    ".tmmu.edu.cn": ["3rd Military Medical University"],
    ".tmu.edu.cn": ["Tianjin Medical University"],
    ".tongji.edu.cn": ["Tongji University"],
    ".tsinghua.edu.cn": ["Tsinghua University"],
    ".mail.tust.edu.cn": ["Tianjin University of Science&Technology"],
    ".tynu.edu.cn": ["Taiyuan Normal University."],
    ".stu.tyust.edu.cn": ["Taiyuan University of Science and Technology"],
    ".tyut.edu.cn": ["Taiyuan University of Technology"],
    ".ucas.edu.cn": ["University of Chinese Academy of Sciences"],
    ".ucass.edu.cn": ["University of Chinese Academy of Social Sciences"],
    ".uestc.edu.cn": ["University of Electronic Science and Technology of China"],
    ".uibe.edu.cn": ["University of International Business and Economics"],
    ".mail.ujn.edu.cn": ["University of Jinan", "ujn.edu.cn", "济南大学"],
    ".ujn.edu.cn": ["University of Jinan"],
    ".stmail.ujs.edu.cn": ["Jiangsu University"],
    ".ujs.edu.cn": ["Jiangsu University"],
    ".s.upc.edu.cn": ["China University of Petroleum-Huadong"],
    ".upc.edu.cn": ["China University of Petroleum-Huadong"],
    ".usc.edu.cn": ["South China University"],
    ".usst.edu.cn": ["Shanghai University of Science and Technology"],
    ".ustb.edu.cn": [
        "Beijing University of Science and Technology",
        "University of Science and Technology Beijing",
    ],
    ".mail.ustc.edu.cn": ["University of Science and Technology of China"],
    ".ustc.edu.cn": ["University of Science and Technology of China"],
    ".usth.edu.cn": ["Heilongjiang University of science and technology"],
    ".usts.edu.cn": ["Suzhou University of Science and Technology"],
    ".utibet.edu.cn": ["Tibet University"],
    ".uvu.edu.cn": ["Urumqi Vocational University"],
    ".whu.edu.cn": [
        "Wuhan University",
        "Computer School of Wuhan University",
        "Wuhan University School of Medicine",
    ],
    ".whut.edu.cn": ["Wuhan University of Technology"],
    ".wmu.edu.cn": ["Wenzhou Medical University"],
    ".wsyu.edu.cn": ["Wuchang Shouyi University", "武昌首义学院", "华中科技大学武昌分校"],
    ".wtu.edu.cn": ["Wuhan Textile University"],
    ".wust.edu.cn": ["Wuhan University of Science and Technology"],
    ".wyu.edu.cn": ["Wuyi University"],
    ".xaau.edu.cn": ["Xi’an Aeronautical University", "西安航空学院"],
    ".xahu.edu.cn": ["Xi'an Highway University"],
    ".xauat.edu.cn": ["Xi'an University of Architecture and Technology"],
    ".xaut.edu.cn": ["Xi'an University of Technology"],
    ".xhcom.edu.cn": ["Xinghai Conservatory of Music"],
    ".xhu.edu.cn": ["Xihua University"],
    ".stu.xidian.edu.cn": ["Xidian University"],
    ".xidian.edu.cn": ["Xi'an University of Electronic Science and Technology"],
    ".xiyou.edu.cn": ["Xi’an University of Posts and Telecommunications"],
    ".xjau.edu.cn": ["Xinjiang Agriculture University"],
    ".xjnu.edu.cn": ["Xinjiang Normal University"],
    ".student.xjtlu.edu.cn": ["Xi'an Jiaotong Liverpool University"],
    ".xjtu.edu.cn": ["Xi'an Jiaotong University"],
    ".xju.edu.cn": ["Xinjiang University"],
    ".stu.xmu.edu.cn": ["Xiamen University"],
    ".xmu.edu.cn": ["Xiamen University"],
    ".stu.xmut.edu.cn": ["Xiamen University Of Technology"],
    ".xsyu.edu.cn": ["西安石油大学", "Xi’an Shiyou University "],
    ".xtu.edu.cn": ["Xiangtan University"],
    ".stu.xupt.edu.cn": [None],
    ".xupt.edu.cn": ["Xi’an University of Posts and Telecommunications"],
    ".xust.edu.cn": ["Xi'an University of Science and Technology"],
    ".xxu.edu.cn": ["Xinxiang University"],
    ".yau.edu.cn": ["延安大学", "Yanan University"],
    ".ynu.edu.cn": ["Yunnan University"],
    ".ysu.edu.cn": ["Yanshan University"],
    ".yzu.edu.cn": ["Yangzhou University"],
    ".zbti.edu.cn": ["Zhejiang Business Technology Institute"],
    ".zjgsu.edu.cn": ["Zhejiang Gongshang University"],
    ".zjnu.edu.cn": ["Zhejiang Normal University"],
    ".zju.edu.cn": ["Zhejiang University, Hangzhou, China", "浙江大学，中国杭州"],
    ".zjut.edu.cn": ["ZheJiang University of Technology"],
    ".zjvtit.edu.cn": ["Zhejiang Institute of Communications", "浙江交通职业技术学院"],
    ".stu.zjweu.edu.cn": [
        "\ufeffZhejiang University of Water Resources and Electric Power",
        "浙江水利水电学院",
    ],
    ".zknu.edu.cn": ["ADD Zhoukou Normal University"],
    ".zqu.edu.cn": ["ZHAOQING UNIVERSITY", "肇庆学院"],
    ".zsc.edu.cn": [
        "\ufeffUniversity of Electronic Science and Technology of China，Zhongshan Institute"
    ],
    ".stu.zucc.edu.cn": ["Zhejiang University City College", "浙江大学城市学院"],
    ".zucc.edu.cn": ["Zhejiang University City College", "浙江大学城市学院"],
    ".zuel.edu.cn": ["Zhongnan University of Economics and Law"],
    ".zufe.edu.cn": ["Zhejiang University of Finance & Economic, Hangzhou, China"],
    ".zust.edu.cn": ["Zhejiang University of Science & Technology", "浙江科技学院(浙江科技大学)"],
    ".zut.edu.cn": ["  Zhongyuan University of Technology (ZUT)"],
    ".zyufl.edu.cn": ["ZheJiang YueXiu University", "浙江越秀外国语学院"],
    ".zzu.edu.cn": ["Zhengzhou University"],
    ".zzuli.edu.cn": ["Zhengzhou University of light industry"],
    ".gdcp.cn": ["Guangdong Communication Polytechnic"],
    ".gnnu.cn": ["Gannan Normal University"],
    ".gyu.cn": ["Guiyang University"],
    ".xs.gzcc.cn": ["广州商学院", "Guangzhou College of  Commerce"],
    ".gzmhxy.cn": ["贵州民用航空职业学院"],
    ".harrowbeijing.cn": ["北京哈罗国际学校", "Harrow International School Beijing"],
    ".mail.hniu.cn": ["湖南信息职业技术学院", "Hunan College of Information"],
    ".hsefz.cn": ["华东师范大学第二附属中学", "No.2 High School of East China Normal University"],
    ".stu.ccit.js.cn": ["常州信息职业技术学院", "ChangZhou College Of Information Technology"],
    ".ecjtu.jx.cn": ["East China Jiao Tong University"],
    ".jxvc.jx.cn": ["江西财经职业学院", "Jiangxi Vocational College of Finance and Economis"],
    ".stu.jxufe.cn": ["Jiangxi University of Finance and Economics"],
    ".lut.cn": ["LanZhou University Of Technology"],
    ".nbcc.cn": ["NingBo City College Of Vacational Technology"],
    ".nit.net.cn": ["Ningbo Institute of Technology. Zhejiang University"],
    ".shouhua.net.cn": ["Shanghai Ouhua Vocational Technical College"],
    ".tjbhzy.net.cn": ["TIANJIN BOHAI VOCATIONAL TECHNOLOGY COLLEGE"],
    ".zjbti.net.cn": ["Zhejiang Business Technology Institute"],
    ".nj13z.cn": ["南京市第十三中学", "Nanjing No.13 Middle School"],
    ".njcit.cn": ["Nanjing Collage Of Information Technology"],
    ".sis.org.cn": [
        "Shekou International School",
        "蛇口国际学校",
        "URL: https://www.sis-shekou.org/",
    ],
    ".sdcet.cn": ["山东电子职业技术学院", "SHANDONG COLLEGE OF ELECTRONIC TECHNOLOGY"],
    ".sia.cn": [
        "中国科学院沈阳自动化研究所",
        "SHENYANG INSTITUTE OF AUTOMATION, CHINESE ACADEMY OF SCIENCES",
    ],
    ".tsinglan.cn": ["清阑山学校", "Tsinglan School"],
    ".mail.tust.cn": ["Tianjin University of Science and Technology"],
    ".ybzy.cn": ["YiBin Vocational And Technical College"],
    ".ykpaoschool.cn": ["YK Pao School", "YK Pao School"],
    ".yznu.cn": ["Yangtze Normal University"],
    ".zimc.cn": ["Zhejiang International Maritime College"],
    ".stu.zjweu.cn": [
        "Zhejiang University of Water Resources and Electric Power",
        "浙江水利水电学院",
    ],
    ".colc.co": ["The City of Liverpool College"],
    ".cyberacademy.co": ["Cyber Academy"],
    ".dallam.co": [],
    ".americana.edu.co": ["corporación universitaria americana"],
    ".amigo.edu.co": ["Universidad Católica Luis Amigó"],
    ".estudiantes.areandina.edu.co": ["Fundación Universitaria del Área Andina"],
    ".artesyletras.edu.co": ["Escuela de Artes y Letras", "School of Arts and Letters"],
    ".asys.edu.co": ["Corporacion Universitaria Remington "],
    ".aunarvillavicencio.edu.co": [None],
    ".autonoma.edu.co": ["Universidad Autónoma de Manizales"],
    ".bellasartes.edu.co": ["Universidad Bellas Artes"],
    ".campusucc.edu.co": [
        "Universidad Cooperativa De Colombia",
        "Cooperative University of Colombia",
        "UCC",
    ],
    ".cecar.edu.co": ["Coorporacion Universitaria del Caribe - CECAR"],
    ".ces.edu.co": ["Universidad CES"],
    ".cesa.edu.co": ["Colegio de Estudios Superiores de Administración - CESA"],
    ".cgb.edu.co": ["\ufeffColegio Gran Bretaña"],
    ".colegionuevocampestre.edu.co": ["colegio nuevo campestre", "new country school"],
    ".colmabrija.edu.co": [
        "Instituto Técnico Padre Manuel Briceño Jauregui Fe y Alegría"
    ],
    ".colmayor.edu.co": ["Colegio Mayor de Antioquia", "Colegio Mayor de Antioquia"],
    ".coreducacion.edu.co": [
        "Coreducación – Patrimonio Educativo Regional Honda Tolima"
    ],
    ".corhuila.edu.co": ["Corporación Universitaria del Huila - Corhuila"],
    ".correounivalle.edu.co": ["Universidad del Valle"],
    ".coruniamericana.edu.co": ["Corporación Universitaria Americana"],
    ".cotecnova.edu.co": [
        "Corporación de Estudios Tecnológicos del Norte del Valle",
        "North Valley Technological Studies Corporation",
    ],
    ".cuc.edu.co": ["Corporación Universitaria de la Costa (UNICOSTA)"],
    ".cues.edu.co": ["Corporacion Universitaria Empresarial de Salamanca"],
    ".cun.edu.co": ["Corporación Unificada Nacional de Educación Superior CUN"],
    ".curnvirtual.edu.co": [
        "Corporacion Universitaria Rafael Nuñez",
        "Universitary Coporation Rafael Nunez",
    ],
    ".eafit.edu.co": ["Universidad EAFIT"],
    ".eam.edu.co": ["EAM", "EAM"],
    ".ean.edu.co": ["Escuela de Administración de Negocios"],
    ".ecci.edu.co": ["Escuela Colombiana de Carreras Industriales"],
    ".ecr.edu.co": ["Fundacion Escuela Colombiana de Rehabiliación"],
    ".eia.edu.co": ["Escuela de Ingeniería de Antioquia"],
    ".elpoli.edu.co": [
        "Institución universitaria Politécnico Colombiano Jaime Isaza Cadavid"
    ],
    ".esap.edu.co": ["Escuela Superiore de Administración Pública"],
    ".escuelaing.edu.co": ["Escuela Colombiana de Ingeniería Julio Garavito"],
    ".estudiantesunibague.edu.co": ["Universidad de Ibague"],
    ".fet.edu.co": ['FET Fundación Escuela Tecnológica De Neiva "Jesús Oviedo Perez"'],
    ".fuac.edu.co": ["Universidad Autónoma de Colombia"],
    ".fumc.edu.co": ["FUNDACIÓN UNIVERSITARIA MARIA CANO"],
    ".funlam.edu.co": ["Fundación Universitaria Luis Amigó"],
    ".granadino.edu.co": ["Colegio Granadino"],
    ".ibero.edu.co": ["Corporacion Universitaria Iberoamericana "],
    ".iberoamericana.edu.co": ["Institución Universitaria Iberoamericana"],
    ".icesi.edu.co": ["Universidad ICESI"],
    ".inalde.edu.co": ["INALDE Business School"],
    ".inemjose.edu.co": ["Institucion Educativa INEM Jose Felix de Restrepo"],
    ".institutocenis.edu.co": ["Instituto cenis de colombia"],
    ".institutosanrafael.edu.co": ["Instituto Técnico San Rafael"],
    ".isc.edu.co": [
        "Instituto San Carlos de la Salle",
        "Institut San Carlos de la Salle",
    ],
    ".itc.edu.co": ["Escuela Tecnológica Instituto Técnico Central"],
    ".itm.edu.co": ["Instituto Tecnológico Metropolitano"],
    ".itp.edu.co": ["Instituto Tecnológico del Putumayo"],
    ".est.iudigital.edu.co": [
        "IUDigital De Antioquia",
        "Website: https://www.iudigital.edu.co/Paginas/default.aspx",
        "Software Development: https://www.iudigital.edu.co/OfertaEducativa/Paginas/Tecnologia-en-Desarrollo-de-Software.aspx",
    ],
    ".iue.edu.co": ["Institucion Universitaria de Envigado"],
    ".comunidad.iush.edu.co": ["Universidad Salazar y herrera"],
    ".javeriana.edu.co": ["Pontificia Universidad Javeriana"],
    ".javerianacali.edu.co": ["Pontificia Universidad Javeriana Cali"],
    ".jdc.edu.co": ["Fundación Universitaria Juan De Castellanos"],
    ".jefferson.edu.co": ["Colegio Jefferson", "Jefferson school"],
    ".konradlorenz.edu.co": [],
    ".lakhumbre.edu.co": ["GLK Gimnasio la Khumbre", "Khumbre"],
    ".lasalle.edu.co": ["Universidad de La Salle"],
    ".lasierra.edu.co": ["Fundación Instituto Técnico de la Sierra"],
    ".libertadores.edu.co": [
        " Fundación Universitaria Los Libertadores",
        " Fundacion Universitaria Los Libertadores",
    ],
    ".miremington.edu.co": [
        "Corporación Universitaria Remington",
        "University Corporation Remington",
    ],
    ".misena.edu.co": ["Servicio Nacional de Aprendizaje SENA"],
    ".pascualbravo.edu.co": ["Institución universitaria Pascual Bravo"],
    ".pca.edu.co": ["Politécnico de la costa atlántica"],
    ".pedagogica.edu.co": ["Universidad Pedagogica Nacional"],
    ".poligran.edu.co": ["Politécnico Grancolombiano - Institución Universitaria"],
    ".sanmartin.edu.co": ["Fundación Universitaria San Martín"],
    ".sanmateo.edu.co": [
        " Fundación Universitaria San Mateo",
        " Fundación Universitaria San Mateo",
    ],
    ".sena.edu.co": [
        "Servicio Nacional de Aprendizaje SENA",
        "National Learning Service SENA",
    ],
    ".sgs.edu.co": ["Saint George School"],
    ".soyucn.edu.co": ["Universidad Católica del Norte"],
    ".soyudemedellin.edu.co": ["Universidad De Medellín", "University of Medellín"],
    ".systemplus.edu.co": [
        "SystemPlus - Red Nacional de Educación ",
        "SystemPlus - National Education Network ",
    ],
    ".correo.tdea.edu.co": ["Tecnologico de Antioquia"],
    ".tecnocomfenalco.edu.co": ["Fundacion Universitaria Tecnologico Comfenalco"],
    ".teinco.edu.co": ["Corporación Tecnológica Industrial Colombiana – TEINCO"],
    ".uac.edu.co": ["Universidad Autónoma del Caribe"],
    ".uam.edu.co": ["Universidad Autónoma de Las Américas"],
    ".uamerica.edu.co": ["Universidad de América Bogotá"],
    ".uan.edu.co": ["Universidad Antonio Narino"],
    ".uao.edu.co": [
        "Universidad Autonoma de Occidente",
        "Universidad Autonoma de Occidente",
    ],
    ".ucaldas.edu.co": ["Universidad de Caldas"],
    ".ucatolica.edu.co": ["Universidad Católica de Colombia"],
    ".ucauca.edu.co": ["Universidad del Cauca"],
    ".ucc.edu.co": ["Universidad Cooperativa de Colombia"],
    ".ucentral.edu.co": ["Universidad Central"],
    ".uceva.edu.co": ["Universidad Central del Valle del Cauca"],
    ".ucn.edu.co": ["Universidad Católica del Norte"],
    ".uco.edu.co": ["Universidad Católica del Oriente"],
    ".ucompensar.edu.co": ["Fundación Universitaria Compensar"],
    ".ucp.edu.co": ["Universidad Católica de Pereira", "https://www.ucp.edu.co/"],
    ".ucundinamarca.edu.co": [
        "Universidad de Cundianamarca",
        "University of Cundinamarca",
    ],
    ".udca.edu.co": ["Universidad de Ciencias Aplicadas y Ambientales (UDCA)"],
    ".udea.edu.co": ["Universidad de Antioquia", "Universidad de Antioquía"],
    ".udem.edu.co": ["Universidad de Medellín"],
    ".udenar.edu.co": ["Universidad de Nariño"],
    ".udes.edu.co": ["Corporación Universitaria de Santander (UDES)"],
    ".udi.edu.co": ["Universidad de investigación y desarrollo - UDI"],
    ".udistrital.edu.co": ["Universidad Distral Francisco José de Caldas"],
    ".udla.edu.co": ["Universidad de la Amazonia"],
    ".uexternado.edu.co": ["Universidad Externado de Colombia"],
    ".ufps.edu.co": ["Universidad Francisco de Paula Santander"],
    ".ufpso.edu.co": [
        "\ufeffUniversidad Francisco de Paula Santander Ocaña, Norte de Santander - Colombia"
    ],
    ".uis.edu.co": ["Universidad Industrial de Santander"],
    ".ul.edu.co": ["Corporación Universitaria Latinoamericana"],
    ".umanizales.edu.co": ["Universidad de Manizales"],
    ".umariana.edu.co": ["Universidad Mariana"],
    ".umb.edu.co": ["Fundación Universitaria Manuela Beltrán"],
    ".umng.edu.co": ["Universidad Militar Nueva Granada"],
    ".unab.edu.co": ["Universidad Autónoma de Bucaramanga"],
    ".unac.edu.co": ["Universidad Adventista de Colombia"],
    ".unad.edu.co": ["Universidad Nacional Abierta y a Distancia"],
    ".unadvirtual.edu.co": ["Universidad Nacional Abierta y a Distancia"],
    ".unal.edu.co": ["Universidad Nacional de Colombia"],
    ".unaula.edu.co": ["Universidad Autónoma Latinoamericana"],
    ".unbosque.edu.co": ["Universidad El Bosque"],
    ".uniagraria.edu.co": ["Fundación Universitaria Agraria de Colombia"],
    ".uniagustiniana.edu.co": ["Uniagustiniana"],
    ".estudiante.uniajc.edu.co": ["institucion universitaria antonio jose camacho"],
    ".estudiantes.uniajc.edu.co": ["Institución Universitaria Antonio Jose Camacho"],
    ".profesores.uniajc.edu.co": [
        "Institución Universitaria Antonio Jose Camacho",
        "Antonio Jose Camacho University Institution",
    ],
    ".uniamazonia.edu.co": ["Universidad de La Amazonia"],
    ".uniandes.edu.co": ["Universidad de Los Andes"],
    ".uniatlantico.edu.co": ["Universidad del Atlántico"],
    ".uniautonoma.edu.co": ["Corporacion Universitaria Autonoma del Cauca"],
    ".unibague.edu.co": ["Universidad de Ibagué "],
    ".uniboyaca.edu.co": ["Fundación Universitaria de Boyacá"],
    ".unicartagena.edu.co": ["Universidad de Cartagena"],
    ".unicatolica.edu.co": ["unicatolica", "unicatolica"],
    ".unicauca.edu.co": ["Universidad del Cauca"],
    ".unicesar.edu.co": ["Universidad Popular del Cesar"],
    ".unicesmag.edu.co": ["Universidad Cesmag"],
    ".unicoc.edu.co": [
        "Institucion universitaria colegios de colombia",
        "University institution colleges of colombia",
    ],
    ".unicolmayor.edu.co": [
        "Universidad Colegio Mayor de Cundinamarca ",
        "University College of Cundinamarca",
    ],
    ".unicomfacauca.edu.co": ["Corporación Universitaria Comfacauca"],
    ".unicordoba.edu.co": ["Universidad de Córdoba"],
    ".uniempresarial.edu.co": [
        "fundacion empresarial de la camara de comercio de bogota"
    ],
    ".uniguajira.edu.co": ["Universidad de La Guajira"],
    ".unihorizonte.edu.co": [
        "Fundacion Universitaria Horizonte",
        "Fundacion Universitaria Horizonte",
    ],
    ".unilatina.edu.co": ["Institución Universitaria Latina Unilatina"],
    ".unilibre.edu.co": ["Universidad Libre de Colombia"],
    ".unilibrebog.edu.co": ["Universidad Libre de Colombia Bogota"],
    ".unilibrepereira.edu.co": ["Universidad Libre, Pereira"],
    ".unillanos.edu.co": ["Universidad de Los Llanos"],
    ".unimagdalena.edu.co": ["Universidad del Magdalena"],
    ".unimayor.edu.co": ["Institución Universitaria Colegio Mayor del Cauca"],
    ".academia.unimeta.edu.co": ["Corporación universitaria del Meta"],
    ".unimetro.edu.co": ["Universidad Metropolitana"],
    ".unimilitar.edu.co": [
        "Universidad Militar Nueva Granada",
        "Universidad Militar Nueva Granada",
    ],
    ".uniminuto.edu.co": ["Corporación Universitaria Minuto de Dios"],
    ".unimonserrate.edu.co": ["Fundación Universitaria Monserrate - Unimonserrate"],
    ".unincca.edu.co": ["Universidad INCCA de Colombia"],
    ".uninorte.edu.co": ["Universidad del Norte"],
    ".uninpahu.edu.co": [
        "UNINPAHU - Fundación Universitaria Para El Desarrollo Humano"
    ],
    ".unipacifico.edu.co": ["Universidad Del Pacifico", "unipacifico.edu.co"],
    ".unipamplona.edu.co": ["Universidad de Pamplona"],
    ".unipanamericana.edu.co": ["Fundación Universitaria Unipanamericana"],
    ".unipaz.edu.co": ["Instituto Universitario de La Paz"],
    ".unipiloto.edu.co": ["Universidad Piloto de Colombia"],
    ".uniquindio.edu.co": ["Universidad del Quindío"],
    ".uniremington.edu.co": ["uniremingtonmanizales", "uniremingtonmanizales"],
    ".uniremingtonmanizales.edu.co": ["Uniremington Manizales"],
    ".unisabana.edu.co": ["Universidad de La Sabana"],
    ".unisabaneta.edu.co": ["Corporación Universitaria de Sabaneta - UNISABANETA"],
    ".unisalle.edu.co": ["Universidad de la Salle", "La Salle university"],
    ".unisimon.edu.co": ["universidad simón bolívar "],
    ".unisimonbolivar.edu.co": [
        "Corporación Educativa Mayor del Desarrollo Simón Bolivar"
    ],
    ".unisinu.edu.co": ["Universidad del Sinú", "Sinú University "],
    ".unisinucartagena.edu.co": ["Universidad del Sinú"],
    ".unisucre.edu.co": ["Universidad de Sucre"],
    ".unitec.edu.co": ["Corporación Universitaria UNITEC"],
    ".unitecnar.edu.co": ["Unitecnar"],
    ".unitropico.edu.co": [
        "Fundación Universitaria Internacional del Trópico Americano UNITRÓPICO",
        "International University Foundation of the American Tropics UNITRÓPICO",
    ],
    ".univalle.edu.co": ["Universidad del Valle del Cauca"],
    ".universidadean.edu.co": ["universidad EAN", "EAN university"],
    ".upb.edu.co": ["Universidad Pontificia Bolivariana"],
    ".upc.edu.co": ["Universidad Piloto de Colombia Students email"],
    ".uptc.edu.co": ["Universidad Pedagógica y Tecnológica de Colombia"],
    ".uqvirtual.edu.co": ["\ufeffUniversidad del Quindío"],
    ".urosario.edu.co": ["Universidad del Rosario"],
    ".correo.usa.edu.co": ["Sergio Arboleda", "Sergio Arboleda"],
    ".usantoto.edu.co": ["Universidad Santo Tomás"],
    ".usantotomas.edu.co": ["Universidad Santo Tomás"],
    ".usb.edu.co": ["Universidad de San Buenaventura"],
    ".academia.usbbog.edu.co": ["Universidad de san buenaventura Bogotá"],
    ".usbcali.edu.co": ["Universidad de San Buenaventura Cali"],
    ".tau.usbmed.edu.co": ["Universidad de San Buenaventura"],
    ".usc.edu.co": ["Universidad Santiago de Cali"],
    ".usco.edu.co": ["Universidad Surcolombiana", "Surcolombian university"],
    ".usergioarboleda.edu.co": ["Universidad Sergio Arboleda"],
    ".usta.edu.co": ["Universidad Santo Tomás"],
    ".ustadistancia.edu.co": ["Universidad Santo Tomas", "Santo Tomas University"],
    ".ut.edu.co": ["Universidad del Tolima"],
    ".utadeo.edu.co": ["Universidad de Bogotá Jorge Tadeo Lozano"],
    ".utb.edu.co": [
        "Universidad Tecnológica de Bolivar",
        "Technological University of Bolivar",
    ],
    ".utch.edu.co": ["Universidad Tecnológica del Choco Diego Luis Cordoba"],
    ".utp.edu.co": ["Universidad Tecnológica de Pereira"],
    ".uts.edu.co": ["Unidades tecnologicas de santander"],
    ".uvirtual.edu.co": ["Universidad Virtual Internacional"],
    ".uco.net.co": ["Universidad Católica de Oriente"],
    ".uckfield.college": ["Uckfield College", "www.uckfield.college"],
    ".125su.com": ['125 СУ "Боян Пенев"', '125 SU "Boqn Penev"'],
    ".2els.com": [
        'Second English Language School "Thomas Jefferson"',
        'Second English Language School "Thomas Jefferson"',
    ],
    ".2isa.com": [
        "Institut Informatique Sud Aveyron",
        "Website: http://www.2isa.com/",
        "trainers emails at @2isa.com for example gg@2isa.com",
        "student emails at @2isa.org for example sergey.epifanov@2isa.org",
    ],
    ".42quebec.com": ["42 Québec"],
    ".a-s-b.com": ["American School of Barcelona"],
    ".abmcollege.com": ["ABM College"],
    ".accitesz.com": [
        "Instituto Tecnologico de Estudios Superiores de Zamora",
        "Technological Institute of Superior Studies of Zamora",
    ],
    ".aclcbukidnon.com": ["ACLC Bukidnon", "AMA Computer Learning Center Bukidnon"],
    ".actonlascruces.com": ["Acton Academy Mesilla Valley"],
    ".adenformations.com": ["ADEN Formations"],
    ".adithyatech.com": ["Adithya Institute Of Technology"],
    ".aedu.com": ["Anhanguera University"],
    ".aemaia.com": ["Escola Secundária da Maia"],
    ".aescolasalpendorada.com": [
        "Agrupamento de Escolas de Alpendorada",
        "Alpendorada School Cluster",
    ],
    ".afip-formations.com": ["AFIP FORMATIONS", "AFIP FORMATIONS"],
    ".agenlaacademy.com": ["Agenla Academy Institute", "Agenla Academy Institute"],
    ".agk88.com": ["Adana Gündoğdu Koleji", "Adana Gundogdu College"],
    ".agmrcet.com": ["A G M R College of Engineering and Technology"],
    ".ahlulbaitonline.com": ["Ahlulbait International University"],
    ".ahschool.com": ["American Heritage School"],
    ".algonquincollege.com": ["Algonquin College"],
    ".algonquinlive.com": ["Algonquin College"],
    ".allianceinternationalschool.com": ["alliance international school"],
    ".almaarifah.com": ["Knowledge International University"],
    ".alorubaschools.com": ["Al Oruba International Schools"],
    ".alueducation.com": ["African Leadership University"],
    ".alunouninter.com": ["Centro Universitário Internacional Uninter"],
    ".alustudent.com": ["African Leadership University"],
    ".amityonline.com": ["Amity University"],
    ".amrolicollege.com": ["AMROLI COLLEGE"],
    ".anangpuria.com": ["B.S. ANANGPURIA INSTITUTE OF TECHNOLOGY AND MANAGEMENT"],
    ".andela.com": ["Andela"],
    ".anhanguera.com": ["Universidade Anhanguera"],
    ".animashighschool.com": ["Animas High School"],
    ".aoltoronto.com": [
        "Academy of Learning Bay/Queen",
        "Academy of Learning Bay/Queen",
    ],
    ".armypublicschoolagra.com": ["Army Public School"],
    ".artidisseny.com": ["Escola Municipal d'Art de Terrassa"],
    ".ashtoncollege.com": ["Ashton College"],
    ".asoiu.com": ["ASIPM department, Omsk State Technical University"],
    ".aston-ecole.com": ["Aston Ecole", "Aston School"],
    ".atc2u.com": ["Advance Tertiary College"],
    ".audencia.com": ["Audencia Nantes - School of management"],
    ".students.aula-ee.com": ["Aula Escola Europea Students"],
    ".aula-ee.com": ["Aula Escola Europea"],
    ".ausiasmarch.com": [
        "Colegio Internacional Ausias March",
        "https://www.ausiasmarch.com",
    ],
    ".st.bcc1852.com": ["Bangkok Christian College"],
    ".students.berlinsbi.com": ["Berlin School of Business and Innovation (BSBI)"],
    ".bernardsboe.com": ["Bernards Township School District"],
    ".bic-benal.com": ["The Benalmádena International College"],
    ".bis-school.com": ["Bavarian International School"],
    ".bishopstopford.com": ["Bishop Stopford School"],
    ".bj35.com": ["No.35 high school of Beijing"],
    ".bluecoatschool.com": ["Blue Coat C of E School Coventry"],
    ".bmcmedcollege.com": ["Al-Batterjee Medical College"],
    ".bohuntwokingham.com": ["Bohunt School Wokingham"],
    ".bosworthcollege.com": ["Bosworth Independent College"],
    ".bothouniversity.com": ["Botho Univerisity"],
    ".bpitindia.com": ["Bhagwan Parshuram Institute of Technology"],
    ".bpp.com": ['"BPP" '],
    ".bramptoncollege.com": ["Brampton College"],
    ".brest-opencampus.com": ["brest-opencampus"],
    ".breyerstate.com": ["Breyer State University (Virtual University)"],
    ".brownsburgstudents.com": ["Brownsburg High School"],
    ".bsb-education.com": ["Burgundy School of Business"],
    ".buchananschools.com": ["Buchanan Community Schools"],
    ".buraouniversity.com": ["University of Burao"],
    ".burntwoodschool.com": ["Burntwood School"],
    ".burygrammar.com": ["Bury Grammar School"],
    ".bwscampus.com": ["Brentwood School"],
    ".c-isd.com": ["Cleburne Independent School District"],
    ".campus-cd.com": ["EPSI", "EPSI"],
    ".campus-id.com": ["Campus Id"],
    ".campus-numerique-in-the-alps.com": ["Campus Numérique In The Alps"],
    ".campusaula.com": ["Aula Campus"],
    ".canadahanson.com": ["Hanson College"],
    ".canadiancollege.com": ["Canadian College"],
    ".canford.com": ["Independent Co-educational Boarding Dorset UK | Canford School"],
    ".careerdevs.com": ["CareerDevs Computer Science University", "CareerDevs"],
    ".carrollwooddayschool.com": ["Carrollwood Day School"],
    ".cchsrams.com": ["Central Catholic High School"],
    ".ccndpr.com": ["Colegio Cat�lico Notre Dame"],
    ".ccsdschools.com": ["Charleston County School District, South Carolina"],
    ".cdsantodomingo.com": ["Colegio Diocesano Santo Domingo"],
    ".centralcatholichs.com": ["Central Catholic High School, Pittsburgh Pennsylvania"],
    ".centrosanluis.com": ["Centro San Luis"],
    ".ceste.com": ["CESTE, Escuela Internacional de Negocios"],
    ".cesurformacion.com": ["CESUR FORMACIÓN"],
    ".cev.com": ["CEV"],
    ".cfedundrum.com": ["Dundrum College of Further Education"],
    ".cfpj.com": ["Centre de Formation et de Perfectionnement des Journalistes"],
    ".chapeltownacademy.com": ["Chapeltown Academy"],
    ".chethams.com": ["Chetham's School of Music"],
    ".chippingsodburyschool.com": ["Chipping Sodbury School"],
    ".chrysalis-school.com": ["Chrysalis School"],
    ".churcherscollege.com": ["  Churcher's College"],
    ".cic-cairo.com": ["Canadian International College"],
    ".cieep.com": ["Centro de formación Profesional Progresa Formación"],
    ".cifacom.com": ["Cifacom"],
    ".clarendonacademy.com": ["Clarendon Academy"],
    ".cmscbe.com": ["CMS College of Science & Commerce"],
    ".codecool.com": ["Code Cool", "Code Cool"],
    ".colegioirlandesas.com": ["Colegio irlandesas", "Irish school "],
    ".colegiolitterator.com": ["Colegio Litterator"],
    ".colegiovivas.com": ["Colegio Vivas "],
    ".collegecanada.com": ["Canada College / Collège Canada"],
    ".collegelasalle.com": ["LaSalle College / Collège LaSalle"],
    ".collierschools.com": ["Collier County Schools"],
    ".columbushs.com": ["Christopher Columbus High School"],
    ".columbusu.com": ["Columbus University"],
    ".comcave.com": ["Comcave College"],
    ".confetti-live.com": ["Confetti Institute of Creative Technologies"],
    ".coppellisd.com": ["Coppell Independent School District", "Coppell High School"],
    ".coresteam.com": ["Core School"],
    ".cpilosenlaces.com": [
        "Centro Público Integrado de Formación Profesional Los Enlaces",
        "Integrated Public Vocational Training Center",
    ],
    ".cpschools.com": ["Chesapeake Public Schools", ".group"],
    ".cqumail.com": ["Central Queensland University (CQU) "],
    ".crescent.com": ["B.S.Abdur Rahman Crescent Institute of Science and Technology"],
    ".crsmu.com": ["Crimea State Medical University"],
    ".cs2i-bourgogne.com": ["CS2I Bourgogne"],
    ".csafa.com": [
        "Colegio Sagrada Familia Zaragoza",
        "Sagrada Familia School, Zaragoza",
    ],
    ".cse-strasbourg.com": ["Collège Episcopal Saint-Etienne"],
    ".csgrammar.com": ["Chiselhurst and Sidcup Grammar School"],
    ".csioviedo.com": ["Colegio \xa0San Ignacio"],
    ".cusdstudent.com": ["Clovis North High School"],
    ".d4university.com": ["D4 University", "D4 University"],
    ".daarululuumlido.com": ["MA Daarul Uluum Lido", "MA Daarul Uluum Lido"],
    ".davjalandhar.com": ["DAV College Jalandhar"],
    ".dcmschoolambala.com": ["DCM Senior Secondary School"],
    ".dgg-gz.com": ["Dossenberger-Gymnasium Günzburg"],
    ".digitalartschool.com": [
        "Create digitalartschool.txt",
        "http://www.digitalartschool.com",
        "100-1632 Dickson Avenue • Kelowna, British Columbia • V1Y 7T2",
    ],
    ".dijonformation.com": ["Dijon Formation"],
    ".dlevh.com": ["Lev Hasharon Democratic School", "בית הספר הדמוקרטי לב השרון"],
    ".dnsalbarsha.com": ["Dubai national school", "Dubai National School"],
    ".docchula.com": ["Faculty of Medicine, Chulalongkorn University"],
    ".doonschool.com": ["The Doon School"],
    ".doverbroecks.com": ["D'Overbroecks School "],
    ".dpsjaipur.com": ["Delhi Public School"],
    ".dpssrinagar.com": ["Delhi Public School Srinagar"],
    ".drgitr.com": ["Dr. Rajendra Gode Institute of Technology and Research"],
    ".ecam-rennes.com": ["ECAM Rennes"],
    ".ecccomp.com": ["ECCコンピュータ専門学校", "ECC College of Computer & Multimedia"],
    ".eccoschool.com": ["Ecclesfield School"],
    ".ece-france.com": ["BBA INSEEC - Ecole de Commerce Européenne"],
    ".ecnudec.com": ["华东师范大学开放教育学院", "School of Open Learning and Education"],
    ".ecole-hexagone.com": ["École Hexagone"],
    ".ecole-ipssi.com": ["IPSSI - École d’Informatique, Web et Design Graphique"],
    ".ecole-it.com": ["Ecole-IT - École Supérieure des Technologies de l'Information"],
    ".ecole-multimedia.com": ["Ecole Multimédia"],
    ".ecole-webstart.com": ["Webstart"],
    ".ecole2600.com": ["École 2600"],
    ".lyn.ecolescreatives.com": ["CinéCréatis"],
    ".edhec.com": ["Ecole des Hautes Etudes Commerciales du Nord"],
    ".eemi.com": ["École Européenne des Métiers de l'Internet"],
    ".efficom-lille.com": ["Efficom Lille"],
    ".eg-plovdiv.com": ["Plovdiv Language School"],
    ".eieonline.com": ["European Institute of Education"],
    ".eitiedu.com": [
        "Ekibastuz technical and engineering institute (Kazakshstan, Pavlodar Province, Ekibastuz)"
    ],
    ".elorrieta-errekamari.com": ["CIFP Elorrieta-Erreka Mari LHII"],
    ".em-lyon.com": ["Ecole Supérieure de Commerce de Lyon"],
    ".emc-campus.com": ["European Management Center Paris"],
    ".edu.emlyon.com": ["emlyon business school"],
    ".enigma-school.com": ["HIGHER SCHOOL OF COMPUTER SCIENCE IN LILLE"],
    ".epinfante.com": ["Escola Profissional do Infante"],
    ".epschoolsri.com": ["East Providence Public Schools"],
    ".esat-alumni.com": ["\ufeffEscuela Superior de Arte y Tecnología de Valencia"],
    ".escdijon.com": ["Ecole Supérieure de Commerce de Dijon"],
    ".esprit-tn.com": ["Ecole Superieure Privee d'Ingenierie et de Technologies"],
    ".essat-gabes-elearning.com": [
        "Ecole Supérieure des Sciences Appliquées et de la Technologie Privée de Gabès",
        "Private Higher School of Applied Sciences and Technology of Gabès",
    ],
    ".essat-gabes.com": [
        "Ecole Supérieure des Sciences Appliquées et de la Technologie Privée de Gabès",
        "Private Higher School of Applied Sciences and Technology of Gabès",
    ],
    ".ga.essd40.com": ["Excelsior Springs High School"],
    ".estiam.com": [
        "ÉSTIAM - École supérieure des technologies de l'information appliquées aux métiers"
    ],
    ".eticalgarve.com": ["Etic Algarve"],
    ".evolis3d.com": ["Evolis3D", "Evolis3D"],
    ".fac-lisaa.com": ["ESG - Ecole de commerce"],
    ".fallschurchrobotics.com": ["Falls Church High School Robotics"],
    ".fenelon-notredame.com": ["Fenelon Notre-Dame"],
    ".fernando3martos.com": ["I.E.S FERNANDO III MARTOS - JAÉN"],
    ".fitstic-edu.com": ["FITSTIC"],
    ".flatironschool.com": ["Flatiron School"],
    ".fondespierre.com": ["Fondespierre RH"],
    ".student.fortbendisd.com": ["Quail Valley Middle School"],
    ".foundationu.com": ["Foundation University"],
    ".foundationuniversity.com": ["Foundation University"],
    ".frhsd.com": ["Freehold High School"],
    ".ftmsglobal.com": ["FTMS Global Academy"],
    ".fullsail.com": ["Full Sail University"],
    ".furzeplatt.com": ["Furze Platt Senior School"],
    ".student.gatewayhs.com": ["Gateway Regional High School"],
    ".gbg-rs.com": ["Gertrud-Bäumer-Gymnasium", "Gertrud-Bäumer-Gymnasium"],
    ".gcsnc.com": ["Guilford County Public Schools"],
    ".gdgoenkasurat.com": [
        "G D Goenka International School ",
        "http://www.gdgoenkasurat.com/",
    ],
    ".gemselearning.com": ["Gems Millennium School Sharjah"],
    ".generalestudis.com": [
        "General Estudis Online Lleida",
        "https://generalestudis.com/",
    ],
    ".george-heriots.com": ["George Heriot's School"],
    ".georgegreens.com": ["George Green's School"],
    ".gladesmore.com": ["Gladesmore Community School"],
    ".gladesmorestudent.com": ["Gladesmore Community School"],
    ".gocva.com": ["Carrabassett Valley Academy"],
    ".gollisuniversity.com": ["Gollis University"],
    ".grenoble-em.com": ["Grenoble Ecole de Management"],
    ".groupe-esc-troyes.com": ["Groupe ESC Troyes"],
    ".groupe-gema.com": ["IA School"],
    ".groupe-igslyon.com": ["IPI Lyon"],
    ".groupeiam.com": [
        "Institut Africain de Management",
        "African Institute of Management",
    ],
    ".grupofleming.com": ["Grupo Fleming"],
    ".gtu-info.com": ["Gujarat technology University"],
    ".student.h-is.com": [
        "H-International School",
        "H-Farm International School",
        ".group",
    ],
    ".halcyonschool.com": ["Halcyon London International School"],
    ".haringtonschool.com": ["Harrington School"],
    ".hartismere.com": ["Hartismere School"],
    ".hbhgkj.com": ["黄冈科技职业学院", "Huanggang College Of Science and Technology"],
    ".hessleacademy.com": ["Hessle High School and Sixth Form College"],
    ".holbertonschool.com": ["Holberton School"],
    ".hollandcollege.com": ["Holland College"],
    ".htl-shkoder.com": ['Österreichische Schule "Peter Mahringer"'],
    ".htlinternationalschool.com": ["HTL International School"],
    ".hzcollege.com": ["惠州经济职业技术学院", "Huizhou Ecomonics And Polytechnic College"],
    ".iae-aix.com": [
        "Institut d'Administration des Entreprises (Aix-en-Provence, France)"
    ],
    ".iae-toulouse.com": [
        "Institut d'Administration des Entreprises (Toulouse, France)"
    ],
    ".ibnuchaldun.com": ["Universitas Ibn Chaldun Jakarta"],
    ".ici-luzern.com": ["International Culinary Institute (ICI)"],
    ".icn-nancy.com": ["Institut Commercial de Nancy"],
    ".icsw.com": ["Institute of Clinical Social Work"],
    ".idbbxl.com": ["Institut Don Bosco Woluwe-Saint-Pierre"],
    ".ideponline.com": ["IDEP Barcelona"],
    ".iemcal.com": ["Institute of Engineering and Management"],
    ".iesanetwork.com": ["IESA multimédia"],
    ".iescampanillas.com": ["Ies Campanillas "],
    ".iescastelar.com": ["IES Castelar (Badajoz)"],
    ".iesciudadjardin.com": [
        "Instituto de educación secundaria Ciudad Jardín (Sevilla)"
    ],
    ".iesdoctorbalmis.com": ['Instituto de Educación Secundaria "Doctor Balmis"'],
    ".iesemilidarder.com": ["Institut d'Educació Secundària i FP"],
    ".iesiliberis.com": [
        "Instituto de Educación Secundaria Ilíberis",
        "IES Ilíberis",
        "I.E.S Ilíberis",
    ],
    ".iesleopoldoqueipo.com": ["IES. Leopoldo Queipo"],
    ".iesmarenostrum.com": ["IES Mare Nostrum (Alicante)"],
    ".iesmiguelherrero.com": ["IES Miguel Herrero (Cantabria)"],
    ".iesmutxamel.com": ["IES MUTXAMEL", "Secondary Institute MUTXAMEL"],
    ".iespabloserrano.com": ["Instituto de Educación Secundaria Pablo Serrano"],
    ".iessanandres.com": ["IES San Andres"],
    ".iessantiagohernandez.com": [
        "Instituto de Educacion Secundaria Santiago Hernandez"
    ],
    ".iestacio.com": ["IES l'ESTACIO", "IES l'ESTACIO"],
    ".iesvirgendelcarmen.com": ["IES Virgen del Carmen (Jaén)"],
    ".ifp-school.com": ["IFP School"],
    ".ipi.igsgroupe.com": [
        "University from Paris ",
        "Institut Poly Informatique",
        "http://www.ipi-ecoles.com/",
    ],
    ".iihtsrt.com": ["Indian Institute of Hardware Technology,Surat,Gujarat,India"],
    ".iimtu.com": ["iimtu"],
    ".iimtuniversity.com": ["IIMT University"],
    ".iitmjanakpuri.com": [
        "Institute of Information Technology and Management, Janakpuri"
    ],
    ".ikzubirimanteo.com": ["IES Zubiri-Manteo BHI"],
    ".alumnos.ilernaonline.com": ["ILERNA", "ILERNA"],
    ".imerir.com": [
        "Institut Méditerranéen d'Etude et de Recherche en Informatique et Robotique"
    ],
    ".imf.com": ["IMF Business School", "IMF Business School"],
    ".imi-luzern.com": ["International Hotel Management Institute"],
    ".impspolytech.com": ["IMPS Polytechnic College, Jalpaiguri"],
    ".indoreinstitute.com": [
        "Indore Institute of Science and Technology",
        "Indore Institute of Science and Technology",
    ],
    ".indusschoolhyd.com": ["Indus International School Hyderabad"],
    ".indusschoolpune.com": ["Indus International School, Pune"],
    ".infouniron.com": ["Faculdade Interamericana de Porto Velho"],
    ".ingesup.com": ["Ingésup - Ecole supérieure d'ingénierie informatique"],
    ".initcollege.com": ["International IT College of Sweden"],
    ".inseec-edu.com": ["Institut des hautes études économiques et commerciales"],
    ".inseec-france.com": ["Institut des hautes études économiques et commerciales"],
    ".institutotimoteo.com": ["Instituto Timoteo"],
    ".doz.internationale-ba.com": [
        "iba - University of Cooperative Education",
        "iba - Internationale Berufsakademie der F+U Unternehmensgruppe gGmbH",
    ],
    ".intisana.com": ["Colegio Intisana"],
    ".ionis-stm.com": ["Ionis School of Technology and Management"],
    ".iou-students.com": ["Islamic Online University"],
    ".ipnetinstitute.com": ["IPNet Institute of Technology"],
    ".ipssi-lyon.com": ["École Informatique IP Formation Lyon"],
    ".student.isartdigital.com": ["Isart Digital Paris", "https://www.isart.com/en/"],
    ".isartdigital.com": ["ISART Digital"],
    ".isbm-school.com": ["International School of Business Management"],
    ".iscmosuperiori.com": ["Istituto Sacro Cuore"],
    ".isd284.com": ["Wayzata High School", "Wayzata Schools", ".group"],
    ".islamicug.com": ["Islamic University College"],
    ".it-akademija.com": ["It Akademija"],
    ".iticparis.com": [
        "Institut des Techniques Informatiques et Commerciales",
        "Institute of Information Technology and Commercial Techniques",
        "ITIC Paris",
    ],
    ".itismeucci.com": ["ITIS Antonio Meucci, Firenze IT"],
    ".itisvinci.com": ["ITIS Leonardo Da Vinci, Carpi (MO)"],
    ".itlearning-settat.com": ["IT Learning Campus Pole dévelopement"],
    ".iu-travnik.com": ["International University of Travnik"],
    ".ivgpu.com": [
        "Федеральное государственное бюджетное образовательное учреждение высшего образования «Ивановский государственный политехнический университет»",
        "Federal State Budget Educational Institution of Higher Education «Ivanovo State Polytechnic University»",
    ],
    ".jbdelasalle.com": ["Ensemble scolaire Jean-Baptiste de La Salle"],
    ".jeffstateonline.com": ["Jefferson State Community College"],
    ".jmpaneracollege.com": ["J M Panera college Manavadar"],
    ".joyintlschool.com": ["Huai'an Joy International School", "淮安市嘉洋国际学校"],
    ".jpcatholic.com": ["John Paul the Great Catholic University"],
    ".jpgzx.com": ["Golden Apple Jin Cheng No.1 Secondary School"],
    ".jsspsdubai.com": ["JSS Private School", "JSS Private School"],
    ".student.junia.com": ["Junia ISEN Lille"],
    ".junia.com": [
        "Junia Engineering School",
        "Junia ISEN",
        "Junia ISA",
        "Junia HEI",
        ".group",
    ],
    ".karpagam.com": ["Karpagam Institutions"],
    ".kcgcollege.com": ["KCG College of Technology", "KCG College of Technology"],
    ".kdu-online.com": ["KDU University College"],
    ".kedgebs.com": ["Kedge Business School"],
    ".kellerisd.com": ["Keller Center For Advanced Learning (KCAL)"],
    ".keshetschool.com": [
        "Keshet Democratic School in Zichron Yaakov, Israel",
        "בית הספר הדמוקרטי קשת בזכרון יעקב",
    ],
    ".keyin.com": ["Keyin College"],
    ".khawarizmi.com": ["Al Khawarizmi International College"],
    ".kingsolomonhigh.com": ["Kantor King Solomon High School"],
    ".kkumail.com": ["Khon Kaen University"],
    ".kolieh.com": ["International Centre for Isclamic Science"],
    ".kosinka.com": [
        "Střední škola technická a obchodní Olomouc, Kosinova 4",
        "Technical and Business Secondary School Olomouc, Kosinova 4",
    ],
    ".kristujayanti.com": ["Kristu Jayanti College"],
    ".kukullagaikas.com": ["KUKULLAGA HERRI ESKOLA"],
    ".la-joliverie.com": ["School of La Joliverie"],
    ".labmiddleschool.com": ["NYC Lab Middle School"],
    ".lambdastudents.com": ["Lambda School", "Lambda"],
    ".lamerce.com": ["Institut Mare de Déu de la Mercè"],
    ".lasallecollege.com": ["LaSalle College / Collège LaSalle"],
    ".lasallecollegevancouver.com": ["LaSalle College Vancouver"],
    ".lecfl.com": ["LUBAVITCH EDUCATIONAL CENTER"],
    ".lecole-ldlc.com": ["L'Ecole LDLC"],
    ".lecolededesign.com": ["L'Ecole de Design Nantes Atlantique"],
    ".leightonpark.com": ["Leighton Park School"],
    ".lew-port.com": ["Lewiston-Porter High School"],
    ".liceolapaz.com": ['CPR Liceo "La Paz"'],
    ".liceovirgilioroma.com": ["Liceo Ginnasio Statale «Virgilio»"],
    ".litsey7.com": ["High Boarding School #7 / Kazan, Russia"],
    ".lome-bs.com": ["Lome Business School", "Business School of Lome"],
    ".loyalistcollege.com": ["Loyalist College"],
    ".lpssonline.com": ["Lafayette Parish School System"],
    ".lsfed.com": ["Prendergast school"],
    ".lsmu.com": ["Luhansk State Medical University"],
    ".student.ltuc.com": [
        "كلية لومينوس الجامعية التقنية",
        "Luminus Technical University College",
    ],
    ".ludus-academie.com": ["Ludus Academie"],
    ".lycee-langevin-wallon.com": ["Lycée Langevin-Wallon"],
    ".lycee-ndduroc.com": [
        "Lycée Notre Dame du Roc",
        "Formation Informatique : https://www.lycee-ndduroc.com/enseignement-superieur/initiale/30-bts-sio.html",
    ],
    ".lyceeastier.com": [
        "Lycée Polyvalent Astier",
        "BTS SN Informatique et Réseaux : https://www.btssnir.fr/",
    ],
    ".lyceerobertschuman.com": ["LYCÉE PRIVÉ ET UFA ROBERT SCHUMAN"],
    ".lyceesaintefamille.com": ["Lycée Sainte Famille", "Sainte Famille High School"],
    ".mac-eg.com": ["Misr American College"],
    ".madisonu.com": ["Madison University (Distance Education)"],
    ".maghullhigh.com": ["Maghull High School"],
    ".maharishividyamandirch.com": [
        "Maharishi Vidya Mandir",
        "School Website: https://www.maharishividyamandirch.com/",
        "Address:",
        "Maharishi Vidya Mandir Sr. Sec. School",
        "AFFILIATED TO CBSE, DELHI NO: 1930111",
        "(AN ISO 9001 : 2008 CERTIFIED INSTITUTION)",
        "Maharishi Gardens,",
        "28, Dr. Guruswamy Road, Chetpet, Chennai-600 031.",
        "Phone : +91-44-26427088, 26431047, 30527077",
        "Email: mvmchen@gmail.com",
        "Academics Page: https://www.maharishividyamandirch.com/root/academics.html",
    ],
    ".makeschool.com": ["Make School"],
    ".manukaumail.com": ["Manukau Institute of Technology"],
    ".marienschule-students.com": ["Marienschule Opladen"],
    ".marienschule.com": ["Marienschule Opladen"],
    ".marxadella.com": ["IES La Marxadella"],
    ".masonohioschools.com": ["William Mason High School"],
    ".mbrainacademy.com": ["mBrain Academy"],
    ".mediadesignschool.com": ["Media Design School"],
    ".melies.com": ["Faculdade de Tecnologia Melies"],
    ".melroseschools.com": ["Melrose Public Schools"],
    ".millfieldschool.com": ["Millfield School"],
    ".misbbocconi.com": ["MISB Bocconi: Mumbai campus of SDA Bocconi, Milan"],
    ".mitkundapura.com": ["mitkundapura engineering college : mitkundapura.com"],
    ".mitrastudents.com": ["Mitra Academy"],
    ".mittymonarch.com": ["Archbishop Mitty High School"],
    ".mjm-design.com": ["MJM Graphic Design"],
    ".mogadishuuniversity.com": ["Mogadishu University"],
    ".moniris.com": ["Ecole IRIS"],
    ".monlau.com": ["Monlau Centro de Estudios"],
    ".moorelanduniversity.com": ["Mooreland University"],
    ".student.moringaschool.com": ["Moringa School"],
    ".mpcstudent.com": ["Mount Paran Christian School"],
    ".mrjaffesclass.com": ["Patrick Henry High School"],
    ".msijanakpuri.com": ["Maharaja Surajmal Institute"],
    ".msnsixth.com": ["Midsomer Norton Sixth Form"],
    ".mspvl.com": ["MSP Velayutha Nadar Lakshmithaiammal Polytechnic College"],
    ".mtparanschool.com": ["Mount Paran Christian School"],
    ".mutacth.com": [
        "มหาวิทยาลัยเทคโนโลยีมหานคร",
        "Mahanakorn University of Technology",
    ],
    ".edu.my-campus-berlin.com": ["DHGS Deutsche Hochschule für Gesundheit & Sport"],
    ".mydigitalschool.com": ["mydigitalschool.com"],
    ".ust-ics.mygbiz.com": ["University of Santo Tomas", "University of Santo Tomas"],
    ".mygyanvihar.com": ["Suresh Gyan vihar University, Jagatpura Jaipur"],
    ".myiuc.com": [
        "Institut Universitaire de la Côte",
        "Coast University Institute",
        "IUC",
    ],
    ".mypscedu.com": ["Paramount School and College", "Paramount School and College"],
    ".myuax.com": ["Universidad Alfonso X El Sabio"],
    ".mywhitecliffe.com": ["Whitecliffe College of Arts and Design"],
    ".nahdaschools.com": ["Al Nahda National School"],
    ".neelamcollege.com": ["Neelam College of Engineering and Technology"],
    ".nehruworldschool.com": ["Nehru World School, India"],
    ".neoma-bs.com": ["Neoma Business School"],
    ".newprinceshribhavani.com": [
        "New Prince Shri Bhavani College of Engineering and Technology"
    ],
    ".nhlstenden.com": ["NHL Stenden University"],
    ".nortonhillschool.com": ["Norton Hill School"],
    ".notleyhigh.com": ["Notley high"],
    ".noviuniversity.com": [
        "Hogeschool NOVI b.v.",
        "University of Applied Science NOVI",
    ],
    ".npskrm.com": ["NPS Koramangala", "NPS Koramangala"],
    ".nugaaluniversity.com": ["Nugaal University"],
    ".ohel-shem.com": ['תיכון "אהל-שם"', "Ohel shem Ramat gan"],
    ".okaloosaschools.com": ["Davidson Middle School", "FL, US"],
    ".students.olatheschools.com": ["Olathe Public Schools"],
    ".1lokutno.onmicrosoft.com": [
        "I Liceum Ogólnokształcące im. gen. J. H. Dąbrowskiego w Kutnie"
    ],
    ".BBQBerlin.onmicrosoft.com": [
        "BBQ – Baumann Bildung und Qualifizierung",
        "BBQ is an institute where you can get a degree, official website URL:",
        "https://www.bbq.de/",
        "URL of a page on the official website where a long-term (>1 year) IT",
        "https://www.bbq.de/umschulung/koeln/fachinformatiker-anwendungsentwicklung/",
        "The student email differs from the official website, so",
        "The domain that we ask you to add to your database is:",
        "walid.alghanem@BBQBerlin.onmicrosoft.com",
        "best regards",
        "Walid Alghanem",
    ],
    ".bappassau.onmicrosoft.com": [
        "Private Berufsakademie für Aus- und Weiterbildung Passau gGmbH",
        "The BAP IT school is an institute where you can enter a 3 year apprenticeship to earn a degree as Software Engineer.",
        "Official website: https://it-schule-passau.de/",
        'URL with the page detailing the long-term (3 year course) "Ausbildung":',
        "https://it-schule-passau.de/hp412/Ausbildung.htm",
        "Student email differs from the official website URL:",
        "Pattern of the email would be: fi_<FirstNameInitial><LastName>@bappassau.onmicrosoft.com",
        "e.g. fi_cfluegel@bappassau.onmicrosoft.com",
        "Kind regards,",
        "Christopher Flügel",
    ],
    ".bkalsdorfde.onmicrosoft.com": [
        "Berufskolleg Alsdorf",
        "Vocational College Alsdorf",
    ],
    ".bntuby.onmicrosoft.com": [
        "Белорусский национальный технический университет",
        "Belarusian National Technical University",
    ],
    ".bztgoldenburgde.onmicrosoft.com": [
        "Bildungszentrum für Technik und gestaltung",
        "BZTG is an institute where you can get a degree, official website URL:",
        "https://www.bztg-oldenburg.de",
        "Alternative URLs that is being used for different services: https://mybztg.de/",
        "URL of a page on the official website where a long-term (>1 year) IT:",
        "https://www.bztg-oldenburg.de/bildungsangebot/berufsfachschulen/informatik/",
        "The student email differs from the official website, because only the teachers get an E-Mail with the official domain. ",
        "The student E-Mails are mainly used to get access to the office package.",
        "Office Page: https://bztg-oldenburg.de/o356-conditions/",
        "Here is a picture of the page where you get your onmicrosoft.com login email: https://ss.zhost.xyz/images/R804.jpg",
        "You have to login to see your email.",
    ],
    ".chippewavalley.onmicrosoft.com": ["Chippewa Valley Schools"],
    ".comgymdeg.onmicrosoft.com": [
        "Comenius Gymnasium Deggendorf",
        "Comenius Gymnasium Deggendorf",
    ],
    ".csorsay.onmicrosoft.com": ["COURS SECONDAIRE D'ORSAY"],
    ".csssnina.onmicrosoft.com": ["Cirkevná spojená škola Snina"],
    ".dypisp.onmicrosoft.com": ["Dr. D. Y. Patil School of Engineering"],
    ".emineornekkoleji.onmicrosoft.com": ["Emine Örnek Koleji", "Emine Ornek Collage"],
    ".epshl.onmicrosoft.com": ["Emil-Possehl-Schule"],
    ".esimetz.onmicrosoft.com": ["ESI Metz, France"],
    ".fagoceducacional.onmicrosoft.com": ["UniFagoc"],
    ".firstwald.onmicrosoft.com": ["Evangelisches Firstwald Gymnasium Mössingen"],
    ".ghsede.onmicrosoft.com": [
        "Gwerbliche und Hauwirtschaftlich-Sozialpflegerische Schulen Emmendingen"
    ],
    ".gymro.onmicrosoft.com": ["Gymnasium Rodenkirchen"],
    ".hansbockl.onmicrosoft.com": ["Hans-Böckler-Berufskolleg, Marl, Germany"],
    ".htblaperg.onmicrosoft.com": [
        "Höhere Technische Lehranstalt Perg ( Higher Technical College Perg ) / Austria"
    ],
    ".husteduvn.onmicrosoft.com": [
        "Đại học Bách Khoa Hà Nội",
        "Hanoi university of science and technology",
    ],
    ".iisfortunato.onmicrosoft.com": [
        "IIS Giustino Fortunato, Pisticci (MT)",
        "High School in Pisticci, Italy",
        "Official Website: http://www.iisgiustinofortunato.it",
        "Information about IT Department: http://www.iisgiustinofortunato.it/index.php?option=com_content&view=article&id=359&Itemid=1438",
        "We have three years of IT specialization in the 3th, 4th and 5th year with a focus on programming ",
        "http://www.iisgiustinofortunato.it/files/MTIS011001/Quadro_orario_ITT.pdf",
    ],
    ".itiscastelli.onmicrosoft.com": [
        "IIS Castelli, Brescia (former ITIS Castelli)",
        "High School in Brescia, Italy",
        "Official Website: https://www.iiscastelli.edu.it",
        "Information about IT Department: https://www.iiscastelli.edu.it/pager.aspx?Page=dip_info",
        "We have three years of IT specialization in the 3th, 4th and 5th year with a focus on programming ",
        "https://www.slideshare.net/slideshow/embed_code/15570843?wmode=transparent",
    ],
    ".kgsu.onmicrosoft.com": ["ФГБОУ ВО «Курганский государственный университет»"],
    ".klaraopp.onmicrosoft.com": [
        "Klara-Oppenheimer-Schule Würzburg (student accounts)"
    ],
    ".knitukazan.onmicrosoft.com": [
        "Казанский Национальный Исследовательский Университет",
        "Kazan National Research Technological University",
    ],
    ".lbiro.onmicrosoft.com": [
        'Colegiul National de Informatica "Tudor Vianu"',
        'National College of Informatics "Tudor Vianu"',
    ],
    ".lyceeclosmaire.onmicrosoft.com": ["Lycée Polyvalent Clos-Maire"],
    ".madiasu.onmicrosoft.com": [
        "Московский автомобильно-дорожный государственный технический университет (МАДИ)"
    ],
    ".mylifeunisaac.onmicrosoft.com": ["University of South Africa"],
    ".o365frcuutneduar.onmicrosoft.com": [
        "Universidad Tecnológica Nacional, Facultad Regional Concepción del Uruguay (UTN - FRCU)",
        "National Technological University, Concepción del Uruguay Regional Faculty (UTN - FRCU)",
    ],
    ".opolelo3.onmicrosoft.com": [
        "Publiczne Liceum Ogólnokształcące nr III z Oddziałami Dwujęzycznymi im. Marii Skłodowskiej-Curie w Opolu"
    ],
    ".pfaffenhofenschule.onmicrosoft.com": ["Grund und Mittelschule Pfaffenhofen"],
    ".pforta.onmicrosoft.com": [
        "Landesschule Pforta",
        "The Landesschule Pforta is a boarding school located in Germany, with a special concept of furthering talented students in natural sciences.",
        "Official website: https://www.landesschule-pforta.de/en/index.php",
        "Department of Natural Sciences: https://www.landesschule-pforta.de/en/departments.php",
        "We have four years of IT specialization with a focus on programming.",
        "We also have a lot of student led extracurricular activities, which focus on programming.",
        "The email pattern is <name>@pforta.onmicrosoft.com",
        "Best regards",
    ],
    ".pictorius.onmicrosoft.com": ["Pictorius Berufskolleg Coesfeld"],
    ".politecnicamgprogrammersliv.onmicrosoft.com": [
        "Centro Universitário UNA, Brasil"
    ],
    ".sabje.onmicrosoft.com": ["King David Schools"],
    ".sjcacblr.onmicrosoft.com": ["St. Joseph's College (Autonomous)"],
    ".steppingstoneschd.onmicrosoft.com": ["Stepping Stones Senior Secondary School"],
    ".studentmgppu.onmicrosoft.com": [
        "Московский государственный психолого-педагогический университет (МГППУ)",
        "Moscow city university of psychology and pedagogy (second Live ID e-mail, primary e-mail already exists mgppu.ru)",
    ],
    ".studuniroma3.onmicrosoft.com": ["UniRoma3"],
    ".svkmmumbai.onmicrosoft.com": [
        "Dwarkadas Jivanlal Sanghvi College of Engineering "
    ],
    ".tmgdaun.onmicrosoft.com": ["Thomas-Morus-Gymnasium Daun"],
    ".tmsnoida.onmicrosoft.com": ["The Millennium School", "The Millennium School"],
    ".unidebhu.onmicrosoft.com": [
        "Debrecen University of Agricultural Sciences",
        "University of Debrecen ",
    ],
    ".urfume.onmicrosoft.com": ["Ural Federal University"],
    ".uzlabina.onmicrosoft.com": ["SPŠE v Úžlabině"],
    ".venkateshwaraschool.onmicrosoft.com": ["Venkateshwara International School"],
    ".vyatsu.onmicrosoft.com": ["Vyatka State University"],
    ".zskocjan.onmicrosoft.com": [
        "Zespół szkół nr 3 imienia Antoniego Kocjana w Olkuszu",
        "Antoni Kocjan School Complex No. 3 in Olkusz",
    ],
    ".zsp1sieradz.onmicrosoft.com": ["Powiatowy Zespół Szkół nr1 w Sieradzu"],
    ".zsvltava.onmicrosoft.com": [
        "ZŠ a ZUŠ Bezdrevská 3, České Budějovice",
        "ZŠ Vltava",
    ],
    ".openclassrooms.com": ["OpenClassrooms"],
    ".oradeauniversity.com": [
        "Oradea University",
        "University of Medicine and Pharmacology of Oradea",
    ],
    ".oshmed.com": ["Medical Institute,Osh State University"],
    ".oshsch.com": ["Old Swinford Hospital"],
    ".ostrovskeho.com": ["SOŠ Ostrovského"],
    ".oultoncollege.com": ["Oulton College"],
    ".outwood.com": ["Outwood Grange Academies Trust"],
    ".paneurouni.com": ["Paneuropean University"],
    ".parvamat.com": [
        "Първа Частна Математическа Гимназия",
        "First Private Mathematic High School",
    ],
    ".pccsk12.com": ["Plymouth-Canton Community Schools"],
    ".stu.pearlacademy.com": ["Pearl Academy, India"],
    ".peelsb.com": ["Peel District School Board"],
    ".pgknma.com": [
        "\ufeffПрофесионална гимназия по компютърни науки и математически анализи проф. Минко Балкански Стара Загора"
    ],
    ".pharminnotech.com": [
        "St. Petersburg State Chemical Pharmaceutical Academy",
        "St. Petersburg State Chemical Pharmaceutical Academy",
    ],
    ".plaiaundi.com": ["IES Plaiaundi BHI", "Plaiaundi Vocational Institute"],
    ".playgroundsquad.com": ["PlaygroundSquad"],
    ".pmgkn.com": [
        "h.todorov03@pmgkn.com",
        'Maths and Science High School "Prof. Emanuil Ivanov", Kyustendil, Bulgaria',
        'Природоматематическа гимназия "Проф. Емануил Иванов", Кюстендил, България',
    ],
    ".powayusd.com": ["Poway Unified School District"],
    ".preciousheritageschool.com": [
        "Precious Heritage College",
        "https://preciousheritageschool.com/",
    ],
    ".puntlandstateuniversity.com": ["Puntland State University"],
    ".queensmetro.com": [
        "Queens Metropolitan High School",
        "Queens Metropolitan High School",
    ],
    ".ralphthoresby.com": ["Ralph Thoresby School"],
    ".rcsi-mub.com": ["RCSI-Medical University of Bahrain"],
    ".redclayschools.com": ["Red Clay Consolidated School District"],
    ".rennes-sb.com": ["Renne School of Business"],
    ".rgshw.com": ["Royal Grammar School, High Wycombe"],
    ".alunos.ribadouro.com": ["Externato Ribadouro, Porto"],
    ".richardchalloner.com": ["Richard Challoner School"],
    ".ricstudent.com": ["Rochester Independent College"],
    ".rmutsvmail.com": ["Rajamangala University of Technology Srivijaya"],
    ".rondearingutc.com": ["Ron Dearing UTC"],
    ".rothberg100.com": ["Rothberg High School"],
    ".rubika-edu.com": ["Rubika"],
    ".saadcollege.com": ["Saad College of Nursing and Allied Health Sciences"],
    ".saedubai.com": ["Sae Institute Dubai"],
    ".saintadrien.com": ["Lycée Saint-Adrien La Salle"],
    ".sainte-elisabeth.com": [
        "Sainte Elisabeth",
        "https://www.sainte-elisabeth.com/",
        "Proof of School Domain Name in Yellow on top left side of the document : https://i.imgur.com/ljeY6EJ.jpg",
    ],
    ".sainteunans.com": ["saint eunans"],
    ".student.saintkentigern.com": ["Saint Kentigern College"],
    ".saintluc-cambrai.com": [
        "Ensemble Saint Luc Cambrai",
        "Ensemble Saint Luc Cambrai North of France",
    ],
    ".salesianosdosa.com": [
        "Salesianos Domingo Savio Madrid",
        "Salesians Domingo Savio Madrid",
    ],
    ".sanataneducation.com": ["SANATAN PUBLIC SCHOOL, TOHANA, INDIA"],
    ".santhigiricollege.com": ["SANTHIGIRI COLLEGE, THODUPUZHA "],
    ".saveetha.com": ["Saveetha university"],
    ".savio-lambersart.com": ["Dominique SAVIO Enseignement Catholique "],
    ".sbjacksonville.com": ["Sanford-Brown Institute"],
    ".scbaghdad.com": ["College of Science, Baghdad University"],
    ".scetop.com": ["四川托普信息技术职业学院", "SiChuan Top IT Voctional institute"],
    ".schillerstrasbourg.com": ["Schiller International University, Strasbourg"],
    ".sdglobalschool.com": ["sdglobalschool"],
    ".sdsydxx.com": ["\ufeffShandong Post and Telecommunications School"],
    ".sekpacifico.com": ["Colegio Sek Pacifico", "Colegio Internacional Sek Pacifico"],
    ".sempreceub.com": ["Centro Universitário de Brasília"],
    ".sfhs.com": ["Saint Francis High School"],
    ".sgsc-students.com": ["St. georges school cologne", "St. georges school cologne"],
    ".sh-sipopolytechnic.com": ["Shanghai Sipo Polytechnic"],
    ".shannoncollege.com": ["Shannon College of Hotel Management"],
    ".sheldoncollege.com": ["Sheldon College"],
    ".sheldonisd.com": ["C.E. King High School"],
    ".shms.com": ["Swiss Hotel Management School"],
    ".shrikrishnacollegeofeducation.com": [
        "Shri Krishna College of Education (SKCE), Chhatarpur"
    ],
    ".siligurimodelhighschool.com": ["Siliguri Model Senior Secondary School"],
    ".sio-carriat.com": ["Lycée Carriat", "Lycée Polyvalent J.-M. Carriat"],
    ".sitechhs.com": [
        "Staten Island Technical High School",
        "Website: https://www.siths.org ",
        "Email: sitechhs.com",
    ],
    ".sjcwebmail.com": ["St Josephs College"],
    ".skadron.com": ["Skadron College"],
    ".skylineuniversity.com": ["Skyline University College, Sharjah"],
    ".bruinmail.slcc.com": ["Salt Lake Community College"],
    ".smalandsgymnasiet.com": ["Smålandsgymnasiet"],
    ".somosicev.com": ["iCEV Instituto de Ensino Superior"],
    ".soraschools.com": ["Sora High School"],
    ".southoldufsd.com": ["Southold UFSD"],
    ".spbgut.com": [
        "The Bonch-Bruevich Saint - Petersburg State University of Telecommunications"
    ],
    ".springbranchisd.com": ["Spring Branch ISD", ".group"],
    ".spsmma.com": [
        "St. Petersburg StateMechnikov  Medical Academy",
        "St. Petersburg StateMechnikov  Medical Academy",
    ],
    ".spyponders.com": ["Arlington High School"],
    ".srcspatna.com": ["SHRI RAM CENTENNIAL SCHOOL"],
    ".srhstheschool.com": ["Sree Raghavendra High School"],
    ".ssipmt.com": [
        "Shri Shankaracharya Institute of Professional Management and Technology"
    ],
    ".st-andrews.com": ["St Andrew's International School in The Bahamas"],
    ".st-laurence.com": ["St-Laurence School"],
    ".st-teresas.com": ["St Teresa's Independent school"],
    ".stccampus.com": ["Sattahip Commercial Technological College"],
    ".academie.ste-therese.com": ["Académie Ste-Thérèse"],
    ".stenden.com": ["Stenden University"],
    ".stjomaristes.com": ["Saint Joseph les Maristes"],
    ".stockholm-fu.com": ["Free University Stockholm"],
    ".stonarschool.com": ["Stonar School", "Wiltshire, SN12 8NT, United Kingdom"],
    ".stretfordgrammar.com": ["Stretford Grammar School"],
    ".stu-lisaa.com": ["ESG - Ecole de commerce"],
    ".stucom.com": ["El Centre d’Estudis Stucom"],
    ".studygroup.com": ["Study Group"],
    ".stwillibrord.com": [
        "St. Willibrord High School and Juinor College of Science and Commerce",
        "Mumbai, Maharashtra, India.",
    ],
    ".stxtigers.com": ["St. Xavier High School "],
    ".sugunapips.com": ["Suguna PIP School"],
    ".suh-edu.com": ["Salahddin University (Kurdistan Region)"],
    ".summerfields.com": ["Summer Fields School", "summerfields.com"],
    ".summit-academy.com": ["Summit Academy"],
    ".supcareer.com": [
        "Sup Career",
        "École de commerce du groupe INSEEC à Paris, France",
    ],
    ".supdepub.com": ["Sup de Pub"],
    ".supdeweb-paris.com": ["Supdeweb : L'école des métiers du digital"],
    ".supdeweb-strasbourg.com": [
        "Supdeweb : L'école des métiers du web et du multimedia"
    ],
    ".supinfo.com": [
        "SUPINFO International University - École Supérieure d'Informatique de Paris (ESI)"
    ],
    ".suptgniort.com": ["suptg niort"],
    ".svalero.com": ["Fundación San Valero"],
    ".svamail.com": ["Silicon Valley Academy email domain"],
    ".swbgs.com": ["Sir William Borlase's Grammar School"],
    ".taawish.com": ["Taawish College of Education"],
    ".taftcharter.com": ["Taft Charter High School"],
    ".tajamar365.com": ["Formacion Tajamar"],
    ".teccart.com": ["Teccart Institute"],
    ".thcstranvangiau.com": ["\ufeffTHCS Trần Văn Giàu"],
    ".thefarnboroughacademy.com": ["The Farnborough Academy "],
    ".thegameassembly.com": ["The Game Assembly"],
    ".theglobeformacion.com": ["Centro de enseñanza The Globe"],
    ".thesrisaicollege.com": ["Sri Sai College"],
    ".thevallians.com": [
        "The Vallians",
        "The Vallians Digital University, The Valley DBS",
    ],
    ".tkrcet.com": [
        "TKR College of Engineering and Technology",
        "TKR College of Engineering and Technology",
    ],
    ".totharpadgimnazium.com": ["Tóth Árpád Gimnázium", "Tóth Árpád Secondary School"],
    ".trios.com": ["triOS College"],
    ".trioscollege.com": ["triOS College"],
    ".triosstudent.com": ["triOS College"],
    ".truemax.com": ["TRUEMAX academy"],
    ".twynhamschool.com": ["Twynham School"],
    ".u-tad.com": ["U-tad - Centro Universitario de Tecnología y Arte Digital"],
    ".ucreativa.com": ["Universidad Creativa", "Creative University"],
    ".uft-plovdiv.com": ["University of Food Technology"],
    ".students.paca.uk.com": [
        "Portslade Aldridge Community Academy. http://www.paca.uk.com/ email: @students.paca.uk.com"
    ],
    ".turton.uk.com": ["Turton School"],
    ".uktc-bg.com": [None],
    ".ult-tunisie.com": ["Tunisia Private University"],
    ".umi-pk.com": ["University of Munawwar-ul-Islam"],
    ".uni-prizren.com": ["Universiteti i Prizrenit"],
    ".uniactiva.com": ["Universidad Abierta Interactiva"],
    ".students.unicoischools.com": ["Unicoi County High School"],
    ".unidompedro.com": ["Centro Universitario Dom Pedro II"],
    ".uniedpa.com": ["Universidad Interamericana de Educacion a Distancia de Panama"],
    ".unigoias.com": [
        "UNIGOIÁS - Centro Universitário de Goiás",
        "UNIGOIÁS - University Center of Goiás",
    ],
    ".students.uninettunouniversity.com": [
        "Universita Uninettuno ",
        "Uninettuno University",
    ],
    ".studenti.uninsubria.com": ["Università degli studi dell'Insubria"],
    ".uninter.com": ["Centro Universitário Internacional UNINTER"],
    ".univ-barackobama.com": ["University of Barack Obama"],
    ".univ-catho-sjd.com": ["Institut universitaire Saint Jerome de Douala"],
    ".univ-douala.com": ["Université de Douala"],
    ".universitetiaab.com": ["Kolegji AAB", "AAB College"],
    ".university-365.com": ["University 365"],
    ".unswalumni.com": ["University of New South Wales"],
    ".up-esi.com": ["UP-ESI"],
    ".uu-sy.com": ["Ittihad Private University"],
    ".student.uva.com": ["University of Amsterdam"],
    ".vegaschool.com": ["Vega School"],
    ".velhightech.com": [
        "Vel Tech High Tech Dr. Rangarajan Dr. Sakunthala Engineering college"
    ],
    ".vfs.com": ["Vancouver Film School"],
    ".vidyavalley.com": ["Vidya Valley School, Pune, India"],
    ".virolai.com": ["Escola Virolai"],
    ".vivekanandgroup.com": ["Vivekanand Group of Institutions"],
    ".edu.vlerick.com": ["Vlerick Business School"],
    ".vpi-school.com": [
        "مدرسة رواد النصر العالمية",
        "Victory Pioneers International School",
    ],
    ".vpslao.com": ["Vientiane Pattana School International"],
    ".vsavm.com": ["Vitebsk State Academy of Veterinary Medicine"],
    ".vtcsy.com": ["沈阳职业技术学院", "shenyang polytechnic college"],
    ".vtsd.com": ["Vernon Township School District"],
    ".wairaka.com": ["Unitec Institute of Technology"],
    ".waleshigh.com": ["Wales High School"],
    ".wayneschools.com": ["Wayne Township Public Schools"],
    ".wbbroncos.com": ["Western Brown High School"],
    ".wells-cathedral-school.com": ["Wells Cathedral School"],
    ".wernethschool.com": ["Werneth High School"],
    ".westcoastuniversity-edu.com": ["West Coast University (WCU)"],
    ".wildcodeschool.com": ["Wild Code School"],
    ".williamandreed.com": ["William and Reed Academy"],
    ".williambrookes.com": ["William Brookes School"],
    ".students.williscollege.com": [
        "Willis College, Business, Technology and Healthcare",
        "https://williscollege.com/",
    ],
    ".williscollege.com": [
        "Willis College, Business, Technology and Healthcare",
        "https://williscollege.com/",
    ],
    ".williston.com": ["Williston Northampton School"],
    ".wilmslowhigh.com": ["Wilmslow High School"],
    ".wis-ecoles.com": ["Web International School"],
    ".wpsstudent.com": [
        "Domain for students at Winchester High School pull request.",
        "website: http://www.winchesterps.org/",
        "email domain: @wpsstudent.com",
    ],
    ".xabiainternationalcollege.com": ["Xabia International College"],
    ".students.xavierengg.com": ["Xavier Institute of Engineering"],
    ".xujc.com": [
        "Xiamen University Jiageng College",
        "Xiamen University Tan Kah Kee College",
    ],
    ".y-nov.com": [
        "Y-nov | Lim'art - Ingésup - Infosup | Carrefour des formations aux métiers du numérique."
    ],
    ".ynov.com": [
        "Y-nov | Lim'art - Ingésup - Infosup | Carrefour des formations aux métiers du numérique."
    ],
    ".zealeducation.com": ["Zeal College of Engineering and Research", ".group"],
    ".zhbit.com": ["Beijing Institute of Technology, Zhuhai"],
    ".zictcollege.com": ["Zambia ICT College"],
    ".zubirimanteo.com": ["IES Zubiri-Manteo BHI"],
    ".universita.corsica": ["Università di Corsica Pasquale Paoli"],
    ".fundepos.ac.cr": ["Universidad Fundepos Alma Mater"],
    ".itcr.ac.cr": ["Instituto Tecnológico de Costa Rica"],
    ".uaca.ac.cr": ["Universidad Autónoma de Centro América"],
    ".uam.ac.cr": ["Universidad Americana"],
    ".uca.ac.cr": ["Universidad de Cartago Florencio del Castillo"],
    ".ucatolica.ac.cr": ["Universidad Católica Anselmo Llorente"],
    ".ucem.ac.cr": ["Universidad Centroamericana de Ciencias Empresariales"],
    ".ucenfotec.ac.cr": ["Universidad Cenfotec"],
    ".uci.ac.cr": ["Universidad para la Cooperación Internacional"],
    ".ucr.ac.cr": ["Universidad de Costa Rica"],
    ".ufide.ac.cr": ["Universidad Fidélitas"],
    ".ufidelitas.ac.cr": ["Universidad Fidélitas"],
    ".uhispanoamericana.ac.cr": ["Universidad Hispanoamericana"],
    ".uia.ac.cr": ["Universidad Internacional de las Américas"],
    ".ulacit.ac.cr": ["Universidad Latinoamericana de Ciencia y Tecnología"],
    ".ulasalle.ac.cr": ["Universidad de La Salle"],
    ".ulatina.ac.cr": ["Universidad Latina de Costa Rica"],
    ".ulicori.ac.cr": ["Universidad Libre de Costa Rica"],
    ".una.ac.cr": ["Universidad Nacional"],
    ".unam.ac.cr": ["Universidad Autonoma Monterrey"],
    ".uned.ac.cr": ["Universidad Estatal a Distancia"],
    ".usam.ac.cr": ["Universidad San Marcos"],
    ".usj.ac.cr": ["Universidad de San José"],
    ".utur.ac.cr": ["Universidad del Turismo"],
    ".uveritas.ac.cr": ["Universidad Veritas"],
    ".cuc.cr": ["Colegio Universitario de Cartago"],
    ".ulacit.ed.cr": ["Universidad Latinoamericana de Ciencia y Tecnología"],
    ".estudiantec.cr": ["Costa Rica Institute of Technology"],
    ".est.mep.go.cr": [
        "COTEPECOS (Colegio Técnico Profesional de Educación Comercial y Servicios)",
        "Professional Technical College of Business Education and Services",
    ],
    ".estudiantes.tec.cr": [
        "Tecnológico de Costa Rica",
        "Costa Rica Technology Institute",
    ],
    ".una.cr": ["Universidad Nacional de Costa Rica"],
    ".uned.cr": ["Universidad Estatal a Distancia"],
    ".co.cu": ["Universidad de Granma"],
    ".cujae.edu.cu": ["Instituto Superior Politécnico José Antonio Echeverría"],
    ".ismm.edu.cu": ["Instituto Superior Minero Metalúrgico Dr. Antonio Núñez Jiménez"],
    ".reduc.edu.cu": ["Universidad de Camagüey"],
    ".ucf.edu.cu": ["Universidad de Cienfuegos"],
    ".uclv.edu.cu": ["Universidad Central de Las Villas"],
    ".uho.edu.cu": ["Universidad de Holguín"],
    ".uo.edu.cu": ["Universidad de Oriente"],
    ".upr.edu.cu": ["Universidad de Pinar del Río"],
    ".rimed.cu": ["Universidad Pedagógica José Martí, Camagüey"],
    ".uh.cu": ["Universidad de La Habana"],
    ".unica.cu": ["Universidad de Ciego de Avila"],
    ".iscee.edu.cv": [
        "Instituto Superior de Ciências Económicas e Empresariais",
        "http://iscee.edu.cv/",
    ],
    ".unicv.edu.cv": ["Universidade Cabo Verde"],
    ".us.edu.cv": ["Universidade de Santiago", "University of Santiago"],
    ".frateraureliosbo.cw": ["Frater Aurelio SBO"],
    ".uoc.cw": ["University of Curaçao"],
    ".ac.ac.cy": ["Americanos College"],
    ".ciim.ac.cy": ["Cyprus International Institute of Management (CIIM)"],
    ".ctleuro.ac.cy": ["The CTL Eurocollege"],
    ".cut.ac.cy": ["Cyprus University of Technology"],
    ".cycollege.ac.cy": ["Cyprus College"],
    ".frederick.ac.cy": ["Frederick University"],
    ".nup.ac.cy": ["Neapolis University Pafos"],
    ".ouc.ac.cy": ["Open University of Cyprus"],
    ".ucy.ac.cy": ["University of Cyprus"],
    ".unic.ac.cy": ["University of Nicosia"],
    ".bryngwyn.cymru": ["Bryngwyn Comprehensive School"],
    ".agstepanska.cz": ["Akademické gymnázium Štěpánská"],
    ".ambis.cz": [
        "Vysoká škola regionálního rozvoje a Bankovní institut - AMBIS, a.s."
    ],
    ".amu.cz": ["Academy of Performing Arts"],
    ".bigy-cb.cz": ["Biskupské gymnázium J. N. Neumanna a Církevní základní škola"],
    ".bivs.cz": ["The College of Banking", "Bankovní institut vysoká škola"],
    ".math.cas.cz": [" Institute of Mathematics of the Czech Academy of Sciences"],
    ".cerge-ei.cz": [
        "Center for Economic Research and Graduate Education - Economics Institute"
    ],
    ".ceskolipska.cz": ["Gymnázium, Praha 9, Českolipská 373"],
    ".cichnovabrno.cz": [
        "High School of informatics, postal services and finance Brno, funded organization"
    ],
    ".copsu.cz": ["VOŠ, SŠ, COP Sezimovo Ústí"],
    ".coptkm.cz": ["Střední škola - Centrum odborné přípravy technické Kroměříž"],
    ".cuni.cz": ["Charles University Prague"],
    ".cvut.cz": ["Czech Technical University of Prague"],
    ".czu.cz": ["Czech University of Agriculture Prague"],
    ".duhovkagymnazium.cz": ["GYMNÁZIUM DUHOVKA"],
    ".educanet.cz": [
        "EDUCAnet - Gymnázium, střední odborná škola a základní škola Praha, s.r.o."
    ],
    ".educhem.cz": [
        "Střední Škola Educhem a.s.",
        "Official Web: https://educhem.cz",
        "Long-term courses website page: https://educhem.cz/uchazec-o-studium/nabidka-oboru-vzdelavani/informacni-technologie/",
        "Contact: https://educhem.cz/o-skole/uredni-deska/ ",
        "Address: Okružní 128 435 13 Meziboří u Litvínova",
        "Domain: educhem.cz",
    ],
    ".edukomplex.cz": ["European Polytechnic Institute"],
    ".ekodom.cz": ["VOŠ, OA a SZŠ Domažlice"],
    ".famu.cz": ["Academy of Performing Arts, Film and TV Fakulty"],
    ".frengp.cz": [
        "Gymnázium a Střední průmyslová škola elektrotechniky a informatiky, Frenštát pod Radhoštěm, příspěvková organizace"
    ],
    ".g8mb.cz": ["GYMNÁZIUM, MLADÁ BOLESLAV, PALACKÉHO 191/1"],
    ".gbl.cz": ["Josef Svatopluk Machar's high school"],
    ".gchd.cz": ["Gymnazium Christiana Dopplera"],
    ".gfp.cz": [
        "Gymnazium F. Palackeho v Neratovicich",
        "Grammar School of Frantisek Palacky in Neratovice",
    ],
    ".ggg.cz": ["Gymnázium, Praha 8, Ústavní 400"],
    ".ghb.cz": ["\ufeffGymnázium Havlíčkův Brod"],
    ".gjak.cz": ["Gymnázium J. A. Komenského a Jazyková škola Uherský Brod"],
    ".gjj.cz": ["Gymnázium Josefa Jungmanna Litoměřice"],
    ".gjk.cz": ["Gymnazium Jana Keplera"],
    ".student.gjvj.cz": ["Gymnázium Jana Valeriána Jirsíka"],
    ".gjvj.cz": ["Gymnázium Jana Valeriána Jirsíka"],
    ".gkolin.cz": [
        "Gymnázium, Kolín III, Žižkova 162",
        "Grammar school in Kolín, the Czech Rep.",
    ],
    ".glnb.cz": ["Gymnazium Lipnik nad Becvou"],
    ".gml.cz": ["Gymnázium Matyáše Lercha"],
    ".goa-orlova.cz": ["Gymnázium a Obchodní akademie Orlová"],
    ".gyarab.cz": ["Gymnázium Arabská"],
    ".gybon.cz": ["Božena Němcová Grammar School"],
    ".gymberoun.cz": [
        "Gymnázium Joachima Barranda Beroun",
        "Joachim Barrand Beroun Grammar School",
    ],
    ".gymhu.cz": ["Gymnazium dr. A. Hrdlicky, Humpolec"],
    ".gymi.cz": [
        "Gymnázium Mimoň, Gymnázium, Mimoň, Letná 263, příspěvková organizace"
    ],
    ".gymkc.cz": ["Gymnázium Karla Čapka v Dobříši"],
    ".gymnasiumkladno.cz": ["Gymnasium Kladno"],
    ".gymspit.cz": ["Gymnázium, Praha 9, Špitálská 700"],
    ".gymzr.cz": ["Gymnazium Zdar nad Sazavou"],
    ".gyohavl.cz": [
        "Gymnázium Olgy Havlové, Ostrava-Poruba",
        "Olga Havlova Grammar School, Ostrava-Poruba",
    ],
    ".infis.cz": [
        "Střední škola informatiky a finančních služeb, Plzeň, Klatovská 200G",
        "Secondary School of Informatics and Financial Services, Plzeň, Klatovská 200G",
    ],
    ".infovsem.cz": [
        "University of economics and management Prague",
        "Vysoká škola ekonomie a managementu",
    ],
    ".jcu.cz": ["University of South Bohemia"],
    ".kyberna.cz": ["High School and College of Applied Cybernetic"],
    ".mendelu.cz": ["Mendel University in Brno"],
    ".mensagymnazium.cz": ["Mensa gymnázium, o.p.s."],
    ".meruzalka.cz": ["Meruzalka-Montessori MŠ a ZŠ v Jihlavě"],
    ".mg-akademie.cz": ["\ufeffSOŠ Manažerská Akademie"],
    ".muni.cz": ["Masaryk University"],
    ".mup.cz": ["Metropolitní univerzita Praha", "Metropolitan University Prague"],
    ".novyporg.cz": ["Nový Porg Základní Škola a Gymnázium"],
    ".oa-opava.cz": [
        "Obchodní akademie a Střední odborná škola logistická, Opava, příspěvková organizace"
    ],
    ".oaopava.cz": [
        "Obchodní akademie a Střední odborná škola logistická, Opava, příspěvková organizace"
    ],
    ".oauh.cz": ["Obchodní Akademie Uherské Hradiště"],
    ".odbskmb.cz": [
        "STŘEDNÍ ODBORNÁ ŠKOLA A STŘEDNÍ ODBORNÉ UČILIŠTĚ, MLADÁ BOLESLAV, JIČÍNSKÁ 762"
    ],
    ".orangefactory.cz": ["Soukroma VOS umeni a reklamy s.r.o. Orange Factory"],
    ".ossp.cz": ["Odborná střední škola podnikání a mediální tvorby Kolín s.r.o. "],
    ".osu.cz": ["University of Ostrava"],
    ".polac.cz": ["Police Academy of Czech Republic"],
    ".porg.cz": ["PORG – gymnázium a základní škola, o. p. s. "],
    ".praguecollege.cz": ["Prague College"],
    ".prumkadc.cz": [
        "Vyšší odborná škola a Střední průmyslová škola strojní, stavební a dopravní, Děčín, příspěvková organizace"
    ],
    ".pslib.cz": [
        "Střední průmyslová škola strojní a elektrotechnická a Vyšší odborná škola Liberec"
    ],
    ".pspbystrice.cz": [
        "Základní škola a mateřská škola Stanisława Hadyny s polským jazykem vyučovacím Bystřice 366, okr. Frýdek-Místek, příspěvková organizace",
        "Stanisław Hadyna Elementary School and Kindergarten with Polish language of instruction Bystřice 366, okr. Frýdek-Místek, contributory organization",
    ],
    ".sgagy.cz": ["Sportovní gymnázium Kladno"],
    ".skolaac.cz": ["Střední škola André Citroëna Boskovice, příspěvková organizace"],
    ".skolakrizik.cz": [
        "Vyšší odborná škola a střední průmyslová škola elektrotechnická Františka Křižíka"
    ],
    ".slu.cz": ["Silesian University"],
    ".sostp.cz": [
        "Hotelová škola, Obchodní akademie a Střední průmyslová škola Teplice"
    ],
    ".sps-cl.cz": ["Střední průmyslová škola Česká Lípa"],
    ".sps-karvina.cz": ["Střední průmyslová škola, Karviná, příspěvková organizace"],
    ".sps-pi.cz": ["SPŠ a VOŠ Písek"],
    ".sps-prosek.cz": ["Střední průmyslová škola na Proseku"],
    ".sps-tabor.cz": ["SPŠ strojní a stavební, Tábor"],
    ".spscv.cz": ["SPS a VOS Chomutov"],
    ".spse.cz": ["SPŠE a VOŠ Pardubice"],
    ".spsejecna.cz": ["SPŠE Ječná"],
    ".spselit.cz": [
        "Střední průmyslová škola elektrotechniky a informačních technologií"
    ],
    ".spseol.cz": [
        "Vyšší odborná škola a Střední průmyslová škola elektrotehcnická Olomouc"
    ],
    ".spseplzen.cz": ["VOŠ a SPŠE Plzeň"],
    ".spshranice.cz": ["Střední průmyslová škola Hranice"],
    ".spsjc.cz": ["VOŠ a SPŠ, Jičín"],
    ".spsoafm.cz": [
        "Střední průmyslová škola a obchodní akademie, Frýdek-Místek",
        "Secondary High School - SPSOAFM",
    ],
    ".spsostrov.cz": ["Střední průmyslová škola Ostrov, příspěvková organizace"],
    ".spspzlin.cz": ["\ufeffStřední průmyslová škola polytechnická – COP Zlín"],
    ".spsrakovnik.cz": [
        "Střední průmyslová škola Emila Kolbena Rakovník, příspěvková organizace"
    ],
    ".spsstavbrno.cz": ["Střední průmyslová škola stavební Brno"],
    ".spstrutnov.cz": ["Střední průmyslová škola Trutnov Školní 101"],
    ".spsul.cz": [
        "Střední průmyslová škola, Ústí nad Labem, Resslova 5, příspěvková organizace"
    ],
    ".spszr.cz": ["VOŠ a SPŠ Žďár nad Sázavou"],
    ".ssakhk.cz": ["High School and College of Applied Cybernetic"],
    ".ssemi.cz": ["Střední škola elektrotechniky, multimédií a informatiky"],
    ".ssinfotech.cz": ["Stredni skola informacnich technologii, s.r.o."],
    ".sspbrno.cz": ["High School of Electrical Engineering and Information Technology"],
    ".ssps.cz": ["Smíchovská střední průmyslová škola"],
    ".sspu-opava.cz": ["Střední škola průmyslová a umělecká Opava"],
    ".sssvt.cz": ["Soukromá střední škola výpočetní techniky"],
    ".stredniskola.cz": ["Střední škola informatiky a právních studií"],
    ".tul.cz": ["Technical University of Liberec"],
    ".ufe.cz": ["Institute of Photonics and Electronics, Czech Academy of Sciences"],
    ".uhk.cz": ["University of Hradec Králové"],
    ".ujep.cz": ["University of Jan Evangelista Purkyne"],
    ".unicorncollege.cz": ["Unicorn College"],
    ".unob.cz": ["University of Defence"],
    ".unva.cz": ["University of Northern Virginia, Prague Campus"],
    ".unyp.cz": ["University of New York in Prague"],
    ".upce.cz": ["University of Pardubice"],
    ".upol.cz": ["Palacky University"],
    ".utb.cz": ["Tomas Bata University in Zlin"],
    ".uzlabina.cz": ["SPŠE v Úžlabině"],
    ".vassboskovice.cz": [
        "Vyšší odborná škola ekonomická a zdravotnická a Střední škola Boskovice"
    ],
    ".vfu.cz": ["University of Veterinary and Pharmaceutical Science"],
    ".vosp.cz": ["College of Media and Journalism"],
    ".vsb.cz": ["Technical University of Mining and Metallurgy Ostrava"],
    ".vscht.cz": ["Prague Institute of Chemical Technology"],
    ".vsci.cz": ["Cevro Institut College"],
    ".vse.cz": ["University of Economics Prague"],
    ".vsfs.cz": ["The University of Finance and Administration"],
    ".vslib.cz": ["Technical University of Liberec"],
    ".vsp.cz": ["University of Education Hradec Kralove"],
    ".vspj.cz": ["College of Polytechnics Jihlava"],
    ".vspp.cz": ["University of Education business and law"],
    ".vsps-su.cz": ["VOŠ a SPŠ Šumperk"],
    ".vutbr.cz": ["Brno University of Technology"],
    ".zcu.cz": ["University of West Bohemia"],
    ".zshanusovice.cz": ["Elementary School in Hanušovice"],
    ".zsjunacka.cz": ["Základní škola Ostrava-Stará Bělá"],
    ".zskomenskeho.cz": [
        "Základní škola, Kroměříž, Komenského náměstí 440, příspěvková organizace"
    ],
    ".zssvat.cz": ["Základní škola Svatoplukova 7, Šternberk, příspěvková organizace"],
    ".student.42wolfsburg.de": ["42wolfsburg", "42wolfsburg"],
    ".Birklehof.de": ["Schule Birklehof e.V. Hinterzarten"],
    ".aagcux.de": ["Amandus-Abendroth-Gymnasium Cuxhaven"],
    ".abendgymnasium-muenster.de": ["Abendgymnasium Münster"],
    ".extern.abk-stuttgart.de": ["Staatliche Akademie der Bildenden Künste Stuttgart"],
    ".stud.abk-stuttgart.de": ["Staatliche Akademie der Bildenden Künste Stuttgart"],
    ".adolfinum.de": ["Gymnasium Adolfinum Moers"],
    ".aeg-nb.de": ["Albert-Einstein-Gymnasium Neubrandenburg"],
    ".aegmail.de": ["Albert-Einstein-Gymnasium Duisburg-Rumeln"],
    ".students.ajc-bk.de": ["Adam - Josef - Cüppers - Berufskolleg Ratingen"],
    ".akad.de": [
        "AKAD Hochschulen für Berufstätige, Fachhochschule Leipzig",
        "Hochschule für Berufstätige Rendsburg",
    ],
    ".albbw.de": ["Annedore-Leber-Berufsbildungswerk Berlin"],
    ".alstergymnasium.de": ["Alster Gymnasium"],
    ".ammersee-gymnasium.de": ["Ammersee-Gymnasium"],
    ".amseegym.de": ["Ammersee-Gymnasium"],
    ".anno-gymnasium.de": ["Städtisches Anno-Gymnasium Siegburg"],
    ".schueler.ars-mr.de": ["Adolf-Reichwein-Schule Marburg"],
    ".ars-mr.de": ["Adolf Reichwein Schule"],
    ".asfh-berlin.de": [
        "Alice-Salomon-Fachhochschule für Sozialarbeit und Sozialpädagogik Berlin"
    ],
    ".asg-ehst.de": ["Albert-Schweitzer Gymnasium Eisenhüttenstadt"],
    ".asg-huerth.de": ["Albert-Schweitzer-Gymnasium Hürth"],
    ".ass-vs.de": ["Albert-Schweitzer-Schule"],
    ".asw-berufsakademie.de": ["ASW – Berufsakademie Saarland e.V."],
    ".athenetz.de": ["Gymnasium Athenaeum Stade"],
    ".atiw.de": ["ATIW Berufskolleg"],
    ".augustana.de": ["Augustana Hochschule Neuendettelsau"],
    ".ausbildungswolken.de": [
        "E-Learning ALBBW (Annedore-Leber-Berufsbildungswerk Berlin)",
        "Homepage: https://moodle.ausbildungswolken.de",
        "3 years vocational education: https://www.albbw.de/fuer-lehrkraefte-betreuerinnen/ausbildungsangebote/berufsausbildung/informationstechnologie/",
        "Domain for repository: ausbildungswolken.de",
    ],
    ".avs-itzehoe1.de": ["Auguste-Viktoria-Schule Itzehoe, Hs. 1"],
    ".b-tu.de": ["Brandenburg University of Technology Cottbus–Senftenberg"],
    ".b3-fuerth.de": [
        "Martin-Segitz-Schule / Staatliche Berufsschule III Fürth",
        "Martin-Segitz-Schule / State vocational school III Fürth",
    ],
    ".ba-bautzen.de": ["Berufsakademie Sachsen Staatliche Studienakademie Bautzen"],
    ".rz.ba-dresden.de": ["Staatliche Studienakademie Dresden"],
    ".ba-dresden.de": ["Berufsakademie Sachsen Staatliche Studienakademie Dresden"],
    ".ba-eisenach.de": ["Berufsakademie Eisenach"],
    ".ba-fulda.de": [
        "Private Berufsakademie Fulda University of Cooperative Education ",
        "http://www.ba-fulda.de",
    ],
    ".ba-glauchau.de": ["Staatliche Studienakademie Glauchau"],
    ".ba-leipzig.de": ["Berufsakademie Leipzig"],
    ".ba-riesa.de": ["Berufsakademie Sachsen Staatliche Studienakademie Riesa"],
    ".ba-rm.de": ["Berufsakademie Rhein Main"],
    ".ba-sachsen.de": ["Berufsakademie Sachsen Staatliche Studienakademie Leipzig"],
    ".sibi.badhonnef.de": ["Siebengebrigsgymnasium"],
    ".bbs-buchholz.de": [
        "BBS Buchholz",
        "Berufsbildende Schulen Buchholz in der Nordheide",
        "www.bbs-buchholz.de",
        "www.bbs-buchholz.de/internet/bildungsangebote/fachrichtungen/fachrichtungen.php#Informationsverarbeitung",
    ],
    ".bbs-buxtehude.de": ["Berufsbildende Schulen Buxtehude"],
    ".bbs-me.de": ["BBS-ME – Otto-Brenner-Schule "],
    ".bbs-meppen.de": ["Berufsbildende Schulen Meppen"],
    ".bbs-montabaur.de": ["BBS Montabaur"],
    ".bbs-nienburg.de": ["Berufsbildende Schulen des Landkreises Nienburg/Weser"],
    ".bbs-ohz.de": ["Berufsbildende Schulen Osterholz-Scharmbeck"],
    ".bbs-stadthagen.de": [
        "Berufsbildende Schule Stadthagen",
        "vocational schools Stadthagen",
    ],
    ".bbs-wittlich.de": ["Berufsbildende Schule Wittlich"],
    ".bbs1-gifhorn.de": ["BBS1 Gifhorn", "Berufsbildene Schule 1 Gifhorn"],
    ".bbs1-kl.de": ["Berufsbildenden Schulen I Kaiserslautern"],
    ".bbs1-lg.de": ["Berufsbildenden Schulen I Lüneburg"],
    ".bbs1-lueneburg.de": [None],
    ".unterricht.bbs1-mainz.de": ["BBS 1 Mainz"],
    ".bbs1emd.de": ["Berufsbildende Schulen I Emden"],
    ".bbs2-mainz.de": ["Sophie Scholl Schule Mainz"],
    ".bbs2-northeim.de": ["BBS 2 Northeim"],
    ".bbs2.de": [
        "Berufsbildende Schule 2 Delmenhorst (BBS 2 Delmenhorst)",
        "Kerschensteiner School Delmenhorst",
    ],
    ".bbs2wob.de": ["Berufsbildende Schulen 2 Wolfsburg"],
    ".students.bbssth.de": [
        "Berufsbildende Schule Stadthagen",
        "vocational schools Stadthagen",
    ],
    ".bbssth.de": ["Berufsbildende Schule Stadthagen", "vocational schools Stadthagen"],
    ".bbstghs.de": ["\ufeffBerufliches Gymnasium Technik Bad Kreuznach"],
    ".bbstghs365.de": ["\ufeffBerufliches Gymnasium Technik Bad Kreuznach"],
    ".bbw-fi.de": ["SFZ Förderzentrum gGmbH (Berufsbildungswerk Chemnitz)"],
    ".bbw-rki-berlin.de": [
        "Rotkreuz-Institut Berufsbildungswerk",
        "Homepage:https://www.rkibbw.de/",
        "IT-Course example: https://www.rkibbw.de/angebote/berufsausbildung/fachinformatiker-anwendungsentwicklung.html",
    ],
    ".bbzsm.de": ["Berufsbildungszentrum Schmalkalden"],
    ".bccn-berlin.de": ["BERNSTEIN CENTER FOR COMPUTATIONAL NEUROSCIENCE, BERLIN"],
    ".bcw-gruppe-net.de": ["bcw-gruppe-net"],
    ".berlin.de": ["Fachhochschule für Verwaltung und Rechtspflege Berlin"],
    ".sus.bertha-online.de": ["Bertha-von-Suttner Schule "],
    ".berufsakademie-oldenburg.de": ["Berufsakademie Oldenburg"],
    ".berufsakademie-sh.de": ["Berufsakademie Schleswig-Holstein"],
    ".schueler.berufskolleg.de": [
        "Berufskolleg Hilden",
        "Berufskolleg Hilden des Kreises Mettmann",
    ],
    ".berufskolleg-beckum.de": [
        "Berufskolleg Beckum des Kreises Warendorf Europaschule"
    ],
    ".berufskolleg-geilenkirchen.de": [
        "Berufskolleg Ernaehrung, Sozialwesen, Technik des Kreises Heinsberg in Geilenkirchen"
    ],
    ".berufskolleg-kleve.de": ["Berufskolleg des Kreises Kleve in Kleve"],
    ".berufskolleg-rheine.de": ["Berufskolleg Rheine des Kreises Steinfurt"],
    ".berufskolleg-werne.de": ["Freiherr-vom-Stein Berufskolleg Werne"],
    ".berufskolleg.de": [
        "Berufskolleg Hilden des Kreises Mettmann",
        "Berufskolleg Hilden",
    ],
    ".berufsschule-dachau.de": [
        "Staatliche Berufsschule Dachau",
        "Nikolaus-Lehner-Schule",
    ],
    ".bethel.de": ["Kirchliche Hochschule Bethel"],
    ".beuth-hochschule.de": ["Beuth Hochschule für Technik Berlin"],
    ".bfw-hamburg.de": ["Berufsförderungswerk Hamburg", "Bfw Hamburg"],
    ".bfw-oberhausen.de": ["Berufsförderungswerk Oberhausen, Primary Domain"],
    ".bfwob.de": ["Berufsförderungswerk Oberhausen"],
    ".bgbentheim.de": ["Burg-Gymnasium Bad Bentheim"],
    ".bht-berlin.de": ["Berliner Hochschule für Technik"],
    ".bib.de": ["Fachhochschule für die Wirtschaft"],
    ".gym-muentzer.bildung-lsa.de": ['GIEBICHENSTEIN-GYMNASIUM "THOMAS MÜNTZER" HALLE'],
    ".bildung-unna.de": ["Hellweg Berufskolleg Unna"],
    ".bits-iserlohn.de": ["BiTS - Business and Information Technology School gGmbH"],
    ".bk-berliner-platz.de": ["Berufskolleg Berliner Platz"],
    ".bk-deutz.de": ["Berufskolleg Deutzer Freiheit "],
    ".bk-h.de": ["Berufskolleg Hattingen"],
    ".bk-hennef.de": ["Carl-Reuther-Berufskolleg des Rhein-Sieg-Kreises in Hennef"],
    ".bk-opladen.de": ["Berufskolleg Opladen"],
    ".bk-technik-moers.de": ["Berufskolleg für Technik Moers"],
    ".bk-tm.de": ["Berufskolleg Platz der Republik fur Technik und Medien"],
    ".bkgeldern.de": ["Berufskolleg Geldern des Kreises Kleve"],
    ".bkhaspel.de": ["Berufskolleg Am Haspel"],
    ".student.bkukr.de": ["Berufskolleg Krefeld Uerdingen"],
    ".hhek.bonn.de": ["Heinrich Hertz Europakolleg"],
    ".bracke-igs.de": ["Wilhelm Bracke Gesamtschule"],
    ".brand-university.de": ["Brand University of Applied Sciences, Hamburg, Germany"],
    ".schule.bremen.de": ["Bremer Schulzentrum"],
    ".bs-an.de": ["Staatliche Berufsshule I Ansbach"],
    ".bs-elmshorn.de": [
        "Berufliche Schule des Kreises Pinneberg in Elmshorn, Europaschule",
        "http://www.bs-elmshorn.de",
    ],
    ".bs-erlangen.de": ["Staatliche Berufsschule Erlangen"],
    ".bs-hassfurt.de": [
        "Heinrich-Thein-Schule",
        "Staatliches Berufliches Schulzentrum Haßfurt",
    ],
    ".bs-korbach.de": [
        "Berufliche Schulen des Landkreises Waldeck-Frankenberg in Korbach und Bad Arolsen AöR"
    ],
    ".bs-riedlingen.de": ["Berufliche Schule Riedlingen"],
    ".bs-wangen.de": ["Berufliches Schulzentrum Wangen"],
    ".bs1-kempten.de": ["Staatliche Berufsschule I Kempten"],
    ".bs1traunstein.de": ["Staatliche Berufsschule 1 Traunstein"],
    ".bs7-augsburg.de": ["Berufsschule 7 ", "Career School 7 "],
    ".bso-hef.de": ["Berufliche Schulen Bad Hersfeld"],
    ".bsutaunus.de": ["Berufliche Schulen Untertaunus"],
    ".student.bsz-bietigheim.de": ["BSZ Bietigheim-Bissingen"],
    ".bsz-eoplauen.de": ["Berufliches Schulzentrum e.o.plauen"],
    ".bszh.de": ["Staatliches Berufsschulzentrum Hermsdorf"],
    ".bt-office.de": ["Berufskolleg für Technik des Kreis Borken"],
    ".buhmann-hannover.de": [
        "Dr. Buhmann Schule Hannover",
        "Dr. Buhmann Schule Hanover",
    ],
    ".burg-halle.de": ["Burg Giebichenstein Kunsthochschule Halle"],
    ".burggymnasium-altena.de": ["Burggymnasium Altena"],
    ".bws-hofheim.de": ["Brühlwiesenschule Hofheim"],
    ".schueler.bwv-ac.de": [
        "Berufskolleg für Wirtschaft und Verwaltung der StädteRegion Aachen"
    ],
    ".bwv-ahaus.de": ["Berufskolleg Wirtschaft und Verwaltung Ahaus"],
    ".bztg-oldenburg.de": ["Bildungszentrum für Technik und Gestaltung Oldenburg"],
    ".caeci-ol.de": ["Gymnasium Cäcilienschule Oldenburg"],
    ".carl-orff-gym.de": ["Carl-Orff-Gymnasium Unterschleißheim"],
    ".cased.de": ["Center for Advanced Security Research Darmstadt"],
    ".cato-achim.de": ["Cato Bontjes van Beek-Gymnasium"],
    ".cbk1.de": ["Cuno-Berufskolleg I"],
    ".cbs-edu.de": ["Cologne Business School"],
    ".cdtm.de": ["Center for Digital Technology and Management"],
    ".charite.de": ["\ufeffCharité - Universitätsmedizin Berlin"],
    ".chf.de": ["Institut Dr. Flad"],
    ".cit-leipzig.de": ["CiT Leipzig"],
    ".cjd-bs.de": ["CJD Jugenddorf-Christophorusschule Braunschweig"],
    ".cmb-portal.de": ["Carl-Miele-Berufskolleg des Kreises Gütersloh"],
    ".csbme.de": ["Carl-Severing-Berufskolleg für Metall- und Elektrotechnik"],
    ".dacs-bund.de": ["Hochschule des Bundes für öffentliche Verwaltung"],
    ".dalberg-gymnasium.de": ["Karl-Theodor-v.-Dalberg-Gymnasium"],
    ".das-mgh-hamm.de": ["Name: Märkisches Gymnasium Hamm / MGH Hamm"],
    ".db-gym.de": ["Dietrich-Bonhoeffer-Gymnasium Ahlhorn"],
    ".dbb-detmold.de": [
        "Dietrich-Bonhoeffer-Berufskolleg des Kreises Lippe in Detmold (dbb)"
    ],
    ".dbb-lippe.de": [
        "Dietrich-Bonhoeffer-Berufskolleg des Kreises Lippe in Detmold (dbb)"
    ],
    ".dbg-ratingen.de": ["Dietrich-Bonhoeffer-Gymnasium Ratingen"],
    ".student.dbuas.de": [
        "Digital Business University of Applied Sciences",
        "Digital Business University of Applied Sciences",
    ],
    ".design-akademie-berlin.de": [
        "design akademie berlin / SRH Hochschule für Kommunikation und Design"
    ],
    ".cas.dhbw.de": ["Center for Advanced Studies Duale Hochschule Baden Württemberg"],
    ".heilbronn.dhbw.de": ["DHBW Heilbronn"],
    ".lehre.mosbach.dhbw.de": ["\ufeffDuale Hochschule Baden-Württemberg, Mosbach"],
    ".mosbach.dhbw.de": ["Duale Hochschule Baden-Württemberg Mosbach"],
    ".dhbw-heidenheim.de": ["Duale Hochschule Baden-Württemberg, Heidenheim"],
    ".student.dhbw-karlsruhe.de": ["Duale Hochschule Baden-Württemberg Karlsruhe"],
    ".dhbw-karlsruhe.de": ["Duale Hochschule Baden-Württemberg Karlsruhe"],
    ".dhbw-loerrach.de": ["Duale Hochschule Baden-Württemberg Lörrach"],
    ".dhbw-mannheim.de": ["Duale Hochschule Baden-Württemberg, Mannheim"],
    ".dhbw-mosbach.de": ["Duale Hochschule Baden-Württemberg, Mosbach"],
    ".stud.dhbw-ravensburg.de": ["Duale Hochschule Baden-Württemberg Ravensburg"],
    ".dhbw-ravensburg.de": ["Duale Hochschule Baden-Württemberg Ravensburg"],
    ".lehre.dhbw-stuttgart.de": [
        "DHBW Stuttgart",
        "Cooperative State University Stuttgart",
    ],
    ".dhbw-stuttgart.de": ["Duale Hochschule Baden-Württemberg Stuttgart"],
    ".dhbw-vs.de": ["Baden-Wuerttemberg Cooperative State University"],
    ".dhfpg-bsa.de": ["Deutsche Hochschule für Prävention und Gesundheitsmanagement"],
    ".dhfpg.de": ["Deutsche Hochschule für Prävention und Gesundheitsmanagement"],
    ".stud.eisenach.dhge.de": [
        "Duale Hochschule Gera Eisenach",
        "Gera Eisenach Cooperative State University",
        "Homepage: https://www.dhge.de/DHGE.html",
    ],
    ".stud.gera.dhge.de": [
        "Duale Hochschule Gera Eisenach",
        "Gera Eisenach Cooperative State University",
        "Homepage: https://www.dhge.de/DHGE.html",
    ],
    ".dhge.de": [
        "Duale Hochschule Gera Eisenach",
        "Gera Eisenach Cooperative State University",
    ],
    ".dhsh.de": ["Berufsakademie Schleswig-Holstein"],
    ".dhv-speyer.de": ["Deutsche Hochschule für Verwaltungswissenschaften Speyer"],
    ".diesterweg-gymnasium.de": ["Diesterweg Gymnasium"],
    ".diploma.de": [
        "DIPLOMA-Fachhochschule Ölsnitz/Vogtland",
        "Fachhochschule Nordhessen",
    ],
    ".dkfz-heidelberg.de": ["DKFZ Heidelberg"],
    ".domgymnasium-verden.de": ["Domgymnasium Verden"],
    ".doz-provadis-hochschule.de": [
        "Provadis School of International Management & Technology AG"
    ],
    ".dshs-koeln.de": ["Deutsche Sporthochschule Köln"],
    ".dv-schulen.de": [
        "Städtische Berufsfachschule für IT-Berufe",
        "Städtische Berufsfachschule für Büroberufe",
        "Städtische Berufsfachschule für Kaufmännische Assistenten",
        "Städtische Fachschule für Datenverarbeitung",
        "Städtische Wirtschafsschule Außenstelle Grombühl",
        ".group",
    ],
    ".dzne.de": [
        "Deutsches Zentrum für Neurodegenerative Erkrankungen, (DZNE)",
        "German Center for Neurodegenerative Diseases",
    ],
    ".e-b-z.de": [
        "Europäisches Bildungszentrum der Wohnungs- und Immobilienwirtschaft (EBZ)- gemeinnützige Stiftung"
    ],
    ".eah-jena.de": ["Ernst-Abbe-Hochschule Jena"],
    ".eba-muenchen.de": ["Europäische Betriebswirtschafts-Akademie"],
    ".campus.ebc-hochschule.de": ["EBC Hochschule"],
    ".ebs-iserv.de": ["ELSA-BRÄNDSTRÖM-SCHULE"],
    ".ebs.de": ["European Business School Schloß Reichartshausen"],
    ".ecla.de": ["European College of Liberal Arts"],
    ".mmbbs.eduplaza.de": ["multi media BBS"],
    ".edv-schulen-wiesau.de": [
        "Staatliche EDV-Schulen Wiesau",
        "Berufliches Schulzentrum Wiesau",
    ],
    ".edvschule-plattling.de": ["EDV-Schulen des Landkreises Deggendrof"],
    ".edvw.de": ["EDV-Schule Wiesau"],
    ".efh-bochum.de": ["Evangelische Fachhochschule Rheinland-Westfalen-Lippe"],
    ".efh-darmstadt.de": ["Evangelische Fachhochschule Darmstadt"],
    ".efh-freiburg.de": [
        "Evangelische Fachhochschule Freiburg, Hochschule für Soziale Arbeit, Diakonie und Religionspädagogik"
    ],
    ".efh-hannover.de": ["Evangelische Fachhochschule Hannover"],
    ".efh-reutlingen-ludwigsburg.de": [
        "Evangelische Fachhochschule Reutlingen-Ludwigsburg, Hochschule für Soziale Arbeit, Religionspädagogik und Diakonie"
    ],
    ".efhlu.de": [
        "Evangelische Fachhochschule Ludwigshafen Hochschule für Sozial- und Gesundheitswesen"
    ],
    ".egb-koeln.de": ["Erich-Gutenberg Berufskolleg "],
    ".ehs-dresden.de": ["Evangelische Hochschule für Soziale Arbeit Dresden (FH)"],
    ".imap.elektronikschule.de": ["Elektronikschule Tettnang"],
    ".elektronikschule.de": ["Elektronikschule Tettnang"],
    ".embl.de": [
        "European Molecular Biology Laboratory",
        "EMBL, Heidelberg",
        "URL: https://www.embl.de/",
        "Courses: https://www.embl.de/training/index.php",
    ],
    ".emg-haar.de": ["Emg Haar"],
    ".ems-mainz.de": ["European Management School"],
    ".erasgym.de": ["Erasmus Gymnasium"],
    ".erasmus-kittler-schule.de": ["Erasmus-Kittler-Schule, Darmstadt"],
    ".ernestinum-rinteln.de": ["Gymnasium Ernestinum Rinteln"],
    ".ers-hameln.de": ["Eugen-Reintjes-Schule Hameln"],
    ".ess-erfurt.de": ["Edith Stein Schule Erfurt", "Edith Stein School Erfurt"],
    ".eufh-mail.de": ["Europäische Fachhochschule"],
    ".eufh.de": ["Europäische Fachhochschule"],
    ".europa-uni.de": [" "],
    ".euv-frankfurt-o.de": ["Europa-Universität Viadrina Frankfurt (Oder)"],
    ".evfh-berlin.de": [
        "Evangelische Fachhochschule Berlin, Fachhochschule für Sozialarbeit und Sozialpädagogik"
    ],
    ".evfh-nuernberg.de": ["Evangelische Fachhochschule Nürnberg"],
    ".fau.de": ["Friedrich-Alexander-Universität Erlangen-Nürnberg"],
    ".schule.fcbg.de": ["Freie Christliche Bekenntnisschule Gummersbach"],
    ".febb.de": ["FEBB (Freie Evangelische Bekenntnis Schule Bremen)"],
    ".feintechnikschule.de": [
        "Staatliche Feintechnikschule mit Technischem Gymnasium Schwenningen"
    ],
    ".ferdinand-braun-schule.de": ["Ferdinand-Braun-Schule"],
    ".ferdinand-steinbeis-institut.de": [
        "Ferdinand Steinbeis Institute, Stuttgart ",
        "Steinbeis University, Berlin ",
        "Bildungscampus, Heilbronn ",
    ],
    ".fern-fh.de": ["Fern-Fachhochschule Hamburg"],
    ".fernuni-hagen.de": ["Fernuniversität Gesamthochschule Hagen"],
    ".fes-wiesbaden.de": [
        "Friedrich-Ebert-Schule Wiesbaden",
        "Friedrich-Ebert-School Wiesbaden",
    ],
    ".fes365-pfungstadt.de": [
        "Friedrich-Ebert-Schule, Pfungstadt",
        "http://www.fes-pfungstadt.de",
    ],
    ".fh-Kempten.de": ["Fachhochschule Kempten, Hochschule für Technik und Wirtschaft"],
    ".alumni.fh-aachen.de": ["Fachhochschule Aachen"],
    ".fh-aachen.de": ["Fachhochschule Aachen"],
    ".fh-aalen.de": ["Internationale Fachhochschule Aalen"],
    ".fh-aschaffenburg.de": ["Fachhochschule Aschaffenburg"],
    ".fh-augsburg.de": ["Fachhochschule Augsburg"],
    ".fh-bad-honnef.de": ["Internationale Fachhochschule Bad Honnef"],
    ".fh-biberach.de": [
        "Fachhochschule Biberach, Hochschule für Bauwesen und Wirtschaft"
    ],
    ".fh-bielefeld.de": ["Fachhochschule Bielefeld"],
    ".fh-bingen.de": ["Fachhochschule Bingen"],
    ".fh-bochum.de": ["Fachhochschule Bochum"],
    ".fh-bonn-rhein-sieg.de": ["Fachhochschule Bonn-Rhein-Sieg"],
    ".fh-brandenburg.de": ["Technische Hochschule Brandenburg"],
    ".fh-deggendorf.de": [
        "Fachhochschule Deggendorf/Deggendorf Institute of Technology",
        "Domain:th-deg.de",
        "Email: ..@stud.th-deg.de",
        "Email: ..@th-deg.de",
    ],
    ".fh-dortmund.de": ["Fachhochschule Dortmund"],
    ".fh-duesseldorf.de": ["Hochschule Düsseldorf"],
    ".fh-erfurt.de": ["Fachhochschule Erfurt"],
    ".fh-flensburg.de": [
        "Hochschule Flensburg",
        "The old domain of Fachhochschule Flensburg, renamed to Hochschule Flensburg.",
        "The domain ist still in use for student email accounts.",
    ],
    ".fh-frankfurt.de": ["Fachhochschule Frankfurt am Main"],
    ".fh-fresenius.de": ["Europa Fachhochschule Fresenius"],
    ".fh-furtwangen.de": [
        "Fachhochschule Furtwangen, Hochschule für Technik und Wirtschaft"
    ],
    ".fh-gelsenkirchen.de": ["Fachhochschule Gelsenkirchen"],
    ".fh-giessen.de": ["Fachhochschule Gießen-Friedberg"],
    ".fh-hamburg.de": ["Fachhochschule Hamburg"],
    ".fh-hannover.de": ["Fachhochschule Hannover"],
    ".fh-heidelberg.de": ["Fachhochschule Heidelberg"],
    ".fh-heilbronn.de": [
        "Fachhochschule Heilbronn, Hochschule für Technik und Wirtschaft"
    ],
    ".fh-hildesheim.de": [
        "Fachhochschule Hildesheim/Holzminden/Göttingen, Hochschule für angewandte Wissenschaft und Kunst"
    ],
    ".fh-hof.de": ["Fachhochschule Hof"],
    ".fh-ingolstadt.de": ["Fachhochschule Ingolstadt"],
    ".fh-isny.de": [
        "Fachhochschule und Berufskollegs NTA, Prof.Dr. Grübler gemein. GmbH"
    ],
    ".fh-jena.de": ["Fachhochschule Jena"],
    ".fh-karlsruhe.de": ["Fachhochschule Karlsruhe, Hochschule für Technik"],
    ".fh-kiel.de": ["Fachhochschule Kiel"],
    ".fh-kl.de": ["Fachhochschule Kaiserslautern"],
    ".fh-koblenz.de": ["Fachhochschule Koblenz"],
    ".fh-koeln.de": ["Technische Hochschule Köln"],
    ".fh-konstanz.de": [
        "Fachhochschule Konstanz, Hochschule für Technik, Wirtschaft und Gestaltung"
    ],
    ".fh-landshut.de": [
        "Fachhochschule Landshut, Hochschule für Wirtschaft - Sozialwesen - Technik"
    ],
    ".fh-lausitz.de": ["Fachhochschule Lausitz"],
    ".fh-lippe.de": ["Fachhochschule Lippe"],
    ".fh-ludwigshafen.de": ["Fachhochschule Ludwigshafen, Hochschule für Wirtschaft"],
    ".fh-luebeck.de": ["Fachhochschule Lübeck"],
    ".fh-mainz.de": ["Fachhochschule Mainz"],
    ".fh-mannheim.de": [
        "Fachhochschule Mannheim, Hochschule für Technik und Gestaltung"
    ],
    ".fh-merseburg.de": ["Fachhochschule Merseburg"],
    ".fh-muenchen.de": ["Fachhochschule München"],
    ".fh-muenster.de": ["Fachhochschule Münster"],
    ".fh-neu-ulm.de": ["Fachhochschule Neu-Ulm"],
    ".fh-niederrhein.de": ["Fachhochschule Niederrhein"],
    ".fh-nordhausen.de": ["Fachhochschule Nordhausen"],
    ".fh-nuernberg.de": ["Georg-Simon-Ohm-Fachhochschule Nürnberg"],
    ".fh-nuertingen.de": [
        "Fachhochschule Nürtingen, Hochschule für Wirtschaft, Landwirtschaft und Landespflege"
    ],
    ".fh-offenburg.de": [
        "Fachhochschule Offenburg, Hochschule für Technik und Wirtschaft"
    ],
    ".fh-oow.de": ["Fachhochschule Oldenburg/Ostfriesland/Wilhelmshaven"],
    ".fh-osnabrueck.de": ["Fachhochschule Osnabrück"],
    ".fh-ottersberg.de": ["Freie Kunst-Studienstätte Ottersberg"],
    ".fh-potsdam.de": ["Fachhochschule Potsdam"],
    ".fh-regensburg.de": ["Fachhochschule Regensburg"],
    ".fh-reutlingen.de": [
        "Fachhochschule Reutlingen, Hochschule für Technik und Wirtschaft"
    ],
    ".fh-rosenheim.de": [
        "Fachhochschule Rosenheim, Hochschule für Technik und Wirtschaft"
    ],
    ".fh-rottenburg.de": ["Fachhochschule Rottenburg, Hochschule für Forstwirtschaft"],
    ".fh-schwaebischhall.de": [
        "Fachhochschule Schwäbisch Hall, Hochschule für Gestaltung"
    ],
    ".fh-sm.de": ["Fachhochschule Schmalkalden"],
    ".fh-stralsund.de": ["Fachhochschule Stralsund"],
    ".fh-swf.de": ["Fachhochschule Südwestfahlen"],
    ".fh-telekom-leipzig.de": ["Deutsche Telekom Fachhochschule Leipzig"],
    ".fh-trier.de": [
        "Fachhochschule Trier, Hochschule für Technik, Wirtschaft und Gestaltung"
    ],
    ".fh-ulm.de": ["Fachhochschule Ulm, Hochschule für Technik"],
    ".fh-wedel.de": ["Fachhochschule Wedel"],
    ".fh-weihenstephan.de": ["Fachhochschule Weihenstephan"],
    ".fh-weingarten.de": ["Fachhochschule Ravensburg-Weingarten"],
    ".fh-westkueste.de": [
        "Fachhochschule Westküste, Hochschule für Wirtschaft und Technik"
    ],
    ".fh-wiesbaden.de": ["Fachhochschule Wiesbaden"],
    ".fh-wolfenbuettel.de": ["Fachhochschule Braunschweig/Wolfenbüttel"],
    ".fh-worms.de": ["Fachhochschule Worms"],
    ".fh-wuerzburg.de": [
        "Hochschule für angewandte Wissenschaften Würzburg-Schweinfurt"
    ],
    ".fh-zwickau.de": ["Westsächsische Hochschule Zwickau"],
    ".edu.fham.de": [
        "Hochschule für angewandtes Management - Ismaning/München",
        "University of Applied Management - Ismaning/Munich",
    ],
    ".fham.de": [
        "Hochschule für angewandtes Management - Ismaning/München",
        "University of Applied Management - Ismaning/Munich",
    ],
    ".fhdw.de": ["Fachhochschule der Wirtschaft"],
    ".fhkt.de": ["Staatlich anerkannte Fachhochschule für Kunsttherapie"],
    ".fhm-mittelstand.de": ["Fachhochschule des Mittelstandes (FHM)"],
    ".fhnon.de": ["Fachhochschule Nordostniedersachsen"],
    ".fhoebb.de": ["Fachhochschule für das öffentliche Bibliothekswesen Bonn"],
    ".fhs-mannheim.de": ["Fachhochschule Mannheim, Hochschule für Sozialwesen"],
    ".fhs-moritzburg.de": [
        "Evangelische Fachhochschule für Religionspädagogik, und Gemeindediakonie Moritzburg"
    ],
    ".fht-stuttgart.de": ["Fachhochschule Stuttgart, Hochschule für Technik"],
    ".fhtw-berlin.de": ["Fachhochschule für Technik und Wirtschaft Berlin"],
    ".fhw-berlin.de": ["Fachhochschule für Wirtschaft Berlin"],
    ".fhws.de": ["Hochschule für angewandte Wissenschaften Würzburg-Schweinfurt"],
    ".fhwt.de": ["Private Fachhochschule für Wirtschaft und Technik Vechta/Diepholz"],
    ".fhwue.de": ["Hochschule für angewandte Wissenschaften Würzburg-Schweinfurt"],
    ".filderbenden.de": ["Gymnasium in den Filder Benden"],
    ".filmakademie.de": ["Filmakademie Baden-Württemberg"],
    ".filmuniversitaet.de": ["Filmuniversität Babelsberg-Potsdam"],
    ".firstwald.de": ["Evangelisches Firstwald Gymnasium Mössingen"],
    ".flachsland-hamburg.de": ["Flachsland Zukunftsschulen"],
    ".fli.de": ["Friedrich-Loeffler-Institut"],
    ".fls-da.de": ["Friedrich-List Schule Darmstadt"],
    ".fmg-brk.de": ["Franz-Miltenberger-Gymnasium"],
    ".fmsg-speyer.de": ["Friedrich-Magnus-Schwerd Gymnasium Speyer"],
    ".fom-net.de": ["Fachhochschule für Oekonomie und Management (FOM)"],
    ".fom.de": ["Fachhochschule für Oekonomie und Management (FOM)"],
    ".fosbos-neumarkt.de": [
        "Maximilian Kolbe (Fachober- & Berufsober-) Schule Neumarkt"
    ],
    ".fra-uas.de": ["Frankfurt University of Applied Sciences"],
    ".franz-oberthuer-schule.de": ["Franz Oberthür Schule"],
    ".freie-georgenschule.de": ["Freie Georgenschule"],
    ".freie-schule-anne-sophie.de": ["Freie Schule Anne-Sophie"],
    ".fs-students.de": ["Frankfurt School of Finance & Management"],
    ".fs.de": ["Frankfurt School of Finance and Management"],
    ".ftsvs.de": [
        "Staatliche Feintechnikschule mit Technischem Gymnasium Schwenningen"
    ],
    ".fu-berlin.de": ["Freie Universität Berlin"],
    ".fz-juelich.de": ["Juelich Forschungzentrum"],
    ".g18.de": ["Staatliche Gewerbeschule G18 - Technical College G18"],
    ".games-academy.de": ["Games Academy"],
    ".gaussschule-bs.de": ["Gaußschule - Gymnasium am Löwenwall"],
    ".gbg-remscheid.de": ["Gertrud-Bäumer-Gymnasium", "Gertrud-Bäumer-Gymnasium"],
    ".gbgrs.de": ["Gertrud-Bäumer-Gymnasium", "Gertrud-Bäumer-Gymnasium"],
    ".sus.gbs-grafschaft.de": ["GBS Grafschaft Bentheim"],
    ".gbs-sha.de": ["Gewerbliche Schule Schwäbisch Hall"],
    ".gbsleipzig.de": [
        "GBS Fachschule für Technik und Wirtschaft",
        "GBS Professional School of Technology and Business Administration",
    ],
    ".gd-serv.de": ["Gymnasium Damme"],
    ".gds2.de": [
        "\ufeffGottlieb-Daimler-Schule 2",
        "Technisches Schulzentrum Sindelfingen",
        "mit Abteilung Akademie für Datenverarbeitung",
    ],
    ".geestnetz.de": ["Geestlandschule"],
    ".gemont.de": ["Gebrüder-Montgolfier-Gymnasium Berlin"],
    ".genoapps.de": ["Genokolleg Münster"],
    ".genth-schule.de": ["Kooperative Gesamtschule des Main-Kinzig-Kreises"],
    ".gesa-rhede.de": ["Gesamtschule Rhede", "Rhede comprehensive school"],
    ".cloud.gesamtschule-barmen.de": ["Gesamtschule Barmen"],
    ".gesamtschule-fischbach.de": ["Gesamtschule Fischbach"],
    ".gesamtschule-hardt.de": ["gesamtschule-hardt.de"],
    ".gesamtschule-stolberg.de": [
        "Staedtische Gesamtschule Stolberg",
        "https://gesamtschule-stolberg.de",
        "https://gesamtschule-stolberg.de/wp-content/uploads/2018/09/Schulprogramm017-09-19.pdf",
    ],
    ".gewerbeschule-vs.de": ["Gewerbeschule villingen Schwenningen"],
    ".gg-lin.de": ["Gymnasium Georgianum Lingen", "Georgianum High School Lingen"],
    ".student.giu-uni.de": ["German International University of Applied Sciences"],
    ".gms-da.de": ["Georg Mueller Schule Darmstadt"],
    ".goegy.de": ["Goethe-Gymnasium Regensburg", "Goethe-Gymnasium Regensburg"],
    ".os-scultetus.goerlitz.de": ["Scultetus-Oberschule Goerlitz"],
    ".grimmels.de": [
        "Name: Grimmelshausen Gymnasium Gelnhausen",
        "Website: http://grimmels.de/wordpress/",
        "Computer science course: http://grimmels.de/wordpress/qualifikationsphase/ (Proof that is it offered as intensive course: On the site jump to: E > Kursangebot des GGG > Leistungsfächerangebot > ",
        "\tAufgabenfeld III > Informatik )",
        "Email proof: http://grimmels.de/wordpress/kontakte/",
    ],
    ".gs-bk.de": ["Gewerbliche Schule Backnang"],
    ".schueler.gs-wt.de": ["Gewerbliche Schulen Waldshut"],
    ".gs-wt.de": ["Gewerbliche Schulen Waldshut"],
    ".gso-koeln.de": ["Georg-Simon-Ohm-Berufskolleg Köln"],
    ".student.gsso.de": ["Grafenbergschule Schorndorf"],
    ".gsz-bl.de": ["Philipp-Matthäus-Hahn-Schule – Gewerbliches Schulzentrum Balingen"],
    ".gsz-zak.de": [
        "Philipp-Matthäus-Hahn-Schule – Gewerbliches Schulzentrum Balingen"
    ],
    ".msedu.gutenberg-gym.de": ["Gutenbergschule Wiesbaden"],
    ".gwdg.de": [
        "Georg-August-Universtät Göttingen",
        "Georg-August-University Goettingen",
    ],
    ".mail.gws-loerrach.de": ["Gewerbliche Schule Lörrach"],
    ".gym-kothen.de": ["Gymnasium Am Kothen"],
    ".gym-meiendorf.de": [
        "Name: Gymnasium Meiendorf",
        "Website: https://www.gymei.de/",
        "E-Mail Proof: https://www.gymei.de/impressum/",
    ],
    ".gym-papenburg.de": ["Gymnasium Papenburg"],
    ".gym-stolz.de": ["Gymnasium Stolzenau"],
    ".gymburlo.de": ["Gymnasium Mariengarden", "Mariengarden high school"],
    ".gymger.de": ["Gymnasium Geretsried"],
    ".gymhum.de": ["Gymnasium Hummelsbüttel"],
    ".gymlgh.de": ["Gymnasium Langenhagen"],
    ".gymlil.de": ["Gymnasium Lilienthal"],
    ".gymn-benedictinum.de": ["Gymnasium der Benediktiner, Meschede"],
    ".gymnasium-babelsberg.de": ["Bertha von Suttner Gymnasium Babelsberg"],
    ".gymnasium-essen-werden.de": ["Gymnasium Essen-Werden"],
    ".gymnasium-gag.de": ["Graf-Anton-Günther-Schule"],
    ".gymnasium-himmelsthuer.de": ["Gymnasium Himmelsthür"],
    ".gymnasium-hohenschwangau.de": [
        "Staatliches Gymnasium mit Internat Hohenschwangau"
    ],
    ".gymnasium-mariengarden.de": ["Gymnasium Mariengarden"],
    ".gymnasium-schmallenberg.de": ["Gymnasium Schmallenberg"],
    ".gymolching.de": ["Gymnasium Olching"],
    ".gymsas.de": ["Sankt-Ansgar-Schule Hamburg"],
    ".gywem.de": ["Gymnasium Wesermünde"],
    ".h-ab.de": ["Hochschule Aschaffenburg"],
    ".h-brs.de": ["Bonn-Rhein-Sieg University of Applied Sciences"],
    ".h-da.de": ["Hochschule Darmstadt University of Applied Sciences"],
    ".h-ka.de": ["Karlsruhe University of Applied Sciences"],
    ".bsb.hamburg.de": [
        "Name: Immanuel Kant Gymnasium",
        "Website: https://immanuel-kant-gymnasium.de",
        "It-Course ( On Site 13) : http://download.immanuel-kant-gymnasium.de/WPU-Brosch%C3%BCre%202015%20Jg%209.pdf",
        "E-Mail Proof: https://immanuel-kant-gymnasium.de/index.php/impressum-footer",
    ],
    ".hibb.hamburg.de": [
        "Berufliche Schule ITECH Elbinsel Wilhelmsburg (BS14) ",
        "Vocational school ITECH Elbinsel Wilhelmsburg (BS14)",
    ],
    ".jbg.hamburg.de": ["Johannes-Brahms-Gymnasium"],
    ".johannes-brahms-gymnasium.hamburg.de": ["Johannes-Brahms-Gymnasium, Hamburg"],
    ".hamburger-fh.de": ["Hamburger Fern-Hochschule (HFH)"],
    ".hans-baldung-gymnasium.de": ["Hans-Baldung-Gymnasium"],
    ".edu.hansenberg.de": [
        "Internatsschule Schloss Hansenberg",
        "Boarding School Schloss Hansenberg",
    ],
    ".hanseuni.de": ["Private Hanseuniversität"],
    ".haw-hamburg.de": ["Hamburg University of Applied Sciences"],
    ".haw-ingolstadt.de": ["Ingolstadt University of Applied Sciences"],
    ".haw-landshut.de": ["Landshut University of Applied Sciences"],
    ".hawk-hhg.de": [
        "HAWK Hochschule für angewandte Wissenschaft und Kunst Hildesheim Holzminden Göttingen"
    ],
    ".hawk.de": ["HAWK Hochschule für angewandte Wissenschaft und Kunst"],
    ".hbbk-office.de": ["Hans-Böckler-Berufskolleg, Münster", "(hbbk-muenster.de)"],
    ".hbg-troisdorf.de": ["Heinrich-Böll-Gymnasium"],
    ".hbksaar.de": ["Hochschule der Bildenden Künste Saar"],
    ".hcu-hamburg.de": ["Hafencity Universität Hamburg"],
    ".hdbw-hochschule.de": [
        "Hochschule der Bayerischen Wirtschaft für angewandte Wissenschaften (HDBW) gGmbH",
        "University of the Bavarian Economy for Applied Sciences (HDBW)",
    ],
    ".hdm-stuttgart.de": ["Fachhochschule Stuttgart, Hochschule der Medien"],
    ".hebk.de": ["Hermann-Emanuel-Berufskolleg"],
    ".hector-seminar.de": ["Hector Seminar Heidelberg, Karlsruhe, Mannheim, Pforzheim"],
    ".heinrichheinedo.de": ["Heinrich-Heine-Gymnasium Dortmund"],
    ".helmholtz-gymnasium.de": ["Helmholtz-Gymnasium Essen"],
    ".helmholtz-muenchen.de": ["Helmholtz Zentrum München"],
    ".helmholtzschule.de": ["Hermann-von-Helmholtz Gymnasium Potsdam"],
    ".hfb.de": [
        "Hochschule für Bankwirtschaft (HfB), Private Fachhochschule der Bankakademie"
    ],
    ".hfbk-hamburg.de": ["Hochschule für bildende Künste Hamburg"],
    ".hfg-gmuend.de": ["Fachhochschule Schwäbisch Gmünd, Hochschule für Gestaltung"],
    ".hfk-bremen.de": ["Hochschule für Künste Bremen"],
    ".hfm-detmold.de": ["Hochschule für Musik Detmold", "University for Music Detmold"],
    ".hfm-karlsruhe.de": ["University of Music Karlsruhe"],
    ".hfmt-koeln.de": ["Hochschule für Musik und Tanz Köln"],
    ".aiv.hfoed.de": [
        "Hochschule für den öffentlichen Dienst in Bayern (Allgemeine Innere Verwaltung)"
    ],
    ".aub.hfoed.de": [
        "Hochschule für den öffentlichen Dienst in Bayern (Archiv- und Bibliothekswesen)"
    ],
    ".hfph.de": ["Hochschule für Philosophie, Muenchen"],
    ".hfpol-bw.de": ["Hochschule für Polizei Baden-Württemberg"],
    ".hfpv-hessen.de": [
        "Hessian University of Applied Sciences for Police and Public Administration",
        "Hessische Hochschule für Polizei und Verwaltung",
    ],
    ".hft-leipzig.de": ["Deutsche Telekom University of Applied Sciences Leipzig"],
    ".hft-stuttgart.de": ["Stuttgart University of Applied Sciences"],
    ".hfwu.de": ["Hochschule für Wirtschaft und Umwelt Nürtingen-Geislingen"],
    ".hg-gf.de": ["Humboldt-Gymnasium Gifhorn"],
    ".hgb-leipzig.de": ["Academy of Visual Arts Leipzig"],
    ".hgo-ol.de": ["Herbartgymnasium Oldenburg"],
    ".hgs-singen.de": ["Hohentwiel Gewerbeschule Singen"],
    ".hgw-iserv.de": ["Hölty-Gymnasium Wunstorf"],
    ".hhek.de": ["Heinrich Hertz Europakolleg"],
    ".hhg-kl.de": ["Staatliches Heinrich-Heine-Gymnasium Kaiserslautern"],
    ".hhgym.de": ["Heinrich-Hertz-Gymnasium Berlin"],
    ".hhl.de": ["Handelshochschule Leipzig"],
    ".hhu.de": ["Heinrich Heine University Düsseldorf"],
    ".hit-thueringen.de": [
        "HIT | Akademische Personalentwicklung an Hochschulen in Thüringen",
        "hit-thueringen.de",
    ],
    ".hkdm.de": ["Hochschule für Kunst, Design und populäre Musik Freiburg"],
    ".stud.hmtm-hannover.de": [
        "Hochschule für Musik, Theater und Medien Hannover",
        "Hanover University of Music, Drama and Media",
    ],
    ".stud.hn.de": ["Hochschule Niederrhein"],
    ".hn.de": ["Hochschule Niederrhein"],
    ".hnee.de": ["Eberswalde University for Sustainable Development"],
    ".student.hnu.de": ["Hochschule Neu Ulm University of applied sciences"],
    ".hnu.de": ["Hochschule Neu Ulm University of applied sciences"],
    ".hochschule-bc.de": [
        "Hochschule Biberach ",
        "Hochschule Biberach (Biberach University of Applied Sciences)",
    ],
    ".hochschule-heidelberg.de": ["SRH Hochschule Heidelberg"],
    ".hochschule-regensburg.de": ["Hochschule Regensburg"],
    ".hochschule-rhein-waal.de": ["Hochschule Rhein-Waal"],
    ".hochschule-stralsund.de": ["Fachhochschule Stralsund"],
    ".hochschule-trier.de": ["Trier University of Applied Sciences"],
    ".hochtaunusschule.de": ["Hochtaunusschule Oberursel"],
    ".hoenne-berufskolleg.de": ["Hoenne-Berufskolleg"],
    ".hoev-rlp.de": ["Hochschule für öffentliche Verwaltung Rheinland-Pfalz"],
    ".hof-university.de": ["Hochschule für Angewandte Wissenschaften Hof"],
    ".hpi.de": ["Hasso Plattner Institute"],
    ".hrsaaf.de": ["Schule Altes Amt Friedeburg"],
    ".hs-aalen.de": ["Hochschule Aalen"],
    ".hs-albsig.de": ["Hochschule Albstadt-Sigmaringen"],
    ".hs-anhalt.de": [
        "Hochschule Anhalt (FH), Hochschule für angewandte Wissenschaften"
    ],
    ".hs-ansbach.de": ["Ansbach University of Applied Sciences"],
    ".hs-augsburg.de": ["Augsburg University of Applied Sciences"],
    ".hs-bochum.de": ["Hochschule Bochum"],
    ".hs-bremen.de": ["Hochschule Bremen"],
    ".hs-bremerhaven.de": ["Hochschule Bremerhaven"],
    ".hs-coburg.de": ["Hochschule Coburg"],
    ".hs-darmstadt.de": ["Hochschule Darmstadt"],
    ".study.hs-duesseldorf.de": ["Hochschule Düsseldorf"],
    ".hs-duesseldorf.de": ["Hochschule Düsseldorf"],
    ".hs-emden-leer.de": ["Hochschule Emden / Leer"],
    ".hs-esslingen.de": ["Hochschule Esslingen"],
    ".hs-flensburg.de": ["Hochschule Flensburg"],
    ".hs-fresenius.de": ["Hochschule Fresenius"],
    ".hs-fulda.de": ["Hochschule Fulda"],
    ".hs-furtwangen.de": ["Furtwangen University of Applied Sciences"],
    ".hs-gesundheit.de": ["Hochschule für Gesundheit"],
    ".hs-hannover.de": ["Hochschule Hannover"],
    ".hs-harz.de": ["Hochschule Harz, Hochschule für angewandte Wissenschaften (FH)"],
    ".hs-heilbronn.de": ["Hochschule Heilbronn (FH)"],
    ".hs-kempten.de": [
        "Hochschule für angewandte Wissenschaften Kempten",
        "University of Applied Sciences Kempten",
    ],
    ".hs-kl.de": ["Hochschule Kaiserslautern", "University of Applied Sciences"],
    ".hs-koblenz.de": ["Hochschule Koblenz"],
    ".hs-lausitz.de": ["Hochschule Lausitz"],
    ".hs-lu.de": ["Hochschule Ludwigshafen am Rhein"],
    ".hs-magdeburg.de": ["Hochschule Magdeburg-Stendal (FH)"],
    ".hs-mainz.de": ["Hochschule Mainz - University of Applied Sciences"],
    ".hs-mannheim.de": ["Mannheim University of Applied Sciences"],
    ".stud.hs-merseburg.de": ["University of Applied Sciences Merseburg"],
    ".hs-merseburg.de": ["University of Applied Sciences Merseburg"],
    ".hs-mittweida.de": ["University of Applied Sciences Mittweida"],
    ".hs-nb.de": ["Hochschule Neubrandenburg"],
    ".student.hs-neu-ulm.de": ["Hochschule Neu Ulm University of applied sciences"],
    ".hs-neu-ulm.de": ["Hochschule Neu Ulm University of applied sciences"],
    ".hs-niederrhein.de": ["Hochschule Niederrhein"],
    ".hs-nordhausen.de": ["Hochschule Nordhausen"],
    ".hs-offenburg.de": ["Offenburg University of Applied Sciences"],
    ".hs-osnabrueck.de": ["University Of Osnabrück"],
    ".hs-owl.de": ["Hochschule Ostwestfalen-Lippe"],
    ".hs-pforzheim.de": ["Hochschule Pforzheim für Gestaltung, Technik und Wirtschaft"],
    ".hs-rm.de": ["Rheinmain University of Applied Sciences"],
    ".hs-ruhrwest.de": ["Hochschule Ruhr West"],
    ".hs-sm.de": ["Hochschule Schmalkalden"],
    ".hs-ulm.de": ["University of Applied Sciences Ulm"],
    ".hs-weingarten.de": ["University of Applied Sciences Ravensburg-Weingarten"],
    ".hs-wismar.de": [
        "Hochschule Wismar, Fachhochschule für Technik, Wirtschaft und Gestaltung"
    ],
    ".hs-worms.de": ["Hochschule Worms University of Applied Sciences"],
    ".hs-zigr.de": ["Hochschule Zittau/Görlitz (FH)"],
    ".hs21.de": ["Hochschule 21/Buxtehude (FH)"],
    ".hsba.de": ["HSBA Hamburg School of Business Administration (old accounts)"],
    ".hshl.de": ["Hochschule Hamm-Lippstadt"],
    ".hss-wi.de": ["Hubert-Sternberg-Schule Wiesloch"],
    ".hss-wiesloch.de": ["Hubert-Sternberg-Schule Wiesloch"],
    ".hsu-hh.de": [
        "Helmut-Schmidt-Universität - Universität der Bundeswehr Hamburg",
        "Helmut-Schmidt-University Hamburg (Germany)",
    ],
    ".hsw-hameln.de": ["Hochschule Weserbergland"],
    ".hsw-stud.de": ["Hochschule Weserbergland"],
    ".hswt.de": ["Weihenstephan-Triesdorf University of Applied Sciences"],
    ".hszg.de": ["Hochschule Zittau/Görlitz (FH)"],
    ".htw-aalen.de": ["hs-aalen.txt"],
    ".htw-berlin.de": ["University of Applied Sciences, Berlin"],
    ".htw-dresden.de": ["Hochschule für Technik und Wirtschaft Dresden (FH)"],
    ".htw-saarland.de": ["Hochschule für Technik und Wirtschaft des Saarlandes"],
    ".htwg-konstanz.de": ["Hochschule Konstanz University of Applied Sciences"],
    ".htwk-leipzig.de": ["Hochschule für Technik, Wirtschaft und Kultur Leipzig (FH)"],
    ".htwm.de": ["Hochschule Mittweida (FH)"],
    ".htwsaar.de": ["Hochschule für Technik und Wirtschaft des Saarlandes"],
    ".hu-berlin.de": ["Humboldt Universität Berlin"],
    ".hwg-lu.de": ["Hochschule für Wirtschaft und Gesellschaft Ludwigshafen"],
    ".hwp-hamburg.de": ["HWP - Hamburger Universität für Wirtschaft und Politik"],
    ".hwr-berlin.de": [
        "HWR Berlin - Hochschule für Wirtschaft und Recht Berlin (Berlin School of Economics and Law)"
    ],
    ".stud.hwtk.de": ["Hochschule für Wirtschaft, Technik und Kultur"],
    ".hzdr.de": ["Helmholtz-Zentrum Dresden-Rossendorf"],
    ".i-u.de": ["International University in Germany"],
    ".ib-hochschule.de": ["IB Hochschule Berlin", "IB University Berlin"],
    ".ibs-ol.de": [
        "IBS IT & Business School Oldenburg e. V.",
        "Berufsakademie für IT & Wirtschaft Oldenburg",
    ],
    ".ids-mannheim.de": ["Leibniz-Institut für Deutsche Sprache"],
    ".igs-goettingen.de": [
        "Georg-Christoph-Lichtenberg-Gesamtschule Göttingen-Geismar"
    ],
    ".igs-kastellaun.de": ["Integrierte Gesamtschule Kastellaun"],
    ".igs-kreyenbrueck.de": ["Integrierte Gesamtschule Kreyenbrück"],
    ".igs-os.de": ["Integrierte Gesamtschule Osnabrück"],
    ".igs-seevetal.de": ["IGS Seevetal"],
    ".igs-wunstorf.de": ["IGS Wunstorf"],
    ".igsquerum.de": ["IGS Querum"],
    ".igssolms-ldk.de": ["Integrierte Gesamtschule Solms"],
    ".ihi-zittau.de": ["Internationales Hochschulinstitut Zittau"],
    ".imtek.de": [
        "Institut für Mikrosystemtechnik - IMTEK Albert-Ludwigs-Universität Freiburg"
    ],
    ".io-warnemuende.de": [
        "Leibniz Insitut für Ostseeforschung Warnemünde (IOW)",
        "Leibniz Institute for Baltic Sea Research Warnemünde (IOW)",
    ],
    ".ipu.de": ["International Psychoanalytic University"],
    ".isdedu.de": ["International School of Düsseldorf"],
    ".iserv-gis.de": ["Gymnasium im Schloss Wolfenbüttel"],
    ".iserv-trg-oha.de": ["Tilman-Riemenschneider-Gymnasium Osterode am Harz"],
    ".student.ism.de": ["International School of Management"],
    ".ism-dortmund.de": ["International School of Management ISM Dortmund"],
    ".isnm.de": ["International School of New Media, University of Lübeck"],
    ".isr-school.de": ["International School on the Rhine"],
    ".itc-dortmund.de": ["IT-Center Dortmund"],
    ".itc-studenten.de": ["IT-Center Dortmund"],
    ".itech-bs14.de": [
        "Berufliche Schule ITECH Elbinsel Wilhelmsburg (BS14)",
        "Vocational school ITECH Elbinsel Wilhelmsburg (BS14)",
    ],
    ".its-stuttgart.de": ["it.schule Stuttgart"],
    ".iubh-dualesstudium.de": ["IUBH Internationale Hochschule GmbH"],
    ".iubh-fernstudium.de": ["Internationale Hochschule Bad Honnef · Bonn"],
    ".iubh.de": ["International University of Applied Sciences Bad Honnef - Bonn"],
    ".jacobs-university.de": ["Jacobs University Bremen"],
    ".jade-hs.de": ["Jade Hochschule Wilhelms/Oldenburg/Elsfleth"],
    ".jakob-brucker-gymnasium.de": ["Jakob-Brucker-Gymnasium, Kaufbeuren"],
    ".angergymnasium.jena.de": ["Staatliches Angergymnasium Jena"],
    ".cz-gymnasium.jena.de": ["Carl Zeiss Gymnasium Jena"],
    ".stud.jfg-augsburg.de": ["Jakob-Fugger-Gymnasium"],
    ".jhgcloud.de": ["JosephHaydenGymnasium"],
    ".jkg-ibb.de": ["Johannes-Kepler-Gymnasium Ibbenbüren"],
    ".johanneum-lg.de": ["Johanneum Lüneburg"],
    ".joseph-koenig-gymnasium.de": ["Joseph-Koenig-Gymnasium Haltern am See"],
    ".jprs.de": [
        "Johann-Philipp-Reis-Schule Friedberg (Hessen), Berufliches Gymnasium"
    ],
    ".jsg-karlstadt.de": ["Johann-Schöner-Gymnasium Karlstadt"],
    ".julianum.de": ["Gymnasium Julianum"],
    ".julius-wegeler-schule.de": ["Julius-Wegeler-Schule Koblenz"],
    ".jws-rv.de": ["Josef-Wilhelm-Schule Ravensburg"],
    ".kag-erding.de": ["Korbinian-Aigner-Gymnasium Erding"],
    ".karlkuebelschule.de": ["Karl Kübel Schule"],
    ".karlshochschule.de": ["Karlshochschule International University"],
    ".hhs.karlsruhe.de": ["Heinrich-Hertz-Schule Karlsruhe"],
    ".mgg.karlsruhe.de": [
        "Markgrafen-Gymnasium Karlsruhe",
        "Markgrafen High School Karlsruhe",
    ],
    ".kath-fh-nord.de": ["Katholische Fachhochschule Norddeutschland"],
    ".katharineum.de": ["Katharineum zu Lübeck"],
    ".student.kbm-du.de": [
        "Kaufmännisches Berufskolleg Duisburg-Mitte",
        "Kaufmännisches Berufskolleg Duisburg-Mitte",
    ],
    ".kbs-nordhorn.de": ["Kaufmännische Berufsbildende Schulen Nordhorn (KBS)"],
    ".kfb-berlin.de": ["Katholische Fachhochschule Berlin (KFB)"],
    ".kfh-Freiburg.de": [
        "Katholische Fachhochschule Freiburg, Hochschule für Sozialwesen, Religionspädagogik und Pflege"
    ],
    ".kfh-mainz.de": ["Katholische Fachhochschule Mainz"],
    ".kfhnw.de": ["Katholische Fachhochschule Nordrhein-Westfalen"],
    ".kgw-duisburg.de": ["Kopernikus Gymnasium Walsum"],
    ".kh-berlin.de": ["Kunsthochschule Berlin-Weissensee, Hochschule für Gestaltung "],
    ".khgmettmann.de": ["Konrad-Heresbach-Gymnasium Mettmann"],
    ".khm.de": ["Academy of Media Arts, Cologne"],
    ".khsa.de": ["Katholische Hochschule für Soziale Arbeit Saarbrücken"],
    ".kinzig-schule.de": [
        "Berufliches Schulzentrum des Main-Kinzig-Kreises in Schlüchtern"
    ],
    ".kisd.de": ["KISD - Köln International School of Design"],
    ".kitz-heidelberg.de": [
        "Hopp Children's Cancer Center Heidelberg (KiTZ)",
        "Heidelberg University Hospital and the German Cancer Research Center (DKFZ)",
    ],
    ".kks-kiel.de": ["Käthe-Kollwitz Gymnasium Kiel"],
    ".klara-oppenheimer-schule.de": ["Klara-Oppenheimer-Schule Würzburg"],
    ".knabenrealschule-neumarkt.de": ["Staatliche Knabenrealschule"],
    ".kolleg-st-sebastian.de": ["Kolleg St. Sebastian, Stegen"],
    ".konrad-zuse-schule.de": ["Konrad-Zuse-Schule"],
    ".krbor.de": ["Berufskollegs des Kreises Borken"],
    ".mail.kreuzgymnasium.de": ["Evangelisches Kreuzgymnasium Dresden"],
    ".ks-ldk.de": ["Kaufmännische Schulen Dillenburg"],
    ".edu.ksan.de": ["Medienzentrum Kassel", ".group"],
    ".ksfh.de": ["Katholische Stiftungsfachhochschule München"],
    ".kst-vechta.de": ["Kolleg St. Thomas"],
    ".ku-eichstaett.de": ["Katholische Universität Eichstätt"],
    ".ku.de": ["Katholische Universität Eichstätt"],
    ".kunstakademie-duesseldorf.de": ["Kunstakademie Düsseldorf."],
    ".kvg-mettingen.de": ["Kardinal von Galen Gymnasium Mettingen"],
    ".kvgg.de": ["Kardinal-von-Galen-Gymnasium Kevelaer"],
    ".kvgschulen.de": ["Kardinal von Galen Gymnasium Mettingen"],
    ".kwr-hannover.de": ["Kaiser- Wilhelm und Ratsgymnasium Hannover"],
    ".schule.landsh.de": ["Gymnasium Sylt"],
    ".law-school.de": ["Bucerius Law School gGmbH"],
    ".lazi-akademie.de": [
        "Lazi Akademie is an Academy for Media Design in Esslingen, Germany",
        "Homepage: https://www.lazi-akademie.de/",
        "3 years education:",
        "https://www.lazi-akademie.de/ausbildung/grafik-kommunikationsdesign/",
        "https://www.lazi-akademie.de/master-of-arts/",
        "Domain for repository: lazi-akademie.de",
    ],
    ".lebk247.de": ["Ludwig-Erhard-Berufskolleg Muenster"],
    ".leibniz-fh.de": ["Leibniz Fachhochschule"],
    ".leibniz-gymnasium-essen.de": ["Leibniz-Gymnasium Essen"],
    ".leo-statz-berufskolleg.de": [
        "Leo-Statz-Berufskolleg",
        "we'll use webstorm in this course of study: ",
        "https://www.leo-statz-berufskolleg.de/bildungsangebot/kfm-assistentin-fuer-informationsverarbeitung",
    ],
    ".leogos.de": ["Leononore Goldschmidt Schule"],
    ".afra.lernsax.de": ["Sächsisches Landesgymnasium Sankt Afra zu Meißen"],
    ".ars-bsz.lernsax.de": [
        "Arwed-Rossbach-Schule, Berufliches Schulzentrum der Stadt Leipzig"
    ],
    ".bszetdd.lernsax.de": [
        "Berufliches Schulzentrum für Elektrotechnik, Dresden",
        "Vocational high school for electrical engineering, Dresden",
    ],
    ".bsztw-riesa.lernsax.de": [
        "Berufliches Schulzentrum für Technik und Wirtschaft Riesa"
    ],
    ".ewvt.lernsax.de": [
        "School: Ehrenfried-Walther-von-Tschirnhaus-Gymnasium Dresden",
        "E-Mail-Suffix: ewvt.lernsax.de",
        "Proof that this school use this mail provider:",
        'On the page lernsax.de is on the left side a botton with the text "LernSax Kennenlernen" it means get to know lernsax. You have to click this button.',
        'On this new page is on the left side a botton with the text "Karte der LernSax-Nutzer" it shows you a map of the lernsax users. ',
        "On this map you have to click this circle (https://prnt.sc/1ak5py1).",
        "You can also check the official Website (https://ewvt.de) and the part explaining Lernsax (https://ewvt.de/index.php/kontakt-und-service/lernsax2).",
        'Click the "Impressium" (inprint) botton to check if the school website is ewvt.de',
    ],
    ".gsg-loebau.lernsax.de": ["Geschwister-Scholl-Gymnasium Löbau"],
    ".whg-rie.lernsax.de": [
        "School: Werner-Heisenberg-Gymnasium Riesa",
        "E-Mail-Suffix: whg-rie.lernsax.de",
        "Proof that this school use this mail provider:",
        'On the page lernsax.de is on the left side a botton with the text "LernSax Kennenlernen" it means get to know lernsax. You have to click this button.',
        'On this new page is on the left side a botton with the text "Karte der LernSax-Nutzer" it shows you a map of the lernsax users. ',
        "On this map you have to click this circle (http://prntscr.com/ltmjc4). There are now some links one of this is the link of the school (Werner-Heisenberg-Gymnasium Riesa).",
        '"whg-rie" is the short form of "Werner-Heisenberg-Gymnasium Riesa". The school website uses this short form too because the school website is whg-rie.de.',
        'Click the "Impressium" (inprint) botton to check if the school website is whg-rie.de',
    ],
    ".lernsax.de": [
        "School: Schülerrechenzentrum Dresden",
        "E-Mail-Suffix: srz.lernsax.de",
        "Proof that this school use this mail provider:",
        'On the page lernsax.de is on the left side a botton with the text "LernSax Kennenlernen" it means get to know lernsax. You have to click this button.',
        'On this new page is on the left side a botton with the text "Karte der LernSax-Nutzer" it shows you a map of the lernsax users. ',
        "On this map you have to click this circle (https://prnt.sc/1ak5py1).",
        'Click the "Impressium" (inprint) botton to check if the school website is ewvt.de',
    ],
    ".leuphana.de": ["Leuphana Universität Lüneburg"],
    ".lg-bs.de": ["Lessinggymnasium Braunschweig"],
    ".schueler.lg-ks.de": ["Lichtenberg-Gymnasium Kassel"],
    ".lgbk.de": ["Lessing Gymnasium | Berufskolleg"],
    ".liebigschule-giessen.de": ["Liebigschule Giessen"],
    ".ligcux.de": ["Lichtenberg-Gymnasium Cuxhaven"],
    ".lindengymnasium.de": ["Staedtisches Lindengymnasium Gummersbach"],
    ".lio-darmstadt.de": [
        "Justus-Liebig-Schule Darmstadt",
        "Justus-Liebig school Darmstadt, Germany",
    ],
    ".lls-bad.de": ["Louis-Lepoix-Schule"],
    ".lmgrhl.de": ["Lise-Meitner-Gesamtschule"],
    ".lmu.de": ["Ludwig Maximilian University of Munich"],
    ".gd.by.lo-net2.de": ["Schmuttertal-Gymnasium Diedorf"],
    ".bbs-hol.ni.lo-net2.de": [
        "Georg-von-Langen-Schule - Berufsbildende Schulen Holzminden"
    ],
    ".bbs-whv.ni.lo-net2.de": ["Berufsbildene Schule Wilhelmshaven"],
    ".fvsg-ob.nw.lo-net2.de": ["Freiherr-vom-Stein Gymnasium Oberhausen"],
    ".gyko.nw.lo-net2.de": ["Gymnasium Korschenbroich"],
    ".lhbk.nw.lo-net2.de": ["Lebenshilfe Berufskolleg Huerth"],
    ".mcgduesseldorf.nw.lo-net2.de": ["Marie-Curie Gymnasium Düsseldorf"],
    ".tbs1.nw.lo-net2.de": ["Technische Berufliche Schule 1 - Bochum"],
    ".lornsenschule.sh.lo-net2.de": ["Lornsenschule Schleswig"],
    ".bkbe.logineo.de": ["Berufskolleg Barmen Europaschule"],
    ".louis-leitz-schule.de": ["Louis Leitz Schule"],
    ".louisenlund.de": ["Stiftung Louisenlund", "Louisenlund Foundation"],
    ".lsbkmi.de": ["Leo-Sympher-Berufskolleg"],
    ".ludwig-geissler-schule.de": ["Ludwig-Geißler-Schule"],
    ".stud.macromedia.de": ["Macromedia University Munich (stud.macromedia.de)"],
    ".maedchenrealschule-neumarkt.de": ["Staatliche Mädchenrealschule"],
    ".marienschule-bielefeld.de": ["Marienschule Bielefeld"],
    ".markdorf-robotics.de": ["Gymnasium im Bildungszentrum Markdorf - Roboter AG"],
    ".schueler.max-eyth-schule.de": ["Max-Eyth-Schule Berufliche Schule Kassel"],
    ".max-weber-schule.de": ["Max-Weber-Schule Freiburg im Breisgau"],
    ".maxplanckschools.de": ["Max Planck School of Cognition"],
    ".mbg-germering.de": ["Max-Born-Gymnasium Germering"],
    ".mcg-berlin.de": ["Marie Curie Gymnasium"],
    ".mcggehrden.de": ["Matthias Claudius Gymnasium Gehrden"],
    ".mdc-berlin.de": ["Max-Delbrück-Centrum für Molekulare Medizin Graduate School"],
    ".mdg-hamburg.de": ["Marion Dönhoff Gymnasium"],
    ".mediadesign.de": ["Mediadesign Hochschule"],
    ".merz-akademie.de": ["Merz Akademie, Hochschule für Gestaltung Stuttgart"],
    ".mes-portal.de": ["Max Eyth Schule Schiffdorf"],
    ".mesk.de": ["Max-Eyth-Schule Kirchheim"],
    ".mfh-iserlohn.de": ["Märkische Fachhochschule Iserlohn"],
    ".mh-freiburg.de": ["Hochschule für Musik Freiburg"],
    ".mh-hannover.de": ["Medizinische Hochschule Hannover"],
    ".mh-trossingen.de": ["Staatliche Hochschule für Musik"],
    ".mhmk.de": ["Hochschule Macromedia University of Applied Sciences"],
    ".mhn.de": ["Hochschule für Politik (HFP)"],
    ".mint-kolleg.de": ["MINT-Kolleg Baden-Württemberg"],
    ".mk-bs.de": ["Martino-Katharineum Gymnasium", "Martino-Katharineum high school"],
    ".mls-marburg.de": ["Martin-Luther Schule Marburg"],
    ".mm-bbs.de": ["multi media BBS Hannover"],
    ".stud.mobile-university.de": ["SRH Fernhochschule ", "The Mobile University"],
    ".monte-koeln.de": ["Montessori Gymnasium Köln"],
    ".ae.mpg.de": ["Max-Planck Institute for Empirical Aesthetics"],
    ".brain.mpg.de": ["Max Planck Institute for Brain Research"],
    ".cbs.mpg.de": [
        "International Max Planck Research School on Neuroscience of Communication"
    ],
    ".coll.mpg.de": [
        "Max-Planck-Institut zur Erforschung von Gemeinschaftsgütern",
        "Max-Planck-Institute for research on collective goods",
    ],
    ".ds.mpg.de": ["Max Planck Institute for Dynamics and Self-Organization"],
    ".eva.mpg.de": [
        "Max-Planck-Institut für evolutionäre Anthropologie",
        "Max Planck Institute for Evolutionary Anthropology",
    ],
    ".is.mpg.de": ["Max Planck Institute for Intelligent Systems, Stuttgart, Germany"],
    ".molgen.mpg.de": ["Max Planck Institute for Molecular Genetics"],
    ".mpe.mpg.de": ["Max-Planck Institute for Extraterrestrial Physics"],
    ".mpi-inf.mpg.de": ["Max Planck Institute for Informatics"],
    ".mpia-hd.mpg.de": [
        "International Max Planck Research School for Astronomy and Cosmic Physics at the University of Heidelberg"
    ],
    ".mpimet.mpg.de": [
        "Max-Planck-Institut für Meteorologie",
        "Max Planck Institute for Meteorology",
    ],
    ".mpip-mainz.mpg.de": [
        "Max Planck Institute for Polymer Research, mainz, Germany",
        "http://www.mpip-mainz.mpg.de",
    ],
    ".mpiwg-berlin.mpg.de": ["Max Planck Institute for the History of Science"],
    ".mpl.mpg.de": [
        "Max-Planck-Institut für die Physik des Lichts",
        "Max Planck Institute for the Science of Light",
    ],
    ".mpp.mpg.de": [
        "Max Planck Institut für Physik",
        "Max Planck Institute for Physics",
    ],
    ".pks.mpg.de": ["Max Planck Institute for the Physics of Complex Systems"],
    ".psych.mpg.de": [
        "Max-Planck-Institut für Psychiatrie",
        "Max Planck Institute of Psychiatry",
    ],
    ".tue.mpg.de": ["Max Planck Institute for Intelligent Systems, Tuebingen, Germany"],
    ".mpg-bb.de": ["Max-Planck-Gymnasium Böblingen"],
    ".schueler.mpg-umstadt.de": ["Max-Planck-Gymnasium Groß-Umstadt"],
    ".mpi-cbg.de": ["Max Planck Institute of Molecular Cell Biology and Genetics"],
    ".mpia.de": [
        "International Max Planck Research School for Astronomy and Cosmic Physics at the University of Heidelberg"
    ],
    ".annette.ms.de": ["Annette-von-Droste-Hülshoff-Gymnasium Münster"],
    ".pascal.ms.de": ["Pascalgymnasium Münster", "Pascal College Muenster"],
    ".stein.ms.de": ["Freiherr-vom-Stein Gymnasium Muenster"],
    ".ms-muc.de": [
        "Meisterschulen am Ostbahnhof, München",
        "Master Schools at Ostbahnhof, Munich, Germany",
    ],
    ".mtgmuenchen.de": ["Staatliches Maria-Theresia-Gymnasium München"],
    ".mu-luebeck.de": ["Medizinische Universität Lübeck"],
    ".mtg.musin.de": ["Maria-Theresia-Gymnasium München"],
    ".bs-info.muenchen.musin.de": ["Städtische Berufsschule für Informationstechnik"],
    ".fosbos-technik.muenchen.musin.de": [
        "Staatliche Fachoberschule und Berufsoberschule München - Ausbildungsrichtungen: Technik / Agrarwirtschaft, Bio- und Umwelttechnologie"
    ],
    ".gmm.muenchen.musin.de": ["Gymnasium München Moosach"],
    ".hhg.muenchen.musin.de": ["Städtisches Heinrich Heine Gymnasium München"],
    ".kkg.muenchen.musin.de": ["Käthe-Kollwitz-Gymnasium"],
    ".lfg.muenchen.musin.de": ["Städtisches Lion-Feuchtwanger-Gymnasium"],
    ".lpg.muenchen.musin.de": ["Luitpold-Gymnasium München"],
    ".ts.muenchen.musin.de": ["Technikerschule München"],
    ".wsg.muenchen.musin.de": ["Städtisches Werner-von-Siemens-Gymnasium München"],
    ".wsg.musin.de": ["Städtisches Werner-von-Siemens-Gymnasium München"],
    ".muthesius.de": ["Muthesius-Hochschule, Fachhochschule für Kunst und Gestaltung"],
    ".mwn.de": ["Hochschule für Philosophie München"],
    ".mws-mainz.de": ["Maria Ward-Schule Mainz"],
    ".mycorvey.de": ["Gymnasium Corveystraße", "high school Corveystraße"],
    ".myhsba.de": ["HSBA Hamburg School of Business Administration"],
    ".myhss.de": ["Hubert-Sternberg-Schule Wiesloch"],
    ".mytum.de": ["Technical University of Munich"],
    ".noether-gymnasium.de": ["Emmy-Noether-Gymnasium"],
    ".nordakademie.de": [
        "Nordakademie, Staatlich anerkannte private Fachhochschule mit dualen Studiengängen"
    ],
    ".hspv.nrw.de": [
        "Hochschule für Polizei und öffentliche Verwaltung NRW",
        "University of Applied Sciences for Police and Public Administration in North Rhine-Westphalia",
    ],
    ".nta-isny.de": [
        "Naturwissenschaftlich technische Akademie Isny - Fachhochschule & Berufskollegs Prof. Dr. Grübler GmbH",
        "Scientific and technical academy Isny - University of Applied Science and Vocational Colleges, Prof. Dr. Gruebler ltd.",
    ],
    ".dg.nuernberg.de": ["Nuernberg Schule"],
    ".schulen.nuernberg.de": ["Nuernberg Schule"],
    ".obs-ganderkesee.de": ["Oberschule Ganderkesee"],
    ".obs-weener.de": ["Oberschule Weener"],
    ".obs1celle.de": ["Oberschule Celle 1"],
    ".obsbs.de": [
        "Otto-Bennemann-Schule, Berufsbildende Schulen Wirtschaft und Verwaltung"
    ],
    ".oegym.de": ["Ökumenisches Gymnasium zu Bremen"],
    ".ohggf.de": ["Otto-Hahn-Gymnasium"],
    ".ohs-bensberg.de": ["Otto-Hahn-Gymnasium Bergisch Gladbach - Bensberg"],
    ".onbtineuss.de": ["Berufskolleg für Technik und Informatik Neuss", "BTI Neuss"],
    ".ostendorfer.de": ["Ostendorfer Gymnasium"],
    ".ostfalia.de": ["Ostfalia Hochschule für angewandte Wissenschaften"],
    ".oszimt.de": ["Oberstufenzentrum Informations- und Medizintechnik"],
    ".schueler.osztiem.de": ["OSZ TIEM"],
    ".oth-aw.de": ["Ostbayerische Technische Hochschule Amberg-Weiden"],
    ".oth-regensburg.de": ["Ostbayerische Technische Hochschule Regensburg"],
    ".otto-nagel-gymnasium.de": ["Otto-Nagel-Gymnasium"],
    ".ovgu.de": ["Otto von Guericke University of Magdeburg"],
    ".ovm-kassel.de": ["Oskar-von-Miller-Schule", "Oskar-von-Miller-School"],
    ".paderborn.de": ["Theologische Fakultät Paderborn"],
    ".pdr-kelkheim.de": ["Privatgymnasium Dr. Richter"],
    ".pfh.de": ["Private Hochschule Göttingen"],
    ".pgs-portal.de": ["Paul-Gerhardt Schule Dassel"],
    ".ph-erfurt.de": ["Pädagogische Hochschule Erfurt/Mühlhausen"],
    ".ph-freiburg.de": ["Pädagogische Hochschule Freiburg"],
    ".ph-gmuend.de": ["Pädagogische Hochschule Schwäbisch Gmünd"],
    ".ph-heidelberg.de": ["Pädagogische Hochschule Heidelberg"],
    ".ph-karlsruhe.de": ["Pädagogische Hochschule Karlsruhe"],
    ".ph-ludwigsburg.de": ["Pädagogische Hochschule Ludwigsburg"],
    ".ph-weingarten.de": ["Pädagogische Hochschule Weingarten"],
    ".philtheol-augustin.de": [
        "Philosophisch-Theologische Hochschule SVD Sankt Augustin"
    ],
    ".phwt.de": ["Private Hochschule fur Wirtschaft und Technick"],
    ".popakademie.de": ["Popakademie Baden-Württemberg"],
    ".ppc-schule.de": ["Peter-Paul-Cahensly Schule"],
    ".privatfh-da.de": ["Private FernFachhochschule Darmstadt"],
    ".pth-bb.de": ["Philosophisch-Theologische Hochschule der Salesianer Don Boscos"],
    ".pth-muenster.de": ["Philosophisch-Theologische Hochschule Münster"],
    ".pthv.de": [
        "Philosophisch-Theologische Hochschule Vallendar der Gesellschaft des Katholischen Apostolates (Pallottiner)"
    ],
    ".rak.de": [
        "RHEINISCHE AKADEMI KÖLN ",
        "https://www.rak.de",
        "https://www.rak.de/die-rak/service-fuer-schueler-und-studierende/",
    ],
    ".ratsgymnasium-pe.de": ["Ratsgymnasium Peine"],
    ".ratsgympeine.de": ["Ratsgymnasium Peine"],
    ".rauheshaus.de": [
        "Evangelische Fachhochschule für Sozialpädagogik der Diakonenanstalt des Rauhen Hauses Hamburg"
    ],
    ".rbbk-dortmund.de": ["Robert-Bosch-Berufskolleg"],
    ".rbs-ulm.de": ["Robert-Bosch-Schule Ulm"],
    ".reuchlin-gymnasium.de": ["Reuchlin-Gymnasium Pforzheim"],
    ".reutlingen-university.de": ["Reutlingen University"],
    ".schule.rfgs.de": ["Richard Fehrenbach Gewerbeschule"],
    ".rfgs.de": ["Richard Fehrenbach Gewerbeschule"],
    ".rfh-campus.de": ["Rheinische Fachhochschule Koeln"],
    ".rfh-koeln.de": ["Rheinische Fachhochschule Köln"],
    ".rhein-gymnasium-sinzig.de": ["Rhein-Gymnasium Sinzig"],
    ".rheinahrcampus.de": ["Hochschule Koblenz Rhein-Ahr-Campus"],
    ".rhs-bs.de": ["Ricarda-Huch-Schule Braunschweig"],
    ".rks-linz.de": ["Robert-Koch-Schule"],
    ".pl.rlp.de": [
        "Pädagogisches Landesinstitut Rheinland-Pfalz",
        "Pedagogical Institute of the State of Rhineland-Palatinate",
    ],
    ".rs-ilsede.de": ["Realschule Groß Ilsede"],
    ".rs-leimen.de": ["Otto-Graf Realschule"],
    ".rs-unterpfaffenhofen.de": ["Staatliche Realschule Unterpfaffenhofen"],
    ".rsh-duesseldorf.de": [
        "Robert Schumann Hochschule Düsseldorf",
        "Robert Schumann University of Music and Media",
    ],
    ".rsnibelungen.de": ["Nibelungen-Realschule"],
    ".rsplus-nierstein.de": [
        "Carl-Zuckmayer-Realschule Plus und Fachoberschule Nierstein"
    ],
    ".rss-witten.de": ["Rudolf-Steiner-Schule Witten", "Rudolf-Steiner-School Witten"],
    ".rsu-germering.de": ["Staatliche Realschule Unterpfaffenhofen"],
    ".rub.de": ["Ruhr-Universität Bochum"],
    ".ruhr-uni-bochum.de": ["Ruhr-Universität Bochum"],
    ".rvwbk.de": ["Richard-von-Weizsäcker-Berufskolleg"],
    ".stud.rwg-waren.de": ["Richard Wossidlo Gymnasium"],
    ".rwth-aachen.de": ["Rheinisch Westfälische Technische Hochschule Aachen"],
    ".rwu.de": ["RWU Hochschule Ravensburg-Weingarten University of Applied Sciences"],
    ".sadds.de": ["Schule an der Donauschleife"],
    ".sbs-herzogenaurach.de": [
        "SBS Herzogenaurach-Höchstadt ",
        "www.sbs-herzogenaurach.de",
    ],
    ".sbsz-jena.de": [
        "Staatliches Berufsbildendes Schulzentrum Jena-Göschwitz",
        "State vocational school center Jena-Göschwitz",
        "SBSZ Jena-Göschwitz",
        "https://www.sbsz-jena.de/",
    ],
    ".schueler-bsd.de": ["Staatliche Berufsschule Dachau", "Nikolaus-Lehner-Schule"],
    ".gjo.schulbistum.de": ["Gymnasium Johanneum", '"Die Loburg"'],
    ".gsma.schulbistum.de": [
        "St. Michael Gymnasium Ahlen",
        "Website: http://www.gymnasium-sankt-michael.de/",
        "Proof of long-term IT course: http://www.gymnasium-sankt-michael.de/unterricht/informatik/index.html",
    ],
    ".schuldorf.de": ["Schuldorf Bergstraße, Seeheim-Jugenheim"],
    ".mgl.lb.bw.schule.de": ["Mörike-Gymnasium Ludwigsburg"],
    ".dbg.rt.bw.schule.de": ["Dietrich-Bonhoeffer-Gymnasium"],
    ".vbs.ul.bw.schule.de": ["Valckenburgschule Ulm"],
    ".rbb.do.nw.schule.de": [
        "http://do.nw.schule.de/rbb/",
        "http://do.nw.schule.de/rbb/itberufe.html",
    ],
    ".bs-tnk1.c.sn.schule.de": [
        "Berufliches Schulzentrum für Technik 1 - Industrieschule Chemnitz"
    ],
    ".siemens.md.st.schule.de": ["Werner-von-Siemens-Gymnasium Magdeburg"],
    ".ghsem.em.schule-bw.de": [
        "Gewerbliche und Hauswirtschaftlich-Sozialpflegerische Schulen Emmendingen"
    ],
    ".hoelderlin.hd.schule-bw.de": ["Hölderlin Gymnasium Heidelberg"],
    ".schule-franzburg.de": ["Regionale Schule mit Grundschule Franzburg"],
    ".ass.schulen-offenbach.de": ["Albert Schweitzer Schule"],
    ".schulverbund.de": ["Isar-Gymnasium München"],
    ".schulzentrum-am-sund.de": ["Schulzentrum am Sund"],
    ".sdi-muenchen.de": ["Sprachen und Dolmetscher Institut München"],
    ".selk.de": ["Lutherische Theologische Hochschule Oberursel"],
    ".sembska.de": ["Seminar Berufliche Schulen Karlsruhe "],
    ".semper-schulen.de": ["Semper Schulen"],
    ".semperschulen.de": ["Semper Schulen"],
    ".shg-hi.de": ["Scharnhorstgymnasium Hildesheim"],
    ".siegtal-gymnasium.de": ["Siegtal-Gymnasium Eitorf"],
    ".siewerth-akademie.de": ["Gustav-Siewerth-Akademie"],
    ".siu-heidelberg.de": ["Schiller International University, Heidelberg"],
    ".bkt.siwiwissen.de": ["Berufskolleg Technik des Kreises Siegen-Wittgenstein"],
    ".bwv.siwiwissen.de": [
        "Berufskolleg Wirtschaft und Verwaltung des Kreises Siegen-Wittgenstein"
    ],
    ".sportschule-potsdam.de": ["Sportschule Potsdam"],
    ".spranger-hamm.de": ["Eduard Spranger Berufskolleg Hamm www.esb-hamm.de"],
    ".bfw.srh.de": [
        "SRH Berufliche Rehabilitation GmbH. Berufsförderungswerk Heidelberg"
    ],
    ".srh-berlin.de": ["SRH University of Applied Sciences"],
    ".stud.srh-campus-berlin.de": ["Design Akademie Berlin"],
    ".srh.de": ["SRH Berufliche Rehabilitation GmbH"],
    ".staedelschule.de": ["Hochschule für bildende Künste Frankfurt, Städelschule"],
    ".stiftkeppel.de": ["Gymnasium Stift Keppel"],
    ".stiftsgymnasium.de": ["Stiftsgymnasium Sindelfingen"],
    ".stresemanngymnasium.de": ["Gustav Stresemann Gymnasium"],
    ".sts-old.de": ["Stadtteilschule Oldenfelde"],
    ".stud-provadis-hochschule.de": [
        "Provadis School of International Management and Technology AG, 65926 Frankfurt am Main"
    ],
    ".students-hnbk.de": ["Heinz-Nixdorf Berufskolleg"],
    ".stw.de": ["Steinbeis-Hochschule-Berlin"],
    ".sus-am-bktm.de": ["Berufskolleg Platz der Republik für Technik und Medien"],
    ".sus-bbswhs.de": ["Berufliches Gymnasium Wildeshausen"],
    ".edu.sz-deg.de": ["Robert-Koch-Gymnasium Deggendorf"],
    ".sz-haltern.de": [
        "Joseph-König-Gymnasium Haltern am See",
        "Alexander-Lebenstein-Realschule Haltern am See",
        "at Schulzentrum Haltern am See",
    ],
    ".sz-uetze.de": ["Gymnasium unter den Eichen Uetze"],
    ".szh-ahrensburg.de": ["Gemeinschafts Schule am Heimgarten"],
    ".tagore-gymnasium.de": ["Tagore-Gymnasium"],
    ".tbs1.de": ["Technische Berufliche Schule 1 - Bochum"],
    ".technik-emden.de": ["Hochschule Emden-Leer"],
    ".technikerschule-berlin.de": ["Staatliche Technikerschule Berlin"],
    ".tek-up.de": ["TEK-UP University", "TEK-UP University"],
    ".tel-ran.de": ["Tel-Ran.de"],
    ".tfh-berlin.de": ["Technische Fachhochschule Berlin"],
    ".tfh-bochum.de": [
        "Technische Fachhochschule Georg Agricola für Rohstoff, Energie und, Umwelt zu Bochum"
    ],
    ".tfh-wildau.de": ["Technische Fachhochschule Wildau"],
    ".th-ab.de": [
        "Technische Hochschule Aschaffenburg",
        "University of applied sciences Aschaffenburg",
    ],
    ".th-bingen.de": ["Technische Hochschule Bingen University of Applied Sciences"],
    ".th-brandenburg.de": ["Technische Hochschule Brandenburg"],
    ".th-deg.de": ["Technische Hochschule Deggendorf"],
    ".th-koeln.de": ["Fachhochschule Köln", "Technische Hochschule Köln"],
    ".th-luebeck.de": ["TH Lübeck"],
    ".th-nuernberg.de": ["Technische Hochschule Nürnberg Georg Simon Ohm"],
    ".th-owl.de": [
        "Technische Hochschule Ostwestfalen-Lippe",
        "OWL University of Applied Sciences",
    ],
    ".stud.th-rosenheim.de": [
        "Technische Hochschule Rosenheim",
        "Rosenheim Technical University of Applied Sciences",
    ],
    ".th-rosenheim.de": [
        "Technische Hochschule Rosenheim",
        "Technical University Of Applied Sciences Rosenheim",
    ],
    ".th-wildau.de": ["Wildau Technical University of Applied Sciences"],
    ".thga.de": [
        "Technische Hochschule Georg Agricola",
        "University of Applied Sciences Georg Agricola",
    ],
    ".thh-friedensau.de": ["Theologische Hochschule Friedensau"],
    ".thi.de": ["Technische Hochschule Ingolstadt"],
    ".thm.de": ["University of Applied Sciences Giessen-Friedberg"],
    ".ths-berlin.de": ["Theodor-Haubach-Schule"],
    ".thu.de": ["Technische Hochschule Ulm", "Ulm University of Applied Science "],
    ".tiho-hannover.de": ["Tierärztliche Hochschule Hannover"],
    ".tms-badoldesloe.de": ["TMS Bad Oldesloe"],
    ".ts-aalen.de": ["Technische Schule Aalen"],
    ".tu-berlin.de": ["Technische Universität Berlin"],
    ".tu-braunschweig.de": ["Technische Universität Carolo-Wilhelmina zu Braunschweig"],
    ".tu-bs.de": ["Technische Universität Carolo-Wilhelmina zu Braunschweig"],
    ".tu-chemnitz.de": ["Technische Universität Chemnitz-Zwickau"],
    ".tu-clausthal.de": ["Technische Universität Clausthal"],
    ".tu-cottbus.de": ["Brandenburgische Technische Universität Cottbus"],
    ".tu-darmstadt.de": ["Technische Universität Darmstadt"],
    ".tu-dortmund.de": ["Dortmund University"],
    ".tu-dresden.de": ["Technische Universität Dresden"],
    ".tu-freiberg.de": ["Technische Universität Bergakademie Freiberg"],
    ".tu-harburg.de": ["Technische Universität Hamburg-Harburg"],
    ".tu-ilmenau.de": ["Technische Universität Ilmenau"],
    ".tu-muenchen.de": ["Technical University of Munich"],
    ".tuhh.de": ["Technische Universität Hamburg-Harburg"],
    ".tum.de": ["Technical University of Munich"],
    ".udk-berlin.de": ["Universität der Künste Berlin"],
    ".ue-germany.de": [
        "University of Applied Sciences Europe (Campus Hamburg)",
        "University of Applied Sciences Europe (Campus Hamburg)",
    ],
    ".ulricianum-aurich.de": ["Gymnasium Ulricianum Aurich"],
    ".umwelt-campus.de": ["Hochschule Trier, Umwelt-Campus Birkenfeld"],
    ".uni-a.de": ["Universität Augsburg", "Augsburg University"],
    ".uni-augsburg.de": ["Universität Augsburg"],
    ".uni-bamberg.de": ["Otto-Friedrich Universität Bamberg"],
    ".uni-bayreuth.de": ["Universität Bayreuth"],
    ".uni-bielefeld.de": ["Universität Bielefeld"],
    ".uni-bonn.de": [
        "Rheinische Friedrich-Wilhelms Universität Bonn",
        "University of Bonn",
    ],
    ".uni-bremen.de": ["Universität Bremen"],
    ".uni-dortmund.de": ["Universität Dortmund"],
    ".uni-due.de": ["University Duisburg-Essen"],
    ".uni-duesseldorf.de": ["Heinrich-Heine Universität Düsseldorf"],
    ".uni-duisburg-essen.de": ["Universität Duisburg-Essen"],
    ".uni-erfurt.de": [
        "Philosophisch-Theologisches Studium Erfurt, Staatlich anerkannte Wissenschaftliche Hochschule",
        "Universität Erfurt",
    ],
    ".uni-erlangen.de": ["Friedrich-Alexander Universität Erlangen-Nürnberg"],
    ".uni-flensburg.de": ["Universität Flensburg"],
    ".uni-frankfurt.de": [
        "Johann Wolfgang Goethe Universität Frankfurt am Main",
        "Philosophisch-Theologische Hochschule Sankt Georgen",
    ],
    ".uni-freiburg.de": ["Albert-Ludwigs-Universität Freiburg"],
    ".uni-giessen.de": ["Justus Liebig Universität Gießen"],
    ".stud.uni-goettingen.de": ["Georg-August-Universität Göttingen"],
    ".uni-goettingen.de": ["Georg-August Universität Göttingen"],
    ".uni-greifswald.de": ["Ernst-Moritz-Arndt Universität Greifswald"],
    ".uni-halle.de": [
        "Martin-Luther-Universität Halle-Wittenberg",
        "Martin Luther University Halle-Wittenberg",
    ],
    ".uni-hamburg.de": ["Universität Hamburg"],
    ".uni-hannover.de": ["Universität Hannover"],
    ".uni-heidelberg.de": [
        "Hochschule für Jüdische Studien Heidelberg",
        "Ruprecht-Karls-Universität Heidelberg",
    ],
    ".uni-hildesheim.de": ["Universität Hildesheim"],
    ".uni-hohenheim.de": ["Universität Hohenheim"],
    ".uni-jena.de": ["Friedrich-Schiller Universität Jena"],
    ".uni-karlsruhe.de": ["Universität Fridericana Karlsruhe (Technische Hochschule)"],
    ".uni-kassel.de": ["Universität Kassel"],
    ".uni-kiel.de": ["Christian-Albrechts-Universität Kiel"],
    ".uni-kl.de": ["Universität Kaiserslautern"],
    ".uni-koblenz-landau.de": ["Universität Koblenz-Landau"],
    ".uni-koblenz.de": ["University of Koblenz and Landau"],
    ".uni-koeln.de": ["Universität Köln"],
    ".uni-konstanz.de": ["Universität Konstanz"],
    ".uni-landau.de": ["Universität Koblenz-Landau"],
    ".uni-leipzig.de": ["Universität Leipzig"],
    ".uni-luebeck.de": ["University of Lübeck"],
    ".uni-lueneburg.de": ["Universität Lüneburg"],
    ".uni-magdeburg.de": ["Otto-von-Guericke Universität Magdeburg"],
    ".uni-mainz.de": ["Johannes-Gutenberg Universität Mainz"],
    ".uni-mannheim.de": ["Universität Mannheim"],
    ".uni-marburg.de": ["Philipps-Universität Marburg"],
    ".uni-muenchen.de": ["Ludwig-Maximilians-Universität München"],
    ".uni-muenster.de": ["Westfälische Wilhelms-Universität Münster"],
    ".uni-oldenburg.de": ["Carl von Ossietzky Universität Oldenburg"],
    ".uni-osnabrueck.de": ["Universität Osnabrück"],
    ".uni-paderborn.de": ["Universität Paderborn"],
    ".uni-passau.de": ["Universität Passau"],
    ".uni-potsdam.de": ["Universität Potsdam"],
    ".uni-regensburg.de": ["Universität Regensburg"],
    ".uni-rostock.de": ["Universität Rostock"],
    ".uni-saarland.de": ["Universität des Saarlandes"],
    ".uni-siegen.de": ["Universität Siegen"],
    ".uni-stuttgart.de": ["Universität Stuttgart"],
    ".uni-trier.de": ["Theologische Fakultät Trier", "Universität Trier"],
    ".uni-tuebingen.de": ["Eberhard-Karls-Universität Tübingen"],
    ".uni-ulm.de": ["Universität Ulm"],
    ".uni-vechta.de": ["Hochschule Vechta"],
    ".uni-weimar.de": ["Bauhaus-Universität Weimar"],
    ".uni-wh.de": ["Private Universität Witten/Herdecke"],
    ".uni-wuerzburg.de": ["Bayerische Julius-Maximilians-Universität Würzburg"],
    ".uni-wuppertal.de": [
        "Bergische Universität Gesamthochschule Wuppertal",
        "Kirchliche Hochschule Wuppertal",
    ],
    ".unibw-hamburg.de": ["Universität der Bundeswehr Hamburg"],
    ".unibw-muenchen.de": ["Universität der Bundeswehr München"],
    ".unibw.de": ["Universität der Bundeswehr München", "www.unibw.de"],
    ".uniklinik-freiburg.de": ["University Medical Center University of Freiburg"],
    ".uos.de": ["University of Osnabrueck"],
    ".upb.de": ["University of Paderborn"],
    ".ursulinenschule.de": ["Ursulinenschule Fritzlar"],
    ".vbs-lauterbach.de": ["Vogelsbergschule Lauterbach"],
    ".grosse-schule.versus-wf.de": ["Gymnasium Große Schule Wolfenbüttel"],
    ".vit-bund.de": [
        "Federal University of Applied Administrative Sciences > Departmental Branch of Financial Administration > degree course: administrative information systems"
    ],
    ".w-hs.de": ["Westfalia University of Applied Sciences"],
    ".wak-sh.de": ["Wirtschaftsakademie Schleswig-Holstein"],
    ".wara.de": ["Walther-Rathenau Gewerbeschule Freiburg"],
    ".webmail.wavelearn.de": ["sgd-OnlineCampus"],
    ".wb-fernstudium.de": ["Wilhelm Büchner Hochschule", "Wilhelm Büchner Hochschule"],
    ".wgg-neumarkt.de": ["Willibald-Gluck-Gymnasium"],
    ".whg-lu.de": ["Wilhelm-von-Humboldt-Gymnasium"],
    ".whu-koblenz.de": [
        "Wissenschaftliche Hochschule für Unternehmensführung, Otto-Beisheim Hochschule"
    ],
    ".wilhelm-busch-gymnasium.de": ["Wilhelm Busch Gymnasium Stadthagen"],
    ".wrs-lueneburg.de": ["Wilhelm Raabe Schule"],
    ".bsg.wtkedu.de": ["Berufliche Schulen am Gradierwerk", "BSG Bad Nauheim"],
    ".wuemmeschule.de": ["Wümmeschule Ottersberg"],
    ".wvo-dbg.de": ["Wilhelm von Oranien Schule"],
    ".wvss-hildesheim.de": ["Werner-von-Siemens-Schule Hildesheim"],
    ".wvss2-hildesheim.de": ["Werner-von-Siemens-Schule Hildesheim"],
    ".wwgsk.de": [" Wirtschaftswissenschaftliches Gymnasium und Saarland-Kolleg"],
    ".gnr.wwschool.de": ["Gymnasium Nepomucenum Rietberg"],
    ".wwu.de": ["University of Münster"],
    ".student.xu-university.de": ["xu-university", "xu-university"],
    ".zgk-konstanz.de": ["Zeppelin-Gewerbeschule Konstanz"],
    ".zgs-konstanz.de": ["Zeppelin Gewerbeschule Konstanz"],
    ".zu.de": ["Zeppelin University"],
    ".epitech.digital": ["Epitech Digital - L’ÉCOLE DE LA TRANSFORMATION DIGITALE"],
    ".edu.dj": ["Université de Djibouti"],
    ".aaks.dk": ["Aarhus Kommune Skoler", "Aarhus Municipality Schools"],
    ".katrinebjergskolen.aarhus.dk": ["Katrinebjergskolen"],
    ".edu.aarhustech.dk": ["Aarhus Tech"],
    ".aarhustech.dk": ["Aarhus Tech"],
    ".aatg.dk": ["Aalborg Tekniske Gymnasium"],
    ".aau.dk": ["Aalborg University"],
    ".ah.dk": ["Aalborg Business College"],
    ".akademiaarhus.dk": ["Business Academy Aarhus"],
    ".ats.dk": ["Aarhus Technical College"],
    ".au.dk": ["Aarhus University"],
    ".auc.dk": ["Aalborg University"],
    ".brock.dk": ["Niels Brock"],
    ".edu.campusvejle.dk": ["Campus Vejle, Denmark"],
    ".cbs.dk": ["Copenhagen Business School"],
    ".ciid.dk": ["Copenhagen Institute of Interaction Design (CIID)"],
    ".cphbusiness.dk": ["Copenhagen Business Academy"],
    ".db.dk": ["Royal School of Library and Information Science"],
    ".ddea.dk": ["Danish Business Academy"],
    ".detfri.dk": ["Det frie Gymnasium"],
    ".diku.dk": ["University of Copenhagen"],
    ".dkdm.dk": ["Royal Danish Academy of Music"],
    ".dlh.dk": ["Royal Danish School of Educational Sciences"],
    ".mail.dmjx.dk": [
        "Danmarks Medie- og Journalisthøjskole / Danish School of Media and Journalism"
    ],
    ".dmjx.dk": ["Danish School of Media and Journalism"],
    ".dpu.dk": ["Danish University of Education"],
    ".dtu.dk": ["Technical University of Denmark"],
    ".eaaa.dk": ["Erhvervs Akademi Aarhus", "Business Academy Aarhus"],
    ".eadania.dk": ["Dania Academy of Higher Education"],
    ".eal.dk": ["Erhvervsakademiet Lillebælt"],
    ".eamv.dk": ["Erhvervsakademi MidtVest"],
    ".easj.dk": ["ErhvervsAkademi Sjælland"],
    ".easv.dk": ["Business Academy SouthWest"],
    ".easv365.dk": ["Business Academy SouthWest"],
    ".elevcampus.dk": ["EUC Syd - Teknisk Gymnasium Sønderjylland"],
    ".elevportal.dk": ["elevportal.dk"],
    ".euclive.dk": ["EUC Nord HTX Frederikshavn", "EUC North HTX Frederikshavn"],
    ".eucnordvest.dk": ["EUC Nordvest"],
    ".unv.eucsj.dk": ["EUC SJÆLLAND"],
    ".eucsyd.dk": ["EUC SYD"],
    ".gefion-gym.dk": ["Gefion Gymnasium"],
    ".ghg.dk": ["Gammel Hellerup Gymnasium"],
    ".hansenberg.dk": ["Hansenberg"],
    ".herningsholm.dk": ["Herningsholm Erhvervsskole"],
    ".hha.dk": ["Aarhus School of Business"],
    ".hhs.dk": ["Southern Denmark Business School"],
    ".iha.dk": ["Engineering College of Aarhus"],
    ".ihk-edu.dk": ["Engineering College of Copenhagen"],
    ".ihk.dk": ["Engineering College of Copenhagen"],
    ".ipc.dk": ["International People's College"],
    ".itu.dk": ["IT University of Copenhagen"],
    ".edu.kadk.dk": [
        "Det Kongelige Akademi ",
        "Royal Danish Academy, School of Visual Design",
        "Formerly KADK ",
        "The Royal Danish Academy of Fine Arts' Schools of Architecture, Design and Conservation",
        "@edu.kadk.dk",
    ],
    ".karch.dk": ["Royal Danish Academy of Fine Arts, School of Architecture"],
    ".kea.dk": ["Copenhagen School of Design and Technology"],
    ".ku.dk": ["Copenhagen University"],
    ".kunstakademiet.dk": ["Royal Danish Academy of Fine Arts, School of Visual Art"],
    ".kvl.dk": ["Royal Veterinary and Agricultural University"],
    ".learnmark.dk": ["Learnmark Horsens"],
    ".mediacollege.dk": ["Media College Aalborg"],
    ".mercantec.dk": ["Mercantec"],
    ".mitvuc.dk": ["VUC Syd"],
    ".musik-kons.dk": ["Royal Academy of Music"],
    ".nbi.dk": ["Niels Bohr Institute"],
    ".edu.nextkbh.dk": ["Next Uddannelse København", "Next Education Copenhagen"],
    ".nextkbh.dk": ["NEXT Uddannelse København", "NEXT Education Copenhagen"],
    ".edu.nyborg-gym.dk": ["Nyborg Gymnasium"],
    ".ofe.dk": ["Osted fri og efterskole"],
    ".ou.dk": ["Odense University"],
    ".pha.dk": ["Professionshøjskolen Absalon"],
    ".phmetropol.dk": ["Professionshøjskolen Metropol"],
    ".rhs.dk": ["Roskilde Business College"],
    ".ruc.dk": ["Roskilde University"],
    ".rybners.dk": ["Rybners"],
    ".sde.dk": [
        "Business School of Southern Denmark (Website, english version: http://www.sde.dk/sde/site.aspx?p=1136)"
    ],
    ".sdu.dk": ["University of Southern Denmark"],
    ".edu.simac.dk": ["Svendborg International Maritime Academy"],
    ".studiebyenesbjerg.dk": ["Erhvervs Akademi Sydvest"],
    ".svhfvuc.dk": ["Skive Viborg Hf & VUC"],
    ".svkskole.dk": ["Svendborg Kommunes Skoler ", "Svendborg Municipality Schools"],
    ".sydfynsfrifagskole.dk": ["Sydfyns Fri Fagskole"],
    ".tcaa.dk": ["Tech College Aalborg"],
    ".tec.dk": ["TEC - Technical Education Copenhagen"],
    ".techcollege.dk": ["Tech College Aalborg"],
    ".teologi.dk": ["Lutheran School Of Theology In Aarhus"],
    ".tietgen.dk": ["Tietgen Business College"],
    ".elev.tradium.dk": ["Tradium (Students)"],
    ".ucl.dk": ["UCL Erhvervsakademi og Professionshøjskole"],
    ".ucn.dk": ["University College of Northern Denmark"],
    ".via.dk": ["VIA University College"],
    ".viauc.dk": ["VIA University College"],
    ".videndjurs.dk": [
        'Videndjus Gymnasier, Videndjurs Erhvervsuddannelser (English website "http://www.videndjurs.dk/Default.aspx?ID=3992")'
    ],
    ".vordingborgskolen.dk": ["Vordingborg Fri Fagskole"],
    ".zbc.dk": ["ZBC - Zealand Business College"],
    ".zealand.dk": [
        "Zealand - Sjællands Erhvervsakademi",
        "Zealand - Academy of Technologies and Business",
    ],
    ".icda.edu.do": [
        "Universidad Dominico-Americana",
        "Universidad Dominico-Americana",
    ],
    ".intec.edu.do": [
        "Instituto Tecnológico de Santo Domingo",
        "Instituto Tecnológico de Santo Domingo",
    ],
    ".itla.edu.do": [
        "Instituto Tecnológico de Las Américas",
        "Las Américas Institute of Technology",
    ],
    ".oym.edu.do": ["Universidad dominicana O&M"],
    ".oymas.edu.do": ["universidad Dominicana O&M"],
    ".pucmm.edu.do": [
        "Pontificia Universidad Católica Madre y Maestra (PUCMM)",
        "Universidad Católica Madre y Maestra",
        "Pontificia Universidad Católica Madre y Maestra (PUCMM)",
        "Universidad Católica Madre y Maestra",
    ],
    ".uafam.edu.do": [
        "Universidad Agroforestal Fernando A.Meriño",
        "Universidad Agroforestal Fernando A.Meriño",
    ],
    ".uapa.edu.do": [
        "Universidad Abierta Para Adultos",
        "Universidad Abierta Para Adultos",
    ],
    ".uasd.edu.do": [
        "Universidad Autónoma de Santo Domingo",
        "Universidad Autónoma de Santo Domingo",
    ],
    ".ucateci.edu.do": [
        "Universidad Católica Tecnológica del Cibao",
        "Universidad Católica Tecnológica del Cibao",
    ],
    ".uce.edu.do": ["Universidad Central del Este", "Universidad Central del Este"],
    ".ucne.edu.do": [
        "Universidad Católica Nordestana",
        "Universidad Católica Nordestana",
    ],
    ".ucsd.edu.do": [
        "Universidad Católica de Santo Domingo",
        "Universidad Católica de Santo Domingo",
    ],
    ".udoym.edu.do": [
        "Universidad Dominicana O&amp;M",
        "Universidad Dominicana O&amp;M",
    ],
    ".ufhec.edu.do": [
        "Universidad Federico Henríquez y Carvajal",
        "Universidad Ulises Francisco Espaillat",
        "Universidad Federico Henríquez y Carvajal",
        "Universidad Ulises Francisco Espaillat",
    ],
    ".unad.edu.do": [
        "Universidad Adventista Dominicana",
        "Universidad Adventista Dominicana",
    ],
    ".unapec.edu.do": ["Universidad APEC", "Universidad APEC"],
    ".unefa.edu.do": [
        "Universidad Experimental Felix Adam",
        "Universidad Experimental Felix Adam",
    ],
    ".unibe.edu.do": ["Universidad Iberoamericana", "Universidad Iberoamericana"],
    ".unicaribe.edu.do": ["Universidad del Caribe", "Universidad del Caribe"],
    ".uniremhos.edu.do": [
        "Universidad Eugenio Maria de Hostos",
        "Universidad Eugenio Maria de Hostos",
    ],
    ".unphu.edu.do": [
        "Universidad Nacional Pedro Henríquez Ureña",
        "Universidad Nacional Pedro Henríquez Ureña",
    ],
    ".uod.edu.do": [
        "Universidad Odontológica Dominicana",
        "Universidad Odontológica Dominicana",
    ],
    ".ute.edu.do": ["Universidad de la Tercera Edad", "Universidad de la Tercera Edad"],
    ".utesur.edu.do": [
        "Universidad Tecnológica del Sur",
        "Universidad Tecnológica del Sur",
    ],
    ".cdta.dz": [
        "Center for Development of Advenced Technologies",
        "Centre de développement des technologies avancées",
    ],
    ".cu-elbayadh.dz": [
        "University Center Nour Bachir El-Bayadh",
        "Centre Universitaire Nour Bachir El-Bayadh",
        "المركز الجامعي نور البشير البيض",
    ],
    ".enp.edu.dz": [
        "Polytechnic School of Algiers",
        "Ecole Nationale Polytechnique, Alger",
    ],
    ".umc.edu.dz": ["Université Mentouri Constantine"],
    ".enp-oran.dz": ["Ecole Nationale Polytechnique d'Oran Maurice Audin"],
    ".ens-kouba.dz": [
        "ENS El-Bachir El-Ibrahimi - Kouba ",
        "El-Bachir El-Ibrahimi ENS - Kouba",
    ],
    ".ensh.dz": [
        "ENSH - Ecole Nationale Supérieure d'Hydraulique de Blida",
        "ENSH - National School of Hydraulics of Blida",
    ],
    ".enst.dz": ["Ecole Nationale Superieure de Technologie"],
    ".epst-oran.dz": ["Ecole Préparatoire en Sciences et Techniques"],
    ".esi-sba.dz": ["Ecole Nationale Supérieure D'Informatique de Sidi Belabbess"],
    ".esi.dz": ["l'Ecole Nationale Supérieure D'Informatique"],
    ".essa-tlemcen.dz": [
        "Ecole Supérieure en Sciences Appliquées de Tlemcen",
        "School of Applied Sciences Tlemcen",
    ],
    ".esti-annaba.dz": ["École Supérieure de Technologies Industrielles d'Annaba"],
    ".estin.dz": [
        "École supérieure en Sciences et Technologies de l'Informatique et du Numérique",
        "Higher School of Digital and Computer Sciences and Technologies",
        "المدرسة العليا في علوم و تكنولوجيات الإعلام الآلي و الرقمنة",
    ],
    ".inttic.dz": [
        "Institut National Télécommunications et en Technologies de l'Information et de la Communications",
        "National Institute of telecommunications and ICT",
    ],
    ".ito.dz": [
        "Institut National des Télécommunications et des TIC",
        "National Institute of Telecommunications and ICT",
    ],
    ".lagh-univ.dz": ["Université Amar Telidji"],
    ".umbb.dz": ["Université M'hamed Bouguerra de Boumerdes"],
    ".ummto.dz": ["Université Mouloud Mammeri de Tizi Ouzou"],
    ".univ-alger.dz": ["Université d'Alger"],
    ".univ-alger3.dz": ["Université d'Alger 3"],
    ".univ-annaba.dz": ["Université Badji Mokhtar"],
    ".univ-batna2.dz": [
        "University of Batna 2, Mostefa Ben Boulaïd",
        "Université Batna 2, Mostefa Ben Boulaïd",
    ],
    ".univ-bba.dz": ["Université Bordj Bou Arreridj"],
    ".univ-bejaia.dz": ["Université de Béjaia"],
    ".univ-biskra.dz": [
        "Université Mohamed Khider Biskra",
        "Mohamed Khider University of Biskra",
    ],
    ".univ-blida.dz": ["Université de Blida"],
    ".univ-bouira.dz": ["Akli Mohand Oulhadj Bouira university"],
    ".univ-boumerdes.dz": ["Université M'hamed Bouguerra de Boumerdes"],
    ".univ-chlef.dz": ["Université de Chlef"],
    ".univ-constantine2.dz": ["Université Abdelhamid Mehri Constantine 2"],
    ".univ-constantine3.dz": [
        "université constantine3 salah boubnider",
        "university constantine3 salah boubnider",
    ],
    ".univ-dbkm.dz": ["Université de khemis miliana"],
    ".univ-eltarf.dz": [
        "Université Chadli Benjedid El tarf",
        "Chadli Benjedid El Tarf University",
    ],
    ".univ-emir.dz": ["Universite des Sciences Islamiques de Constantine"],
    ".univ-ghardaia.dz": ["Université de Ghardaia"],
    ".univ-jijel.dz": ["Centre Universitaire de Jijel"],
    ".univ-mascara.dz": [
        "Université de Mascara - Mustapha Stambouli",
        "University of Mascara",
    ],
    ".univ-mosta.dz": ["Université de Mostaganem"],
    ".univ-msila.dz": ["Université de M'sila"],
    ".univ-oeb.dz": ["Centre Universitaire d'Oum El Bouaghi"],
    ".univ-oran.dz": ["Université d'Oran Es-Senia"],
    ".univ-oran1.dz": ["Université d'Oran 1 Ahmed Ben Bella"],
    ".univ-oran2.dz": [
        "Université d'Oran 2 Mohamed Ben Ahmed",
        "University of Oran 2 Mohamed Ben Ahmed",
    ],
    ".univ-ouargla.dz": ["University of Ouargla"],
    ".univ-saida.dz": ["Université de Saida"],
    ".univ-sba.dz": ["Université de Sidi-Bel-Abbès (Djillali Liabès)"],
    ".univ-setif.dz": ["Université de Sétif"],
    ".univ-skikda.dz": [
        "universite 20 Aout 1955 Skikda",
        "20 August 1955 Skikda University",
    ],
    ".univ-tebessa.dz": ["Centre Universitaire de Tebessa"],
    ".univ-tiaret.dz": ["Centre Universitaire de Tiaret"],
    ".univ-tlemcen.dz": ["Université Abou Bekr Belkaid, Tlemcen"],
    ".univ-usto.dz": ["Université des Sciences et de la Technologie d'Oran"],
    ".usthb.dz": ["Université des Sciences et de la Technologie Houari Boumediène"],
    ".aitec.edu.ec": [
        "Instituto Superior Tecnológico Almirante Illingworth",
        "Instituto Superior Tecnológico Almirante Illingworth",
    ],
    ".casagrande.edu.ec": ["Universidad Casa Grande"],
    ".estudiantes.cordillera.edu.ec": [
        "Instituto Tecnológico Universitario Cordillera"
    ],
    ".cruzrojainstituto.edu.ec": [
        "Instituto Tecnológico Superior Cruz Roja Ecuatoriana",
        "Technological Institute Ecuadorian Red Cross",
    ],
    ".donbosco.edu.ec": ["UEF Don Bosco, Ecuador"],
    ".est.ecotec.edu.ec": ["ECOTEC"],
    ".epn.edu.ec": ["Escuela Politécnica Nacional"],
    ".espe.edu.ec": ["Escuela Politécnica del Ejercito"],
    ".espoch.edu.ec": ["Escuela Superior Politécnica de Chimborazo"],
    ".espol.edu.ec": ["Escuela Superior Politécnica del Litoral"],
    ".indoamerica.edu.ec": ["Universidad Tecnológica Indoamérica"],
    ".internacional.edu.ec": ["Universidad Internacional del Ecuador"],
    ".itb.edu.ec": [
        "Instituto Universitario Superior Bolivariano",
        "Bolivarian University Institute",
    ],
    ".iti.edu.ec": ["Instituto tecnológico internacional"],
    ".itsgg.edu.ec": [
        "Instituto Superior Tecnológico Guayaquil",
        "Instituto Superior Tecnológico Guayaquil",
    ],
    ".itslibertad.edu.ec": ["Instituto superior tecnológico libertad"],
    ".lametro.edu.ec": ['Instituto Metropolitano de Diseño, "La Metro"'],
    ".puce.edu.ec": ["Pontificia Universidad Católica del Ecuador"],
    ".pucesd.edu.ec": [
        "Pontificia Universidad Católica del Ecuador sede Santo Domingo"
    ],
    ".pucese.edu.ec": [
        "PONTIFICIA UNIVERSIDAD CATÓLICA DEL ECUADOR SEDE EN ESMERALDAS"
    ],
    ".pucesi.edu.ec": ["Pontificia Universidad Católica del Ecuador Sede Ibarra"],
    ".sudamericano.edu.ec": ["Instituto Superior Tecnológico Particular Sudamericano"],
    ".tecazuay.edu.ec": [
        "Instituto Superior Tecnológico del Azuay",
        "Higher Technological Institute of Azuay",
    ],
    ".tecnologicoliceocristiano.edu.ec": [
        "Tecnológico Liceo Cristiano de Guayaquil",
        "Tecnológico Liceo Cristiano de Guayaquil",
    ],
    ".tes.edu.ec": ["Tecnológico Universitario Espíritu Santo"],
    ".uagraria.edu.ec": ["Universidad Agraria del Ecuador"],
    ".uartes.edu.ec": ["Universidad de las Artes"],
    ".uasb.edu.ec": ["Universidad Andina Simón Bolívar"],
    ".uazuay.edu.ec": ["Universidad del Azuay"],
    ".ucacue.edu.ec": ["Universidad Católica de Cuenca"],
    ".uce.edu.ec": ["Universidad Central Del Ecuador"],
    ".ucsg.edu.ec": ["Universidad Católica de Santiago de Guayaquil"],
    ".ucuenca.edu.ec": ["Universidad de Cuenca"],
    ".udla.edu.ec": ["Universidad de Las Américas"],
    ".uea.edu.ec": ["Universidad Estatal Amazónica"],
    ".ueb.edu.ec": ["\ufeffUNIVERSIDAD ESTATAL DE BOLÍVAR"],
    ".uees.edu.ec": ["Universidad de Especialidades del Espíritu Santo"],
    ".uefsorteresavalse.edu.ec": ["Unidad Educativa Fiscomisional Sor Teresa Valse"],
    ".ug.edu.ec": ["Universidad de Guayaquil"],
    ".uisek.edu.ec": [
        "Universidad Internacional SEK Ecuador",
        "SEK Ecuador International University",
    ],
    ".uleam.edu.ec": ["Universidad Laica Eloy Alfaro de Manabi"],
    ".ulvr.edu.ec": [
        "Universidad Laica Vicente Rocafuerte",
        "Laica Vicente Rocafuerte University",
    ],
    ".est.umet.edu.ec": ["Universidad Metropolitana", "Metropolitan University"],
    ".unach.edu.ec": ["Universidad Nacional de Chimborazo"],
    ".unemi.edu.ec": [
        "Universidad Estatal De Milagro UNEMI",
        "Milagro State University ",
    ],
    ".unibe.edu.ec": [" Universidad Iberoamericana del Ecuador"],
    ".unl.edu.ec": ["Universidad Nacional de Loja"],
    ".upacifico.edu.ec": ["Universidad del Pacifico"],
    ".ups.edu.ec": ["Universidad Politécnica Salesiana"],
    ".upse.edu.ec": ["Universidad Estatal Península de Santa Elena"],
    ".usfq.edu.ec": ["Universidad San Francisco de Quito"],
    ".usm.edu.ec": ["Universidad Santa María Campus Guayaquil"],
    ".uta.edu.ec": ["Universidad Técnica de Ambato"],
    ".utb.edu.ec": ["Universidad Técnica de Babahoyo"],
    ".utc.edu.ec": ["Universidad Técnica de Cotopaxi"],
    ".ute.edu.ec": ["Universidad Tecnológica Equinoccial"],
    ".utelvt.edu.ec": ["Universidad Técnica de Esmeraldas Luis Vargas Torres"],
    ".uteq.edu.ec": ["Universidad Técnica Estatal de Quevedo"],
    ".utm.edu.ec": ["Universidad Técnica de Manabí"],
    ".utmachala.edu.ec": ["Universidad Técnica de Machala"],
    ".utn.edu.ec": ["Universidad Técnica del Norte"],
    ".utpl.edu.ec": ["Universidad Técnica Particular de Loja"],
    ".yachaytech.edu.ec": ["Universidad Yachay Tech", "Yachay Tech University"],
    ".yavirac.edu.ec": ["Instituto Tecnológico Superior Yavirac"],
    ".udlanet.ec": ["Universidad de Las Americas - UDLA Quito"],
    ".stu.SanJac.edu": ["San Jacinto College"],
    ".Watumull.edu": [
        "Watumull Institute of Electronics Engineering and Computer Technology",
        "affiliated to Mumbai University and is approved by AICTE",
    ],
    ".aacc.edu": ["Anne Arundel Community College"],
    ".aamu.edu": ["Alabama Agricultural and Mechanical University"],
    ".aast.edu": ["Arab Academy for Science &amp; Technology"],
    ".aauj.edu": ["Arab American University - Jenin"],
    ".ab.edu": ["Alderson Broaddus College"],
    ".academy.edu": ["International Academy of  Merchandising and Design Tampa"],
    ".academyart.edu": ["Academy of Art College"],
    ".acp.edu": ["Albany College of Pharmacy"],
    ".act.edu": ["American College of Thessaloniki"],
    ".acu.edu": ["Abilene Christian University"],
    ".adams.edu": ["Adams State University"],
    ".adelphi.edu": ["Adelphi University"],
    ".adler.edu": ["Adler School of Professional Psychology"],
    ".adrian.edu": ["Adrian College"],
    ".africau.edu": ["Africa University"],
    ".ahgaff.edu": ["Alahgaff University"],
    ".aic.edu": ["American International College"],
    ".aicag.edu": ["American Indian College of the Assemblies of God"],
    ".aii.edu": [
        "The Art Institutes International San Francisco",
        "The Art Institutes International Portland",
    ],
    ".aiu.edu": ["Atlantic International University"],
    ".aiub.edu": ["American International University - Bangladesh"],
    ".aiuniv.edu": [
        "American InterContinental University - London",
        "American InterContinental University - Georgia",
        "American InterContinental University - Ft. Lauderdale",
        "American InterContinental University - Atlanta",
    ],
    ".aju.edu": ["Andrew Jackson University"],
    ".akbible.edu": ["Alaska Bible College"],
    ".aku.edu": ["Aga Khan University"],
    ".alaska.edu": [
        "University of Alaska - Anchorage",
        "University of Alaska - Southeast",
        "University of Alaska (System)",
    ],
    ".alaskapacific.edu": ["Alaska Pacific University"],
    ".alasu.edu": ["Alabama State University"],
    ".albany.edu": ["State University of New York at Albany"],
    ".albanylaw.edu": ["Albany Law School"],
    ".albertus.edu": ["Albertus Magnus College"],
    ".albion.edu": ["Albion College"],
    ".albizu.edu": ["Carlos Albizu University"],
    ".albright.edu": ["Albright College"],
    ".alc.edu": ["Alice Lloyd College"],
    ".alcorn.edu": ["Alcorn State University"],
    ".alfaisal.edu": ["Alfaisal University"],
    ".alfred.edu": ["Alfred University"],
    ".alfredadler.edu": ["Alfred Adler Graduate School"],
    ".alma.edu": ["Alma College"],
    ".alquds.edu": ["Al-Quds University - The Arab University in Jerusalem"],
    ".alvernia.edu": ["Alvernia College"],
    ".alverno.edu": ["Alverno College"],
    ".ambassador.edu": ["Ambassador University"],
    ".amc.edu": ["Albany Medical Center"],
    ".amherst.edu": ["Amherst College"],
    ".amity.edu": ["Amity university"],
    ".cb.amrita.edu": ["Amrita Vishwa Vidyapeetham, Coimbatore"],
    ".amrita.edu": ["Amrita Vishwa Vidyapeetham"],
    ".anderson.edu": ["Anderson University"],
    ".andrews.edu": ["Andrews University"],
    ".angelina.edu": ["Angelina College"],
    ".angelo.edu": ["Angelo State University"],
    ".annauniv.edu": ["Anna University, Chennai, India"],
    ".anselm.edu": ["St. Anselm College"],
    ".antioch.edu": ["Antioch University"],
    ".antiochla.edu": ["Antioch University Los Angeles"],
    ".antiochne.edu": ["Antioch New England Graduate School"],
    ".antiochsb.edu": ["Antioch University Santa Barbara"],
    ".antiochsea.edu": ["Antioch University Seattle"],
    ".appstate.edu": ["Appalachian State University"],
    ".apsu.edu": ["Austin Peay State University"],
    ".apu.edu": ["Azusa Pacific University"],
    ".apus.edu": ["American Public University"],
    ".aquinas.edu": ["Aquinas College"],
    ".arapahoe.edu": ["Arapahoe Community College"],
    ".arbor.edu": ["Spring Arbor College"],
    ".argosy.edu": ["Argosy University"],
    ".arizona.edu": ["University of Arizona"],
    ".armstrong.edu": ["Armstrong Atlantic State University"],
    ".artacademy.edu": ["Art Academy of Cincinnati"],
    ".artcenter.edu": ["Art Center College of Design"],
    ".artic.edu": ["The School of the Art Institute of Chicago"],
    ".artinstitutes.edu": [
        "The Illinois Institute of Art-Chicago",
        "Art Institute of Charlotte",
    ],
    ".asbury.edu": ["Asbury College"],
    ".ashland.edu": ["Ashland University"],
    ".assumption.edu": ["Assumption College"],
    ".astate.edu": ["Arkansas State University"],
    ".asu.edu": [
        "Arizona State University",
        "Arizona State University, Polytechnic Campus",
        "Arizona State University, West Campus",
    ],
    ".asub.edu": ["Arkansas State University, Beebe"],
    ".asumh.edu": ["Arkansas State University, Mountain Home"],
    ".asun.edu": ["Arkansas State University, Newport"],
    ".asurams.edu": ["Albany State University"],
    ".ateneo.edu": ["Ateneo de Manila University"],
    ".athabasca.edu": ["Athabasca University"],
    ".athens.edu": ["Athens State College"],
    ".atlanticuniv.edu": ["Atlantic University"],
    ".atu.edu": ["Arkansas Tech University"],
    ".au.edu": ["Assumption University of Thailand"],
    ".mail.aub.edu": ["American University of Beirut"],
    ".auburn.edu": ["Auburn University"],
    ".aucegypt.edu": ["American University in Cairo"],
    ".aucmed.edu": [
        "American University of the Caribbean, Sint Maarten",
        "American University of the Caribbean, School of Medicine",
    ],
    ".aud.edu": ["American University in Dubai"],
    ".augie.edu": ["Augustana College"],
    ".augsburg.edu": ["Augsburg College"],
    ".augusta.edu": ["Augusta University - https://www.augusta.edu/"],
    ".augustana.edu": ["Augustana College"],
    ".aul.edu": ["The American University in London"],
    ".aum.edu": ["Auburn University at Montgomery"],
    ".aurora.edu": ["Aurora University"],
    ".aus.edu": ["American University of Sharjah"],
    ".aust.edu": ["Ahsanullah University of Science &amp; Technology"],
    ".aut.edu": ["American University College of Technology"],
    ".averett.edu": ["Averett College"],
    ".avila.edu": ["Avila College"],
    ".azwestern.edu": ["Arizona Western College"],
    ".b-sc.edu": ["Barber-Scotia College"],
    ".babson.edu": ["Babson College"],
    ".bac.edu": ["Belmont Abbey College"],
    ".baker.edu": [
        "Baker College of Auburn Hills",
        "Baker College of Cadillac",
        "Baker College of Flint",
        "Baker College of Mount Clemens",
        "Baker College of Muskegon",
        "Baker College of Owosso",
        "Baker College of Port Huron",
    ],
    ".bakeru.edu": ["Baker University"],
    ".barclaycollege.edu": ["Barclay College"],
    ".bard.edu": [
        "Bard College",
        "Bard Graduate Center for Studies in the Decorative Arts",
    ],
    ".barry.edu": ["Barry University"],
    ".barton.edu": ["Barton College"],
    ".bastyr.edu": ["Bastyr University"],
    ".bates.edu": ["Bates College"],
    ".bath.edu": [
        "University of Bath",
        "official url: http://www.bath.ac.uk/",
        "long-term IT related course: http://www.bath.ac.uk/courses/undergraduate-2018/computer-science/",
        "recognition of of domain: http://www.bath.ac.uk/alumni/services/bathmail/index.html",
    ],
    ".baylor.edu": ["Baylor University"],
    ".bc.edu": ["Boston College"],
    ".belhaven.edu": ["Belhaven College"],
    ".bellarmine.edu": ["Bellarmine College"],
    ".bellevue.edu": ["Bellevue University"],
    ".bellevuecollege.edu": ["bellevuecollege.edu"],
    ".belmont.edu": ["Belmont University"],
    ".belmontcollege.edu": ["Belmont College"],
    ".beloit.edu": ["Beloit College"],
    ".ben.edu": ["Benedictine University", "Illinois Benedictine University"],
    ".benedict.edu": ["Benedict College"],
    ".benedictine.edu": ["Benedictine College"],
    ".bennett.edu": ["Bennett College"],
    ".bennington.edu": ["Bennington College"],
    ".bentley.edu": ["Bentley College"],
    ".berea.edu": ["Berea College"],
    ".berean.edu": ["Berean University of the Assemblies of God"],
    ".bergen.edu": ["Bergen Community College", "@me.bergen.edu"],
    ".berkeley.edu": ["University of California, Berkeley"],
    ".berklee.edu": ["Berklee College of Music"],
    ".berry.edu": ["Berry College"],
    ".bethany.edu": ["Bethany College California"],
    ".bethanylb.edu": ["Bethany College Kansas"],
    ".bethel.edu": ["Bethel College St. Paul"],
    ".bethelks.edu": ["Bethel College Newton"],
    ".bethlehem.edu": ["Bethlehem University"],
    ".bgsu.edu": [
        "Bowling Green State University",
        "Bowling Green State University, Firelands",
    ],
    ".bhc.edu": ["Black Hawk College"],
    ".bhsu.edu": ["Black Hills State University"],
    ".bhu.edu": ["Baltimore Hebrew University"],
    ".bible.edu": ["Washington Bible College"],
    ".binghamton.edu": ["State University of New York at Binghamton"],
    ".biola.edu": ["Biola University"],
    ".bircham.edu": ["Bircham International University"],
    ".birzeit.edu": ["Birzeit University"],
    ".bju.edu": ["Bob Jones University"],
    ".blackburn.edu": ["Blackburn College"],
    ".bloomfield.edu": ["Bloomfield College"],
    ".bloomu.edu": ["Bloomsburg University of Pennsylvania"],
    ".bluefield.edu": ["Bluefield College"],
    ".bluffton.edu": ["Bluffton College"],
    ".bmc.edu": ["Blue Mountain College"],
    ".boisebible.edu": ["Boise Bible College"],
    ".boisestate.edu": ["Boise State University"],
    ".boricuacollege.edu": ["Boricua College"],
    ".bowdoin.edu": ["Bowdoin College"],
    ".bowiestate.edu": ["Bowie State University"],
    ".bpc.edu": ["Brewton-Parker College"],
    ".bpcc.edu": ["Bossier Parish Community College"],
    ".bpkihs.edu": ["B.P.Koirala Institute of Health Sciences"],
    ".bradley.edu": ["Bradley University"],
    ".brandeis.edu": ["Brandeis University"],
    ".brandman.edu": ["Brandman University"],
    ".brcn.edu": ["Blessing-Rieman College of Nursing"],
    ".brenau.edu": ["Brenau University"],
    ".brescia.edu": ["Brescia University"],
    ".brevard.edu": ["Brevard College"],
    ".bridgeport.edu": ["University of Bridgeport"],
    ".bridgew.edu": ["Bridgewater State College"],
    ".bridgewater.edu": ["Bridgewater College"],
    ".brockport.edu": ["State University of New York College at Brockport"],
    ".brooklaw.edu": ["Brooklyn Law School"],
    ".brooks.edu": ["Brooks Institute of Photography"],
    ".brown.edu": ["Brown University"],
    ".brunswickcc.edu": ["Brunswick Community College"],
    ".bryan.edu": ["Bryan College"],
    ".bryant.edu": ["Bryant University"],
    ".bryantstratton.edu": ["Bryant and Stratton College"],
    ".brynmawr.edu": ["Bryn Mawr College"],
    ".bsc.edu": ["Birmingham-Southern College"],
    ".bsu.edu": ["Ball State University"],
    ".bths.edu": [
        "Brooklyn Technical Highschool",
        "https://www.bths.edu/ourpages/auto/2014/2/22/57015226/Software%20Engineeering%20Major%202019-2020.pdf",
    ],
    ".bu.edu": ["Boston University"],
    ".bucknell.edu": ["Bucknell University"],
    ".bucks.edu": ["Bucks County Community College"],
    ".buffalo.edu": [
        "State University of New York at Buffalo",
        "State University of New York School of Engineering and Applied Sciences",
    ],
    ".butler.edu": ["Butler University"],
    ".bvu.edu": ["Buena Vista University"],
    ".bw.edu": ["Baldwin Wallace University"],
    ".studentbody.byu.edu": ["Brigham Young University"],
    ".byu.edu": ["Brigham Young University"],
    ".byuh.edu": ["Brigham Young University Hawaii"],
    ".byui.edu": ["Brigham Young University"],
    ".cabrini.edu": ["Cabrini College"],
    ".cahsu.edu": [
        "Central America Health Sciences University (Belize Medical College)"
    ],
    ".calarts.edu": ["California Institute of the Arts"],
    ".calbaptist.edu": ["California Baptist College"],
    ".calcoast.edu": ["California Coast University"],
    ".caldwell.edu": ["Caldwell College"],
    ".callutheran.edu": ["California Lutheran University"],
    ".calpoly.edu": ["California Polytechnic State University - San Luis Obispo"],
    ".calstatela.edu": ["California State University, Los Angeles"],
    ".caltech.edu": ["California Institute of Technology"],
    ".calvary.edu": ["Calvary Bible College"],
    ".calvin.edu": ["Calvin College"],
    ".cambridge.edu": ["Cambridge College"],
    ".cameron.edu": ["Cameron University"],
    ".campbell.edu": ["Campbell University"],
    ".campbellsville.edu": ["Campbellsville University"],
    ".canisius.edu": ["Canisius College"],
    ".capecod.edu": ["Cape Cod Community College"],
    ".capella.edu": ["Capella University"],
    ".capellauniversity.edu": ["Capella University"],
    ".capital.edu": ["Capital University", "Capital University Law School"],
    ".capitol-college.edu": ["Capitol College"],
    ".caribbean.edu": ["Caribbean University"],
    ".carleton.edu": ["Carleton College"],
    ".carlow.edu": ["Carlow College"],
    ".carroll.edu": ["Carroll College Helena"],
    ".carthage.edu": ["Carthage College"],
    ".case.edu": ["Case Western Reserve University"],
    ".catawba.edu": ["Catawba College"],
    ".cau.edu": ["Clark Atlanta University"],
    ".cayuga-cc.edu": ["Cayuga Community College"],
    ".cbc.edu": ["Central Baptist College"],
    ".cbcag.edu": ["Central Bible College"],
    ".cbu.edu": ["Christian Brothers University"],
    ".cc-sd.edu": ["California College San Diego"],
    ".cc.edu": ["Carroll College Waukesha"],
    ".ccac.edu": [
        "College name: Community College of Allegheny County",
        "College home page: https://ccac.edu",
        "Software development program: https://ccac.edu/Software_Development_AS.aspx",
        "Email domain: https://www.ccac.edu/ITS__Academic_Email_for_Students_and_Faculty.aspx",
    ],
    ".ccad.edu": ["Columbus College of Art and Design"],
    ".ccc.edu": ["Olive-Harvey College", "Wilbur Wright College"],
    ".cccb.edu": ["Central Christian College of the Bible"],
    ".cccd.edu": [
        "Orange Coast College",
        "Coastline Community College",
        "Golden West College",
        ".group",
    ],
    ".cccs.edu": [
        "Colorado Community College System",
        "Arapahoe Community College",
        ".group",
    ],
    ".ccis.edu": ["Columbia College of Missouri"],
    ".ccp.edu": ["Community College of Philadelphia", "www.ccp.edu"],
    ".ccsf.edu": ["City College of San Francisco"],
    ".ccsj.edu": ["Calumet College of St. Joseph"],
    ".ccsu.edu": ["Central Connecticut State University"],
    ".ccu.edu": ["Colorado Christian University"],
    ".cdrewu.edu": ["Charles R. Drew University of Medicine and Science"],
    ".cedarcrest.edu": ["Cedar Crest College"],
    ".cedarville.edu": ["Cedarville College"],
    ".centenary.edu": ["Centenary College of Louisiana"],
    ".central.edu": ["Central College"],
    ".centralpenn.edu": ["Central Penn College"],
    ".centralstate.edu": ["Central State University"],
    ".centre.edu": ["Centre College"],
    ".cga.edu": ["United States Coast Guard Academy"],
    ".cgu.edu": ["Claremont Graduate University"],
    ".chaminade.edu": ["Chaminade University of Honolulu"],
    ".champlain.edu": ["Champlain College"],
    ".chapman.edu": ["Chapman University"],
    ".chatham.edu": ["Chatham College"],
    ".chc.edu": ["Chestnut Hill College"],
    ".cheyney.edu": ["Cheyney University of Pennsylvania"],
    ".chicagobooth.edu": ["Univsersity of Chicago Booth School of Business"],
    ".chiropractic.edu": ["National College of Chiropractic"],
    ".chowan.edu": ["Chowan College"],
    ".christendom.edu": ["Christendom College"],
    ".cia.edu": ["Cleveland Institute of Art"],
    ".ciis.edu": ["California Institute of Integral Studies"],
    ".cim.edu": ["Cleveland Institute of Music"],
    ".cityu.edu": ["City University"],
    ".ciu.edu": ["Columbia International University"],
    ".clarion.edu": ["Clarion University"],
    ".clarke.edu": ["Clarke College"],
    ".clarkson.edu": ["Clarkson University"],
    ".clarksoncollege.edu": ["Clarkson College"],
    ".clarku.edu": ["Clark University"],
    ".clayton.edu": ["Clayton College &amp; State University"],
    ".clearwater.edu": ["Clearwater Christian College"],
    ".cleary.edu": ["Cleary College"],
    ".clemson.edu": ["Clemson University"],
    ".clu.edu": ["Universidad de Puerto Rico", "Universidad de Puerto Rico, Humacao"],
    ".cmc.edu": ["Central Methodist College"],
    ".cmich.edu": ["Central Michigan University"],
    ".cmsv.edu": ["College of Mount St. Vincent"],
    ".cmu.edu": ["Carnegie Mellon University"],
    ".cn.edu": ["Carson-Newman College"],
    ".cnm.edu": ["Central New Mexico Community College"],
    ".cnr.edu": ["College of New Rochelle"],
    ".cnu.edu": ["Christopher Newport University"],
    ".coa.edu": ["College of the Atlantic"],
    ".coastal.edu": ["Coastal Carolina University"],
    ".cobleskill.edu": [
        "State University of New York College of Agriculture and Technology at Cobleskill"
    ],
    ".cod.edu": ["College of DuPage"],
    ".coe.edu": ["Coe College"],
    ".cofc.edu": ["College of Charleston", "University of Charleston South Carolina"],
    ".cofo.edu": ["College of the Ozarks"],
    ".cogswell.edu": ["Cogswell Polytechnical College"],
    ".coker.edu": ["Coker College"],
    ".colby-sawyer.edu": ["Colby-Sawyer College"],
    ".colby.edu": ["Colby College"],
    ".coleman.edu": ["Coleman College"],
    ".colgate.edu": ["Colgate University"],
    ".collegeamerica.edu": ["CollegeAmerica, Phoenix", "CollegeAmerica, Denver"],
    ".collegeofidaho.edu": ["College of Idaho"],
    ".colorado.edu": ["Colorado College", "University of Colorado at Boulder"],
    ".colostate.edu": ["Colorado State University"],
    ".colum.edu": ["Columbia College Chicago"],
    ".columbia.edu": [
        "Barnard College - Columbia University",
        "Columbia University",
        "Teachers College, Columbia University",
    ],
    ".columbiacollege.edu": ["Columbia College Hollywood"],
    ".columbiasouthern.edu": ["Columbia Southern University"],
    ".columbus.edu": ["Columbus University"],
    ".concord.edu": ["Concord College"],
    ".concordia-ny.edu": ["Concordia College, Bronxville"],
    ".concordia.edu": ["Concordia University, Austin"],
    ".conncoll.edu": ["Connecticut College"],
    ".converse.edu": ["Converse College"],
    ".cookman.edu": ["Bethune-Cookman College"],
    ".cooper.edu": ["The Cooper Union for the Advancement of Science and Art"],
    ".coppin.edu": ["Coppin State College"],
    ".cord.edu": ["Concordia College, Moorhead"],
    ".cornell.edu": [
        "Cornell University",
        "Weill Medical College of Cornell University",
    ],
    ".cornish.edu": ["Cornish College of the Arts"],
    ".cortland.edu": ["State University of New York College at Cortland"],
    ".cos.edu": ["College of the Sequoias"],
    ".cosc.edu": ["Charter Oak State College"],
    ".covenant.edu": ["Covenant College"],
    ".cpcc.edu": ["Central Piedmont Community College"],
    ".cpp.edu": ["California State Polytechnic University - Pomona"],
    ".cranbrook.edu": ["Cranbrook Schools"],
    ".cranbrookart.edu": ["Cranbrook Academy of Art"],
    ".creighton.edu": ["Creighton University"],
    ".crown.edu": ["Crown College"],
    ".csbsju.edu": ["College of St. Benedict and St. John's University"],
    ".csc.edu": ["Chadron State College"],
    ".csi.edu": ["College of Southern Idaho"],
    ".csinow.edu": ["Computer Systems Institute"],
    ".csj.edu": ["College of St. Joseph"],
    ".csld.edu": ["Conway School of Landscape Design"],
    ".csm.edu": ["College of St. Mary"],
    ".csn.edu": ["College of Southern Nevada", "The College of Southern Nevada", "CSN"],
    ".csp.edu": ["Concordia College, St. Paul"],
    ".cspp.edu": [
        "California School of Professional Psychology - Berkley/Alameda",
        "California School of Professional Psychology - Fresno",
        "California School of Professional Psychology - Los Angels",
        "California School of Professional Psychology - San Diego",
    ],
    ".css.edu": ["College of St. Scholastica", "The College of St. Scholastica"],
    ".csu.edu": ["Chicago State University"],
    ".csubak.edu": ["California State University, Bakersfield"],
    ".csuchico.edu": ["California State University, Chico"],
    ".csuci.edu": ["California State University, Channel Islands"],
    ".csudh.edu": ["California State University, Dominguez Hills"],
    ".csueastbay.edu": ["California State University East Bay"],
    ".csufresno.edu": ["California State University, Fresno"],
    ".csuglobal.edu": ["Colorado State University Global Campus"],
    ".csuhayward.edu": ["California State University, Hayward"],
    ".csulb.edu": ["California State University, Long Beach"],
    ".csum.edu": ["California Maritime Academy"],
    ".csumb.edu": ["California State University Monterey Bay"],
    ".csun.edu": ["California State University, Northridge"],
    ".csuniv.edu": ["Charleston Southern University"],
    ".csuohio.edu": ["Cleveland State University"],
    ".csus.edu": ["California State University, Sacramento"],
    ".csusb.edu": ["California State University, San Bernadino"],
    ".csusm.edu": ["California State University, San Marcos"],
    ".csustan.edu": ["California State University, Stanislaus"],
    ".ctsem.edu": ["Continental Theological Seminary"],
    ".ctu.edu": ["Catholic Theological Union"],
    ".cu-portland.edu": ["Concordia University, Portland"],
    ".cuaa.edu": ["Concordia University Ann Arbor"],
    ".cuea.edu": ["Catholic University of Eastern Africa"],
    ".cui.edu": ["Concordia University, Irvine"],
    ".cuk.edu": ["THE CYBER UNIVERSITY OF KOREA"],
    ".culver.edu": ["Culver-Stockton College"],
    ".cumberland.edu": ["Cumberland University"],
    ".cune.edu": ["Concordia College, Seward"],
    ".cuny.edu": [
        "City University of New York, Bernard M. Baruch College",
        "City University of New York, Brooklyn College",
        "City University of New York, City College",
        "City University of New York, College of Staten Island",
        "City University of New York (CUNY) System",
        "City University of New York, Graduate School and University Center",
        "City University of New York, Hunter College",
        "City University of New York, John Jay College of Criminal Justice",
        "City University of New York, Lehman College",
        "City University of New York, Medgar Evers College",
        "City University of New York Medical School / Sophie Davis School of Biomedical Education",
        "City University of New York, New York City Technical College",
        "City University of New York, School of Law at Queens College",
        "City University of New York, York College",
    ],
    ".curtis.edu": ["The Curtis Institute of Music"],
    ".cuw.edu": ["Concordia University, Mequon"],
    ".cw.edu": ["The College of Westchester"],
    ".cwsl.edu": ["California Western School of Law"],
    ".cwu.edu": ["Central Washington University"],
    ".daemen.edu": ["Daemen College"],
    ".dallas.edu": ["Dallas Christian College"],
    ".dartmouth.edu": ["Dartmouth College"],
    ".darton.edu": ["Darton College"],
    ".davenport.edu": [
        "Davenport College of Business, Grand Rapids",
        "Davenport College of Business, Kalamazoo",
        "Davenport College of Business, Lansing",
        "Detroit College of Business - Flint",
        "Detroit College of Business - Warren",
    ],
    ".davidson.edu": ["Davidson College"],
    ".dbq.edu": ["University of Dubuque"],
    ".dbu.edu": ["Dallas Baptist University"],
    ".dbumn.edu": ["Duluth Business University"],
    ".dc.edu": ["Dominican College"],
    ".dcb.edu": ["Detroit College of Business"],
    ".dcccd.edu": ["Dallas County Community College District"],
    ".dcita.edu": ["Defense Cyber Investigations Training Academy"],
    ".defiance.edu": ["The Defiance College"],
    ".deltacollege.edu": ["San Joaquin Delta College"],
    ".denison.edu": ["Denison University"],
    ".depaul.edu": ["DePaul University"],
    ".depauw.edu": ["DePauw University"],
    ".desales.edu": ["DeSales University"],
    ".devry.edu": [
        "DeVry Institute of Technology, Pomona",
        "DeVry Institute of Technology, Decatur",
        "DeVry Institute of Technology, Chicago",
        "DeVry Institute of Technology, DuPage",
        "DeVry Institute of Technology, Kansas City",
        "DeVry Institute of Technology, Irving",
    ],
    ".dgu.edu": ["Dongguk University"],
    ".dickinson.edu": ["Dickinson College"],
    ".digipen.edu": ["DigiPen Institute of Technology"],
    ".dillard.edu": ["Dillard University"],
    ".disd.edu": ["Design Institute of San Diego"],
    ".diu.edu": ["Darul Ihsan University"],
    ".dixie.edu": ["Dixie College"],
    ".dmacc.edu": ["Des Moines Area Community College"],
    ".dmcg.edu": ["Dubai Medical College for Girls"],
    ".doane.edu": ["Doane College"],
    ".dom.edu": ["Dominican University"],
    ".dominican.edu": ["Dominican College of San Rafael"],
    ".dongguk.edu": ["Dongguk University"],
    ".dordt.edu": ["Dordt College"],
    ".dowling.edu": ["Dowling College"],
    ".downstate.edu": ["State University of New York Downstate Medical Center"],
    ".dpc.edu": ["Dubai Pharmacy College"],
    ".drake.edu": ["Drake University"],
    ".drew.edu": ["Drew University"],
    ".drexel.edu": ["Drexel University"],
    ".drury.edu": ["Drury College"],
    ".dspt.edu": ["Dominican School of Philosophy and Theology"],
    ".dsu.edu": ["Dakota State University"],
    ".du.edu": ["University of Denver"],
    ".duep.edu": ["Alfred Nobel University of Economics and Law "],
    ".duke.edu": ["Duke University"],
    ".dunwoody.edu": ["Dunwoody College of Technology"],
    ".dupage.edu": ["College of DuPage"],
    ".duq.edu": ["Duquesne University"],
    ".dwu.edu": ["Dakota Wesleyan University"],
    ".dyc.edu": ["D'Youville College"],
    ".earlham.edu": ["Earlham College"],
    ".eastern.edu": ["Eastern College"],
    ".eastwest.edu": ["East-West University"],
    ".ebs.edu": ["\ufeffEBS UNIVERSITÄT"],
    ".eckerd.edu": ["Eckerd College"],
    ".ecok.edu": ["East Central University"],
    ".ecsu.edu": ["Elizabeth City State University"],
    ".ecu.edu": ["East Carolina University"],
    ".edmail.edcc.edu": ["Edmonds Community College"],
    ".edgewood.edu": ["Edgewood College"],
    ".edinboro.edu": ["Edinboro University of Pennsylvania"],
    ".egs.edu": ["European Graduate School, Media &amp; Communications"],
    ".ehc.edu": ["Emory &amp; Henry College"],
    ".eitc.edu": ["Eastern Idaho Technical College"],
    ".eiu.edu": ["Eastern Illinois University"],
    ".eku.edu": ["Eastern Kentucky University"],
    ".elmhurst.edu": ["Elmhurst College"],
    ".elmira.edu": ["Elmira College"],
    ".elon.edu": ["Elon College"],
    ".embryriddle.edu": ["Embry-Riddle Aeronautical University"],
    ".emich.edu": ["Eastern Michigan University"],
    ".emiratesacademy.edu": ["The Emirates Academy of Hotel Managment"],
    ".emmaus.edu": ["Emmaus Bible College"],
    ".emory.edu": ["Emory University"],
    ".emporia.edu": ["Emporia State University"],
    ".emu.edu": ["Eastern Mennonite University"],
    ".enmu.edu": ["Eastern New Mexico University"],
    ".eou.edu": ["Eastern Oregon University"],
    ".epcc.edu": ["El Paso Community College"],
    ".erau.edu": ["Embry Riddle Aeronautical University, Prescott"],
    ".erskine.edu": ["Erskine College"],
    ".esc.edu": ["State University of New York Empire State College"],
    ".esf.edu": [
        "State University of New York College of Environmental Science and Forestry"
    ],
    ".esu.edu": ["East Stroudsburg State University"],
    ".etbu.edu": ["East Texas Baptist University"],
    ".etf.edu": ["Evangelische Theologische Faculteit, Leuven"],
    ".etown.edu": ["Elizabethtown College"],
    ".etsu.edu": ["East Tennessee State University"],
    ".eurasia.edu": ["Xi'an Eurasia University"],
    ".eureka.edu": ["Eureka College"],
    ".euruni.edu": ["European University", "European University, Athens Campus"],
    ".evangel.edu": ["Evangel University"],
    ".evansville.edu": ["University of Evansville"],
    ".evergreen.edu": ["Evergreen State College"],
    ".evms.edu": ["Eastern Virginia Medical School"],
    ".ewc.edu": ["Edward Waters College"],
    ".ewu.edu": ["Eastern Washington University"],
    ".ewubd.edu": ["East West University", "East-West University, Mohakhali"],
    ".fae.edu": ["FAE Business School - Faculdade de Administração e Economia"],
    ".fairfield.edu": ["Fairfield University"],
    ".famu.edu": ["Florida Agricultural and Mechanical University"],
    ".fandm.edu": ["Franklin and Marshall College"],
    ".farmingdale.edu": [
        "State University of New York College of Technology at Farmingdale"
    ],
    ".fau.edu": ["Florida Atlantic University"],
    ".faulkner.edu": ["Faulkner University"],
    ".fauser.edu": ["Istituto Tecnico Tecnologico Fauser"],
    ".fcps.edu": ["Fairfax County Schools"],
    ".fdu.edu": [
        "Fairleigh Dickinson University, Florham-Madison Campus",
        "Fairleigh Dickinson University, Teaneck-Hackensack Campus",
    ],
    ".felician.edu": ["Felician College"],
    ".ferris.edu": ["Ferris State University"],
    ".ferrum.edu": ["Ferrum College"],
    ".fgcu.edu": ["Florida Gulf Coast University"],
    ".fhda.edu": ["Foothill-De Anza Community College District"],
    ".fhsu.edu": ["Fort Hays State University"],
    ".fhu.edu": ["Freed-Hardeman University"],
    ".fielding.edu": ["Fielding Institute"],
    ".findlay.edu": ["University of Findlay"],
    ".finlandia.edu": ["Finlandia University"],
    ".fisk.edu": ["Fisk University"],
    ".fit.edu": ["Florida Institute of Technology"],
    ".fiu.edu": ["Florida International University"],
    ".flagler.edu": ["Flagler College"],
    ".flsouthern.edu": ["Florida Southern College"],
    ".fmarion.edu": ["Francis Marion University"],
    ".fmc.edu": ["Florida Memorial College"],
    ".fmu.edu": [
        "Florida Metropolitan University, Fort Lauderdale College",
        "Florida Metropolitan University, Tampa College",
        "Florida Metropolitan University, Tampa College Brandon",
        "Florida Metropolitan University, Tampa College Lakeland",
    ],
    ".fontbonne.edu": ["Fontbonne College"],
    ".fontys.edu": ["Fontys University of Applied Sciences"],
    ".fordham.edu": ["Fordham University"],
    ".fortlewis.edu": ["Fort Lewis College"],
    ".franklin.edu": ["Franklin University"],
    ".fredonia.edu": ["State University of New York College at Fredonia"],
    ".fresno.edu": ["Fresno Pacific University"],
    ".fresnocitycollege.edu": ["Fresno City College"],
    ".friends.edu": ["Friends University"],
    ".fscj.edu": ["Florida State College at Jacksonville"],
    ".fst.edu": ["Franciscan School of Theology"],
    ".fsu.edu": ["Florida State University"],
    ".bucs.fsw.edu": ["Florida Southwestern State College"],
    ".fullerton.edu": ["California State University, Fullerton"],
    ".fullsail.edu": ["Full Sail University"],
    ".furman.edu": ["Furman University"],
    ".gac.edu": ["Gustavus Adolphus College"],
    ".galileo.edu": ["Universidad Galileo"],
    ".gannon.edu": ["Gannon University"],
    ".gardner-webb.edu": ["Gardner Webb University"],
    ".gatech.edu": ["Georgia Institute of Technology"],
    ".gbc.edu": ["Goldey-Beacom College"],
    ".gbcol.edu": ["Grace Bible College"],
    ".gbs.edu": ["God's Bible School and College"],
    ".gcc.edu": ["Grove City College"],
    ".gcsu.edu": ["Georgia College &amp; State University"],
    ".gcu.edu": ["Grand Canyon University"],
    ".geneseo.edu": ["State University of New York College at Geneseo"],
    ".geneva.edu": ["Geneva College"],
    ".georgefox.edu": ["George Fox University"],
    ".georgetown.edu": ["Georgetown University"],
    ".georgetowncollege.edu": ["Georgetown College"],
    ".georgian.edu": ["Georgian Court College"],
    ".georgiasouthern.edu": ["Georgia Southern University"],
    ".gettysburg.edu": ["Gettysburg College"],
    ".ggc.edu": ["Georgia Gwinnett College"],
    ".ggu.edu": ["Golden Gate University"],
    ".gia.edu": ["Gemological Institute of America"],
    ".gitam.edu": [
        "Gitam Deemed To Be university, Visakhapatnam, Andhra Pradesh, India.",
        "Official webpage: www.gitam.edu",
        "Proof that it offers a CS course: http://vspgit.gitam.edu/cse/about-department",
    ],
    ".glcc.edu": ["Great Lakes Christian College"],
    ".glendale.edu": ["Glendale Community College"],
    ".glendalelaw.edu": ["Glendale University College of Law"],
    ".glion.edu": ["Glion Institute of Higher Education"],
    ".gmc.edu": ["Gwynedd-Mercy College"],
    ".gmu.edu": ["George Mason University"],
    ".gnomon.edu": ["Gnomon - School of VFX & animation for film and games"],
    ".goddard.edu": ["Goddard College"],
    ".gonzaga.edu": ["Gonzaga University"],
    ".goshen.edu": ["Goshen College"],
    ".goucher.edu": ["Goucher College"],
    ".govst.edu": ["Governors State University"],
    ".grace.edu": ["Grace College"],
    ".graceland.edu": ["Graceland College"],
    ".graceu.edu": ["Grace University"],
    ".gram.edu": ["Grambling State University"],
    ".grand-canyon.edu": ["Grand Canyon University"],
    ".grantham.edu": ["Grantham University"],
    ".gratzcollege.edu": ["Gratz College"],
    ".grcc.edu": ["Grand Rapids Community College"],
    ".greenmtn.edu": ["Green Mountain College"],
    ".greenville.edu": ["Greenville College"],
    ".grinnell.edu": ["Grinnell College"],
    ".gsu.edu": ["Georgia State University"],
    ".gsw.edu": ["Georgia Southwestern University"],
    ".gtu.edu": ["Graduate Theological Union"],
    ".guilford.edu": ["Guilford College"],
    ".gustavus.edu": ["Gustavus Adolphus Colelge"],
    ".gvc.edu": ["Grand View College"],
    ".gvsu.edu": ["Grand Valley State University"],
    ".gwu.edu": ["George Washington University"],
    ".hamilton.edu": ["Hamilton College"],
    ".hamline.edu": ["Hamline University"],
    ".hamptonu.edu": ["Hampton University"],
    ".handong.edu": ["Handong Global University"],
    ".hanover.edu": ["Hanover College"],
    ".harding.edu": ["Harding University"],
    ".harrisburgu.edu": ["Harrisburg University"],
    ".hartford.edu": ["Hartford College for Women", "University of Hartford"],
    ".hartwick.edu": ["Hartwick College"],
    ".harvard.edu": ["Harvard University"],
    ".hastings.edu": ["Hastings College"],
    ".haverford.edu": ["Haverford College"],
    ".hawaii.edu": [
        "University of Hawaii - Hilo",
        "University of Hawaii - Manoa",
        "University Of Hawaii - System",
        "University of Hawaii - West Oahu",
    ],
    ".hbu.edu": ["Houston Baptist University"],
    ".hcc-nd.edu": ["Holy Cross College"],
    ".hawkmail.hccfl.edu": ["Hillsborough Community College"],
    ".hebron.edu": ["Hebron University"],
    ".heidelberg.edu": ["Heidelberg College"],
    ".hendrix.edu": ["Hendrix College"],
    ".heritage.edu": ["Heritage College"],
    ".hgc.edu": ["Hartford Graduate Center (Rensselaer at Hartford)"],
    ".highline.edu": ["Highline College"],
    ".highpoint.edu": ["High Point University"],
    ".hightech.edu": ["Ecole Supérieure d'Informatique et de Management"],
    ".hilbert.edu": ["Hilbert College"],
    ".hillsdale.edu": ["Hillsdale College"],
    ".hiram.edu": ["Hiram College"],
    ".hiu.edu": ["Hope International University"],
    ".hkapa.edu": ["Hong Kong Academy for Performing Arts "],
    ".hlg.edu": ["Hannibal-Lagrange College"],
    ".hm.edu": ["Hochschule Munchen", "University of applied science Munich"],
    ".hmc.edu": ["Harvey Mudd College"],
    ".hodges.edu": ["Hodges University"],
    ".hofstra.edu": ["Hofstra University"],
    ".hollins.edu": ["Hollins University"],
    ".holycross.edu": ["College of the Holy Cross"],
    ".hood.edu": ["Hood College"],
    ".hope.edu": ["Hope College"],
    ".houghton.edu": ["Houghton College"],
    ".howard.edu": ["Howard University"],
    ".hpu.edu": ["Hawaii Pacific University"],
    ".hputx.edu": ["Howard Payne University"],
    ".hsbc.edu": ["Hobe Sound Bible College"],
    ".hsc.edu": ["Hampden-Sydney College"],
    ".hscbklyn.edu": ["State University of New York Downstate Medical Center"],
    ".hscsyr.edu": ["State University of New York Health Sience Centre Syracuse"],
    ".hsu.edu": ["Henderson State Univerisity"],
    ".hsutx.edu": ["Hardin-Simmons University"],
    ".htc.edu": ["Huston-Tillotson College"],
    ".humboldt.edu": ["Humboldt State University"],
    ".humphreys.edu": ["Humphreys College"],
    ".husson.edu": ["Husson College"],
    ".hws.edu": ["Hobart and William Smith Colleges"],
    ".iastate.edu": ["Iowa State University of Science and Technology"],
    ".ic.edu": ["Illinois College"],
    ".ici.edu": ["ICI University"],
    ".ico.edu": ["Illinois College of Optometry"],
    ".ie.edu": ["IE University"],
    ".iit.edu": ["Illinois Institute of Technology"],
    ".illinois.edu": ["University of Illinois at Urbana-Champaign"],
    ".ilstu.edu": ["Illinois State University", "Mennonite College of Nursing"],
    ".immaculata.edu": ["Immaculata University"],
    ".imtu.edu": ["International Medical &amp; Technological University"],
    ".indiana.edu": [
        "Indiana University - East",
        "Indiana University - Northwest",
        "Indiana University - Southeast",
        "Indiana University (System)",
    ],
    ".indstate.edu": ["Indiana State University"],
    ".indwes.edu": ["Indiana Wesleyan University"],
    ".inha.edu": ["INHA University"],
    ".intelliteccollege.edu": ["IntelliTec College - Grand Junction"],
    ".inter.edu": [
        "Universidad Interamericana de Puerto Rico",
        "Universidad Interamericana de Puerto Rico, Bayamón",
        "Universidad Interamericana de Puerto Rico, San Germán",
    ],
    ".intercol.edu": ["Intercollege"],
    ".iona.edu": ["Iona College"],
    ".isu.edu": ["Idaho State University"],
    ".ithaca.edu": ["Ithaca College"],
    ".itt.edu": ["Institute of Textile Technology"],
    ".itu.edu": ["International Technology Institute"],
    ".iub.edu": ["Indiana University at Bloomington"],
    ".iubat.edu": ["International University of Business Agriculture and Technology"],
    ".iufs.edu": [
        "International University of Fundamental Studies, St. Petersburg",
        "International University of Fundamental Studies, St. Petersburg",
    ],
    ".iuk.edu": ["Indiana University at Kokomo"],
    ".iup.edu": ["Indiana University of Pennsylvania"],
    ".iupui.edu": [
        "Indiana University-Purdue University at Columbus",
        "Indiana University-Purdue University at Indianapolis",
    ],
    ".ius.edu": ["Indiana University Southeast"],
    ".iusb.edu": ["Indiana University at South Bend"],
    ".iut-dhaka.edu": ["Islamic University of Technology"],
    ".iutoic-dhaka.edu": ["Islamic University of Technology"],
    ".ivc.edu": ["Irvine Valley College"],
    ".ivcc.edu": ["Illinois Valley Community College"],
    ".iwu.edu": ["Illinois Wesleyan University"],
    ".jarvis.edu": ["Jarvis Christian College"],
    ".jbc.edu": ["Johnson Bible College"],
    ".jbu.edu": ["John Brown University"],
    ".jc.edu": ["Jamestown College"],
    ".jccc.edu": ["Johnson County Community College"],
    ".jcsu.edu": ["Johnson C. Smith University"],
    ".jcu.edu": ["John Carroll University"],
    ".jewell.edu": ["William Jewell College"],
    ".jfku.edu": ["John F. Kennedy University"],
    ".jhu.edu": ["Johns Hopkins University", "The Johns Hopkins University"],
    ".jinnah.edu": ["Mohammad Ali Jinnah University, Karachi"],
    ".jmls.edu": ["John Marshall Law School"],
    ".jmu.edu": ["James Madison University"],
    ".johncabot.edu": ["John Cabot University"],
    ".johnwesley.edu": ["John Wesley College"],
    ".jones.edu": ["Jones College"],
    ".jsu.edu": ["Jacksonville State University"],
    ".jsums.edu": ["Jackson State University"],
    ".ju.edu": ["Jacksonville University"],
    ".juc.edu": ["Jerusalem University College"],
    ".judson.edu": ["Judson College Marion"],
    ".juilliard.edu": ["The Juilliard School"],
    ".juniata.edu": ["Juniata College"],
    ".juniv.edu": ["Jahangirnagar University"],
    ".jwu.edu": [
        "Johnson &amp; Wales University",
        "Johnson &amp; Wales University, Charleston",
    ],
    ".kaplan.edu": ["Kaplan University"],
    ".kcad.edu": ["Kendall College of Art and Design"],
    ".kcai.edu": ["Kansas City Art Institute"],
    ".kcc.edu": ["Kentucky Christian College"],
    ".kctcs.edu": [
        "Ashland Community & Technical College",
        "Big Sandy Community and Technical College",
        "Bluegrass Community & Technical College",
        "Elizabethtown Community & Technical College",
        "Gateway Community & Technical College",
        "Hazard Community & Technical College",
        "Henderson Community College",
        "Hopkinsville Community College",
        "Jefferson Community & Technical College",
        "Madisonville Community College",
        "Maysville Community & Technical College",
        "Owensboro Community & Technical College",
        "Somerset Community College",
        "Southcentral Kentucky Community and Technical College",
        "Southeast Kentucky Community & Technical College",
        "West Kentucky Community & Technical College",
        ".group\x00",
    ],
    ".kean.edu": ["Kean University of New Jersey"],
    ".keene.edu": ["Keene State College"],
    ".keller.edu": ["Keller Graduate School of Management"],
    ".kendall.edu": ["Kendall College"],
    ".students.kennesaw.edu": ["Kennesaw State University"],
    ".kennesaw.edu": ["Kennesaw State University"],
    ".kent.edu": [
        "Kent State University - Stark",
        "Kent State University",
        "Kent State University - Ashtabula",
        "Kent State University - East Liverpool",
        "Kent State University - Salem",
        "Kent State University - Trumbull",
        "Kent State University - Tuscarawas",
    ],
    ".kenyon.edu": ["Kenyon College"],
    ".kettering.edu": ["Kettering University (GMI)"],
    ".keuka.edu": ["Keuka College"],
    ".khai.edu": ["National Aerospace University Kharkov Aviation Institute"],
    ".king.edu": ["King College"],
    ".kings.edu": ["King's College"],
    ".kirkwood.edu": ["Kirkwood Community College"],
    ".kit.edu": ["Karlsruhe Institute of Technology"],
    ".knox.edu": ["Knox College"],
    ".knoxvillecollege.edu": ["Knoxville College"],
    ".kongu.edu": ["Kongu Engineering College, Perundurai"],
    ".ksu.edu": ["Kansas State University"],
    ".ktu.edu": ["Kaunas University of Technology"],
    ".ku.edu": ["University of Kansas"],
    ".kutztown.edu": ["Kutztown University of Pennsylvania"],
    ".kwc.edu": ["Kentucky Wesleyan College"],
    ".kwu.edu": ["Kansas Wesleyan University"],
    ".kysu.edu": ["Kentucky State University"],
    ".kzoo.edu": ["Kalamazoo College"],
    ".lacc.edu": ["Los Angeles College of Chiropractic"],
    ".laccd.edu": ["Los Angeles Community College District"],
    ".lacollege.edu": ["Louisiana College"],
    ".lafayette.edu": ["Lafayette College"],
    ".lakeerie.edu": ["Lake Erie College"],
    ".lakeland.edu": ["Lakeland College"],
    ".lakeviewcol.edu": ["Lakeview College of Nursing"],
    ".lamar.edu": ["Lamar University", "Lamar University - Port Arthur"],
    ".lander.edu": ["Lander University"],
    ".lanecc.edu": ["Lane Community College"],
    ".lanecollege.edu": ["Lane College"],
    ".laroche.edu": ["La Roche College"],
    ".lasalle.edu": ["La Salle University"],
    ".lasierra.edu": ["La Sierra University"],
    ".laspositascollege.edu": ["Las Positas Community College"],
    ".latech.edu": ["Louisiana Tech University"],
    ".lau.edu": ["Lebanese American University"],
    ".lawrence.edu": ["Lawrence University"],
    ".lbc.edu": ["Lancaster Bible College"],
    ".lclark.edu": ["Lewis and Clark College"],
    ".lcsc.edu": ["Lewis-Clark State College"],
    ".lcu.edu": ["Lubbock Christian University"],
    ".leeuniversity.edu": ["Lee University"],
    ".lehigh.edu": ["Lehigh Univervsity"],
    ".lemoyne.edu": ["Le Moyne College"],
    ".lesroches.edu": ["Les Roches International School of Hotel Management"],
    ".letu.edu": ["Letourneau University"],
    ".lewisu.edu": ["Lewis University"],
    ".lfc.edu": ["Lake Forest College"],
    ".lfgsm.edu": ["Lake Forest Graduate School of Management"],
    ".lhup.edu": ["Lock Haven University of Pennsylvania"],
    ".liberty.edu": ["Liberty University"],
    ".life.edu": ["Life University"],
    ".lifewest.edu": ["Life Chiropractic College West"],
    ".limcollege.edu": ["Laboratory Institute of Merchandising"],
    ".limestone.edu": ["Limestone College"],
    ".lincoln.edu": ["Lincoln University Pennsylvania"],
    ".lincolnu.edu": ["Lincoln University Missouri"],
    ".lincolnuca.edu": ["Lincoln University San Francisco"],
    ".lindenwood.edu": ["Lindenwood University"],
    ".lindsey.edu": ["Lindsey Wilson College"],
    ".linfield.edu": ["Linfield College"],
    ".lipscomb.edu": ["Lipscomb University"],
    ".liunet.edu": [
        "Long Island University",
        "Long Island University, C.W. Post Campus",
        "Long Island University, Southampton College",
    ],
    ".livingstone.edu": ["Livingstone College"],
    ".llu.edu": ["Loma Linda University"],
    ".lmc.edu": ["Lees-McRae College"],
    ".lmu.edu": ["Loyola Marymount University"],
    ".lmunet.edu": ["Lincoln Memorial University"],
    ".logan.edu": ["Logan College of Chiropractic"],
    ".lonestar.edu": ["Lone star Community College"],
    ".loras.edu": ["Loras College"],
    ".losrios.edu": [
        "Los Rios Community College District",
        "=======",
        "American River College",
        "Cosumnes River College",
        "Folsom Lake College",
        "Sacramento City College",
        ".group",
    ],
    ".louisiana.edu": ["University of Louisiana at Lafayette"],
    ".louisville.edu": ["University of Louisville"],
    ".lourdes.edu": ["Lourdes College"],
    ".loyno.edu": ["Loyola University New Orleans"],
    ".loyola.edu": ["Loyola College in Maryland"],
    ".lssu.edu": ["Lake Superior State University"],
    ".lsu.edu": ["Louisiana State University and Agricultural and Mechanical College"],
    ".lsus.edu": ["Louisiana State University in Shreveport"],
    ".ltu.edu": ["Lawrence Technological University"],
    ".luc.edu": ["Loyola University of Chicago"],
    ".lunet.edu": ["Langston University"],
    ".luther.edu": ["Luther College"],
    ".lvc.edu": ["Lebanon Valley College"],
    ".lwtech.edu": ["Lake Washington Institute of Technology"],
    ".lycoming.edu": ["Lycoming College"],
    ".lynchburg.edu": ["Lynchburg College"],
    ".lynn.edu": ["Lynn University"],
    ".lyon.edu": ["Lyon College"],
    ".mac.edu": ["MacMurray College"],
    ".macalstr.edu": ["Macalester College"],
    ".mackenzie.edu": ["Mackenzie Presbyterian University"],
    ".madisoncollege.edu": ["Madison Area Technical College"],
    ".maine.edu": [
        "University of Maine, Augusta",
        "University of Maine, Farmington",
        "University of Maine, Fort Kent",
        "University of Maine, Machias",
        "University of Maine, Presque Isle",
        "University of Maine (System)",
        "University of Southern Maine",
    ],
    ".mainemaritime.edu": ["Maine Maritime Academy"],
    ".malone.edu": ["Malone College"],
    ".manchester.edu": ["Manchester College"],
    ".mancol.edu": ["Manhattan College"],
    ".manipal.edu": ["Manipal Academy of Higher Education"],
    ".mansfield.edu": ["Mansfield University of Pennsylvania"],
    ".maranatha.edu": ["Universitas Kristen Maranatha"],
    ".marian.edu": ["Marian College"],
    ".maricopa.edu": ["Maricopa Community Colleges"],
    ".marietta.edu": ["Marietta College"],
    ".marist.edu": ["Marist College"],
    ".marlboro.edu": ["Marlboro College"],
    ".marshall.edu": ["Marshall University"],
    ".martin.edu": ["Martin University"],
    ".martinmethodist.edu": ["Martin Methodist College"],
    ".marygrove.edu": ["Marygrove College"],
    ".marylhurst.edu": ["Marylhurst University"],
    ".marymount.edu": ["Marymount University"],
    ".maryvillecollege.edu": ["Maryville College"],
    ".marywood.edu": ["Marywood University"],
    ".masters.edu": ["The Master's College"],
    ".matc.edu": ["Milwaukee Area Technical College"],
    ".maufl.edu": ["Millennia Atlantic University"],
    ".mayo.edu": ["Mayo Graduate School", "Mayo Medical School"],
    ".mc.edu": ["Mississippi College"],
    ".mca.edu": ["Memphis College of Art"],
    ".mcad.edu": ["Minneapolis College of Art and Design"],
    ".mcckc.edu": ["Metropolitan Community College, Kansas City, Missouri"],
    ".mccks.edu": ["Manhattan Christian College"],
    ".mccn.edu": ["Mount Carmel College of Nursing"],
    ".mccneb.edu": ["Metropolitan Community College"],
    ".mci.edu": ["MCI-Management Center Innsbruck"],
    ".mckendree.edu": ["McKendree College"],
    ".mcm.edu": ["McMurry University"],
    ".mcneese.edu": ["McNeese State University"],
    ".mcpherson.edu": ["McPherson College"],
    ".mcphu.edu": ["Medical College of Pennsylvania and Hahnemann University"],
    ".mcw.edu": ["Medical College of Wisconsin"],
    ".mdanderson.edu": ["University of Texas - MDAnderson Cancer Center"],
    ".meca.edu": ["Maine College of Art"],
    ".medaille.edu": ["Medaille College"],
    ".memphis.edu": ["University of Memphis"],
    ".menlo.edu": ["Menlo College"],
    ".mercer.edu": ["Mercer University", "Mercer University, Cecil B. Day Campus"],
    ".mercyhurst.edu": ["Mercyhurst College"],
    ".meredith.edu": ["Meredith College"],
    ".messiah.edu": ["Messiah College"],
    ".methodist.edu": ["Methodist College"],
    ".methodistcollege.edu": [
        "Nebraska Methodist College of Nursing and Allied Health"
    ],
    ".metrostate.edu": ["Metropolitan State University"],
    ".mhcc.edu": ["Mt. Hood Community College"],
    ".miad.edu": ["Milwaukee Institute of Art and Design"],
    ".miami.edu": ["University of Miami"],
    ".miamioh.edu": ["Miami University"],
    ".mica.edu": ["The Maryland Institute, College of Art"],
    ".middlebury.edu": ["Middlebury College"],
    ".midway.edu": ["Midway College"],
    ".midwestern.edu": ["Midwestern University"],
    ".miis.edu": ["Monterey Institute of International Studies"],
    ".miles.edu": ["Miles College"],
    ".milligan.edu": ["Milligan College"],
    ".millikin.edu": ["Millikin University"],
    ".mills.edu": ["Mills College"],
    ".millsaps.edu": ["Millsaps College"],
    ".mines.edu": ["Colorado School of Mines"],
    ".minneapolis.edu": ["Minneapolis Community and Technical College"],
    ".mispp.edu": ["Michigan School of Professional Psychology"],
    ".missouri.edu": ["University of Missouri - Columbia"],
    ".missouriwestern.edu": ["Missouri Western State University"],
    ".mit.edu": ["Massachusetts Institute of Technology"],
    ".miu.edu": [
        "Maharishi International University",
        "1000 N 4th St, Fairfield, IA 52557, U.S.A.",
    ],
    ".mlc-wels.edu": ["Martin Luther College"],
    ".mlc.edu": ["Midland Lutheran College"],
    ".mmc.edu": ["Meharry Medical College"],
    ".mmm.edu": ["Marymount Manhattan College"],
    ".mnsfld.edu": ["Mansfield University of Pennsylvania"],
    ".mnsu.edu": ["Minnesota State University, Mankato"],
    ".mnu.edu": ["Mid-America Nazarene University"],
    ".mobap.edu": ["Missouri Baptist College"],
    ".molloy.edu": ["Molloy College"],
    ".monash.edu": ["Monash University"],
    ".monmouth.edu": ["Monmouth University"],
    ".montana.edu": ["Montana State University"],
    ".montclair.edu": ["Montclair State University"],
    ".montevallo.edu": ["University of Montevallo"],
    ".montreat.edu": ["Montreat College"],
    ".moody.edu": ["Moody Bible Institute"],
    ".moore.edu": ["Moore College of Art and Design"],
    ".morainevalley.edu": ["Moraine Valley Community College"],
    ".moravian.edu": ["Moravian College"],
    ".morehead-st.edu": ["Morehead State University"],
    ".morehouse.edu": ["Morehouse College"],
    ".morgan.edu": ["Morgan State University"],
    ".morningside.edu": ["Morningside College"],
    ".morrisbrown.edu": ["Morris Brown College"],
    ".mountainstate.edu": ["Mountain State University"],
    ".mountunion.edu": ["Mount Union College"],
    ".msj.edu": ["College of Mount St. Joseph"],
    ".msm.edu": ["Morehouse School of Medicine"],
    ".msmary.edu": ["Mount St. Mary's College Maryland"],
    ".msmc.edu": ["Mount St. Mary College"],
    ".msmnyc.edu": ["Manhattan School of Music"],
    ".msoe.edu": ["Milwaukee School of Engineering"],
    ".mssm.edu": ["Mount Sinai School of Medicine"],
    ".msstate.edu": ["Mississippi State University"],
    ".mssu.edu": ["Missouri Southern State University"],
    ".mst.edu": ["Missouri University of Science and Technology"],
    ".msu.edu": ["Michigan State University"],
    ".msubillings.edu": ["Montana State University - Billings"],
    ".msun.edu": ["Montana State University - Northern"],
    ".mtaloy.edu": ["Mount Aloysius College"],
    ".mtech.edu": ["Montana Tech"],
    ".mtmary.edu": ["Mount Mary College"],
    ".mtmc.edu": ["Mount Marty College"],
    ".mtmercy.edu": ["Mount Mercy College"],
    ".mtsac.edu": ["Mt. San Antonio College"],
    ".mtsu.edu": ["Middle Tennessee State University"],
    ".mtu.edu": ["Michigan Technological University"],
    ".mu.edu": ["Marquette University"],
    ".muhlenberg.edu": ["Muhlenberg College"],
    ".multnomah.edu": ["Multnomah Bible College"],
    ".mum.edu": ["Maharishi University of Management"],
    ".muohio.edu": [
        "Miami University of Ohio",
        "Miami University of Ohio - Hamilton",
        "Miami University of Ohio - Middletown",
    ],
    ".musc.edu": ["Medical University of South Carolina"],
    ".muskingum.edu": ["Muskingum College"],
    ".muw.edu": ["Mississippi University for Women"],
    ".mville.edu": ["Manhattanville College"],
    ".mvsu.edu": ["Mississippi Valley State University"],
    ".mwsu.edu": ["Midwestern State University"],
    ".najah.edu": ["An-Najah National University"],
    ".naropa.edu": ["The Naropa Institute"],
    ".national.edu": ["National American University"],
    ".nau.edu": ["Northern Arizona University"],
    ".navarrocollege.edu": [
        "Navarro College",
        "https://www.navarrocollege.edu/academics/computer-information-technology/",
    ],
    ".nayanova.edu": ["Nayanova University", "Nayanova University"],
    ".naz.edu": ["Nazareth College"],
    ".nbc.edu": ["Nazarene Bible College"],
    ".ncat.edu": ["North Carolina Agricultural and Technical State University"],
    ".ncbc.edu": ["North Central Bible College"],
    ".ncc.edu": ["Nassau Community College"],
    ".nccu.edu": ["North Carolina Central University"],
    ".ncf.edu": ["New College of Florida"],
    ".ncmich.edu": ["North Central Michigan College"],
    ".ncsu.edu": ["North Carolina State University"],
    ".ncu.edu": ["Northcentral University"],
    ".ncwc.edu": ["North Carolina Wesleyan College"],
    ".nd.edu": ["University of Notre Dame"],
    ".ndc.edu": ["Notre Dame College of Ohio"],
    ".ndm.edu": ["College of Notre Dame of Maryland"],
    ".ndnu.edu": ["Notre Dame de Namur University"],
    ".nebraska.edu": ["University of Nebraska (System)"],
    ".nebrwesleyan.edu": ["Nebraska Wesleyan University"],
    ".nec.edu": ["New England College"],
    ".nechristian.edu": ["Nebraska Christian College"],
    ".neit.edu": ["New England Institute of Technology"],
    ".neiu.edu": ["Northeastern Illinois University"],
    ".nescom.edu": ["New England School of Communications"],
    ".neu.edu": ["Northeastern University at Boston"],
    ".neumann.edu": ["Neumann College"],
    ".neumont.edu": ["Morrison College"],
    ".newberry.edu": ["Newberry College"],
    ".newbury.edu": ["Newbury College"],
    ".newcollege.edu": ["New College of California"],
    ".newhaven.edu": ["University of New Haven"],
    ".newpaltz.edu": ["State University of New York at New Paltz"],
    ".newschool.edu": ["The New School"],
    ".newschoolarch.edu": ["Newschool of Architecture and Design"],
    ".nhu.edu": ["National Hispanic University"],
    ".niagara.edu": ["Niagara University"],
    ".nic.edu": ["North Idaho College"],
    ".nitt.edu": ["National Institute of Technology, Tiruchirappalli"],
    ".niu.edu": ["Northern Illinois University"],
    ".njcu.edu": ["New Jersey City University"],
    ".njit.edu": ["New Jersey Institute of Technology"],
    ".nku.edu": ["Northern Kentucky University"],
    ".nl.edu": ["National-Louis University"],
    ".nlu.edu": ["Northeast Louisiana University"],
    ".nmhu.edu": ["New Mexico Highlands University"],
    ".nmsu.edu": ["New Mexico State University"],
    ".nmt.edu": ["New Mexico Institute of Mining and Technology"],
    ".nmu.edu": ["Northern Michigan University"],
    ".nnu.edu": ["Northwest Nazarene University"],
    ".noctrl.edu": ["North Central College"],
    ".nodak.edu": [
        "University of North Dakota",
        "Dickinson State University",
        "Mayville State University",
        "Minot State University",
        "North Dakota State University",
        "Tri-College University",
        "Valley City State University",
    ],
    ".spartan.northampton.edu": ["Northampton Community College"],
    ".northampton.edu": ["Northampton Community College"],
    ".northern.edu": ["Northern State University"],
    ".northland.edu": ["Northland College"],
    ".northpark.edu": ["North Park University"],
    ".northsouth.edu": ["North South University"],
    ".northwestern.edu": ["Northwestern University"],
    ".northwestu.edu": ["Northwest University"],
    ".northwood.edu": [
        "Northwood University, Florida Campus",
        "Northwood University",
        "Northwood University, Texas Campus",
    ],
    ".norwich.edu": ["Norwich University"],
    ".nova.edu": ["Nova Southeastern University"],
    ".nps.edu": ["Naval Postgraduate School"],
    ".nscc.edu": [
        "Nashville State Community College",
        "https://www.nscc.edu",
        "https://www.nscc.edu/academics/degrees-certificates/computer-information-technology-a-a-s",
    ],
    ".nsu.edu": ["Norfolk State University"],
    ".nsula.edu": ["Northwestern State University of Louisiana"],
    ".nsuok.edu": ["Northeastern State University"],
    ".nu.edu": ["National University"],
    ".nur.edu": ["Universidad NUR"],
    ".nus.edu": ["National University of Singapore"],
    ".nwacc.edu": ["Northwest Arkansas Community College"],
    ".nwc.edu": ["Northwestern College St. Paul"],
    ".nwcc.edu": ["Northwest Christian College"],
    ".nwciowa.edu": ["Northwestern College Iowa"],
    ".nwmissouri.edu": ["Northwest Missouri State University"],
    ".nyaa.edu": ["New York Academy of Art, Graduate School of Figurative Art"],
    ".nyackcollege.edu": ["Nyack College"],
    ".nycc.edu": ["New York Chiropractic College"],
    ".nycpm.edu": ["New York College of Podiatric Medicine"],
    ".nyit.edu": ["New York Institute of Technology"],
    ".nyls.edu": ["New York Law School"],
    ".nymc.edu": ["New York Medical College"],
    ".nysid.edu": ["New York School of Interior Design"],
    ".nyu.edu": ["New York University, Abu Dhabi", "New York University"],
    ".oak.edu": ["Oakland City University"],
    ".oakland.edu": ["Oakland University"],
    ".oaklandcc.edu": ["oaklandcc.txt"],
    ".oakton.edu": ["Oakton Community College"],
    ".oakwood.edu": ["Oakwood College"],
    ".oberlin.edu": ["Oberlin College"],
    ".obu.edu": ["Ouachita Baptist University"],
    ".oc.edu": ["Oklahoma Christian University"],
    ".ocac.edu": ["Oregon College of Arts and Crafts"],
    ".occ.edu": ["Ozark Christian College"],
    ".odu.edu": ["Old Dominion University"],
    ".ogi.edu": ["Oregon Graduate Institute of Science and Technology"],
    ".oglethorpe.edu": ["Oglethorpe University"],
    ".ohio-state.edu": [
        "Ohio State University",
        "Ohio State University - Lima",
        "Ohio State University - Mansfield",
        "Ohio State University - Marion",
        "Ohio State University - Newark",
    ],
    ".ohiou.edu": [
        "Ohio University",
        "Ohio University - Chillicothe",
        "Ohio University - Eastern",
        "Ohio University - Lancaster",
        "Ohio University - Southern",
        "Ohio University - Zanesville",
    ],
    ".student.ohlone.edu": ["Ohlone College"],
    ".ohsu.edu": ["Oregon Health Sciences University"],
    ".oit.edu": ["Oregon Institute of Technology"],
    ".okbu.edu": ["Oklahoma Baptist University"],
    ".okcu.edu": ["Oklahoma City University"],
    ".okstate.edu": [
        "Oklahoma State University",
        "Oklahoma State University Center for Health Sciences",
    ],
    ".olc.edu": ["Oglala Lakota College"],
    ".oldwestbury.edu": ["State University of New York College at Old Westbury"],
    ".olemiss.edu": ["University of Mississippi"],
    ".olin.edu": ["Olin College of Engineering"],
    ".olivet.edu": ["Olivet Nazarene University"],
    ".olivetcollege.edu": ["Olivet College"],
    ".olivetuniversity.edu": ["Olivet University"],
    ".ollusa.edu": ["Our Lady of the Lake University"],
    ".olympic.edu": ["Olympic College"],
    ".omorecollege.edu": ["O'More College of Design"],
    ".omsk.edu": [
        "Omsk State Pedagogical University",
        "Omsk State Pedagogical University",
    ],
    ".oneonta.edu": ["State University of New York College at Oneonta"],
    ".onu.edu": ["Ohio Northern University"],
    ".opsu.edu": ["Oklahoma Panhandle State University"],
    ".oregonstate.edu": ["Oregon State University"],
    ".orst.edu": ["Oregon State University"],
    ".oru.edu": ["Oral Roberts University"],
    ".osu.edu": ["The Ohio State University"],
    ".oswego.edu": ["State University of New York at Oswego"],
    ".ottawa.edu": ["Ottawa University"],
    ".otterbein.edu": ["Otterbein College"],
    ".ou.edu": ["University of Oklahoma"],
    ".ouhsc.edu": ["University of Oklahoma Health Sciences Center"],
    ".ovc.edu": ["Ohio Valley College"],
    ".owu.edu": ["Ohio Wesleyan University"],
    ".oxy.edu": ["Occidental College"],
    ".ozarks.edu": ["University of the Ozarks"],
    ".pace.edu": ["Pace University", "Pace University  Pleasantville/Briarcliff"],
    ".pacific.edu": ["University of the Pacific"],
    ".pacifica.edu": ["Pacifica Graduate Institute"],
    ".pacificoaks.edu": ["Pacific Oaks College"],
    ".pacificu.edu": ["Pacific University"],
    ".paine.edu": ["Paine College"],
    ".palermo.edu": ["Universidad de Palermo"],
    ".palmbeachstate.edu": ["Palm Beach State College"],
    ".palmer.edu": [
        "Palmer College of Chiropractic West",
        "Palmer College of Chiropractic",
    ],
    ".park.edu": ["Park College"],
    ".parsons.edu": ["Parsons School of Design"],
    ".pba.edu": ["Palm Beach Atlantic University"],
    ".pbc.edu": ["Piedmont Baptist College"],
    ".pc.edu": ["Pikeville College"],
    ".pcc.edu": ["Portland Community College"],
    ".pcom.edu": ["Philadelphia College of Osteopathic Medicine"],
    ".pct.edu": ["Pennsylvania College of Technology"],
    ".pdx.edu": ["Portland State University"],
    ".peace.edu": ["Peace College"],
    ".peachnet.edu": ["Fort Valley State College", "North Georgia College"],
    ".pepperdine.edu": ["Pepperdine University"],
    ".peru.edu": ["Peru State College"],
    ".pes.edu": ["Pepole's Education Society University"],
    ".pfeiffer.edu": ["Pfeiffer University"],
    ".philander.edu": ["Philander Smith College"],
    ".philau.edu": ["Philadelphia University"],
    ".phillips.edu": ["Phillips University"],
    ".phystech.edu": ["Moscow Institute of Physics and Technology"],
    ".piedmont.edu": ["Piedmont College"],
    ".pit.edu": ["Pennsylvania Institute of Technology"],
    ".pitt.edu": [
        "University of Pittsburgh",
        "University of Pittsburgh at Bradford",
        "University of Pittsburgh at Greensburg",
        "University of Pittsburgh at Johnstown",
    ],
    ".pittstate.edu": ["Pittsburg State University"],
    ".pitzer.edu": ["Pitzer College"],
    ".planwel.edu": ["Planwel University"],
    ".plattsburgh.edu": ["State University of New York College at Plattsburgh"],
    ".plu.edu": ["Pacific Lutheran University"],
    ".plymouth.edu": ["Plymouth State College"],
    ".pnca.edu": ["Pacific Northwest College of Art"],
    ".pointloma.edu": ["Point Loma Nazarene University"],
    ".poly.edu": [
        "Polytechnic University",
        "Polytechnic University, Long Island Campus",
        "Polytechnic University, Westchester Graduate Center",
    ],
    ".pomona.edu": ["Pomona College"],
    ".post.edu": ["Post University of Waterbury"],
    ".potsdam.edu": ["State University of New York College at Potsdam"],
    ".ppu.edu": ["Palestine Polytechnic University"],
    ".pqc.edu": ["Paul Quinn College"],
    ".pratt.edu": ["Pratt Institute"],
    ".presby.edu": ["Presbyterian College"],
    ".prescott.edu": [
        "Prescott College",
        "Prescott College, Center for Indian Bilingual Teacher Education",
    ],
    ".preston.edu": ["Preston University"],
    ".prin.edu": ["Principia College"],
    ".princeton.edu": ["Princeton University"],
    ".providence.edu": ["Providence College"],
    ".psu.edu": [
        "Pennsylvania State University",
        "Pennsylvania State University, campuses: Abington, Altoona, Erie, Harrisburg, Delaware County, Great Valley, Lehigh Valley, Schuylkill",
    ],
    ".puc.edu": ["Pacific Union College"],
    ".pucpr.edu": ["Pontificia Universidad Catolica de Puerto Rico"],
    ".pupr.edu": ["Universidad Politecnica de Puerto Rico"],
    ".purchase.edu": ["State University of New York College at Purchase"],
    ".purdue.edu": ["Purdue University", "Purdue University Calumet"],
    ".pvamu.edu": ["Prairie View Agricultural and Mechanical University"],
    ".qc.edu": ["City University of New York, Queens College"],
    ".qou.edu": ["Al-Quds Open University"],
    ".queens.edu": ["Queens College"],
    ".quincy.edu": ["Quincy University"],
    ".quincycollege.edu": ["Quincy College"],
    ".quinnipiac.edu": ["Quinnipiac College"],
    ".qvius.edu": ["Quantum-Veritas International University"],
    ".ramapo.edu": ["Ramapo College of New Jersey"],
    ".rasmussen.edu": [
        "Rasmussen College, Florida Campuses",
        "Rasmussen College, Illinois Campuses",
        "Rasmussen College, Minnesota Campuses",
        "Rasmussen College, North Dakota Campuses",
        "Rasmussen College, Wisconsin Campuses",
    ],
    ".rc.edu": ["Rochester College"],
    ".redlands.edu": ["University of Redlands"],
    ".reed.edu": ["Reed College"],
    ".regent-college.edu": ["Regent College"],
    ".regent.edu": ["Regent University"],
    ".regents.edu": ["Excelsior College"],
    ".regis.edu": ["Regis University"],
    ".reinhardt.edu": ["Reinhardt College"],
    ".rhodes.edu": ["Rhodes College"],
    ".ric.edu": ["Rhode Island College"],
    ".rice.edu": ["Rice University"],
    ".rider.edu": ["Rider University"],
    ".ringling.edu": ["Ringling College of Art and Design"],
    ".riohondo.edu": ["Rio Hondo College"],
    ".ripon.edu": ["Ripon College"],
    ".risd.edu": ["Rhode Island School of Design"],
    ".rit.edu": [
        "Rochester Institute of Technology, Dubai",
        "Rochester Institute of Technology",
    ],
    ".rivier.edu": ["Rivier College"],
    ".rmc.edu": ["Randolph-Macon College"],
    ".rmcad.edu": ["Rocky Mountain College of Art and Design"],
    ".rmcil.edu": ["Robert Morris College of Chicago"],
    ".mail.rmu.edu": ["Robert Morris University"],
    ".roanoke.edu": ["Roanoke College"],
    ".robert-morris.edu": ["Robert Morris College"],
    ".rochester.edu": ["University of Rochester"],
    ".rockefeller.edu": ["The Rockefeller University"],
    ".rockford.edu": ["Rockford College"],
    ".rockhurst.edu": [
        "Research College of Nursing - Rockhurst University",
        "Rockhurst College",
    ],
    ".rocky.edu": ["Rocky Mountain College"],
    ".rollins.edu": ["Rollins College"],
    ".mail.roosevelt.edu": ["Roosevelt University"],
    ".roosevelt.edu": ["Roosevelt University"],
    ".rose-hulman.edu": ["Rose-Hulman Institute of Technology"],
    ".rosemont.edu": ["Rosemont College"],
    ".rossmed.edu": ["Ross University, School of Medicine"],
    ".rossu.edu": [
        "Ross University Caribbean School of Medicine",
        "Ross University Caribbean School of Veterinary Medicine",
    ],
    ".rowan.edu": ["Rowan University"],
    ".rpi.edu": ["Rensselaer Polytechnic Institute"],
    ".runet.edu": ["Radford University"],
    ".rush.edu": ["Rush University"],
    ".rustcollege.edu": ["Rust College"],
    ".rutgers.edu": ["Rutgers, The State University of New Jersey"],
    ".rwc.edu": ["Roberts Wesleyan College"],
    ".rwu.edu": ["Roger Williams University"],
    ".sacn.edu": ["St. Anthony College of Nursing"],
    ".sacredheart.edu": ["Sacred Heart University"],
    ".saddleback.edu": ["Saddleback College"],
    ".saeinstitute.edu": ["SAE Athens"],
    ".sage.edu": ["The Sage Colleges"],
    ".sagrado.edu": ["Universidad del Sagrado Corazon"],
    ".sagu.edu": ["Southwestern Assemblies of God University"],
    ".saintjoe.edu": ["St. Joseph's College"],
    ".saintleo.edu": ["St. Leo College"],
    ".saintmarys.edu": ["St. Mary's College Indiana"],
    ".saintmeinrad.edu": ["St. Meinrad College"],
    ".salem.edu": ["Salem College"],
    ".salve.edu": ["Salve Regina University"],
    ".samford.edu": ["Samford University"],
    ".samuelmerritt.edu": ["Samuel Merritt College"],
    ".sandiego.edu": ["University of San Diego"],
    ".sanjuanbautista.edu": ["San Juan Bautista School of Medicine"],
    ".sau.edu": ["St. Ambrose University"],
    ".saumag.edu": ["Southern Arkansas University"],
    ".saxion.edu": ["Saxion Universities "],
    ".sbc.edu": ["Sweet Briar College"],
    ".sbccd.edu": ["San Bernardino Community College"],
    ".sbs.edu": ["Swiss Business School Zurich (SBS)"],
    ".sbu.edu": ["St. Bonaventure University"],
    ".sbuniv.edu": ["Southwest Baptist University"],
    ".sc.edu": [
        "University of South Carolina",
        "University of South Carolina - Aiken",
        "University of South Carolina - Beaufort",
        "University of South Carolina - Lancaster",
        "University of South Carolina - Salkehatchie",
        "University of South Carolina - Union",
    ],
    ".scad.edu": ["Savannah College of Art and Design"],
    ".schiller.edu": ["Schiller International University"],
    ".schillermadrid.edu": ["Schiller International University, Madrid"],
    ".schoolofvisualarts.edu": ["School of the Visual Arts"],
    ".schreiner.edu": ["Schreiner College"],
    ".sci.edu": ["Benedictine University, Springfield College in Illinois"],
    ".sciarc.edu": ["Southern California Institute of Architecture"],
    ".science.edu": ["International Academy of Science"],
    ".scit.edu": ["https://www.scit.edu/"],
    ".sckans.edu": ["Southwestern College Kansas"],
    ".sco.edu": ["Southern College of Optometry"],
    ".scranton.edu": ["University of Scranton"],
    ".scripps.edu": ["The Scripps Research Institute"],
    ".scrippscol.edu": ["Scripps College"],
    ".scsu.edu": ["South Carolina State University"],
    ".scu.edu": ["Santa Clara University"],
    ".sdc.edu": ["Sojourner-Douglass College"],
    ".sdsmt.edu": ["South Dakota School of Mines and Technology"],
    ".sdstate.edu": ["South Dakota State University"],
    ".sdsu.edu": ["San Diego State University"],
    ".sduis.edu": ["San Diego University for Integrative Studies"],
    ".seattleu.edu": ["Seattle University"],
    ".sebc.edu": ["Southeastern Bible College"],
    ".sek.edu": ["Universidad Internacional SEK, Quito"],
    ".selu.edu": ["Southeastern Louisiana University"],
    ".semo.edu": ["Southeast Missouri State University"],
    ".setonhill.edu": ["Seton Hill College"],
    ".sewanee.edu": ["University of the South"],
    ".sfai.edu": ["San Francisco Art Institute"],
    ".sfasu.edu": ["Stephen F. Austin State University"],
    ".sfbc.edu": ["South Florida Bible College &amp; Theological Seminary"],
    ".sfc.edu": ["St. Francis College, Fort Wayne"],
    ".sfcm.edu": ["San Francisco Conservatory of Music"],
    ".sfcollege.edu": ["Santa Fe College"],
    ".sfsu.edu": ["San Francisco State University"],
    ".sgu.edu": ["St. George's University", "St. George's University"],
    ".shawnee.edu": ["Shawnee State University"],
    ".shawuniversity.edu": ["Shaw University"],
    ".shc.edu": ["Spring Hill College"],
    ".shepherd.edu": ["Shepherd College"],
    ".sherman.edu": ["Sherman College of Straight Chiropractic"],
    ".shimer.edu": ["Shimer College"],
    ".ship.edu": ["Shippensburg University of Pennsylvania"],
    ".shoreline.edu": ["Shoreline Community College"],
    ".shorter.edu": ["Shorter College"],
    ".shsu.edu": ["Sam Houston State University"],
    ".shu.edu": ["Seton Hall University"],
    ".siam.edu": ["Siam University"],
    ".siena.edu": ["Siena College"],
    ".sierranevada.edu": ["Sierra Nevada College"],
    ".simmons.edu": ["Simmons University"],
    ".simpson.edu": ["Simpson College Iowa"],
    ".mail.sipi.edu": ["Southwestern Indian Polytechnic Institute"],
    ".sit.edu": ["School for International Training"],
    ".siu.edu": ["Southern Illinois University at Carbondale"],
    ".siue.edu": ["Southern Illinois University at Edwardsville"],
    ".sjc.edu": ["St. Joseph College"],
    ".sjca.edu": ["St. John's College Maryland"],
    ".sjcme.edu": ["St. Joseph's College of Maine"],
    ".sjcny.edu": [
        "St. Joseph's College New York",
        "St. Joseph's College New York, Suffolk Campus",
    ],
    ".sjfc.edu": ["St. John Fisher College"],
    ".sjrstate.edu": ["St. Johns River State College"],
    ".sjsu.edu": ["San Jose State University"],
    ".sju.edu": ["St. Joseph's University"],
    ".skidmore.edu": ["Skidmore College"],
    ".skku.edu": ["SungKyunKwan University"],
    ".sl.edu": ["Silver Lake College"],
    ".slc.edu": ["Sarah Lawrence College"],
    ".slcc.edu": ["Salt Lake Community College"],
    ".slu.edu": ["St. Louis University"],
    ".student.smc.edu": ["Santa Monica College"],
    ".smccd.edu": ["San Mateo County Community College District"],
    ".smcm.edu": ["St. Mary's College of Maryland"],
    ".smcvt.edu": ["St. Michael's College"],
    ".smsu.edu": [
        "Southwest Missouri State University",
        "Southwest Missouri State University - West Plains",
    ],
    ".smu.edu": ["Southern Methodist University"],
    ".smumn.edu": ["St. Mary's University of Minnesota"],
    ".smwc.edu": ["St. Mary-of-the-Woods College"],
    ".snc.edu": ["St. Norbert College"],
    ".snhu.edu": ["Southern New Hampshire University"],
    ".snu.edu": ["Southern Nazarene University"],
    ".soka.edu": ["Soka University of America"],
    ".students.solano.edu": ["Solano Community College"],
    ".somaiya.edu": [
        "Institute name: K.J Somaiya Institute of Engineering and Information Technology, Sion",
        "Institute website: https://kjsieit.somaiya.edu/",
    ],
    ".sonoma.edu": ["Sonoma State University"],
    ".sou.edu": ["Southern Oregon University"],
    ".south.edu": ["South University", "southuniversity.edu"],
    ".southeast.edu": ["Southeast Community College"],
    ".southeasternbaptist.edu": ["Southeastern Baptist College"],
    ".southeastmn.edu": ["Minnesota State College Southeast"],
    ".southern.edu": ["Southern Adventist University"],
    ".southernchristian.edu": ["The Southern Christian University"],
    ".southwestern.edu": ["Southwestern University"],
    ".spalding.edu": ["Spalding University"],
    ".spc.edu": ["St. Peter's College"],
    ".live.spcollege.edu": ["St. Petersburg College"],
    ".spelman.edu": ["Spelman College"],
    ".spertus.edu": ["Spertus Institute of Jewish Studies"],
    ".spsu.edu": ["Southern Polytechnic State Univerisity"],
    ".spu.edu": ["Seattle Pacific University"],
    ".srttu.edu": ["Shaheed Rajaei Teacher Training University"],
    ".sru.edu": ["Slippery Rock University"],
    ".ssu.edu": ["Salisbury State University"],
    ".st-aug.edu": ["St. Augustine's College North Carolina"],
    ".stac.edu": ["St. Thomas Aquinas College"],
    ".stamford.edu": ["Stamford International University"],
    ".stanford.edu": ["Stanford University"],
    ".stcl.edu": ["South Texas College of Law"],
    ".stcloudstate.edu": ["St. Cloud State University"],
    ".stedwards.edu": ["St. Edwards University"],
    ".stefan-university.edu": ["Stefan University"],
    ".stephens.edu": ["Stephens College"],
    ".sterling.edu": ["Sterling College"],
    ".stetson.edu": ["Stetson University"],
    ".stevens-tech.edu": ["Stevens Institute of Technology"],
    ".stevens.edu": ["Stevens Institute of Technology"],
    ".stfrancis.edu": ["St. Joseph College of Nursing", "University of St. Francis"],
    ".stikom.edu": ["Institut Bisnis dan Informatika Stikom Surabaya"],
    ".stillman.edu": ["Stillman College"],
    ".stjohns.edu": ["St. John's University"],
    ".stjohnsem.edu": ["St. John's Seminary"],
    ".stkate.edu": ["College of St. Catherine"],
    ".stlawu.edu": ["St. Lawrence University"],
    ".stlcc.edu": ["St. Louis Community College"],
    ".stlcop.edu": ["St. Louis College of Pharmacy"],
    ".stmartin.edu": ["St. Martin's College"],
    ".stmarys-ca.edu": ["St. Mary's College of California"],
    ".stmarytx.edu": ["St. Mary's University of San Antonio"],
    ".stmatthews.edu": ["St. Matthews University"],
    ".stockton.edu": ["Richard Stockton College of New Jersey"],
    ".stolaf.edu": ["St. Olaf College"],
    ".stonybrook.edu": ["State University of New York, Stony Brook"],
    ".strathmore.edu": ["Strathmore University"],
    ".stritch.edu": ["Cardinal Stritch University"],
    ".strose.edu": ["College of St. Rose"],
    ".stthom.edu": ["University of St. Thomas, Houston"],
    ".stthomas.edu": ["University of St. Thomas, St. Paul"],
    ".stu.edu": ["St. Thomas University"],
    ".stvincent.edu": ["St. Vincent College"],
    ".su.edu": ["Shenandoah University"],
    ".suagm.edu": ["Sistema Universitario Ana G. Méndez", "Universidad Metropolitana"],
    ".subr.edu": ["Southern University - Baton Rouge"],
    ".sullivan.edu": ["Sullivan College"],
    ".sulross.edu": ["Sul Ross State University"],
    ".suno.edu": ["Southern University - New Orleans"],
    ".suny.edu": ["Fashion Institute of New York"],
    ".acad.sunybroome.edu": ["SUNY Broome Community College"],
    ".sunycentral.edu": ["State University of New York (SUNY)"],
    ".sunyit.edu": [
        "State University of New York Institute of Technology at Utica/Rome"
    ],
    ".sunymaritime.edu": ["State University of New York Maritime College"],
    ".sunyopt.edu": ["State University of New York College of Optometry"],
    ".sunysb.edu": ["State University of New York at Stony Brook"],
    ".mail.sunysuffolk.edu": [
        "The University of New York Suffolk County Community College"
    ],
    ".susla.edu": ["Southern University - Shreveport"],
    ".susqu.edu": ["Susquehanna University"],
    ".sust.edu": ["Shahjalal University of Science and Technology (SUST)"],
    ".sustech.edu": ["Sudan University for Science and Technology"],
    ".suu.edu": ["Southern Utah University"],
    ".svc.edu": ["Southern Vermont College"],
    ".svsu.edu": ["Saginaw Valley State University"],
    ".svu.edu": ["Southern Virginia University"],
    ".swarthmore.edu": ["Swarthmore College"],
    ".swau.edu": ["Southwestern Adventist University"],
    ".swbts.edu": ["Southwestern Baptist Theological Seminary"],
    ".swc.edu": ["Southwestern College Santa Fe"],
    ".swcu.edu": ["Southwestern Christian University"],
    ".swlaw.edu": ["Southwestern University School of Law"],
    ".swosu.edu": ["Southwestern Oklahoma State University"],
    ".swu.edu": ["Southern Wesleyan University"],
    ".sxu.edu": ["St. Xavier University"],
    ".syr.edu": ["Syracuse University"],
    ".t-bird.edu": ["American Graduate School of International Management"],
    ".tabor.edu": ["Tabor College"],
    ".taliesin.edu": ["Frank Lloyd Wright School of Architecture"],
    ".talladega.edu": ["Talladega College"],
    ".tambcd.edu": ["Baylor College of Dentistry"],
    ".tamiu.edu": ["Texas A&amp;M International University"],
    ".tamu.edu": ["Texas A&amp;M University", "Texas A&amp;M University - Galveston"],
    ".tamucc.edu": ["Texas A&amp;M University - Corpus Christi"],
    ".tamuk.edu": ["Texas A&amp;M University - Kingsville"],
    ".tamut.edu": ["Texas A&amp;M University - Texarkana"],
    ".tarleton.edu": ["Tarleton State University"],
    ".tayloru.edu": ["Taylor University", "Taylor University, Fort Wayne Campus"],
    ".tbc2day.edu": ["Trinity Bible College"],
    ".tci.edu": ["The College of Insurance"],
    ".tcnj.edu": ["The College of New Jersey"],
    ".tcu.edu": ["Texas Christian University"],
    ".temple.edu": ["Temple University"],
    ".tesc.edu": ["Thomas A. Edison State College"],
    ".tesu.edu": ["Thomas Edison State University"],
    ".texascollege.edu": ["Texas College"],
    ".thapar.edu": ["Thapar Institute of Engineering & Technology"],
    ".the-bac.edu": ["Boston Architectural Center"],
    ".thechicagoschool.edu": ["The Chicago School of Professional Psychology"],
    ".thecoo.edu": ["University of Sioux Falls"],
    ".thiel.edu": ["Thiel College"],
    ".thomas.edu": ["Thomas College Maine"],
    ".thomasaquinas.edu": ["Thomas Aquinas College"],
    ".thomasmore.edu": ["Thomas More College"],
    ".thomasmorecollege.edu": ["Thomas More College of Liberal Arts"],
    ".thomasu.edu": ["Thomas University"],
    ".tiffin.edu": ["Tiffin University"],
    ".tiu.edu": ["Trinity International University (Excel), Miami"],
    ".tju.edu": ["Thomas Jefferson University"],
    ".tmc.edu": ["Baylor College of Medicine"],
    ".tnstate.edu": ["Tennessee State University"],
    ".tntech.edu": ["Tennessee Technological University"],
    ".tntemple.edu": ["Tennessee Temple University"],
    ".toccoafalls.edu": ["Toccoa Falls College"],
    ".tougaloo.edu": ["Tougaloo College"],
    ".touro.edu": ["Touro College"],
    ".towson.edu": ["Towson University"],
    ".transy.edu": ["Transylvania University"],
    ".trevecca.edu": ["Trevecca Nazarene University"],
    ".trin.edu": ["Trinity International University"],
    ".trincoll.edu": ["Trinity College Connecticut"],
    ".trinity.edu": ["Trinity University"],
    ".trinitycollege.edu": ["Trinity College of Florida"],
    ".trnty.edu": ["Trinity Christian College"],
    ".troy.edu": [
        "Troy University",
        "Troy University, Dothan",
        "Troy University, Montgomery",
        "Troy University, Phenix City",
        "Troy University, Troy",
    ],
    ".truman.edu": ["Truman State University"],
    ".tsmu.edu": ["Tbilisi State Medical University"],
    ".tstc.edu": ["Texas State Technical College"],
    ".tsu.edu": ["Texas Southern University"],
    ".ttu.edu": ["Texas Tech University"],
    ".ttuhsc.edu": ["Texas Tech University Health Science Center"],
    ".tu.edu": ["Touro University"],
    ".tufts.edu": ["Tufts University"],
    ".tui.edu": ["The Union Institute"],
    ".tulane.edu": ["The Tulane University of New Orleans"],
    ".tusculum.edu": ["Tusculum College"],
    ".twcnet.edu": ["Tennessee Wesleyan College"],
    ".twsu.edu": ["Wichita State University"],
    ".twu.edu": ["Texas Woman's University"],
    ".txchiro.edu": ["Texas Chiropractic College"],
    ".txstate.edu": ["Texas State University"],
    ".txwesleyan.edu": ["Texas Wesleyan University"],
    ".crimson.ua.edu": ["University of Alabama"],
    ".ua.edu": ["University of Alabama - Tuscaloosa"],
    ".uab.edu": ["University of Alabama - Birmingham"],
    ".uaf.edu": ["University of Alaska - Fairbanks"],
    ".uah.edu": ["University of Alabama - Huntsville"],
    ".uakron.edu": ["University of Akron"],
    ".ualr.edu": ["University of Arkansas at Little Rock"],
    ".uamont.edu": ["University of Arkansas at Monticello"],
    ".uams.edu": ["University of Arkansas for Medical Sciences"],
    ".uandresbello.edu": ["Universidad Andres Bello", "UNAB"],
    ".uap-bd.edu": ["University of Asia Pacific, Dhanmondi"],
    ".uapar.edu": ["Universidad Adventista del Plata"],
    ".uapb.edu": ["University of Arkansas at Pine Bluff"],
    ".uark.edu": ["University of Arkansas at Fayetteville"],
    ".uarts.edu": ["University of the Arts"],
    ".uasys.edu": ["University of Arkansas (System)"],
    ".uat.edu": ["University of Advancing Technology (UAT)"],
    ".ub.edu": ["Universitat de Barcelona"],
    ".ubaguio.edu": ["University of Baguio"],
    ".ubalt.edu": ["University of Baltimore"],
    ".ubi.edu": ["United Business Institute"],
    ".uc.edu": ["University of Cincinnati"],
    ".uca.edu": ["University of Central Arkansas"],
    ".ucam.edu": ["Universidad Católica San Antonio"],
    ".ucan.edu": ["Universidade Católica de Angola"],
    ".uccaribe.edu": ["Universidad Central del Caribe"],
    ".uccs.edu": [
        "Beth-El College of Nursing and Health Sciences",
        "University of Colorado at Colorado Springs",
    ],
    ".ucdavis.edu": ["University of California, Davis"],
    ".ucf.edu": ["University of Central Florida"],
    ".uchastings.edu": ["University of California, Hastings College of Law"],
    ".uchc.edu": ["University of Connecticut Health Center"],
    ".uchicago.edu": ["University of Chicago"],
    ".uci.edu": ["University of California, Irvine"],
    ".ucla.edu": ["University of California, Los Angeles"],
    ".ucmerced.edu": ["University of California, Merced"],
    ".ucmo.edu": ["University of Central Missouri"],
    ".ucollege.edu": ["Union College Nebraska"],
    ".uconn.edu": [
        "University of Connecticut",
        "University of Connecticut at Avery Point",
        "University of Connecticut at Hartford",
        "University of Connecticut at Stamford",
        "University of Connecticut at Waterbury",
    ],
    ".ucop.edu": ["University of California, Oakland"],
    ".ucr.edu": ["University of California, Riverside"],
    ".ucsb.edu": ["University of California, Santa Barbara"],
    ".ucsc.edu": ["University of California, Santa Cruz"],
    ".ucsd.edu": ["University of California, San Diego"],
    ".ucsf.edu": ["University of California, San Francisco"],
    ".uctm.edu": ["University of Chemical Technology and Metallurgy"],
    ".ucumberlands.edu": ["University of the Cumberlands"],
    ".udallas.edu": ["University of Dallas"],
    ".udayton.edu": ["University of Dayton"],
    ".udel.edu": ["University of Delaware"],
    ".udg.edu": ["Universitat de Girona", "University of Girona"],
    ".udmercy.edu": ["University of Detroit Mercy"],
    ".ufl.edu": ["University of Florida"],
    ".ufm.edu": ["Universidad Francisco Marroquin"],
    ".uga.edu": ["University of Georgia"],
    ".uh.edu": [
        "University of Houston",
        "University of Houston, Downtown",
        "University of Houston, Victoria",
    ],
    ".uhcl.edu": ["University of Houston Clear Lake"],
    ".uic.edu": ["University of Illinois at Chicago"],
    ".uidaho.edu": ["University of Idaho"],
    ".uillinois.edu": ["University of Illinois"],
    ".uindy.edu": ["University of Indianapolis"],
    ".uiowa.edu": ["University of Iowa"],
    ".uis.edu": ["University of Illinois at Springfield"],
    ".uiu.edu": ["Upper Iowa University"],
    ".uiuc.edu": ["University of Illinois at Urbana-Champaign"],
    ".uiw.edu": ["University of the Incarnate World"],
    ".ujmv.edu": ["Universidad José Maria Vargas"],
    ".uksw.edu": ["Universitas Kristen Satya Wacana"],
    ".uky.edu": ["University of Kentucky"],
    ".ulm.edu": ["University of Louisiana at Monroe"],
    ".umaine.edu": ["University of Maine, Orono"],
    ".umary.edu": ["University of Mary"],
    ".umass.edu": ["University of Massachusetts (Amherst)"],
    ".umassd.edu": ["University of Massachusetts (Dartmouth)"],
    ".umb.edu": ["University of Massachusetts (Boston)"],
    ".umbc.edu": [
        "University of Maryland at Baltimore",
        "University of Maryland Baltimore County",
    ],
    ".umc.edu": ["University of Mississippi Medical Center"],
    ".umd.edu": [
        "Frostburg State University",
        "University of Maryland at College Park",
    ],
    ".umdnj.edu": ["University of Medicine and Dentistry of New Jersey"],
    ".umes.edu": ["University of Maryland Eastern Shore"],
    ".umgc.edu": ["University of Maryland Global Campus"],
    ".umhb.edu": ["University of Mary Hardin-Baylor"],
    ".umich.edu": [
        "University of Michigan - Ann Arbor",
        "University of Michigan - Dearborn",
        "University of Michigan - Flint",
    ],
    ".umkc.edu": ["University of Missouri - Kansas City"],
    ".uml.edu": ["University of Massachusetts Lowell"],
    ".umm.edu": ["University of Maryland Medicine"],
    ".umn.edu": [
        "University of Minnesota - Crookston",
        "University of Minnesota - Duluth",
        "University of Minnesota - Morris",
        "University of Minnesota - Twin Cities Campus",
    ],
    ".umobile.edu": ["University of Mobile"],
    ".ums.edu": ["University of Maryland (System)"],
    ".umsl.edu": ["University of Missouri - Saint Louis"],
    ".umt.edu": ["University of Montana"],
    ".umtweb.edu": ["University of Management &amp; Technology"],
    ".umwestern.edu": ["University of Montana Western"],
    ".una.edu": ["University of North Alabama"],
    ".unc.edu": ["University of North Carolina at Chapel Hill"],
    ".unca.edu": ["University of North Carolina at Asheville"],
    ".uncc.edu": ["University of North Carolina at Charlotte"],
    ".uncfsu.edu": ["Fayetteville State University"],
    ".uncg.edu": ["University of North Carolina at Greensboro"],
    ".uncp.edu": ["University of North Carolina at Pembroke"],
    ".une.edu": [
        "University of New England",
        "University of New England, Westbrook College Campus",
    ],
    ".unem.edu": ["Universidad Empresarial"],
    ".unf.edu": ["University of North Florida"],
    ".unh.edu": [
        "University of New Hampshire",
        "University of New Hampshire - Manchester",
    ],
    ".uni.edu": ["University of Northern Iowa"],
    ".uniben.edu": ["University of Benin"],
    ".unicah.edu": ["Universidad Católica de Honduras"],
    ".union.edu": ["Union College"],
    ".unionky.edu": ["Union College Kentucky"],
    ".uniq.edu": ["Université Quisqueya"],
    ".unitec.edu": ["Universidad Tecnológica Centroamericana"],
    ".unity.edu": ["Unity College"],
    ".univalle.edu": ["Universidad Privada del Valle"],
    ".univdhaka.edu": ["University of Dhaka"],
    ".universityofcalifornia.edu": ["University of California System"],
    ".univnorthco.edu": ["University of Northern Colorado"],
    ".unk.edu": ["University of Nebraska - Kearney"],
    ".unl.edu": ["University of Nebraska - Lincoln"],
    ".unlv.edu": ["University of Nevada - Las Vegas"],
    ".unm.edu": ["University of New Mexico"],
    ".unmc.edu": ["University of Nebraska Medical Center"],
    ".uno.edu": ["University of New Orleans"],
    ".unomaha.edu": ["University of Nebraska - Omaha"],
    ".unr.edu": ["University of Nevada - Reno"],
    ".unt.edu": [
        "Texas College of Osteopathic Medicine",
        "University of North Texas",
        "University of North Texas Health Science Center at Fort Worth",
    ],
    ".unva.edu": ["University of Northern Virginia"],
    ".unw.edu": ["University of Northern Washington"],
    ".uoc.edu": ["Universitat Oberta de Catalunya"],
    ".uofa.edu": ["University of Alanta"],
    ".uofk.edu": ["University of Khartoum"],
    ".uofs.edu": ["University of Scranton"],
    ".uog.edu": ["University of Guam"],
    ".uopeople.edu": ["University of the People"],
    ".uoregon.edu": ["University of Oregon"],
    ".upal.edu": ["Universidad Privada Abierta Latinoamericana"],
    ".upb.edu": ["Universidad Privada Boliviana"],
    ".upc.edu": ["Universidad Politécnica de Cataluna"],
    ".upenn.edu": ["University of Pennsylvania"],
    ".upf.edu": ["Universitat Pompeu Fabra"],
    ".uph.edu": ["Universitas Pelita Harapan"],
    ".upi.edu": ["Universitas Pendidikan Indonesia"],
    ".upr.edu": [
        "Universidad de Puerto Rico, Cayey",
        "Universidad de Puerto Rico, Ciencias Medicas",
        "Universidad de Puerto Rico, Ponce",
    ],
    ".upra.edu": ["Universidad de Puerto Rico, Arecibo"],
    ".uprag.edu": ["Universidad de Puerto Rico, Aguadilla"],
    ".uprb.edu": ["Universidad de Puerto Rico, Bayamon"],
    ".uprm.edu": ["Universidad de Puerto Rico, Mayaguez"],
    ".uprrp.edu": ["Universidad de Puerto Rico, Rio Pedras"],
    ".uprutuado.edu": ["Universidad de Puerto Rico, Utuado"],
    ".ups.edu": ["University of Puget Sound"],
    ".upstate.edu": ["State University of New York Upstate Medical University "],
    ".urbana.edu": ["Urbana University"],
    ".urbaniana.edu": ["Pontifcia Università Urbaniana"],
    ".urbe.edu": ["Universidad Dr. Rafael Belloso Chacín"],
    ".urgrgcc.edu": ["University of Rio Grande"],
    ".uri.edu": ["University of Rhode Island"],
    ".urich.edu": ["University of Richmond"],
    ".ursinus.edu": ["Ursinus College"],
    ".ursuline.edu": ["Ursuline College"],
    ".uru.edu": ["Universidad Rafael Urdaneta"],
    ".usaim.edu": ["University of Seychelles - American Institute of Medicine"],
    ".usao.edu": ["University of Science and Arts of Oklahoma"],
    ".usc.edu": ["University of Southern California"],
    ".uscsumter.edu": ["University of South Carolina - Sumter"],
    ".uscupstate.edu": ["University of South Carolina Upstate"],
    ".usd.edu": ["University of South Dakota"],
    ".usf.edu": ["University of South Florida"],
    ".usfca.edu": ["University of San Francisco"],
    ".usi.edu": ["University of Southern Indiana"],
    ".usip.edu": ["University of the Sciences in Philadelphia"],
    ".usiu.edu": ["United States International University"],
    ".usm.edu": ["University of Southern Mississippi"],
    ".usma.edu": ["United States Military Academy"],
    ".usmma.edu": ["United States Merchant Marine Academy"],
    ".usna.edu": ["United States Naval Academy"],
    ".usouthal.edu": ["University of South Alabama"],
    ".ussa.edu": ["United States Sports Academy"],
    ".ust.edu": ["University of Science and Technology Sana'a"],
    ".usu.edu": ["Utah State University"],
    ".usw.edu": ["University of the Southwest"],
    ".uta.edu": ["University of Texas at Arlington"],
    ".utah.edu": ["University of Utah"],
    ".utampa.edu": ["University of Tampa"],
    ".utb.edu": ["University of Texas at Brownsville"],
    ".utc.edu": ["University of Tennessee - Chattanooga"],
    ".utdallas.edu": ["University of Texas at Dallas"],
    ".utdt.edu": ["Universidad Torcuato di Tella"],
    ".utep.edu": ["University of Texas at El Paso"],
    ".utesa.edu": [
        "Universidad Tecnológica de Santiago",
        "Universidad Tecnológica de Santiago",
    ],
    ".utexas.edu": ["University of Texas at Austin"],
    ".uthct.edu": ["University of Texas Health Center at Tyler"],
    ".uthouston.edu": ["University of Texas Health Center at Houston"],
    ".uthscsa.edu": ["University of Texas Health Science Center at San Antonio"],
    ".utk.edu": ["University of Tennessee - Knoxville"],
    ".utm.edu": ["University of Tennessee - Martin"],
    ".utmb.edu": ["University of Texas Medical Branch Galveston"],
    ".utoledo.edu": ["University of Toledo"],
    ".utpb.edu": ["University of Texas of the Permian Basin"],
    ".utrgv.edu": ["University of Texas at Rio Grande Valley"],
    ".utsa.edu": ["University of Texas at San Antonio"],
    ".utsi.edu": ["University of Tennessee Space Institute"],
    ".utsouthwestern.edu": [
        "University of Texas Southwestern Medical Center at Dallas"
    ],
    ".utsystem.edu": ["University of Texas"],
    ".uttyl.edu": ["University of Texas at Tyler"],
    ".utulsa.edu": ["University of Tulsa"],
    ".uu.edu": ["Union University"],
    ".uvi.edu": ["University of the Virgin Islands"],
    ".uvm.edu": ["University of Vermont"],
    ".uvmnet.edu": [
        "Universidad del Valle de México",
        "Universidad del Valle de México",
    ],
    ".uvs.edu": ["Anton de Kom University"],
    ".uvu.edu": ["Utah Valley University"],
    ".uw.edu": ["University of Washington"],
    ".uwa.edu": ["University of West Alabama"],
    ".uwec.edu": ["University of Wisconsin - Eau Claire"],
    ".uwf.edu": ["University of West Florida"],
    ".uwgb.edu": ["University of Wisconsin - Green Bay"],
    ".uwla.edu": ["University of West Los Angeles"],
    ".uwlax.edu": ["University of Wisconsin - La Crosse"],
    ".uwm.edu": ["University of Wisconsin - Milwaukee"],
    ".uwosh.edu": ["University of Wisconsin - Oshkosh"],
    ".uwp.edu": ["University of Wisconsin - Parkside"],
    ".uwplatt.edu": ["University of Wisconsin - Platteville"],
    ".uwrf.edu": ["University of Wisconsin - River Falls"],
    ".uwsp.edu": ["University of Wisconsin - Stevens Point"],
    ".uwstout.edu": ["University of Wisconsin - Stout"],
    ".uwsuper.edu": ["University of Wisconsin - Superior"],
    ".uww.edu": ["University of Wisconsin - Whitewater"],
    ".uwyo.edu": ["University of Wyoming"],
    ".valdosta.edu": ["Valdosta State University"],
    ".valenciacollege.edu": ["Valencia College"],
    ".valpo.edu": ["Valparaiso University"],
    ".vanderbilt.edu": ["Vanderbilt University"],
    ".vandercook.edu": ["VanderCook College of Music"],
    ".vanguard.edu": ["Vanguard University of Southern California"],
    ".vassar.edu": ["Vassar College"],
    ".vc.edu": ["Virginia College"],
    ".vccs.edu": ["Virginia's Community Colleges"],
    ".vcu.edu": ["Virginia Commonwealth University"],
    ".vermontlaw.edu": ["Vermont Law School"],
    ".vesalius.edu": ["Vesalius College"],
    ".villanova.edu": ["Villanova University"],
    ".villanueva.edu": ["Centro Universitario Villanueva"],
    ".vips.edu": ["Vivekananda Institute of Professional Studies"],
    ".virginia.edu": [
        "University of Virginia",
        "University of Virginia, College at Wise",
    ],
    ".viterbo.edu": ["Viterbo College"],
    ".viu.edu": ["Virginia International University"],
    ".vmi.edu": ["Virginia Military Institute"],
    ".voorhees.edu": ["Voorhees College"],
    ".vsc.edu": [
        "Castleton State College",
        "Johnson State College",
        "Lyndon State College",
        "Vermont Technical College",
    ],
    ".vsu.edu": ["Virginia State University"],
    ".vt.edu": ["Virginia Polytechnic Institute and State University (Virginia Tech)"],
    ".vtu.edu": ["Free University (Virginia Theological University)"],
    ".vuu.edu": ["Virginia Union University"],
    ".wabash.edu": ["Wabash College"],
    ".wagner.edu": ["Wagner College"],
    ".waldenu.edu": ["Walden University"],
    ".wallawalla.edu": ["Walla Walla University"],
    ".walsh.edu": ["Walsh University"],
    ".warnborough.edu": ["Warnborough University", "Warnborough University"],
    ".warner.edu": ["Warner Southern College"],
    ".warnerpacific.edu": ["Warner Pacific College"],
    ".warren-wilson.edu": ["Warren Wilson College"],
    ".wartburg.edu": ["Wartburg College"],
    ".washburn.edu": ["Washburn University"],
    ".washcoll.edu": ["Washington College"],
    ".washington.edu": ["University of Washington", "University of Washington, Tacoma"],
    ".wayne.edu": ["Wayne State University"],
    ".waynesburg.edu": ["Waynesburg College"],
    ".wbcoll.edu": ["Williams Baptist College"],
    ".wbu.edu": ["Wayland Baptist University"],
    ".wcmo.edu": ["Westminster College Fulton"],
    ".wcs.edu": ["Williamson County School District", ".group"],
    ".wcslc.edu": ["Westminster College of Salt Lake City"],
    ".wcu.edu": ["Western Carolina University"],
    ".wcupa.edu": ["West Chester University of Pennsylvania"],
    ".webber.edu": ["Webber College"],
    ".weber.edu": ["Weber State University"],
    ".webster.edu": ["Webster University North Florida", "Webster University"],
    ".wells.edu": ["Wells College"],
    ".wesley.edu": ["Wesley College"],
    ".wesleyan-college.edu": ["Wesleyan College"],
    ".wesleyan.edu": ["Wesleyan University"],
    ".western.edu": ["Western State College"],
    ".westernbible.edu": ["Western Bible College"],
    ".westerntc.edu": [
        "Western Technical College",
        "formerly Western Wisconsin Technical College",
    ],
    ".westernu.edu": [
        "College of Osteopathic Medicine of the Pacific (Western University of Health Sciences)"
    ],
    ".westga.edu": ["State University of West Georgia"],
    ".westminster.edu": ["Westminster College New Wilmington"],
    ".westmont.edu": ["Westmont College"],
    ".westwood.edu": ["Westwood College"],
    ".wfu.edu": ["Wake Forest University"],
    ".wgu.edu": ["Western Governors University"],
    ".wheelock.edu": ["Wheelock College "],
    ".whitman.edu": ["Whitman College"],
    ".whittier.edu": ["Whittier College"],
    ".whitworth.edu": ["Whitworth College"],
    ".whu.edu": ["WHU - Otto Beisheim School of Management"],
    ".widener.edu": ["Widener University"],
    ".wilberforce.edu": ["Wilberforce University"],
    ".wileyc.edu": ["Wiley College"],
    ".wilkes.edu": ["Wilkes University"],
    ".willamette.edu": ["Willamette University"],
    ".williams.edu": ["Williams College"],
    ".my.wilmu.edu": ["Wilmington University"],
    ".wilson.edu": ["Wilson College"],
    ".windsor.edu": ["Windsor University School of Medicine"],
    ".wingate.edu": ["Wingate University"],
    ".winsor.edu": ["The Winsor School"],
    ".winthrop.edu": ["Winthrop University"],
    ".wintu.edu": ["Western International University"],
    ".wisc.edu": ["University of Wisconsin–Madison"],
    ".wit.edu": ["Wentworth Institute of Technology"],
    ".wittenberg.edu": ["Wittenberg University"],
    ".wiu.edu": ["Western Illinois University"],
    ".wju.edu": ["Wheeling Jesuit University"],
    ".wku.edu": ["Western Kentucky University"],
    ".wlc.edu": ["Wisconsin Lutheran College"],
    ".wlu.edu": ["Washington and Lee University"],
    ".email.wm.edu": ["College of William and Mary"],
    ".wm.edu": ["College of William and Mary"],
    ".wmcarey.edu": ["William Carey College"],
    ".wmich.edu": ["Western Michigan University"],
    ".wmpenn.edu": ["William Penn College"],
    ".wnmu.edu": ["Western New Mexico University"],
    ".wofford.edu": ["Wofford College"],
    ".wooster.edu": ["The College of Wooster"],
    ".worwic.edu": ["Wor-Wic Community College"],
    ".wou.edu": ["Western Oregon University"],
    ".wpi.edu": ["Worcester Polytechnic Institute"],
    ".wpunj.edu": ["William Paterson University"],
    ".wright.edu": ["Wright State University"],
    ".wsc.edu": ["Wayne State College"],
    ".wssu.edu": ["Winston-Salem State University"],
    ".wsu.edu": [
        "Washington State University",
        "Washington State University, Spokane",
        "Washington State University, Tri-Cities",
        "Washington State University, Vancouver",
    ],
    ".wsulaw.edu": [
        "Western State University College of Law",
        "Western State University College of Law - Orange County",
    ],
    ".wtamu.edu": ["West Texas A&amp;M University"],
    ".wub.edu": ["World University of Bangladesh (WUB)"],
    ".wustl.edu": ["Washington University in St. Louis"],
    ".wvnet.edu": [
        "Bethany College West Virginia",
        "Bluefield State College",
        "Glenville State College",
        "Salem Teikyo University",
        "West Liberty State College",
        "West Virginia University Institute of Technology",
    ],
    ".wvsom.edu": ["West Virginia School of Osteopathic Medicine"],
    ".mix.wvu.edu": ["West Virginia University"],
    ".wvu.edu": ["West Virginia University"],
    ".wvwc.edu": ["West Virginia Wesleyan College"],
    ".wwcc.edu": ["Walla Walla Community College"],
    ".wwu.edu": ["Western Washington University"],
    ".xu.edu": ["Xavier University"],
    ".xula.edu": ["Xavier University of Louisiana"],
    ".yale.edu": ["Yale University"],
    ".york.edu": ["York College Nebraska"],
    ".my.yosemite.edu": ["Modesto Junior College"],
    ".student.yosemite.edu": ["Modesto Junior College"],
    ".ysu.edu": ["Youngstown State University"],
    ".yu.edu": ["Yeshiva University"],
    ".zamorano.edu": ["Escuela Agricola Panamericana Zamorano"],
    ".adachi-gr.education": ["専門学校東京クールジャパン", "Tokyo Cool Japan"],
    ".aivancity.education": ["aivancity", "aivancity"],
    ".brucity.education": ["Institut Paul Hankar", "Paul Hankar Institut"],
    ".faculty.cacttus.education": ["Cacttus Education"],
    ".student.cacttus.education": ["Cacttus Education"],
    ".cast.education": ["Cambridge Academy for Science and Technology"],
    ".crescent.education": [
        "B.S.ABDUR RAHMAN CRESCENT INSTITUTE OF SCIENCE & TECHNOLOGY"
    ],
    ".eichendorffschule.education": ["Eichendorffschule Kelkheim"],
    ".elitech.education": ["Elitech International University"],
    ".isicom.education": [
        "Higher Institute of Computer Science and Communication ",
        "Institut Superieur d'Informatique et de communication",
        "Democratic Republic Of Congo, KOLWEZI, province of LUALABA",
    ],
    ".kings.education": ["King’s College Saint Michaels"],
    ".mai.education": [
        "федеральное государственное бюджетное образовательное учреждение высшего образования «Московский авиационный институт (национальный исследовательский университет)» ",
        "Moscow Aviation Institute (National Research University) ",
    ],
    ".msg-landau.education": ["Max-Slevogt-Gymnasium"],
    ".0720033v.paysdelaloire.education": [
        "Lycée Public Polyvalent GABRIEL TOUCHARD - GEORGE WASHINGTON"
    ],
    ".sabel.education": ["GBS Schulen München"],
    ".sterling.education": ["Sterling Education"],
    ".tac.education": ["The American Campus"],
    ".46.ukr.education": ["ХГ №46 им. М.В. Ломоносова"],
    ".guzikschool.ukr.education": [
        "Авторська Школа М. П. Гузика",
        "Author's Guzik School",
    ],
    ".harmony.ukr.education": [
        'Боярський академічний ліцей "Гармонія"',
        'Boyarka Academic Lyceum "Harmony"',
    ],
    ".kkrnu.ukr.education": [
        "College of Kremenchug National University named after Mikhail Ostrogradsky"
    ],
    ".lgk.ukr.education": ["Heroes of Kruty State Lyceum of Lviv"],
    ".licej12.ukr.education": [
        "Івано-Франківський Ліцей №12 ім. Івана Франка",
        "Ivano-Frankivskyi Lyceum #12 by name of Ivan Franko",
    ],
    ".uagimberegovo.ukr.education": [
        'Берегівський Ліцей "Платан"',
        'Berehivsʹkyy Litsey "Platan"',
    ],
    ".unimaksl.education": ["University of Makeni", "Unimak"],
    ".ametikool.ee": ["Kuressaare Ametikool", "Kuressaare Regional Training Centre"],
    ".artun.ee": ["Estonian Academy of Arts"],
    ".eava.ee": ["Estonian Aviation Academy"],
    ".ebs.ee": ["Estonian Business School"],
    ".ema.edu.ee": ["Estonian Academy of Music and Theatre"],
    ".eek.ee": ["Estonian Entrepreneurship University of Applied Sciences"],
    ".emu.ee": ["Estonian University of Life Sciences"],
    ".euroakadeemia.ee": ["Euroakadeemia"],
    ".itcollege.ee": ["The Estonian Information Technology College"],
    ".ivkhk.ee": [
        "Ida-Virumaa Kutsehariduskeskus",
        "Ida-Virumaa Vocational Education Center",
    ],
    ".khk.ee": ["Tartu Vocational School"],
    ".edu.lvrkk.ee": ["Lääne-Virumaa Rakenduskõrgkool"],
    ".nooruse.ee": ["Tartu Health Care College"],
    ".sisekaitse.ee": ["Estonian Academy of Security Sciences"],
    ".taltech.ee": ["TalTech"],
    ".tktk.ee": ["University of Applied Sciences"],
    ".tlu.ee": ["Tallinn University"],
    ".tptlive.ee": ["Tallinn Polytechnic School"],
    ".ttu.ee": ["Tallinn University of Technology"],
    ".ut.ee": ["University of Tartu"],
    ".vikk.ee": ["Viljandi Kutseõppekeskus"],
    ".viljandiwaldorf.ee": [
        "Viljandi Vaba Waldorfkool",
        "Viljandi Free Waldorf School",
    ],
    ".westholm.ee": ["Jakob Westholmi Gümnaasium"],
    ".acu.edu.eg": ["Ahram Canadian University"],
    ".aiet.edu.eg": [
        "Alexandria Higher Institute of Engineering and Technology",
        "Alexandria Higher Institute of Engineering and Technology",
    ],
    ".aiu.edu.eg": ["Alamein International University", "جامعة العلمين الدولية"],
    ".akhbaracademy.edu.eg": ["Akhbar El-Yom Academy", "Akhbar El-Yom Academy"],
    ".alex.edu.eg": ["Alexandria University"],
    ".alexmed.edu.eg": ["Faculty of Medicine, Alexandria University"],
    ".alexu.edu.eg": ["Alexandria University"],
    ".alsafwa.edu.eg": [
        "Safwa Higher Institute of Engineering and technology",
        "معهد الصفوة العالي للهندسة والتكنولوجيا",
    ],
    ".aou.edu.eg": ["Arab Open University"],
    ".aru.edu.eg": ["جامعة العريش", "Arish University"],
    ".asu.edu.eg": ["ain shams university"],
    ".eng.aswu.edu.eg": ["Aswan University"],
    ".stu.aswu.edu.eg": ["aswan university"],
    ".au.edu.eg": ["جامعة اسيوط", "Assiut University"],
    ".aun.edu.eg": ["Assiut University"],
    ".azhar.edu.eg": ["Al Azhar University"],
    ".bisc.edu.eg": ["British International School Cairo"],
    ".bsu.edu.eg": ["Beni Suef University"],
    ".bu.edu.eg": ["Benha University"],
    ".bue.edu.eg": ["The British University in Egypt"],
    ".csi.edu.eg": [
        "culture and science city",
        "culture and science city",
        "domain: csi.edu.eg",
    ],
    ".eng1.cu.edu.eg": ["Faculty of Engineering, Cairo University"],
    ".cu.edu.eg": ["Cairo University"],
    ".dmu.edu.eg": [
        "Faculty of computers and information Damnhour University",
        "Faculty of computers and information Damnhour University",
    ],
    ".domazhermedicine.edu.eg": ["Al-Azhar University, Faculty of medicine"],
    ".du.edu.eg": ["Damietta University"],
    ".student.eelu.edu.eg": [
        "الجامعة المصرية للتعليم الاليكتروني الاهلية",
        "The Egyptian E-Learning University",
    ],
    ".eelu.edu.eg": [
        "الجامعة المصرية للتعليم الاليكتروني الاهلية",
        "The Egyptian E-Learning University",
    ],
    ".ejust.edu.eg": [
        "Egypt-Japan University of Science and Technology",
        "Egypt-Japan University of Science and Technology",
    ],
    ".elshoroukacademy.edu.eg": ["El Shorouk Academy"],
    ".fa-hists.edu.eg": [
        "Future Academy",
        "Higher Future Institute For Specialized Technological Studies",
    ],
    ".fayoum.edu.eg": ["Fayoum University"],
    ".stud.fci-cu.edu.eg": ["Cairo University"],
    ".fci-cu.edu.eg": [
        "Faculty of Computers and Artificial Intelligence Cairo University",
        "Faculty of Computers and Artificial Intelligence Cairo University",
    ],
    ".fief.edu.eg": ["Future High Institute of Engineering in Fayoum", "FIEF"],
    ".fue.edu.eg": ["Future University in Egypt"],
    ".futureuniversity.edu.eg": ["Future University"],
    ".guc.edu.eg": ["German University in Cairo"],
    ".helwan.edu.eg": ["Helwan University"],
    ".hti.edu.eg": ["Higher Technological Institute"],
    ".iaet.edu.eg": ["Institute of aviation Engineering and technology "],
    ".kfs-hiet.edu.eg": [
        "المعهد العالي للهندسة والتكنولوجيا بكفرالشيخ",
        "Higher Institute of Engineering and Technology Kafrelsheikh",
    ],
    ".kfs.edu.eg": ["Kafr El-Sheikh University"],
    ".luxor.edu.eg": ["Luxor University", "جامعة الأقصر", "http://www.luxor.edu.eg/"],
    ".madinagroups.edu.eg": ["Madina Academy"],
    ".mans.edu.eg": ["Mansoura University"],
    ".mau.edu.eg": [
        "Faculty of computers and artificial intelligence Matrouh universty"
    ],
    ".menofia.edu.eg": ["Menoufia University"],
    ".mhiet.edu.eg": [
        "المعهد العالي للهندسه والتكنولوجيا",
        "the higher institute of engineering and technology",
    ],
    ".minia.edu.eg": ["Minia University"],
    ".miniauniv.edu.eg": ["جامعة المنيا", "Minia University"],
    ".miuegypt.edu.eg": ["Misr International University"],
    ".modern-academy.edu.eg": ["Modern academy for engineering & technology"],
    ".moe.edu.eg": [
        "وزارة التربية والتعليم والتعليم الفني المصرية",
        "Ministry of Education and Technical Education - Egypt",
    ],
    ".msa.edu.eg": ["October University for Sciences & Arts (MSA University)"],
    ".mtc.edu.eg": ["Military Technical College"],
    ".mti.edu.eg": ["Modern University For Technology and Information"],
    ".mu.edu.eg": ["Minya University"],
    ".must.edu.eg": ["Misr University for Sience and Technology"],
    ".ndeti.edu.eg": [
        "المعهد العالي للهندسة والتكنولوجيا بدمياط الجديدة",
        "Higher Institute For Engineering & Technology in Damietta El-Gadeeda",
    ],
    ".nileu.edu.eg": ["Nile University"],
    ".nu.edu.eg": ["Nile University", "Nile University"],
    ".o6u.edu.eg": ["October 6 university"],
    ".psu.edu.eg": ["Port Said University"],
    ".pua.edu.eg": ["Pharos International University"],
    ".s-mu.edu.eg": ["جامعة المنيا", "Minia University"],
    ".sadatacademy.edu.eg": ["Sadat Academy for Management Sciences"],
    ".sha.edu.eg": ["El Shrouk Academy", "el shrouk academy"],
    ".shams.edu.eg": ["Ain Shams University"],
    ".sinaieng.edu.eg": [
        "The Higher Institute of Engineering and Technology - AlArish"
    ],
    ".fci.sohag.edu.eg": ["Sohag University"],
    ".techedu.sohag.edu.eg": ["sohag university", "sohag university"],
    ".sohag-univ.edu.eg": ["Sohag University"],
    ".su.edu.eg": ["Sinai University"],
    ".suez.edu.eg": ["Suez Canal University"],
    ".fci.suezuni.edu.eg": ["Suez University", "Suez University"],
    ".std.suezuniv.edu.eg": ["Suez University", "Suez University"],
    ".svu.edu.eg": ["South Valley University"],
    ".tanta.edu.eg": ["Tanta University"],
    ".thebes.edu.eg": ["اكاديمية طيبة", "thebes academy"],
    ".thic.edu.eg": [
        "المعهد العالي للحاسبات والمعلومات الادارية وتكنولوجيا- ادارة بطنطا"
    ],
    ".ufe.edu.eg": ["Université Française d'Égypte"],
    ".uofcanada.edu.eg": ["universit of canada in Egypt"],
    ".usc.edu.eg": ["جامعة مدينة السادات", "University Of Sadat City"],
    ".zewailcity.edu.eg": ["Zewail City of Science and Technology"],
    ".zu.edu.eg": ["Zagazig University"],
    ".msa.eun.eg": ["Modern Sciences &amp; Arts University"],
    ".bsg.email": ["The British School Of Geneva", "BSG"],
    ".iramps.email": ["IRAMps"],
    ".mallowcollege.email": ["Mallow College of Further Education"],
    ".woodrushhigh.email": ["Woodrush High School"],
    ".acarballeira.es": ["CIFP A Carballeira"],
    ".adaits.es": [
        "Instituto Tecnológico Superior - ADA (Sevilla)",
        "Higher Education Techlogical Institute - ADA (Sevilla)",
    ],
    ".alumni-eae.es": ["EAE Business School"],
    ".alumnos-eneb.es": ["ENEB. Escuela de Negocios Europea de Barcelona"],
    ".alumnosiesleliana.es": ["IES L'Eliana"],
    ".campuscamara.es": ["ESTUDIOS UNIVERSITARIOS Y SUPERIORES DE ANDALUCIA, SLU"],
    ".campusviu.es": [
        "Universidad Internacional de Valencia",
        "Valencian International University",
    ],
    ".cesma.es": ["CESMA Business School"],
    ".ceu.es": ["Universidad Cardenal Herrera-CEU", "Universidad de San Pablo CEU"],
    ".ceuandalucia.es": ["CEU Andalucía", "CEU Andalusia"],
    ".chabacier.es": ["IES Leonardo de Chabacier", "IES Leonardo de Chabacier"],
    ".cide.es": ["CIDE"],
    ".cifpcarballeira.es": ["CIFP A Carballeira - Marcos Valcárcel"],
    ".aula.cifplalaboral.es": ["Centro Integral de Formacion Profesional La Laboral"],
    ".cifpzonzamas.es": ["CIFP ZONZAMAS"],
    ".colegiotorremalmuerta.es": [
        "C.E.I.P. TORRE MALMUERTA DE CÓRDOBA",
        "Public school Torre Malmuerta",
    ],
    ".deusto.es": ["Universidad de Deusto"],
    ".e-itaca.es": ["IES ITACA", "IES ITACA"],
    ".eae.es": ["EAE Business School"],
    ".easda.es": [
        "Escuela de Arte y Superior de Diseño de Alicante",
        "Alicante School of Art and College of Design",
    ],
    ".fundacionpracticum.edu.es": [
        "\ufeffInstituto Practicum de Investigación Aplicada a la Educación en Ciencias de la Salud"
    ],
    ".inea.edu.es": [
        "Universidad de Valladolid - Escuela Universitaria de Ingeniería Agrícola"
    ],
    ".iunit.edu.es": [
        "Centro de educación superior de negocios, innovación y tecnología"
    ],
    ".ull.edu.es": ["Universidad de La Laguna"],
    ".upv.edu.es": ["Universidad Politécnica de Valencia"],
    ".g.educaand.es": ["Schools in Andalusia"],
    ".educarex.es": ["Institutos de Educación Secundaria de Extremadura (España)"],
    ".educastillalamancha.es": [
        "Educación de Castilla-La Mancha",
        "Castilla-La Mancha's education",
        ".group",
    ],
    ".ehu.es": ["Universidad del País Vasco"],
    ".eoi.es": ["Escuela de Organización Industrial"],
    ".esada.es": ["ESADA"],
    ".esat.es": ["Escuela Superior de Arte y Tecnologia (ESAT)"],
    ".escav.es": [
        "Escuela Superior de Comunicación Audiovisual",
        "High School of audiovisual communication",
    ],
    ".esdmadrid.es": [
        "Escuela Superior de Diseño de Madrid",
        "Madrid School of Design",
    ],
    ".esic.es": ["Escuela Superior de Gestion Comercial y Marketing (ESIC)"],
    ".esne.es": [
        "Esne ( Escuela Universitaria de Diseño, Innovacion y Tecnologia), based in Madrid, Spain"
    ],
    ".profesor.esneasturias.es": ["ESNE"],
    ".eug.es": ["Escoles Universitàries Gimbernat i Tomàs Cerdà"],
    ".euncet.es": ["EUNCET Business School"],
    ".eusa.es": ["CAMPUS FORMATIVO DE LA CÁMARA DE COMERCIO DE SEVILLA"],
    ".correo.evg.es": ["Escuela Virgen de Guadalupe"],
    ".fesac.es": ["FESAC"],
    ".floridauniversitaria.es": ["Florida Universitaria"],
    ".fundacionsafa.es": ["Foundation SAFA"],
    ".edu.gva.es": ["Students and teachers of Comunidad Valenciana, Spain"],
    ".icfo.es": ["The Institute of Photonic Sciences"],
    ".idecrea.es": ["Escuela de artes digitales Idecrea"],
    ".idep.es": ["Idep Barcelona - Escola Superior d'Imatge i Disseny"],
    ".ies-azarquiel.es": ["I.E.S. Azarquiel"],
    ".iesalbarregas.es": ["IES ALBARREGAS"],
    ".iesalbujaira.es": ["Instituto de Educación Secundaria Albujaira", "Albujaira"],
    ".iesandorra.es": ["Pablo Serrano", "Pablo Serrano"],
    ".iesbenigaslo.es": ["IES Benigaslo"],
    ".iescamas.es": ["IES Camas", "IES Camas"],
    ".iescamp.es": ["IES Camp de Morvedre"],
    ".alumno.ieselrincon.es": ["IES El Rincon"],
    ".ieselrincon.es": ["IES El Rincon"],
    ".iesfranciscodelosrios.es": [
        'Instituto de Educación Secundaria "Francisco de Los Ríos"'
    ],
    ".iesfuengirola1.es": [
        "IES Fuengirola Número 1",
        "Fuengirola Number 1 High School",
    ],
    ".iesgalileo.es": ["IES Galileo (Valladolid)"],
    ".ieslavereda.es": ["IES La Vereda"],
    ".iesnervion.es": ["Instituto de Educación Secundaria Nervión."],
    ".iesoleana.es": ["IES Oleana"],
    ".iesoretania.es": ["I.E.S. ORETANIA"],
    ".iespacomolla.es": ["IES Poeta Paco Mollá"],
    ".iesprofesormaximotrueba.es": ["IES Profesor Máximo trueba"],
    ".iespuertasdelcampo.es": ["IES Puertas del Campo"],
    ".iessantaaurelia.es": ["IES Santa Aurelia"],
    ".iessoterohernandez.es": ["\ufeffIES Sotero Hernández"],
    ".iesteis.es": ["IES de Teis"],
    ".informatica.iesvalledeljerteplasencia.es": ["IES Valle del Jerte (Plasencia)"],
    ".iesvegademijas.es": ["IES Vega de Mijas (Málaga)"],
    ".juntadeandalucia.es": ["IES Jaroso"],
    ".students.lesroches.es": ["Les Roches International School of Hotel Management"],
    ".linkiafp.es": ["Linkia FP - Formación Profesional Oficial a Distancia"],
    ".maristaslogrono.es": ["Colegio Maristas San Jose Logroño"],
    ".alu.medac.es": ["MEDAC"],
    ".medac.es": ["MEDAC"],
    ".monlau.es": ["Monlau Centro de Estudios"],
    ".montessorischool.es": ["Montessori School La Florida, Madrid"],
    ".muni.es": ["Mondragon Univertsitatea"],
    ".alu.murciaeduca.es": ["Alumnos Región de Murcia alu.murciaeduca.es"],
    ".murciaeduca.es": ["Educación de la Región de Murcia"],
    ".educacion.navarra.es": ["Cuatrovientos centro integrado"],
    ".nebrija.es": ["Added Universidad Nebrija"],
    ".opendeusto.es": ["Universidad de Deusto"],
    ".riberadeltajo.es": ["IES Ribera del tajo", "IES Ribera del tajo"],
    ".roa.es": ["ROA Spanish Naval Observatory"],
    ".rtve.es": ["Instituto Radio Televisión Española"],
    ".hue.safanet.es": [
        "C.D.P. Escuelas Profesionales de la Sagrada Familia, SAFA-Funcadia"
    ],
    ".safareyes.es": ["Foundation SAFA"],
    ".estudiantes.salesianasnsp.es": ["nuestra señora del pilar salesianas"],
    ".solcnou.es": ["Escola Solc Nou"],
    ".tecnun.es": [
        "TECNUN - Escuela Superior de Ingenieros de la Universidad de Navarra (UNAV)"
    ],
    ".ua.es": ["Universidad de Alicante"],
    ".uab.es": [
        "Universitat Autónoma de Barcelona",
        "Autonomous University of Barcelona",
    ],
    ".uah.es": ["Universidad de Alcalá de Henares"],
    ".ual.es": ["University of Almeria"],
    ".ualm.es": ["Universidad de Almería"],
    ".uam.es": ["Universidad Autónoma de Madrid"],
    ".uao.es": ["Universitat Abat Oliba", "Abat Oliba CEU University"],
    ".uax.es": ["Universidad Alfonso X El Sabio"],
    ".ub.es": ["Universitat de Barcelona"],
    ".ubu.es": ["Universidad de Burgos"],
    ".alumnos.uc3m.es": ["Universidad Carlos III de Madrid"],
    ".uc3m.es": ["Universidad Carlos III de Madrid"],
    ".uca.es": ["Universidad de Cádiz"],
    ".ucavila.es": ["Universidad Católica de Ávila"],
    ".uchceu.es": ["Universidad Cardenal Herrera"],
    ".uclm.es": ["Universidad de Castilla La Mancha"],
    ".ucm.es": ["Universidad Complutense de Madrid"],
    ".uco.es": ["Universidad de Córdoba"],
    ".ucv.es": ["Universidad Católica de Valencia"],
    ".udc.es": ["Universidad de La Coruña"],
    ".udg.es": ["Universidad de Gerona"],
    ".udl.es": ["Universitat de Lleida"],
    ".uem.es": ["Universidad Europea de Madrid"],
    ".uemc.es": ["Universidad Europea Miguel de Cervantes"],
    ".ufv.es": ["Universidad Francisco de Vitoria"],
    ".ugr.es": ["Universidad de Granada"],
    ".uhu.es": ["Universidad de Huelva"],
    ".ui1.es": ["Universidad Internacional Isabel I de Castilla"],
    ".uia.es": [
        "Universidad Internacional de Andalucía",
        "Universidad Internacional de Andalucía, Sede Antonio Machado de Baeza",
        "Universidad Internacional de Andalucía, Sede La Rábida",
    ],
    ".uib.es": ["Universitat de les Illes Balears"],
    ".uic.es": ["Universitat Intenacional de Catalunya"],
    ".uimp.es": ["Universidad Internacional Menéndez Pelayo"],
    ".ujaen.es": ["Universidad de Jaén"],
    ".uji.es": ["Universitat Jaume I de Castellón"],
    ".ull.es": ["Universidad de La Laguna"],
    ".al.uloyola.es": ["Universidad Loyola Andalucia", "Andalusian Loyola University"],
    ".ulpgc.es": ["Universidad de Las Palmas de Gran Canaria"],
    ".um.es": ["Universidad de Murcia"],
    ".uma.es": ["Universidad de Málaga"],
    ".umh.es": ["Universidad Miguel Hernández de Elche"],
    ".unav.es": ["Universidad de Navarra"],
    ".unavarra.es": ["Universidad Pública de Navarra"],
    ".uneatlantico.es": [
        "Universidad Europea del Atlántico",
        "European University of Atlantic",
    ],
    ".uned.es": ["Universidad Nacional de Educación a Distancia"],
    ".unex.es": ["Universidad de Extremadura"],
    ".unican.es": ["Universidad de Cantabria"],
    ".unileon.es": ["Universidad de León"],
    ".uniovi.es": ["Universidad de Oviedo"],
    ".unirioja.es": ["Universidad de La Rioja"],
    ".universidadeuropea.es": ["Universidad Europea de Madrid"],
    ".unizar.es": ["Universidad de Zaragoza"],
    ".unnet.es": ["Universidad Antonio de Nebrija"],
    ".uoc.es": ["Universitat Oberta de Catalunya"],
    ".upco.es": ["Universidad Pontificia Comillas"],
    ".upcomillas.es": ["Universidad Pontificia de Comillas"],
    ".upct.es": ["Universidad Politécnica de Cartagena"],
    ".upf.es": ["Universitat Pompeu Fabra"],
    ".upm.es": ["Universidad Politécnica de Madrid"],
    ".upo.es": ["Universidad Pablo de Olavide"],
    ".upsa.es": ["Universidad Pontificia de Salamanca"],
    ".upv.es": ["Universidad Politécnica de Valencia"],
    ".urjc.es": ["Universidad Rey Juan Carlos"],
    ".url.es": ["Universitat Rámon Llull"],
    ".urv.es": ["Universitat Rovira I Virgili Tarragona"],
    ".alum.us.es": ["Universidad de Sevilla"],
    ".us.es": ["Universidad de Sevilla"],
    ".usal.es": ["Universidad de Salamanca"],
    ".usc.es": ["Universidad de Santiago de Compostela"],
    ".usj.es": ["Universidad San Jorge"],
    ".uv.es": ["Universidad de Valencia"],
    ".uva.es": ["Universidad de Valladolid"],
    ".uvic.es": ["Universitat de Vic"],
    ".uvigo.es": ["Universidad de Vigo"],
    ".alumnos.viu.es": [
        "VIU Universidad Internacional de Valencia",
        "Valencian International University",
    ],
    ".aastu.edu.et": [
        "አዲስ አበባ ሳይንስ እና ቴክኖሎጂ ዩኒቨርሲቲ",
        "Addis Ababa Science and Technology University",
        "AASTU",
    ],
    ".aau.edu.et": ["Addis Ababa University"],
    ".ambou.edu.et": ["Ambo University"],
    ".amu.edu.et": ["Arba Minch University"],
    ".bdu.edu.et": ["Bahir Dar University"],
    ".dillauniversity.edu.et": ["Dilla University"],
    ".haramaya.edu.et": ["Haramaya University"],
    ".hu.edu.et": ["Hawassa University"],
    ".jju.edu.et": ["Jigjiga University"],
    ".ju.edu.et": ["Jimma University"],
    ".mu.edu.et": ["Mekelle University"],
    ".uog.edu.et": ["Gondar University"],
    ".aforp.eu": ["AFORP centre de formation industriel et technologique"],
    ".akademiasztuki.eu": [
        "Akademia Sztuki w Szczecinie",
        "Academy of Art in Szczecin",
    ],
    ".amgd.eu": ["Academy of Music Georghe Dima Cluj-Napoca"],
    ".apeiron-edu.eu": ["Panevropski Univerzitet Apeiron Banja Luka"],
    ".ash-berlin.eu": ["Alice Salomon Hochschule Berlin"],
    ".barcelonagse.eu": ["Barcelona Graduate School of Economics"],
    ".bbs-papenburg.eu": ["BBS Papenburg"],
    ".bbs2-aurich.eu": ["BBS II Aurich"],
    ".bbsam.eu": ["Berufsbildende Schulen am Museumsdorf Cloppenburg"],
    ".bkbocholt-west.eu": ["BK Bocholt-West", "BK Bocholt-West"],
    ".bottyan.eu": ["Bottyán János Szakgimnázium"],
    ".brexgata.eu": ["Brexgata University Academy"],
    ".campusid.eu": ["Campus ID"],
    ".cnva.eu": [
        'Colegiul National "Vasile Alecsandri"',
        "Vasile Alecsandri National College",
    ],
    ".coleurope.eu": ["College of Europe"],
    ".cosmopolitanschool.eu": [
        "Berlin Cosmopolitan School",
        "Berlin Cosmopolitan School",
    ],
    ".dallam.eu": [],
    ".dauphine.eu": ["Université Paris-Dauphine (Paris IX)"],
    ".dgkralupy.eu": ["Dvorakovo gymnazium a SOSE in Kralupy nad Vltavou"],
    ".ecam-strasbourg.eu": ["Ecam Strasbourg"],
    ".uitm.edu.eu": [
        "University of Information Technology and Management in Rzeszow",
        "Wyższa Szkoła Informatyki i Zarządzania w Rzeszowie",
    ],
    ".educa-sos.eu": ["EDUCA SOS s.r.o. private high school"],
    ".eisti.eu": [
        "EISTI - Ecole Internationnale des Sciences du Traitement de l'Information"
    ],
    ".ensam.eu": ["Arts et Métiers ParisTech"],
    ".ensg.eu": ["Ecole Nationale des Sciences Géographiques"],
    ".ensup.eu": ["\ufeffENSUP, Ecole supérieure de Commerce dans le 78 et 95"],
    ".epfc.eu": ["EPFC - Ecole de Promotion et de Formation Continue"],
    ".epitech.eu": ["École de l'Innovation et de l'Expertise Informatique"],
    ".edu.escp.eu": ["ESCP Business School"],
    ".escpeurope.eu": ["ESCP Europe"],
    ".esiee-amiens.eu": [
        "Ecole Supérieure d'Ingénieurs en Electronique et Electrotechnique - Amiens"
    ],
    ".essca.eu": ["Essca", "ESSCA School of Management"],
    ".estaca.eu": [
        "Ecole Supérieure des Techniques Aéronautiques et de Construction Automobile"
    ],
    ".eui.eu": ["European University Institute"],
    ".euroakadeemia.eu": ["Euroakadeemia"],
    ".eursc.eu": ["European schools", "Ecoles européennes", "Europäische Schulen"],
    ".fh-dresden.eu": ["Fachhochschule Dresden – University of Applied Sciences"],
    ".get-mail.eu": ["Groupe ESC Troyes"],
    ".ggs-schenefeld.eu": ["Grund- und Gemeinschaftsschule Schenefeld"],
    ".gym-old.eu": ["Gymnasium Oldenfelde"],
    ".gymcadca.eu": [
        "Gymnázium Jozefa Miloslava Hurbana v Čadci",
        "Grammar school of Jozef Miloslav Hurban in Čadca",
    ],
    ".student.gymkvary.eu": [
        "První české gymnázium v Karlových Varech",
        "First Czech grammar school in Karlovy Vary",
    ],
    ".gymnasium-ganderkesee.eu": ["Gymnasium Ganderkesee"],
    ".gymnasium-rhauderfehn.eu": ["Gymnasium Rhauderfehn"],
    ".student.handlowa.eu": [
        "WYŻSZA SZKOŁA HANDLOWA WE WROCŁAWIU",
        "UNIVERSITY OF BUSINESS IN WROCLAW",
    ],
    ".handlowa.eu": [
        "Wyższa Szkoła Handlowa we Wrocławiu",
        "University of Business in Wroclaw",
    ],
    ".hetic.eu": ["HETIC", "Grande École d’HETIC, France"],
    ".hfm.eu": ["University of Music Karlsruhe"],
    ".horyzont.eu": ['Higher school of applied computer science "Horyzont"'],
    ".hsrw.eu": ["Hochschule Rhein-Waal"],
    ".ibss.eu": ["International Business School of Scandinavia"],
    ".igs-kreyenbrueck.eu": ["Integrierte Gesamtschule Kreyenbrück"],
    ".ihl.eu": ["Internationale Hochschule Bad Liebenzell"],
    ".imc-krems.eu": ["FH University of Applied Sciences Krems"],
    ".imt-bs.eu": [
        "Institut Mines-Telecom Business School (ex-Telecom Ecole de Management)"
    ],
    ".internationalschoolofeurope.eu": ["International School of Europe"],
    ".itis-molinari.eu": ["ITT- LSA “Ettore Molinari”"],
    ".itiscuneo.eu": [
        "\"Istituto Tecnico Industriale Statale 'Mario Delpozzo' Cuneo\"",
        "\"Technical Industrial Institute 'Mario Delpozzo' Cuneo\"",
    ],
    ".julianum.eu": ["Gymnasium Julianum"],
    ".kgs-leeste.eu": ["Kooperative Gesamtschule Leeste"],
    ".kgs-rastede.eu": ["KGS Rastede"],
    ".kgshemmingen.eu": ["KGS Hemmingen"],
    ".kgslaatzen.eu": ["Albert Einstein Schule Laatzen"],
    ".e-zsel.kielce.eu": [
        "Technikum nr 4 im. Ryszarda Kaczorowskiego w Kielcach",
        "Zespół Szkół Elektrycznych (ZSE) w Kielcach",
    ],
    ".kwr-hannover.eu": ["Kaiser- Wilhelm und Ratsgymnasium"],
    ".kwrg.eu": ["Kaiser- Wilhelm und Ratsgymnasium"],
    ".leibnizschule-hannover.eu": ["Leibnizschule Hannover"],
    ".lgs-hu.eu": ["Ludwig-Geissler-Schule Hanau"],
    ".liceocassini.eu": ["Liceo Scientifico Gian Domenico Cassini"],
    ".liceolussana.eu": ["Liceo Scientifico Statale F. Lussana"],
    ".liceosabin.eu": ["Liceo Scientifico Statale Albert Bruce Sabin"],
    ".edu.lublin.eu": [
        "Zintegrowany system jednostek oświatowych miasta Lublin",
        "Integrated system of educational units - city of Lublin",
    ],
    ".gsuite.zsel.lublin.eu": [
        "Technikum Elektroniczne w Lublinie",
        "Electronical School Complex in Lublin",
    ],
    ".mruni.eu": ["Mykolo Romerio university"],
    ".student.mwsl.eu": [
        "Międzynarodowa Wyższa Szkoła Logistyki i Transportu we Wrocławiu",
        "The International University of Logistics and Transport in Wroclaw",
    ],
    ".nvna.eu": ["Nikola Vaptsarov Naval Academy - Bulgarian Maritime University"],
    ".obs-sottrum.eu": ["Oberschule An der Wieste Sottrum"],
    ".ozanam.eu": ["LYCEE OZANAM, LILLE"],
    ".pacr.eu": ["Police Academy of Czech Republic"],
    ".chartes.psl.eu": ["École Nationale des Chartes"],
    ".psl.eu": [
        "Paris Sciences and Letters",
        "Paris Sciences et Lettres",
        "PSL url: https://www.psl.eu/en",
    ],
    ".pwsz.eu": ["Walcz College", "Walcz College"],
    ".reacollege.eu": ["REA College"],
    ".rmbk.eu": ["Rhein Maas Berufskolleg", "http://rmbk.de/"],
    ".schloss-online.eu": ["Gymnasium am kurfuerstlichen Schloss Mainz"],
    ".schoolmath.eu": [
        'Математическа Гимназия "Акад. Кирил Попов" Пловдив',
        'High School of Mathematics "Acad. Kiril Popov"',
    ],
    ".sciencespo-lille.eu": [
        "Sciences Po Lille",
        "Lille Institute of political studies",
    ],
    ".sekundarschule-soest.eu": ["Sekundar Schule Soest"],
    ".seuniversity.eu": [
        "Vysoká škola zdravotníctva a sociálnej práce sv. Alžbety",
        "St. Elizabeth College of Health and Social Work",
    ],
    ".citycollege.sheffield.eu": [
        "The University of Sheffield International Faculty, CITY College"
    ],
    ".spsbj.eu": ["SPŠT Bardejov"],
    ".spsjm.eu": ["Stredná priemyselná škola Jozefa Murgaša, Banská Bystrica"],
    ".sstebrno.eu": [
        "Střední škola technická a ekonomická Brno, Olomoucká, příspěvková organizace"
    ],
    ".steinbart-gym.eu": ["Steinbart Gymnasium Duisburg"],
    ".teb-eu.eu": ["Thomas-Eßer-Berufskolleg Euskirchen"],
    ".telecom-bretagne.eu": ["Telecom Bretagne"],
    ".telecom-em.eu": ["Télécom École de Management"],
    ".telecom-sudparis.eu": ["Télécom SudParis"],
    ".telecomnancy.eu": ["TELECOM Nancy"],
    ".tismbree.eu": ["TISM Bree"],
    ".tls-giessen.eu": ["Theodor-Litt-Schule Gießen"],
    ".uib.eu": ["Universitat de les Illes Balears"],
    ".unifortunato.eu": ["Giustino Fortunato University"],
    ".unilodz.eu": ["Uniwersytet Łódzki"],
    ".uniroma2.eu": ["University of Tor Vergata"],
    ".utad.eu": ["Universidade de Trás-os-Montes e Alto Douro"],
    ".vumk.eu": ["International University College"],
    ".wittenborg.eu": ["Wittenborg University"],
    ".student.wsinf.eu": ["University of Computer Sciences and Skills in Łódź"],
    ".yschools.eu": ["Yschools"],
    ".zielone.eu": [
        "Zespół\xa0Szkół im. Jędrzeja Śniadeckiego w Pionkach",
        "Jędrzej Śniadecki School Complex in Pionki",
    ],
    ".zsge.eu": ["Zespół Szkół Górniczo-Energetycznych im. Stanisława Staszica"],
    ".zszatopkovych.eu": ["ZS Dany a Emila Zatopkovych, Trinec, prisp. org."],
    ".ikasle.aeg.eus": ["AEG Ikastetxea"],
    ".birt.eus": [
        "BIRTLH / CIFP de aprendizajes virtuales y digitalizados, Vitoria, Basque Country"
    ],
    ".doloresibarruribhi.eus": ["Dolores Ibarruri BHI"],
    ".ehu.eus": ["University of the Basque Country"],
    ".irakasle.eus": ["Escuela publica del Gobierno Vasco en el Pais Vasco"],
    ".olabide.eus": ["Olabide Ikastola Koop. Elk."],
    ".plaiaundi.eus": ["IES Plaiaundi BHI", "Plaiaundi Vocational Institute"],
    ".uni.eus": ["IES Uni Eibar-Ermua BHI"],
    ".Prakticum.fi": ["Prakticum  framtidsskolan"],
    ".aalto.fi": ["Aalto University"],
    ".abo.fi": ["Abo Akademi University"],
    ".arcada.fi": ["Arcada University of Applied Sciences"],
    ".edu.bc.fi": ["Suomen Liikemiesten Kauppaopisto", "Business College Helsinki"],
    ".bc.fi": ["Suomen Liikemiesten Kauppaopisto", "Business College Helsinki"],
    ".centria.fi": ["Centria University of Applied Sciences"],
    ".cou.fi": ["Central Ostrobothnia University of Applied Sciences"],
    ".diak.fi": ["Diaconia University of Applied Sciences"],
    ".eduespoo.fi": ["All schools in the city of Espoo, Finland", "    ", ".group"],
    ".oppilas.eduhat.fi": ["Parolan Yhteiskoulu", "Parola Co-Educational"],
    ".eduouka.fi": ["The City of Oulu Department of Education"],
    ".eduvammalanlukio.fi": ["Vammala/Sastamala High School, Finland"],
    ".opp.eduvantaa.fi": ["Vantaan ammattiopisto Varia", "Vocational College Varia"],
    ".edu.espoo.fi": ["All schools in the city of Espoo, Finland"],
    ".evtek.fi": ["EVTEK University of Applied Sciences"],
    ".gradia.fi": ["Gradia", "Jyväskylän koulutuskuntayhtymä Gradia"],
    ".haaga-helia.fi": ["HAAGA-HELIA University of Appliced Sciences"],
    ".hamk.fi": ["HAMK University of Applied Sciences", "Hämeen ammattikorkeakoulu"],
    ".hanken.fi": ["Hanken School of Economics"],
    ".edu.hel.fi": ["All schools in the city of Helsinki, Finland"],
    ".helsinki.fi": ["University of Helsinki"],
    ".hive.fi": ["Hive Helsinki"],
    ".hkkk.fi": ["Helsinki School of Economics and Business Administration"],
    ".hut.fi": ["Helsinki University of Technology"],
    ".edu.hyria.fi": ["Hyria koulutus", "Hyria education"],
    ".oppilas.hyvinkaa.fi": ["Tapainlinnan Koulu"],
    ".jamk.fi": ["JAMK University of Applied Sciences"],
    ".jedu.fi": ["Vocational school of Oulainen"],
    ".joensuu.fi": ["University of Joensuu"],
    ".jyu.fi": ["University of Jyväskylä"],
    ".koulut.kaarina.fi": ["All schools in the city of Kaarina, Finland"],
    ".kamk.fi": ["Kajaani University of Applied Sciences"],
    ".karelia.fi": ["Karelia University of Applied Sciences"],
    ".kauniaistenlukio.fi": ["High school of Kauniainen"],
    ".kktavastia.fi": ["Koulutuskuntayhtymä Tavastia", "Tavastia Education Consortium"],
    ".edu.kokkola.fi": ["All schools in the city of Kokkola, Finland"],
    ".edu.kotka.fi": ["All schools in the city of Kotka, Finland"],
    ".koudata.fi": ["Kouvola Region Vocational College"],
    ".edu.kuopio.fi": ["Schools in the city of Kuopio"],
    ".kuva.fi": ["Academy of Fine Arts"],
    ".kyamk.fi": ["Kymenlaakso University of Applied Sciences"],
    ".student.lab.fi": ["LAB university of applied sciences"],
    ".edu.lahti.fi": ["All schools in the city of Lahti, Finland"],
    ".lamk.fi": ["Lahti Polytechnic"],
    ".edu.lao.fi": ["State-run vocational schools in Lapland"],
    ".lapinamk.fi": ["Lapland University of Applied Sciences"],
    ".lappee.fi": ["Lappeenrannan Lyseon lukio"],
    ".laurea.fi": [
        "Laurea University of Applied Science",
        "laurea ammattikorkeakoulu",
        "Website: https://www.laurea.fi/en",
        "Domains: @laurea.fi",
    ],
    ".edu.lohja.fi": ["Lohjan Yhteislyseon lukio", "Lohja Upper Secondary School"],
    ".edu.loimaa.fi": ["Schools in and near Loimaa,Finland"],
    ".lut.fi": ["Lappeenranta University of Technology"],
    ".lyk.fi": ["Lahden Yhteiskoulu"],
    ".mamk.fi": ["Mikkeli University of Applied Sciences"],
    ".mayk.fi": [
        "Maunula Secondary School and Helsinki Math School (Maunulan yhteiskoulu ja Helsingin matematiikkalukio)"
    ],
    ".metropolia.fi": ["Helsinki Metropolia University of Applied Sciences"],
    ".munkka.fi": ["Munkka Secondary School (Munkkiniemen Yhteiskoulu)"],
    ".edu.nivala.fi": ["Nivalan Sivistystoimi"],
    ".edu.novia.fi": ["Novia University of Applied Sciences"],
    ".oamk.fi": ["Oulu Polytechnic"],
    ".omnia.fi": ["Omnia"],
    ".oulu.fi": ["University of Oulu"],
    ".puv.fi": ["Vaasa University of Applied Sciences"],
    ".ramk.fi": ["Rovaniemi University of Applied Sciences"],
    ".edu.raseko.fi": ["Rasekon ammattiopisto", "Raseko Vocational School"],
    ".redu.fi": ["State-run vocational schools in Lapland"],
    ".edu.riveria.fi": ["Riveria"],
    ".roiedu.fi": ["State-run schools of Rovaniemi"],
    ".saimia.fi": ["Saimaa University of Applied Sciences"],
    ".salpaus.fi": ["Salpaus college"],
    ".samk.fi": ["Satakunta University Of Applied Scinces"],
    ".sasky.fi": [
        "SASKY koulutuskuntayhtymä",
        "SASKY Municipal Education and Training Consortium",
    ],
    ".savonia.fi": ["Savonia University of Applied Sciences"],
    ".scp.fi": ["South Carelian Polytechnic"],
    ".seamk.fi": ["Seinäjoki University of Applied Sciences"],
    ".shh.fi": ["Swedish School of Economics and Business Administration, Finland"],
    ".siba.fi": ["Sibelius Academy"],
    ".edu.siikalatva.fi": ["Siikalatvan lukio"],
    ".syk.fi": [
        "Helsingin Suomalainen Yhteiskoulu",
        "Helsinki Finnish joint school",
        "https://syk.fi/ib-subjects-at-syk/",
        "https://syk.fi/syk/yhteystiedot/",
    ],
    ".taitajantie.fi": ["Aikuiskoulutus Taitaja"],
    ".tamk.fi": ["Tampere University of Applied Sciences "],
    ".teak.fi": ["Theatre Academy Finland"],
    ".tiedenorssi.fi": ["Oulun Normaalikoulu"],
    ".tpu.fi": ["Tampere Polytechnic"],
    ".tukkk.fi": ["Turku School of Economics and Business Administration"],
    ".tuni.fi": ["Tampere University, Tampere"],
    ".edu.turku.fi": ["Turku Schools"],
    ".turkuamk.fi": ["Turku University of Applied Sciences"],
    ".tut.fi": ["Tampere University of Technology"],
    ".edu.tuusula.fi": ["Tuuusulan Sivistystoimi"],
    ".tyk.fi": ["Töölön Yhteiskoulu"],
    ".uef.fi": ["University of Eastern Finland"],
    ".uku.fi": ["University of Kuopio"],
    ".ulapland.fi": ["University of Lapland"],
    ".uniarts.fi": ["University of the Arts Helsinki"],
    ".uta.fi": ["University of Tampere"],
    ".utu.fi": ["University of Turku"],
    ".uwasa.fi": ["University of Vaasa"],
    ".student.vaasa.fi": ["Vamia", "vamia, vocational school in Vaasa, Finland"],
    ".vamk.fi": ["Vaasa University of Applied Sciences"],
    ".xamk.fi": ["South-Eastern Finland University of Applied Sciences"],
    ".edu.ylojarvi.fi": [
        "\ufeffYlöjärven Yhtenäiskoulu",
        "Ylöjärvi's Comprehensive school",
    ],
    ".fnu.ac.fj": ["Fiji National University "],
    ".fsm.ac.fj": ["Fiji School of Medicine"],
    ".unifiji.ac.fj": ["University of Fiji"],
    ".usp.ac.fj": [
        "University of the South Pacific",
        "University of the South Pacific",
        "University of the South Pacific Centre",
        "University of the South Pacific School of Agriculture",
    ],
    ".comfsm.fm": ["College of Micronesia"],
    ".setur.fo": ["University of the Faroe Islands"],
    ".tsk.fo": ["Tekniski skúlin í klaksvík", "technical school in klaksvÍk"],
    ".3il.fr": ["ÉCOLE D'INGÉNIEURS EN INFORMATIQUE"],
    ".42.fr": ["Ecole 42"],
    ".student.42lyon.fr": ["42 LYON", "42 LYON"],
    ".42nice.fr": ["42 Nice"],
    ".ac-aix-marseille.fr": ["Académie d'Aix-Marseille"],
    ".ac-amiens.fr": ["Adadémie d'Amiens"],
    ".ac-besancon.fr": ["Académie de Besançon"],
    ".ac-bordeaux.fr": ["Académie de Bordeaux"],
    ".ac-caen.fr": ["Académie de Caen"],
    ".ac-clermont.fr": ["Académie de Clermont-Ferrand"],
    ".ac-corse.fr": ["Académie de Corse"],
    ".ac-creteil.fr": ["Académie de Créteil"],
    ".ac-dijon.fr": ["Académie de Dijon"],
    ".ac-grenoble.fr": ["Académie de Grenoble"],
    ".ac-guadeloupe.fr": ["Académie de Guadeloupe"],
    ".ac-guyane.fr": ["Académie de la Guyane"],
    ".ac-lille.fr": ["Académie de Lille"],
    ".ac-limoges.fr": ["Académie de Limoges"],
    ".ac-lyon.fr": ["Académie de Lyon"],
    ".ac-martinique.fr": ["Académie de Martinique"],
    ".ac-montpellier.fr": ["Académie de Montpellier"],
    ".ac-nancy-metz.fr": ["Académie de Nancy-Metz"],
    ".ac-nantes.fr": ["Académie de Nantes"],
    ".ac-nice.fr": ["Académie de Nice"],
    ".ac-orleans-tours.fr": ["Académie d'Orléans-Tours"],
    ".ac-paris.fr": ["Académie de Paris", "ifocop"],
    ".ac-poitiers.fr": ["Académie de Poitiers"],
    ".ac-reims.fr": ["Académie de Reims"],
    ".ac-rennes.fr": ["Académie de Rennes"],
    ".ac-reunion.fr": ["Académie de la Réunion"],
    ".ac-rouen.fr": ["Académie de Rouen"],
    ".ac-strasbourg.fr": ["Académie de Strasbourg"],
    ".ac-toulouse.fr": ["Académie de Toulouse"],
    ".ac-versailles.fr": ["Académie de Versailles"],
    ".aformac.fr": ["aformac"],
    ".afpa.fr": ["Agence nationale pour la Formation Professionnelle des Adultes"],
    ".agro-bordeaux.fr": ["Bordeaux Sciences Agro"],
    ".agrocampus-ouest.fr": ["Agro Campus Ouest", "West Agro Campus"],
    ".agroparistech.fr": ["AgroParisTech"],
    ".archi.fr": ["Ecole d'Architecture de Nancy"],
    ".artfx.fr": ["ArtFX Digital Arts school, Montpellier, France"],
    ".asparis.fr": ["American School of Paris"],
    ".aea.asso.fr": ["Ecole de l'Air"],
    ".arfp.asso.fr": ["Centre de Réadaptation de Mulhouse"],
    ".essca.asso.fr": ["Ecole Supérieure des Sciences Commerciales d'Angers"],
    ".fupl.asso.fr": [
        "Ecole Supérieure des Techniques Industrielles et des Textiles",
        "Institut Supérieur d'Agriculture Lille",
        "Université Catholique de Lille",
    ],
    ".lyon.ort.asso.fr": ["ORT Lyon Sup'"],
    ".audencia.fr": ["Audencia Nantes"],
    ".aup.fr": ["American University of Paris"],
    ".bde-insa-lyon.fr": ["Institut National des Sciences Appliquées de Lyon"],
    ".bordeaux-inp.fr": ["Institut polytechnique de Bordeaux (Bordeaux INP)"],
    ".bts-lachartreuse.fr": ["Étudiants en BTS au pôle la chartreuse"],
    ".campus-centre.fr": [
        "CCi Campus Centre",
        "-Chambre de Commerce et d'Industrie de l'Indre",
        "-Called aswell CCI Campus Centre",
        "Official website of the school:",
        "https://www.campus-centre.fr/",
    ],
    ".campus-eni.fr": [
        "http://www.eni-ecole.fr/",
        "Formations diplômantes aux métiers de l’informatique",
        "Titres homologués par l'Etat Bac+2 à Bac+5",
    ],
    ".campus-igs-toulouse.fr": ["Campus IGS Toulouse - Ecole en Informatique IPI"],
    ".formation.aveyron.cci.fr": ["Chambre de Commerce et d'Industrie Aveyron"],
    ".sudformation.cci.fr": ["CCI Sud Formation"],
    ".ccicampus.fr": [
        "-Chambre de Commerce et d'Industrie Colmar",
        "-Called aswell ccicampus",
        "-Mail are formatted like : studentId@ccicampus.fr",
        "Official website of the school:",
        "http://www.ccicampus.fr/",
    ],
    ".centrale-marseille.fr": ["Ecole Centrale Marseille"],
    ".centrale.centralelille.fr": ["Ecole Centrale de Lille"],
    ".ig2i.centralelille.fr": [
        "Institut de génie informatique et industriel (Département de Centrale Lille)"
    ],
    ".centralelille.fr": ["Centrale Lille"],
    ".centralesupelec.fr": ["CentraleSupélec"],
    ".cesi.fr": ["Centre d'Etudes Supérieures Industrielles Paris"],
    ".cfa-afti.fr": [
        "École supérieure du Numérique Industriel",
        "http://www.cfa-afti.com/",
    ],
    ".cfa-insta.fr": ["Centre de formation d'apprenties Insta"],
    ".cfai-formation.fr": [
        "Institut des Techniques d'Ingénieur de l'Industrie (ITII)",
        "Conservatoire National des Arts et Métiers (CNAM)",
        "Centre de Formation d'Apprentis de l'Industrie (CFAI)",
    ],
    ".cfautec.fr": [
        "CFA - UTEC",
        "School website : ",
        "\thttps://www.utec77.fr/",
        "IT related course 1 :",
        "\thttps://www.utec77.fr/jeunes/diplomes-filiere/informatique/-technologies-numeriques/bts-services-informatiques-0",
        "IT related course 2 :",
        "\thttps://www.utec77.fr/jeunes/diplomes-filiere/informatique-technologies-numeriques-fibre-optique/developpeur-charge",
        "IT related course 3 :",
        "\thttps://www.utec77.fr/jeunes/diplomes-filiere/informatique/-technologies-numeriques/manager-ingenierie-informatique",
        "proof domain :",
        "\thttps://imgur.com/dq137sI",
    ],
    ".edu.cfi-formations.fr": ["CFI"],
    ".chu-bordeaux.fr": [
        "Centre Hospitalier Universitaire Bordeaux",
        " University Hospital Center of Bordeaux",
    ],
    ".cnam-ara.fr": [
        "\ufeffConservatoire National des Arts et Métiers - Auvergne Rhône-Alpes"
    ],
    ".cnam-enjmin.fr": ["École nationale du jeu et des médias interactifs numériques"],
    ".cnam-picardie.fr": ["Conservatoire National des Arts et Métiers - Picardie"],
    ".cnam.fr": ["Conservatoire National des Arts et Métiers"],
    ".cnearc.fr": ["Centre National d'Etudes Agronomiques des Régions Chaudes"],
    ".cnsmdp.fr": ["Conservatoire National Supérieur de Musique et de Danse de Paris"],
    ".coding-academy.fr": ["Coding Academy"],
    ".cohl.fr": ["+École d'art Emile Cohl de Lyon"],
    ".collegekarr.fr": ["Collège Alphonse Karr"],
    ".cpe.fr": ["Ecole Supérieure de Chimie Physique Electronique de Lyon"],
    ".csilyon.fr": [
        "Cité Scolaire Internationale de Gerland",
        "International City School of Gerland",
    ],
    ".curie.fr": [
        "Centre de lutte contre le cancer Curie - Université Pierre et Marie Curie"
    ],
    ".etu.cyu.fr": ["CY Cergy Paris Université", "CY Cergy Paris Université"],
    ".cyu.fr": ["CY Cergy Paris Université", "CY Cergy Paris Université"],
    ".dauphine.fr": ["Université Paris-Dauphine (Paris IX)"],
    ".edu.ifa.delorozoy.fr": ["Institut de Formation par Alternance Robert Delorozoy"],
    ".devinci.fr": ["Ecole Superieur d'Ingenieurs Leonard de Vinci"],
    ".eap.fr": ["Ecole Européen des Affaires"],
    ".ec-lille.fr": ["Ecole Centrale de Lille"],
    ".ec-lyon.fr": ["Ecole Centrale de Lyon"],
    ".ec-nantes.fr": ["Ecole Centrale de Nantes"],
    ".ecam.fr": ["Ecole Catholique d'Arts &amp; Metiers"],
    ".ece.fr": ["Ecole Centrale d'Electronique - ECE"],
    ".edu.ecetech.fr": ["Ecole Centrale d'Electronique - ECE"],
    ".ecole-air.fr": [
        "+En: French Air Force Academy",
        "+Fr: Ecole de l'Air",
        "+",
        "+website: http://www.ecole-air.fr/",
    ],
    ".ecole-isitech.fr": [
        "+email domaine : ecole-isitech.fr ==> école d'expert en système d'information by  shoog",
        " +website : http://www.ecole-isitech.com",
    ],
    ".ecole-navale.fr": [
        "En: French Naval Academy",
        "Fr: Ecole Navale",
        "website: https://www.ecole-navale.fr/",
    ],
    ".ecole-webstart.fr": ["Webstart"],
    ".ecole404.fr": ["Ecole 404"],
    ".ecoledulouvre.fr": ["ECOLE DU LOUVRE"],
    ".etudiant.ecolemelies.fr": ["Ecole Georges Méliès"],
    ".ecp.fr": ["Centrale Paris"],
    ".etu.ecvdigital.fr": ["Ecv digital"],
    ".edenschool.fr": ["EDENSchool"],
    ".edmond-labbe.fr": ["Lycee Edmond Labbe "],
    ".edu-groupesaintmichel.fr": ["Groupe Saint Michel"],
    ".efficom-lille.fr": ["Efficom Lille"],
    ".efrei.fr": ["Ecole Française d'Electronique et d'Informatique"],
    ".eleve.ehesp.fr": ["Ecole des hautes études en santé publique"],
    ".ehess.fr": ["School for Advanced Studies in the Social Sciences"],
    ".eigsi.fr": ["Ecole d'ingénieurs"],
    ".eilco-ulco.fr": ["Ecole d'ingénieur du littoral côte d'opale"],
    ".eisti.fr": ["École internationale des sciences du traitement de l'information"],
    ".eivp-paris.fr": ["Ecole des Ingénieurs de la Ville de Paris"],
    ".emse.fr": ["Ecole Nationale Supérieure des Mines de St-Etienne"],
    ".emweb.fr": ["L'école des métiers du web"],
    ".en3s.fr": ["Ecole Nationale Supérieure de Sécurité Sociale"],
    ".ena.fr": ["Ecole Nationale d'Administration"],
    ".enac.fr": ["Ecole Nationale de l'Aviation Civile"],
    ".enc-sorbonne.fr": ["École Nationale des Chartes"],
    ".enib.fr": ["École Nationale d'Ingénieurs de Brest"],
    ".enic.fr": ["ENIC Telecom Lille 1"],
    ".enim.fr": ["Ecole Nationale d'Ingénieurs de Metz"],
    ".enise.fr": ["Ecole Nationale d'Ingénieurs de Saint-Etienne"],
    ".enit.fr": ["Ecole Nationale d'Ingénieurs de Tarbes"],
    ".enitab.fr": ["Ecole Nationale d'Ingénieurs des Travaux Agricoles de Bordeaux"],
    ".enitiaa-nantes.fr": [
        "Ecole Nationale d'Ingénieurs des Techniques des Industries Agricoles et Alimentaires"
    ],
    ".enpc.fr": ["Ecole Nationale des Ponts et Chausees"],
    ".ens-cachan.fr": ["Ecole Normale Supérieure de Cachan"],
    ".ens-fcl.fr": ["Ecole Normale Supérieure de Fontenay-Saint Cloud"],
    ".ens-lyon.fr": ["Ecole Normale Supérieure de Lyon"],
    ".ens-paris-saclay.fr": ["ENS Paris-Saclay"],
    ".ens-rennes.fr": ["École Nationale Supérieure de Rennes"],
    ".ens.fr": ["Ecole Normale Supérieure de Paris"],
    ".ens2m.fr": ["Ecole Nationale Supérieur de Mécaniques et des Microtechniques"],
    ".ensae-paristech.fr": ["Paris Graduate School of Economics"],
    ".ensae.fr": [
        "Ecole Nationale de la Statistique et de l'Administration Economique"
    ],
    ".ensai.fr": ["Ecole Nationale de la Statistique et de l'Analyse de l'information"],
    ".ensait.fr": ["Ecole Nationale Supérieure des Arts et Industries Textiles"],
    ".ensam.fr": ["Ecole Nationale Supérieure d'Arts et Métiers de Paris"],
    ".ensat.fr": ["Ecole Nationale Supérieure Agronomique de Toulouse"],
    ".ensc-lille.fr": ["Ecole Nationale Supérieure de Chimie de Lille"],
    ".ensc-rennes.fr": ["Ecole Nationale Supérieure de Chimie de Rennes"],
    ".ensc.fr": ["Ecole Nationale Supérieure de Cognitique"],
    ".enscm.fr": ["Ecole Nationale Supérieure de Chimie de Montpellier"],
    ".ensea.fr": [
        "Ecole Nationale Supérieure de l'Electronique et de ses Applications"
    ],
    ".enseeiht.fr": [
        "Ecole Nationale Supérieure d'Electronique, d'Electrotechnique, d'Informatique et d'Hydraulique de Toulouse",
        "Ecole Nationale Supérieure en Electrotechnique, Electronique, Informatique et Hydraulique de Toulouse",
    ],
    ".enseirb-matmeca.fr": ["Bordeaux Institute of Technlogy"],
    ".enserg.fr": [
        "Ecole Nationale Supérieure d'Electronique et de Radioelectricite de Grenoble"
    ],
    ".ensiacet.fr": ["INP ENSIACET"],
    ".ensica.fr": [
        "Ecole Nationale Supérieur d'Ingénieurs de Constructions Aéronautique",
        "École Nationale Supérieure d'Ingénieurs de Constructions Aéronautiques",
    ],
    ".ensicaen.fr": ["Ecole Nationale Supérieure d'Ingénieurs de Caen"],
    ".ensiie.fr": [
        "École nationale supérieure d'informatique pour l'industrie et l'entreprise"
    ],
    ".ensimag.fr": ["Grenoble INP Ensimag"],
    ".ensm-ales.fr": ["Ecole Nationale Supérieure des Mines d'Alès"],
    ".ensm-douai.fr": ["Ecole Nationale Supérieure des Mines de Douai"],
    ".ensma.fr": ["Ecole Nationale Supérieur de Mécanique et d'Aéronautique"],
    ".ensmp.fr": ["Ecole Nationale Supérieure des Mines de Paris"],
    ".enssat.fr": [
        "École Nationale Supérieure des Sciences Appliquées et de Technologie",
        "advanced national college of applied science and technology",
    ],
    ".enst-bretagne.fr": [
        "Ecole Nationale Supérieure des Telecommunications de Bretagne"
    ],
    ".enst.fr": ["Ecole Nationale Supérieure des Telecommunications de Paris"],
    ".ensta-bretagne.fr": ["ENSTA Bretagne"],
    ".ensta-paris.fr": ["Ecole Nationate Superieure des Techniques Avancées"],
    ".ensta-paristech.fr": ["ENSTA ParisTech"],
    ".ensta.fr": ["Ecole Nationale Supérieure de Techniques Avancées"],
    ".ent-st-joseph-hasparren.fr": [
        "Lycée Général Technologique et Professionnel Saint Joseph"
    ],
    ".entpe.fr": ["Ecole Nationale des Travaux Publics de l'Etat"],
    ".envt.fr": ["Ecole Nationale Vétérinaire de Toulouse"],
    ".epf.fr": ["EPF Ecole d'Ingénieurs"],
    ".epfedu.fr": ["+EPF Ecole d'Ingénieurs"],
    ".epita.fr": ["École Pour l'Informatique et les Techniques Avancées"],
    ".epitech.fr": ["L'Ecole de l'innovation et de l'expertise informatique."],
    ".epsi.fr": ["Ecole Privée des Sciences Informatiques"],
    ".esa-purpan.fr": ["Ecole Supérieure d'Agriculture de Purpan"],
    ".esc-bordeaux.fr": ["Ecole Supérieure de Commerce de Bordeaux"],
    ".esc-brest.fr": ["Ecole Supérieure de Commerce de Brest"],
    ".esc-clermont.fr": ["Ecole Supérieure de Commerce de Clermont-Ferrand"],
    ".esc-grenoble.fr": ["Ecole Supérieure de Commerce de Grenoble"],
    ".esc-lille.fr": ["Ecole Supérieure de Commerce de Lille"],
    ".esc-pau.fr": ["Ecole Supérieure de Commerce de Pau"],
    ".esc-rouen.fr": ["Ecole Supérieure de Commerce de Rouen"],
    ".esc-toulouse.fr": ["Ecole Supérieure de Commerce de Toulouse"],
    ".escem.fr": ["Ecole Supérieure de Commerce et Management"],
    ".escna.fr": ["Ecole Supérieure de Commerce de Nantes-Atlantique"],
    ".escom.fr": ["Ecole Supérieure de Chimie Organique et Minérale"],
    ".escp.fr": ["Ecole Supérieure de Commerce de Paris"],
    ".eseo.fr": ["Ecole Supérieure d'Electronique de l'Ouest"],
    ".esg.fr": ["ESG - Ecole de commerce"],
    ".esgi.fr": ["\ufeffESGI (Ecole Supérieure de Génie Informatique)"],
    ".esh64.fr": ["Ensemble Scolaire Hazparne"],
    ".esi-metz.fr": ["ESI Metz, France"],
    ".esiae.fr": ["Ecole Supérieure Internationale d'Administration des Entreprises"],
    ".esiea.fr": ["Ecole Supérieure d'Informatique-Electronique-Automatique"],
    ".esiee-amiens.fr": [
        "Ecole Supérieure d'Ingénieurs en Electronique et Electrotechnique - Amiens"
    ],
    ".edu.esiee-it.fr": ["CodingFactory Esiee-IT"],
    ".esiee.fr": ["Ecole Supérieure d'Ingénieurs en Electronique et Electrotechnique"],
    ".esigelec.fr": ["Ecole Supérieure d'Ingénieurs en Génie Electrique"],
    ".esigetel.fr": [
        "Ecole d’ingénieur généraliste en systèmes numériques & objets communicants"
    ],
    ".esimed.fr": ["École supérieur d'informatique de la Méditerranée"],
    ".esitc-paris.fr": ["ESITC PARIS", "ESITC PARIS"],
    ".esme.fr": ["Ecole Spéciale de Mécanique et d'Electricité"],
    ".espci.fr": ["Ecole Supérieure de Physique et de Chimie Industrielles"],
    ".esqese.fr": [" ESQESE"],
    ".essec.fr": ["Ecole Supérieure des Sciences Economiques et Commerciales"],
    ".esta-belfort.fr": ["Ecole Supérieure de Technologie et des Affaires"],
    ".estei.fr": [
        "École Supérieure des Technologies Électronique, Informatique et Infographie"
    ],
    ".etu.estia.fr": ["École Supérieure des Technologies Industrielles Avancées"],
    ".net.estia.fr": ["Ecole d’ingénieurs ESTIA"],
    ".estp.fr": ["Ecole Spéciale des Travaux Publics du Bâtiment et de l'Industrie"],
    ".etu-webschoolfactory.fr": ["La Web School Factory"],
    ".accueil.etud-espas.fr": ["ESTICE"],
    ".etud-ices.fr": ["https://ices.fr/", "Institut Catholique d'Études Supérieures"],
    ".eudil.fr": ["Ecole Universitaire d'Ingénieurs de Lille"],
    ".eurecom.fr": ["Institut EURECOM"],
    ".fac-digital-campus.fr": ["ESG - Ecole de commerce"],
    ".fac-esarc-evolution.fr": ["ESG - Ecole de commerce"],
    ".fac-esg.fr": ["ESG - Ecole de commerce"],
    ".fblasalle.fr": ["Les Franc-Bourgeois Lasalle"],
    ".flst.fr": [
        "Faculté des Sciences et Technologies (Université Catholique de Lille)"
    ],
    ".formation-cci.fr": ["CCI Formation - CCI Haute-Savoie"],
    ".formation-cci12.fr": ["3iL Ingénieurs", "ÉCOLE D'INGÉNIEURS EN INFORMATIQUE"],
    ".formation-technologique.fr": ["CFA de l'Industrie 84"],
    ".g-4.fr": ["Institut G4 Marseille"],
    ".gastonberger.fr": ["Lycée Gaston Berger"],
    ".gobelins.fr": ["Gobelins, l'école de l'image"],
    ".grenoble-em.fr": ["Grenoble Ecole de Management"],
    ".ensimag.grenoble-inp.fr": [
        "École Nationale Supérieure d'Informatique et de Mathématiques Appliquées de Grenoble"
    ],
    ".etu.esisar.grenoble-inp.fr": [
        "Ecole nationale supérieure d’ingénieurs en systèmes avancés et réseaux"
    ],
    ".esisar.grenoble-inp.fr": [
        "Ecole nationale supérieure d’ingénieurs en systèmes avancés et réseaux"
    ],
    ".grenoble-inp.fr": ["Grenoble INP"],
    ".greta-sud-aquitaine.fr": ["GRETA Sud Aquitaine"],
    ".groupe-esigelec.fr": ["Ecole Supérieure d'Ingénieurs en Génie Electrique"],
    ".groupemontroland.fr": ["PASTEUR MONT ROLAND"],
    ".gustaveroussy.fr": [
        "Centre de lutte contre le cancer Gustave Roussy - Institut Français Supérieur de Biologie Médicale (IFSBM)"
    ],
    ".h3hitema.fr": ["HITEMA"],
    ".hec.fr": ["Ecole des Hautes Etudes Commerciales"],
    ".hei.fr": ["Ecole des Hautes Etudes Industrielles de Lille"],
    ".hetic.fr": ["Hetic"],
    ".iae-toulouse.fr": ["Institut d'Administration des Entreprises de Toulouse"],
    ".icam.fr": [
        "Institut Catholique d'Arts et Métiers",
        "ICAM Lille",
        "ICAM Nantes",
        "ICAM Toulouse",
        "ICAM Paris-Sénart",
        "ICAM Bretagne",
        "ICAM Vendée",
    ],
    ".ices.fr": ["https://ices.fr/", "Institut Catholique d'Études Supérieures"],
    ".icl-lille.fr": ["Institut Catholique de Lille"],
    ".icof.fr": ["Lycée technologique secondaire et supérieur privé sous contrat"],
    ".icp.fr": ["Institut Catholique de Paris"],
    ".ict-edu.fr": ["Institut Catholique de Toulouse"],
    ".etudiant.ief2i.fr": ["INSTITUT F2I"],
    ".ieseg.fr": ["IESEG School Of Management"],
    ".ifma.fr": ["Institut Français de Mécanique Avancée"],
    ".ifp.fr": ["Ecole Nationale Supérieure du Pétrole et des Monteurs"],
    ".ig2i.fr": ["Institut de génie informatique et industriel"],
    ".ign.fr": ["Ecole Nationale des Sciences Géographiques"],
    ".iia-laval.fr": ["IIA Laval"],
    ".imag.fr": [
        "Ecole Nationale Superieure d'Informatique et de Mathematiques Appliquees de Grenoble"
    ],
    ".imie-paris.fr": ["IMIE : Ecole de la Filière Numérique"],
    ".imt-atlantique.fr": [
        "IMT Atlantique Bretagne-Pays de la Loire École Mines-Télécom"
    ],
    ".imt-lille-douai.fr": ["Ecole nationale superieure Mines-Telecom Lille-Douai"],
    ".imt-mrs.fr": ["Ecole Supérieure d'Ingénieurs de Marseille"],
    ".inalco.fr": [
        "Institut national des langues et civilisations orientales",
        "National Institute for Oriental Languages and Civilizations",
    ],
    ".inp-fc.fr": [
        "Ecole Nationale Supérieure d'Ingénieurs de Génie Chimique",
        "Institut National Polytechnique de Toulouse",
    ],
    ".inp-toulouse.fr": ["Institut national polytechnique de Toulouse"],
    ".inpg.fr": [
        "Ecole Française de Papeterie et des Industries Graphiques",
        "Ecole Nationale Supérieure d'Electrochimie et d'Electrométallurgie de Gernoble",
        "Ecole Nationale Supérieure de Physique de Grenoble",
        "Ecole Nationale Supérieure d'Hydraulique et de Mécanique de Grenoble",
        "Ecole Nationale Supérieure d'Ingenieurs Electriciens de Grenoble",
        "Institut National Polytechnique de Grenoble",
    ],
    ".inpl-nancy.fr": ["Institut National Polytechnique de Lorraine"],
    ".inra.fr": [
        "Ecole Nationale Supérieure d'Agronomie de Montpellier",
        "Ecole Nationale Supérieure d'Agronomie de Rennes",
        "Institut National Supérieur de Formation Agro-Alimentaire",
    ],
    ".inrae.fr": [
        "Ecole Nationale Supérieure d'Agronomie de Montpellier",
        "Ecole Nationale Supérieure d'Agronomie de Rennes",
        "Institut National Supérieur de Formation Agro-Alimentaire",
        "Agro campus Ouest",
    ],
    ".inria.fr": ["National Institute for Research in Computer Science and Control"],
    ".insa-cvl.fr": [
        "Institut National des Sciences Appliquées de Centre Val de Loire"
    ],
    ".insa-lyon.fr": ["Institut National des Sciences Appliquées de Lyon"],
    ".insa-rennes.fr": ["Institut National des Sciences Appliquées de Rennes"],
    ".insa-rouen.fr": ["Institut National des Sciences Appliquées de Rouen"],
    ".insa-strasbourg.fr": ["Institut National des Sciences Appliquées de Strasbourg"],
    ".insa-toulouse.fr": ["Institut National des Sciences Appliquées de Toulouse"],
    ".insta.fr": ["institut de technologies avancées"],
    ".institutdegenech.fr": ["Institut de Genech"],
    ".int-evry.fr": ["Institut National des Télécommunications"],
    ".intech-so.fr": ["IN'TECH", "IN'TECH"],
    ".intech-sud.fr": ["IN'TECH Sud"],
    ".intechinfo.fr": ["Ecole Supérieure d'Ingénierie Informatique"],
    ".ip-formation.fr": ["École Informatique IP Formation"],
    ".ipag.fr": ["IPAG Business School", "IPAG Business School"],
    ".ipb.fr": ["Institut Polytechnique de Bordeaux (ou INP Bordeaux)"],
    ".ipgp.fr": ["Institut de Physique du Globe de Paris"],
    ".ipsa.fr": ["École d'Ingénieurs de l'Air et de l'Espace"],
    ".ird.fr": [
        "Institut de Recherche pour le Développement",
        "French National Research Institute for Sustainable Development",
    ],
    ".irisa.fr": ["Institut de Recherche en Informatique et Systèmes Aléatoires"],
    ".etu.isae-ensma.fr": ["ISAE ENSMA"],
    ".isae-supaero.fr": ["ISAE-SUPAERO"],
    ".isae.fr": ["ISAE-SUPAERO"],
    ".isara.fr": ["Institut Supérieur d'Agriculture Rhone-Alpes"],
    ".isefac.fr": ["isefac"],
    ".isen-bretagne.fr": [
        "ISEN - Institut Supérieur de l'Electronique et du Numérique",
        "http://www.isen.fr/",
    ],
    ".isen-lille.fr": [
        "ISEN Lille - Institut Supérieur de l'Electronique et du Numérique",
        "http://www.isen.fr/",
    ],
    ".isen.fr": ["Institut Supérieure d'Electronique du Nord"],
    ".isep.fr": ["Institut Supérieure d'Electronique de Paris"],
    ".isima.fr": [
        "Institut Supérieur d’Informatique, de Modélisation et de leurs Applications"
    ],
    ".ismcm-cesti.fr": ["Centre d'Etudes Supérieures des Techniques Industrielles"],
    ".istef.fr": ["Ecole supérieure de formation en alternance à Toulouse"],
    ".it-akademy.fr": ["École Informatique IT-Akademy à Lyon"],
    ".itecboisfleury.fr": ["Lycée ItecBoisfleury"],
    ".itech.fr": ["Institut Textile et Chimique de Lyon"],
    ".itescia.fr": ["Ecole Itescia, Cergy, www.itescia.fr"],
    ".iut-rodez.fr": ["Institut Universitaire de Technologie de Rodez"],
    ".iut-tlse3.fr": [
        "Institut Universitaire Technologique Paul Sabatier (Toulouse III)"
    ],
    ".iut-valence.fr": ["Institut Universitaire de Technologie de Valence"],
    ".jeanne-darc-vitre.fr": ["Jeanne d'arc Vitré"],
    ".jussieu.fr": [
        "Ecole Nationale Supérieure de Chimie de Paris",
        "Université Denis Diderot (Paris VII)",
        "Université Pierre et Marie Curie (Paris VI)",
    ],
    ".keyce-academy.fr": ["Keyce International Academy", "Keyce International Academy"],
    ".lacatholille.fr": ["Université Catholique de Lille"],
    ".lasallepantin.fr": ["St Joseph La Salle Pantin"],
    ".lbsi14.fr": ["La Bruyère Sainte Isabelle"],
    ".le-101.fr": ["Ecole le-101"],
    ".le-campus-numerique.fr": ["Le Campus Numérique"],
    ".lgf09.fr": ["Lycée Général et Technologique Gabriel Fauré"],
    ".limayrac.fr": ["Institut Limayrac"],
    ".lip6.fr": ["Laboratoire d'informatique de Paris 6 (UPMC)"],
    ".lmdsio.fr": ["Lycée La Martinière Duchère de Lyon"],
    ".lprs.fr": ["LYCÉE PRIVÉ ET UFA ROBERT SCHUMAN", "Lycee Robert Schuman "],
    ".lycam.fr": ["Lycée André Malraux", "André Malraux High School"],
    ".lycee-basch.fr": ["Lycée Victor et Hélène Basch - Rennes"],
    ".lycee-monge.fr": ["Lycée Gaspard Monge", "Gaspard Monge High School"],
    ".lycee-nevers.fr": ["Lycée Nevers"],
    ".lyceeconnecte.fr": ["Académie Bordeaux Mails for students"],
    ".lyceedelasalle.fr": ["lycee de La Salle"],
    ".lyceefulbert.fr": ["Lycée Fulbert", "Fulbert High School"],
    ".lyceepergaud.fr": ["Lycée Louis Pergaud - Besançon"],
    ".lyceesudmedoc.fr": ["Lycée Sud Médoc"],
    ".lyon-epsi.fr": ["EPSI Lyon"],
    ".mail-ecv.fr": ["Ecole de Communication Visuelle"],
    ".malrauxbethune.fr": [
        "Lycée André Malraux Bethune",
        "André Malraux High school (Bethune)",
    ],
    ".mancheopenschool.fr": ["Manche Open School"],
    ".master-developpement-logiciel.fr": [
        "Master Developpement Logiciel - Université Paul Sabatier (Toulouse III)"
    ],
    ".meteo.fr": ["Ecole Nationale de la Météorologie"],
    ".mewo-campus.fr": ["ESI Metz, France"],
    ".mewo.fr": ["ESI Metz, France"],
    ".toulouse.miage.fr": ["Université Paul Sabatier", "Paul Sabatier University"],
    ".mines-albi.fr": ["École des Mines d'Albi"],
    ".mines-ales.fr": ["Ecole des Mines d'Alès"],
    ".mines-nantes.fr": ["École des Mines de Nantes"],
    ".mines-paristech.fr": ["MINES ParisTech"],
    ".minesdedouai.fr": ["Mines Douai"],
    ".mjm-design.fr": ["MJM Graphic Design"],
    ".monbureaunumerique.fr": ["Lycée Robert Schuman", ".group"],
    ".msw-lachartreuse.fr": ["Étudiants en BAC+3 MSW au pôle la chartreuse"],
    ".myges.fr": ["Réseau GES"],
    ".neoma-bs.fr": ["Neoma Business School", "Neoma Business School"],
    ".nermont.fr": ["Lycee d'enseignement agricole prive de Nermont"],
    ".netocentre.fr": ["Environnement Numérique de Travail de la région Centre"],
    ".next-u.fr": ["WebTech Institute", "WebTech Institute"],
    ".normandiewebschool.fr": ["Normandie Web School"],
    ".obspm.fr": ["Observatoire de Paris"],
    ".oniris-nantes.fr": [
        "Oniris - Ecole Nationale Vétérinaire, Agroalimentaire et de l'Alimentation"
    ],
    ".opensourceschool.fr": ["Open Source School"],
    ".ort-france.fr": ["ORT-FRANCE", "ORT-FRANCE"],
    ".ortmontreuil.fr": ["Ort Montreuil"],
    ".i2bc.paris-saclay.fr": ["Institute for Integrative Biology of the Cell"],
    ".paris-sorbonne.fr": ["Université Paris-Sorbonne (Paris IV)"],
    ".parisdescartes.fr": ["University Paris Descartes "],
    ".parisnanterre.fr": ["Université Paris Nanterre"],
    ".pasteur.fr": ["Institut Pasteur"],
    ".pole-lachartreuse.fr": ["Professeurs au pôle la chartreuse"],
    ".polytech-lille.fr": ["Ecole polytechnique universitaire de Lille"],
    ".polytechnique.fr": ["Ecole Polytechnique"],
    ".prof-webschoolfactory.fr": ["La Web School Factory"],
    ".purpan.fr": ["Ecole d'Ingenieurs de Purpan"],
    ".ri7.fr": ["École Ri7"],
    ".riviera.fr": ["University of Southern Europe (Monaco Business School)"],
    ".rouenbs.fr": ["Rouen Business School", "Ecole Supérieure de Commerce de Rouen"],
    ".sciencespo-aix.fr": ["Sciences Po Aix"],
    ".sciencespo.fr": ["Institut d'Etudes Politiques de Paris (Sciences Po)"],
    ".sciencesu-lyon.fr": ["sciencesu-lyon"],
    ".sjc43.fr": ["Ensemble Scolaire St Jaques de Compostelle"],
    ".sorbon.fr": ["Ecole Superieure Robert de Sorbon"],
    ".edu.sorbonne-paris-nord.fr": [
        "Université Sorbonne Paris Nord",
        "Sorbonne Paris Nord University",
    ],
    ".sorbonne-universite.fr": [
        "Université de la Sorbonne",
        "https://www.sorbonne-universite.fr/",
    ],
    ".sornas.fr": ["EDTA Sornas"],
    ".stfelixlasalle.fr": ["St Félix-La Salle"],
    ".stjolorient.fr": [
        "Lycee Saint Joseph La Salle Lorient",
        "http://www.st-joseph-lorient.org/",
    ],
    ".stu-digital-campus.fr": ["ESG - Ecole de commerce"],
    ".stu-esarc-evolution.fr": ["ESG - Ecole de commerce"],
    ".stu-esg.fr": ["ESG - Ecole de commerce"],
    ".student-cs.fr": ["CentraleSupélec"],
    ".supaero.fr": ["Ecole Nationale Supérieure de l'Aéronautique et de l'Espace"],
    ".supagro.fr": ["L'institut Agro | Montpellier SupAgro"],
    ".supbiotech.fr": ["École des Experts en Biotechnologies"],
    ".supco-amiens.fr": ["Groupe Sup de Co Amiens Picardie"],
    ".supco-montpellier.fr": ["Groupe Sup de Co Montpellier"],
    ".supdevinci-edu.fr": ["SUP DE VINCI "],
    ".supdevinci.fr": ["SUP DE VINCI"],
    ".supelec.fr": ["Ecole Supérieure d'Electricité"],
    ".supinternet.fr": ["École Supérieure des Métiers de l'Internet"],
    ".supmeca.fr": [" Institut supérieur de mécanique de Paris"],
    ".supwallon.fr": ["\ufeffLycée Henri Wallon - Valenciennes"],
    ".tbs-education.fr": ["Toulouse Business School"],
    ".telecom-lille.fr": ["Telecom Lille"],
    ".telecom-paris.fr": [
        "Telecom Paris",
        "Telecom ParisTech",
        "Télécom Paris",
        "Télécom ParisTech",
    ],
    ".telecom-paristech.fr": ["Télécom ParisTech"],
    ".telecom-st-etienne.fr": ["\ufeffTélécom Saint-Etienne"],
    ".etu.toulouse-inp.fr": ["Institut national polytechnique de Toulouse"],
    ".u-3mrs.fr": [
        "Ecole Nationale Supérieure de Physique de Marseille",
        "Université d'Aix-Marseille III",
    ],
    ".etu.u-bordeaux-montaigne.fr": ["Etudiant à l'Université Bordeaux Montaigne"],
    ".iut.u-bordeaux-montaigne.fr": ["IUT Bordeaux Montaigne"],
    ".u-bordeaux-montaigne.fr": [
        "Université Bordeaux Montaigne",
        "Bordeaux Montaigne university",
    ],
    ".u-bordeaux.fr": [
        "Ecole Nationale Supérieure de Chimie et de Physique de Bordeaux",
        "Ecole Nationale Supérieure d'Electronique et de Radioelectricite de Bordeaux",
        "Institut d'Etudes Politiques de Bordeaux",
        "Université Bordeaux I",
        "Université Michel de Montaigne (Bordeaux III )",
        "Université Montesquieu (Bordeaux IV)",
    ],
    ".u-bordeaux2.fr": ["Université Victor Segalen (Bordeaux II)"],
    ".u-bordeaux3.fr": ["\ufeffUniversité Michel Montaigne (Bordeaux III)"],
    ".etu.u-bourgogne.fr": [
        "université de bourgogne",
        "University of Burgundy, Dijon, France",
        "Website : http://en.u-bourgogne.fr",
    ],
    ".u-bourgogne.fr": [
        "Ecole Nationale Supérieure de Biologie Appliquée à la Nutrition et à l'Alementation",
        "Université de Bourgogne",
    ],
    ".u-cergy.fr": ["Université de Cergy-Pontoise"],
    ".u-clermont1.fr": ["Université d'Auvergne (Clermont-Ferrand I)"],
    ".u-grenoble3.fr": ["Université Stendhal (Grenoble III)"],
    ".u-nancy.fr": [
        "Ecole Nationale Supérieur de Géologie de Nancy",
        "Ecole Nationale Supérieure d'Agronomie et des Industries Alimentaires",
        "Ecole Nationale Supérieure des Industries Chimiques de Nancy",
        "Ecole Nationale Supérieure des Mines de Nancy",
        "Ecole Nationale Supérieure Electricité et Mécanique",
        "Ecole Supérieure des Sciences et Technologie de l'Ingénieur de Nancy",
    ],
    ".etu.u-paris.fr": ["Université de Paris", "University of Paris"],
    ".u-paris10.fr": ["Université Paris Nanterre (Paris X)"],
    ".u-paris2.fr": ["Université Panthéon-Assas (Paris II)"],
    ".u-pe.fr": ["Paris-Est Créteil Val-de-Marne University"],
    ".u-pec.fr": ["Université Paris-Est Créteil"],
    ".u-pem.fr": ["\ufeffUniversité Paris Est Marne la Vallée"],
    ".u-picardie.fr": ["Université de Picardie Jules-Verne"],
    ".u-psud.fr": ["université paris saclay", "PARIS-SACLAY UNIVERSITY"],
    ".u-strasbg.fr": [
        "Ecole Européenne de Chimie, Polymères et Matériaux de Strasbourg",
        "Ecole Nationale du Génie de l'Eau et de l'Environnement de Strasbourg",
        "Ecole Nationale Supérieure de Physique de Strasbourg",
        "Ecole Nationale Supérieure des Arts et Industries de Strasbourg",
        "Université des Sciences Humaines (Strasbourg II)",
        "Université Louis Pasteur (Strasbourg I)",
        "Université Robert Schuman (Strasbourg III)",
    ],
    ".uca.fr": ["Université Clermont-Auvergne"],
    ".ucly.fr": ["UCLY"],
    ".uco.fr": ["Université Catholique de l' Ouest"],
    ".etu.udamail.fr": ["Université d'auvergne"],
    ".udamail.fr": ["Université d'Auvergne"],
    ".uha.fr": ["Université de Haute Alsace"],
    ".uhb.fr": ["Université Rennes II - Haute-Bretagne"],
    ".uhp-nancy.fr": ["Université Henri Poincaré (Nancy I)"],
    ".ujf-grenoble.fr": ["Université Joseph Fourier (Grenoble I)"],
    ".umontpellier.fr": ["Université de Montpellier"],
    ".unicaen.fr": ["Université de Caen Basse Normandie"],
    ".etu.unice.fr": ["Université Nice Sophia Antipolis"],
    ".unice.fr": ["Université de Nice-Sophia Antipolis"],
    ".etu.unilasalle.fr": ["UniLaSalle Amiens"],
    ".unilim.fr": ["Université de Limoges"],
    ".unimes.fr": ["Université de Nîmes"],
    ".unistra.fr": ["University of Strasbourg"],
    ".etu.univ-ag.fr": ["Université des Antilles"],
    ".univ-ag.fr": ["Université des Antilles"],
    ".etu.univ-amu.fr": [
        "Polytech Marseille (Aix-Marseille Université)",
        "Polytech Marseille (Engineering School, part of Aix-Marseille Academy)",
    ],
    ".univ-amu.fr": ["Aix-Marseille University"],
    ".univ-angers.fr": ["Université d'Angers"],
    ".etu.univ-antilles.fr": ["Université des Antilles"],
    ".univ-antilles.fr": ["Université des Antilles"],
    ".univ-artois.fr": ["Université d'Artois"],
    ".univ-avignon.fr": ["Université d'Avignon"],
    ".univ-bpclermont.fr": [
        "Ecole Nationale Supérieure de Chimie de Clermont-Ferrand",
        "Institut des Sciences de l'Ingénieur de Clermont-Ferrand",
        "Université Blaise Pascal (Clermont-Ferrand II)",
    ],
    ".univ-brest.fr": ["Université de Bretagne Occidentale"],
    ".univ-catholille.fr": ["Université Catholique de Lille"],
    ".univ-catholyon.fr": ["Université Catholique de Lyon"],
    ".univ-corse.fr": ["Università di Corsica Pasquale Paoli"],
    ".univ-cotedazur.fr": ["Université Côte d'Azur"],
    ".univ-eiffel.fr": ["Université Gustave Eiffel", "University Gustave Eiffel"],
    ".univ-evry.fr": ["Université d'Evry Val d'Essonne"],
    ".univ-fcomte.fr": ["Université de Franche-Comté"],
    ".iut2.univ-grenoble-alpes.fr": [
        "IUT2 Informatique",
        "Science computing University Institute of Technology",
    ],
    ".univ-grenoble-alpes.fr": ["Université Grenoble Alpes"],
    ".univ-inpt.fr": ["Ecole Nationale Supérieure de Chimie de Toulouse"],
    ".univ-jfc.fr": ["Centre universitaire Jean-François Champollion"],
    ".univ-lehavre.fr": ["Université du Havre"],
    ".univ-lemans.fr": ["Université du Maine"],
    ".univ-lille.fr": ["Université de Lille"],
    ".univ-lille1.fr": ["Université des Sciences et Technologies de Lille (Lille I)"],
    ".univ-lille2.fr": ["Université du Droit et de la Sante (Lille II)"],
    ".univ-lille3.fr": ["Université Charles-de-Gaulle (Lille III)"],
    ".univ-littoral.fr": ["Université du Littoral Cote d'Opale"],
    ".univ-lorraine.fr": ["Université de Lorraine"],
    ".etudiant.univ-lr.fr": ["Université de La Rochelle"],
    ".univ-lr.fr": ["Université de La Rochelle"],
    ".univ-lyon1.fr": ["Université Claude Bernard (Lyon I)"],
    ".univ-lyon2.fr": ["Université Lumiére (Lyon II)"],
    ".univ-lyon3.fr": ["Université Jean Moulin (Lyon III)"],
    ".univ-metz.fr": ["Université de Metz"],
    ".univ-mlv.fr": ["Université de Marne la Vallée"],
    ".univ-montp1.fr": ["Université de Montpellier I"],
    ".univ-montp2.fr": [
        "Institut des Sciences de l'Ingénieur de Montpellier",
        "Université de Montpellier II",
    ],
    ".univ-montp3.fr": ["Université Paul Valéry (Montpellier III)"],
    ".univ-montpellier.fr": ["Université Paul Valery Montpellier 3"],
    ".univ-mrs.fr": ["Université de Provence (Aix-Marseille I)"],
    ".univ-mulhouse.fr": [
        "Ecole Nationale Supérieure de Chimie de Mulhouse",
        "Université de Haute-Alsace",
    ],
    ".univ-nancy2.fr": ["Université Nancy II"],
    ".univ-nantes.fr": ["Université de Nantes"],
    ".univ-orleans.fr": ["Université d'Orléans"],
    ".univ-paris-diderot.fr": ["Paris Diderot University"],
    ".univ-paris-est.fr": ["Université Paris-Est", "University of Paris-Est", "UPE"],
    ".univ-paris1.fr": ["Université Panthéon-Sorbonne (Paris I)"],
    ".univ-paris12.fr": ["Université Val-de-Marne (Paris XII)"],
    ".univ-paris13.fr": ["Université Paris Nord (Paris XIII)"],
    ".univ-paris3.fr": ["Université Sorbonne-Nouvelle (Paris III)"],
    ".univ-paris5.fr": ["Université René Descartes (Paris V)"],
    ".univ-paris8.fr": ["Université Vincennes Saint-Denis (Paris VIII)"],
    ".univ-pau.fr": ["Université de Pau et des Pays de l'Adour"],
    ".univ-perp.fr": ["Université de Perpignan"],
    ".univ-poitiers.fr": ["Université de Poitiers"],
    ".univ-reims.fr": ["Université de Reims Champagne-Ardenne"],
    ".univ-rennes1.fr": ["Université Rennes I"],
    ".univ-rennes2.fr": ["Université Rennes 2, FRANCE", "Rennes 2 university, FRANCE"],
    ".univ-reunion.fr": ["Université de la Reunion"],
    ".univ-rouen.fr": ["Université de Rouen - Haute Normandie"],
    ".univ-savoie.fr": ["Université de Savoie"],
    ".univ-smb.fr": ["Université Savoie Mont Blanc"],
    ".etu.univ-st-etienne.fr": ["Université Jean Monnet"],
    ".univ-st-etienne.fr": ["Université Jean Monnet"],
    ".univ-tln.fr": ["Université du Sud, Toulon et Var"],
    ".univ-tlse1.fr": ["Université des Sciences Sociales (Toulouse I)"],
    ".univ-tlse2.fr": ["Université de Toulouse-le-Mirail (Toulouse II)"],
    ".univ-tlse3.fr": ["Université Paul Sabatier (Toulouse III)"],
    ".univ-toulouse.fr": ["Université de Toulouse"],
    ".univ-tours.fr": [
        "Ecole d'Ingénieurs en Informatique pour l'Industrie",
        "Université François Rabelais de Tours",
    ],
    ".univ-ubs.fr": ["Université de Bretagne Sud"],
    ".etu.univ-valenciennes.fr": ["Université de Valenciennes et du Hainaut-Cambrésis"],
    ".univ-valenciennes.fr": [
        "Ecole Nationale Supérieure d'Ingénieurs en Mécanique et Energétique de Valenciennes",
        "Université de Valenciennes et du Hainaut-Cambrésis",
    ],
    ".universite-lyon.fr": ["Université de Lyon"],
    ".universite-paris-saclay.fr": ["Université Paris Saclay"],
    ".univmed.fr": ["Université de la Méditerranée (Aix Marseille II)"],
    ".etu.uphf.fr": ["Université Polytechnique des Hauts de France"],
    ".uphf.fr": ["Université Polytechnique des Hauts de France"],
    ".upmc.fr": ["Pierre-and-Marie-Curie University"],
    ".upmf-grenoble.fr": ["Université Pierre Mendes-France (Grenoble II)"],
    ".ups-tlse.fr": ["Université Paul Sabatier (Toulouse III)"],
    ".ut-capitole.fr": ["Université Toulouse 1 Capitole"],
    ".utbm.fr": ["Université de Technologie de Belfort Montbéliard"],
    ".utc.fr": ["Université de Technologie de Compiègne"],
    ".utt.fr": ["Université de Technologie de Troyes"],
    ".uvsq.fr": ["Université de Versailles Saint-Quentin-en-Yvelines"],
    ".vet-alfort.fr": ["Ecole Nationale Vétérinaire d'Alfort"],
    ".vet-lyon.fr": ["Ecole Nationale Vétérinaire de Lyon"],
    ".vet-nantes.fr": ["Ecole Nationale Vétérinaire de Nantes"],
    ".viacesi.fr": ["CESI Enseignement Supérieur et Formation Professionnelle"],
    ".webschoolfactory.fr": ["La Web School Factory"],
    ".hei.yncrea.fr": ["Ecole des Hautes Etudes Industrielles de Lille"],
    ".isen-ouest.yncrea.fr": [
        "Institut supérieur de l'électronique et du numérique Yncrea Ouest"
    ],
    ".isen.yncrea.fr": ["Institut supérieur de l'électronique et du numérique"],
    ".student.yncrea.fr": [
        "Institut supérieur de l'électronique et du numérique (ISEN)"
    ],
    ".yncrea.fr": ["ISEN Yncréa Méditerranée"],
    ".yschools.fr": ["Yschools"],
    ".udc.gal": ["Universidade da Coruña"],
    ".bsu.ge": [
        "ბათუმის შოთა რუსთაველის სახელმწიფო უნივერსიტეტი",
        "Batumi Shota Rustaveli State University",
    ],
    ".agruni.edu.ge": ["Agricultural University of Georgia"],
    ".atsu.edu.ge": ["Akaki Tsereteli State University"],
    ".bsu.edu.ge": [
        "\ufeffბათუმის შოთა რუსთაველის სახელმწიფო უნივერსიტეტი",
        "Batumi Shota Rustaveli State University",
    ],
    ".btu.edu.ge": ["Business and Technology University, Tbilisi, Georgia"],
    ".ciu.edu.ge": ["Caucasus International University"],
    ".cu.edu.ge": ["Caucasus University"],
    ".eu.edu.ge": ["European university, Tbilisi, Georgia"],
    ".fesvebi.edu.ge": ['N187 საჯარო სკოლა "ფესვები"', 'Public school N187 "Fesvebi"'],
    ".freeuni.edu.ge": ["Free University of Tbilisi"],
    ".gau.edu.ge": ["Georgian-American University"],
    ".gruni.edu.ge": ["University of Grigol Robakidze"],
    ".gsau.edu.ge": ["Georgian Agricultural University"],
    ".gtu.edu.ge": ["Georgian Technical University"],
    ".ibsu.edu.ge": ["International Black sea University"],
    ".iliauni.edu.ge": ["Ilia Chavchavadze State University"],
    ".kiu.edu.ge": ["Kutaisi International University"],
    ".newton.edu.ge": ["ნიუტონის თავისუფალი სკოლა", "Newton Free School"],
    ".sangu.edu.ge": ["St. Andrew Georgian University"],
    ".tesau.edu.ge": [
        "იაკობ გოგებაშვილის სახელობის თელავის სახელმწიფო უნივერსიტეტი",
        "IAKOB GOGEBASHVILI TELAVI STATE UNIVERSITY",
    ],
    ".tsu.edu.ge": ["Tbilisi State University"],
    ".ug.edu.ge": ["საქართველოს უნივერსიტეტი", "The University Of Georgia"],
    ".unik.edu.ge": ["Kutaisi University"],
    ".gipa.ge": ["Georgian Institute of Public Affairs"],
    ".students.gov.ge": ["Students of schools in Georgia", "Microsoft platform"],
    ".gtu.ge": ["საქართველოს ტექნიკური უნივერსიტეტი", "Georgian Technical University"],
    ".iset.ge": ["International School of Economics at TSU"],
    ".itvet.ge": [
        "ინფრომაციული ტექნოლოგიების აკადემია",
        "Information Technologies Academy",
    ],
    ".mziuri.ge": ["IT Center Mziuri"],
    ".tsu.ge": ["თბილისის სახელმწიფო უნივერსიტეტი", "Tbilisi State University"],
    ".accrapolytechnic.edu.gh": ["Accra Polytechnic "],
    ".anuc.edu.gh": ["all nations university college"],
    ".ashesi.edu.gh": ["Ashesi University"],
    ".central.edu.gh": ["central university college"],
    ".cug.edu.gh": ["catholic university college"],
    ".datalink.edu.gh": ["data link insitute"],
    ".gcuc.edu.gh": ["garden city university college"],
    ".gimpa.edu.gh": [
        "Ghana Institute of Management and Public Administration (GIMPA)"
    ],
    ".gtuc.edu.gh": ["Ghana Telecom University College"],
    ".knust.edu.gh": ["Kwame Nkrumah University of Science and Technology"],
    ".kpoly.edu.gh": ["Kumasi Polytechnic "],
    ".mucg.edu.gh": ["methodist university college"],
    ".pentvars.edu.gh": ["pentecost university college"],
    ".presbyuniversity.edu.gh": ["Presbyterian University College"],
    ".regent.edu.gh": ["regent university college"],
    ".rmu.edu.gh": ["regional maritime university"],
    ".tpoly.edu.gh": ["Takoradi Polytechnic "],
    ".ucc.edu.gh": ["University of Cape Coast"],
    ".uds.edu.gh": ["University for Development Studies"],
    ".uew.edu.gh": ["University of Education,Winneba"],
    ".ug.edu.gh": ["University of Ghana"],
    ".umat.edu.gh": ["university of mines and technology"],
    ".vvu.edu.gh": ["Valley View University"],
    ".wiuc-ghana.edu.gh": ["wisconsin international university college"],
    ".ilisimatusarfik.gl": ["University of Greenland"],
    ".dwight.global": ["Dwight Global"],
    ".aiu.edu.gm": ["American International University West Africa, The Gambia"],
    ".iou.edu.gm": ["Islamic Online University"],
    ".utg.edu.gm": ["University of The Gambia"],
    ".schools.nyc.gov": ["New York City Department of Education", "NYC DOE", ".group"],
    ".acg.gr": ["American College of Greece"],
    ".aeath.gr": [
        "University Ecclesiastical Academy of Thessaloniki",
        "Ανώτατη Εκκλησιαστική Ακαδημία Θεσσαλονίκης",
    ],
    ".aegean.gr": ["Aegean University"],
    ".agsm.gr": ["Athens Graduate School of Management (AGSM)"],
    ".aktocollege.gr": ["AKTO College"],
    ".asfa.gr": ["Athens School of Fine Arts"],
    ".elec.aspete.gr": [
        "Ανώτατη Σχολή Παιδαγωγικής και Τεχνολογικής Εκπαίδευσης",
        " Higher School of Pedagogical and Technological Education",
    ],
    ".mec.aspete.gr": [
        "Ανώτατη Σχολή Παιδαγωγικής και Τεχνολογικής Εκπαίδευσης",
        "Higher School of Pedagogical and Technological Education",
    ],
    ".athtech.gr": ["Athens Tech College"],
    ".aua.gr": ["Agricultural University of Athens"],
    ".aueb.gr": ["Athens University of Economics and Business"],
    ".csd.auth.gr": ["School of Informatics of AUTh"],
    ".math.auth.gr": ["School of Mathematics of AUTH"],
    ".auth.gr": ["Aristotle University of Thessaloniki"],
    ".cityu.gr": ["City University Athens"],
    ".demokritos.gr": ["NCSR Demokritos"],
    ".duth.gr": ["Dimocritus University of Thrace"],
    ".eap.gr": ["Hellenic Open University"],
    ".alba.edu.gr": ["Athens Laboratory of Business Administration (ALBA)"],
    ".amcstudent.edu.gr": ["Μητροπολιτικό Κολλέγιο", "AMC - Metropolitan College"],
    ".anatolia.edu.gr": ["Anatolia College"],
    ".athenscollege.edu.gr": ["HAEF - Athens College"],
    ".campion.edu.gr": ["Campion School"],
    ".dei.edu.gr": ["DEI Bachelor &amp; Master Degrees"],
    ".iceberg.edu.gr": ["ICEBERG. Θεσσαλίας", "ICEBERG of Thessaly"],
    ".ihu.edu.gr": ["International Hellenic University"],
    ".imd.edu.gr": [
        "Institute of Management Development - Ohrid",
        "Institute of Management Development, Ohrid",
    ],
    ".mitropolitiko.edu.gr": ["Μητροπολιτικό Κολλέγιο", "AMC - Metropolitan College"],
    ".teikav.edu.gr": ["Technological Education Institute of Kavala"],
    ".uindy.edu.gr": ["University of Indianapolis in Athens"],
    ".uom.edu.gr": ["University Of Macedonia"],
    ".forthnet.gr": ["Harokopio University"],
    ".grbc.gr": ["Greek Bible College"],
    ".hmu.gr": [
        "\ufeffHellenic Mediterranean University",
        "ΕΛΛΗΝΙΚΟ ΜΕΣΟΓΕΙΑΚΟ ΠΑΝΕΠΙΣΤΗΜΙΟ",
        "University Official URL:",
        "https://www.hmu.gr/",
        "University official webmail:",
        "https://webmail.edu.hmu.gr",
        "Master in Advanced Manufacturing, Automation and Robotics Link (2years):",
        "https://www.teicrete.gr/amsar/",
        "Msc in Informatics Engineering:",
        "https://www.hmu.gr/mscie/en",
        "Department of Informatics:",
        "https://www.teicrete.gr/en/stef/13802",
        "All the departments: ",
        "https://www.hmu.gr/hmu/8600",
        'Notes : Currently the unniversity is changing domain from the older "teicrete" to the new "hellenic mediteranean university" (hmu).',
    ],
    ".hua.gr": ["Harokopio University"],
    ".ihu.gr": [
        "Διεθνές Πανεπιστήμιο της Ελλάδος",
        "International Hellenic University",
    ],
    ".imese.gr": [
        "Institute of Management &amp; Enteurpreneurship of South East Europe"
    ],
    ".ionio.gr": ["Ionian University"],
    ".ntua.gr": ["National Technical University of Athens"],
    ".nyc.gr": ["New York College of Athens"],
    ".panteion.gr": ["Panteios University of Economics and Political Sciences Athens"],
    ".pinewood-school.gr": ["Pinewood International American School"],
    ".students.puas.gr": ["Students of Piraeus University of Applied Sciences"],
    ".puas.gr": ["Piraeus University of Applied Sciences"],
    ".sse.gr": ["Hellenic Army Academy"],
    ".ssl-unipi.gr": ["Systems Security Laboratory, University of Piraeus"],
    ".teiath.gr": ["Technological Education Institute of Athens"],
    ".teicm.gr": ["Technological Educational Institute of Central Macedonia"],
    ".teicrete.gr": ["Technological Educational Institute of Crete"],
    ".teiemt.gr": ["Eastern Macedonia and Thrace Institute of Technology"],
    ".teiep.gr": ["Technological Education Institute of Epiros"],
    ".teiher.gr": ["Technological Education Institute of Heraklion"],
    ".teikal.gr": ["Technological Education Institute of Kalamata"],
    ".teikoz.gr": ["Technological Education Institute of Kozani"],
    ".teilam.gr": ["Technological Education Institute of Lamia"],
    ".teilar.gr": ["Technological Education Institute of Larissa"],
    ".teimes.gr": ["Technological Education Institute of Mesologgi"],
    ".teipat.gr": ["Technological Education Institute of Patras"],
    ".teipir.gr": ["Technological Education Institute of Piraeus"],
    ".teiser.gr": ["Technological Education Institute of Serres"],
    ".teiste.gr": ["Technological Education Institute of Sterea Ellada"],
    ".teithe.gr": ["Technological Education Institute of Thessaloniki"],
    ".teiwest.gr": ["Technological Educational Institute of Western Greece"],
    ".students.kastoria.teiwm.gr": [
        "University of Applied Science of Western Macedonia School Of Applied Science Departement Of Informatics Engineering"
    ],
    ".tuc.gr": ["Technical University of Crete"],
    ".ucg.gr": ["University of Central Greece"],
    ".unipi.gr": ["University of Piraeus"],
    ".uniwa.gr": ["Πανεπιστήμιο Δυτικής Αττικής", "University of West Attica"],
    ".uoa.gr": ["University of Athens"],
    ".uoc.gr": ["University of Crete"],
    ".uoi.gr": ["University of Ioannina"],
    ".uom.gr": ["University of Macedonia"],
    ".uop.gr": ["University of Peloponnese"],
    ".icte.uowm.gr": [
        "University of Western Macedonia Department of Informatics & Telecommunications Engineering"
    ],
    ".uowm.gr": ["University of Western Macedonia"],
    ".upatras.gr": ["University of Patras"],
    ".upnet.gr": ["University of Patra"],
    ".uth.gr": ["University of Thessaly"],
    ".cucv.edu.gt": ["Centro Universitario Ciudad Vieja"],
    ".cunoc.edu.gt": ["Centro Universitario de Occidente"],
    ".ufm.edu.gt": ["Universidad Francisco Marroquín"],
    ".umg.edu.gt": ["Universidad Mariano Gálvez"],
    ".unis.edu.gt": ["Universidad del Istmo"],
    ".upana.edu.gt": ["Universidad Panamericana"],
    ".url.edu.gt": ["Universidad Rafael Landívar"],
    ".urural.edu.gt": ["Universidad Rural de Guatemala"],
    ".usac.edu.gt": ["Universidad de San Carlos de Guatemala"],
    ".uvg.edu.gt": ["Universidad del Valle de Guatemala"],
    ".edu.gy": ["University of Guyana"],
    ".avh.hamburg": ["Alexander von Humboldt Gymnasium"],
    ".bs-citynord.hamburg": [
        "Berufliche Schule City Nord",
        "Homepage: https://www.bs28.hamburg/",
        "ContactSite: https://www.bs28.hamburg/kontakt/impressum.html",
        "Adress: Tessenowweg 3 22297 Hamburg Germany",
        "School Mail Example: example@bs-citynord.hamburg",
        "Reason for the Mail: School is using an Prowim/FirstClass https://www.prowim.de/login",
        "You can see contact Mail on the Homepage as a Proof At the Top on the right",
    ],
    ".cuhk.hk": ["Chinese University of Hong Kong"],
    ".bhjs.edu.hk": ["何明華會督銀禧中學", "Bishop Hall Jubilee School"],
    ".bhscmc.edu.hk": ["佛教孔仙洲紀念中學", "Buddhist Hung Sean Chau Memorial College"],
    ".cccmyc.edu.hk": ["中華基督教會銘賢書院", "The Church of Christ in China Ming Yin College"],
    ".chuhai.edu.hk": ["Chu Hai College"],
    ".cihe.edu.hk": ["Caritas Institute of Higher Education"],
    ".student.cis.edu.hk": [
        "Chinese International School",
        "Chinese International School",
    ],
    ".cis.edu.hk": ["Chinese International School", "Chinese International School"],
    ".my.cityu.edu.hk": ["City University of Hong Kong"],
    ".cityu.edu.hk": ["City University of Hong Kong"],
    ".link.cuhk.edu.hk": ["The Chinese University of Hong Kong"],
    ".cuhk.edu.hk": [
        "The Chinese University of Hong Kong",
        "The Chinese University of Hong Kong",
    ],
    ".cloud.elegantia.edu.hk": [
        "Elegantia College (Sponsored by Education Convergence)"
    ],
    ".stu.elegantia.edu.hk": ["Elegantia College (Sponsored by Education Convergence)"],
    ".learning.gsis.edu.hk": ["German Swiss International School"],
    ".hkbu.edu.hk": ["Hong Kong Baptist University"],
    ".hkct.edu.hk": [
        "Hong Kong College of Technology",
        "Hong Kong College of Technology",
    ],
    ".hkis.edu.hk": ["Hong Kong International School"],
    ".hkmu.edu.hk": ["Hong Kong Metropolitan University"],
    ".hksyu.edu.hk": [
        "香港樹仁大學",
        "Hong Kong Shue Yan University",
        "https://ba.hksyu.edu/bba-hons-dm/programme-details",
    ],
    ".hsu.edu.hk": ["The Hang Seng University of Hong Kong"],
    ".ied.edu.hk": ["Hong Kong Institute of Education"],
    ".isf.edu.hk": ["The Independent Schools Foundation Academy "],
    ".island.edu.hk": ["Island School, Hong Kong"],
    ".la-salle.edu.hk": ["La salle primary school"],
    ".lkpfc.edu.hk": ["NLSI Lui Kwok Pat Fong College"],
    ".ln.edu.hk": ["Lingnan University"],
    ".ouhk.edu.hk": ["Open University of Hong Kong"],
    ".polyu.edu.hk": ["Hong Kong Polytechnic University"],
    ".pyc.edu.hk": ["Shatin Pui Ying College"],
    ".sais.edu.hk": ["Stamford American School Hong Kong"],
    ".sfxc.edu.hk": ["聖方濟書院", "St. Francis Xavier's College"],
    ".student.speed-polyu.edu.hk": [
        "Polyu Speed",
        "School of Professional Education and Executive Development",
    ],
    ".stc.edu.hk": ["天主教崇德英文書院", "Shung Tak Catholic English College"],
    ".tanghin.edu.hk": ["香港道教聯合會鄧顯紀念中學", "H.K.T.A. Tang Hin Memorial Secondary School"],
    ".twc.edu.hk": ["東華學院", "Tung Wah College"],
    ".twghlkss.edu.hk": ["Tung Wah Group of Hospitals Li Ka Shing College"],
    ".mail.uic.edu.hk": ["北京师范大学-香港浸会大学联合国际学院", "UIC"],
    ".stu.vtc.edu.hk": ["Vocational Training Council", "Vocational Training Council"],
    ".vtc.edu.hk": ["職業訓練局", "Vocational Training Council"],
    ".wahyan.edu.hk": ["Wah Yan College Hong Kong"],
    ".wis.edu.hk": ["West Island School"],
    ".eduhk.hk": ["The Education University of Hong Kong"],
    ".learner.hkuspace.hku.hk": ["HKU School of Professional and Continuing Education"],
    ".hku.hk": ["University of Hong Kong"],
    ".kgv.hk": ["King George V School"],
    ".ln.hk": ["Lingnan University"],
    ".connect.polyu.hk": ["Hong Kong Polytechnic University"],
    ".ust.hk": ["Hong Kong University of Science and Technology"],
    ".ujcv.edu.hn": ["Universidad José Cecilio del Valle"],
    ".unah.edu.hn": ["Universidad Nacional Autónoma de Honduras"],
    ".unimetro.edu.hn": ["Universidad Metropolitana de Honduras"],
    ".upnfm.edu.hn": ["Universidad Pedagógica Nacional Francisco Morazán"],
    ".unah.hn": ["Universidad Nacional Autónoma de Honduras"],
    ".uth.hn": ["Universidad Tecnológica de Honduras"],
    ".reddam.house": ["Reddam House Atlantic Seaboard"],
    ".aspira.hr": ["Visoka škola Aspira"],
    ".bak.hr": ["University of Applied Sciences BALTAZAR"],
    ".efos.hr": ["University of Osijek Faculty of Economics"],
    ".efri.hr": [
        "Ekonomski Fakultet u Rijeci",
        "University of Rijeka, Faculty of Economics and Business",
    ],
    ".efst.hr": ["University of Split Faculty of Economics"],
    ".net.efzg.hr": [
        "Sveučilište u Zagrebu, Ekonomski fakultet",
        "University of Zagreb, Faculty of Economics and Business",
    ],
    ".etfos.hr": ["University of Osijek Faculty of Electrical Engineering"],
    ".fer.hr": ["University of Zagreb Faculty of Electrical Engineering and Computing"],
    ".ferit.hr": ["University of Osijek Faculty of Electrical Engineering"],
    ".fesb.hr": [
        "University of Split Faculty of Electrical Engineering, Mechanical Engineering and Naval Architecture"
    ],
    ".ffos.hr": ["University of Osijek Faculty of humanities and social sciences"],
    ".ffri.hr": ["University of Rijeka Faculty of Humanities and Social Sciences"],
    ".ffst.hr": ["Faculty of Humanities and Social Sciences, University of Split"],
    ".ffzg.hr": ["Faculty of Humanities and Social Sciences, University of Zagreb"],
    ".foi.hr": ["Faculty of Organization and Informatics"],
    ".fpz.hr": ["Faculty of Transport and Traffic Sciences, University of Zagreb "],
    ".fsb.hr": [
        "Faculty of Mechanical Engineering and Naval Architecture, University of Zagreb"
    ],
    ".geof.hr": ["UNIVERSITY OF ZAGREB, FACULTY OF GEODESY"],
    ".gfos.hr": ["Faculty of civil engineering"],
    ".gfz.hr": [
        "University of Zagreb Faculty of Mathematics and Natural Sciences - Department of Geophysics"
    ],
    ".grad.hr": ["Faculty of Civil Engineering University of Zagreb"],
    ".gradst.hr": [
        "University of Split Faculty of Civil Engineering, Architecture and Geodesy"
    ],
    ".hrstud.hr": [
        "Fakultet hrvatskih studija, Sveuciliste u Zagrebu",
        "Faculty of Croatian Studies, University of Zagreb",
    ],
    ".math.hr": [
        "University of Zagreb Faculty of Mathematics and Natural Sciences - Department of Mathematics"
    ],
    ".mathos.hr": [
        "University of Osijek Department of Mathematics",
        "Sveučilište J. J. Strossmayera u Osijeku - Odjel za matematiku",
    ],
    ".mef.hr": ["Medicinski fakultet", "School of Medicine"],
    ".mev.hr": ["Polytechnic of Međimurje in Čakovec"],
    ".pbf.hr": ["University of Zagreb Faculty of Food Technology and Biotechnology"],
    ".phy.hr": [
        "University of Zagreb Faculty of Mathematics and Natural Sciences - Department of Physics"
    ],
    ".pmf.hr": ["University of Zagreb Faculty of Science"],
    ".pmfst.hr": ["University of Split Faculty of Natural Sciences and Mathematics"],
    ".pou.hr": ["Public Open University Zagreb"],
    ".pravos.hr": ["University of Osijek Faculty of Law"],
    ".racunarstvo.hr": ["University College for Applied Computer Engineering"],
    ".riteh.hr": ["University of Rijeka Faculty of Engineering"],
    ".skole.hr": ["Croatian Academic and Research network"],
    ".srce.hr": ["Unversity of Zagreb - University Computing Centre - Srce"],
    ".sumfak.hr": ["University of Zagreb Faculty of Forestry"],
    ".tvz.hr": ["Polytechnic of Zagreb"],
    ".ufzg.hr": ["University of Zagreb - Faculty of Teacher Education"],
    ".unidu.hr": ["University of Dubrovnik"],
    ".unin.hr": ["University North"],
    ".unios.hr": ["University of Osijek"],
    ".unipu.hr": ["University of Pula"],
    ".uniri.hr": ["University of Rijeka"],
    ".unist.hr": ["University of Split"],
    ".unizd.hr": ["University of Zadar"],
    ".unizg.hr": ["University of Zagreb"],
    ".veleri.hr": ["Polytechnic of Rijeka"],
    ".vern.hr": ["VERN University of applied sciences"],
    ".vernnet.hr": ["Vern University of Applied Sciences"],
    ".vevu.hr": ["Polytechnic Lavoslav Ružička Vukovar"],
    ".vsite.hr": ["College for Information Technologies"],
    ".vsmti.hr": ["Virovitica College"],
    ".vub.hr": ["Veleučilište u Bjelovaru", "Bjelovar University of Applied Sciences"],
    ".vvg.hr": ["University of Applied Sciences Velika Gorica"],
    ".zsem.hr": [
        "Zagreb School of Economics and Management",
        "Zagrebačka škola ekonomije i managementa",
    ],
    ".ueh.edu.ht": ["Université d'Etat d'Haiti"],
    ".andrassyuni.hu": ["Andrassy Gyula German Speaking University Budapest"],
    ".arts7.hu": ["Hungarian Academy of Fine Arts Budapest"],
    ".avicenna.hu": ["Avicenna International College"],
    ".bdtf.hu": ["Dániel Berzsenyi Teacher Training College"],
    ".bjg.hu": ["Batsanyi Janos Gimnazium"],
    ".bke.hu": ["Budapest University of Economic Sciences and Public Administration"],
    ".bme.hu": ["Technical University of Budapest"],
    ".ceu.hu": ["Central European University"],
    ".dote.hu": ["University Medical School of Debrecen"],
    ".drk.hu": ["Reformed Theological Academy of Debrecen"],
    ".duf.hu": ["College of Dunaujvaros"],
    ".efe.hu": ["University of Sopron"],
    ".ehf.hu": ["Esztergom Theological College"],
    ".elte.hu": ["Eötvös Lorand University"],
    ".filmacademy.hu": ["Academy of Drama and Film"],
    ".neptun.gdf.hu": ["Gábor Dénes Főiskola"],
    ".gdf.hu": ["Gábor Dénes Főiskola", "Dennis Gabor College"],
    ".hengersor.hu": [
        "Budapesti Gazdasági Szakképzési Centrum Pestszentlőrinci Közgazdasági és Informatikai Szakgimnáziuma"
    ],
    ".hiete.hu": ["Haynal Imre University of Health Sciences Budapest"],
    ".hupe.hu": ["Hungarian University of Physical Education"],
    ".ibs-b.hu": ["IBS International Business School, Budapest"],
    ".jpte.hu": ["Janus Pannonius University"],
    ".ke.hu": ["University of Kaposvar"],
    ".kee.hu": ["University of Horticulture and Food Industry"],
    ".kefo.hu": ["Kecskemet College"],
    ".kgre.hu": ["Károl Gáspár University of the Reformed Church"],
    ".klte.hu": ["Kossuth Lajos University"],
    ".kodolanyi.hu": ["Kodolanyi Janos University College"],
    ".cloud.kre.hu": [
        "Károli Gáspár Református Egyetem",
        "Károli Gáspár University of the Reformed Church in Hungary ",
        "IT releated course: https://btk.kre.hu/index.php/tarsadalmi-viseledeselemzes-ma",
    ],
    ".lauder.hu": ["Lauder Javne Jewish school"],
    ".lfze.hu": ["Liszt Ferenc Academy of Music Budapest"],
    ".lonyayrefi.hu": [
        "Lónyay utcai Református gimnázium",
        "Lónyay utcai reformed high school",
    ],
    ".student.metropolitan.hu": ["Budapesti Metropolitan Egyetem"],
    ".mif.hu": ["Hungarian Academy of Craft and Design"],
    ".mke.hu": ["Hungarian University of Fine Arts"],
    ".mome.hu": ["Moholy-Nagy University of Art and Design"],
    ".nytud.mta.hu": [
        "Research Institute for Linguistics of the Hungarian Academy of Sciences",
        "Magyar Tudományos Akadémia Nyelvtudományi Intézete",
    ],
    ".mtf.hu": ["Hungarian Dance Academy"],
    ".mzsg.hu": ["Móricz Zsigmond Gimnázium", "Móricz Zsigmond High School"],
    ".njszg.hu": [
        "Budapesti Műszaki Szakképzési Centrum Neumann János Számítástechnikai Szakgimnáziuma"
    ],
    ".nye.hu": ["University of Nyíregyháza"],
    ".nyme.hu": ["University of West Hungary"],
    ".pataky.hu": [
        "\ufeffBudapesti Műszaki Szakképző Centrum Pataky István Híradásipari és Informatikai Szakgimnáziuma",
        " ",
    ],
    ".petrik.hu": [
        "Budapesti Műszaki Szakképzési Centrum Petrik Lajos Két Tanítási Nyelvű Technikum"
    ],
    ".pote.hu": ["University Medical School of Pécs"],
    ".ppke.hu": ["Pázmány Péter Catholic University"],
    ".pte.hu": ["University of Pecs"],
    ".stud.semmelweis.hu": ["Semmelweis University"],
    ".semmelweis-univ.hu": ["Semmelweis University"],
    ".sote.hu": ["Semmelweis University of Medical Sciences"],
    ".blathy-bp.sulinet.hu": [
        "Budapesti Műszaki Szakképzési Centrum Bláthy Ottó Titusz Informatikai Technikum"
    ],
    ".diak.szamalk-szalezi.hu": [
        "SZÁMALK-Szalézi Technikum és Szakgimnázium",
        "SZÁMALK-Salesian Technical School",
    ],
    ".szamalk-szalezi.hu": [
        "SZÁMALK-Szalézi Technikum és Szakgimnázium",
        "SZÁMALK-Salesian Technical School",
    ],
    ".szbi.hu": ["Szent Benedek Gimnázium", "Saint Benedict High School"],
    ".sze.hu": ["Széchenyi István University"],
    ".szegbp.hu": [
        "Budapest I. Kerületi Szilágyi Erzsébet Gimnázium",
        "Szilágyi Ezsébet Secondary School, Budapest 1st District",
    ],
    ".szjgdebrecen.hu": [
        "Szent József Általános Iskola, Gimnázium, Szakgimnázium és Kollégium"
    ],
    ".sztaki.hu": ["Számítástechnikai és Automatizálási Kutatóintézet"],
    ".taszi.hu": [
        "Békéscsabai SZC Trefort Ágoston Szakgimnáziuma, Szakközépiskolája és Kollégiuma"
    ],
    ".tkbf.hu": ["Budapest Buddhist University"],
    ".u-szeged.hu": ["University of Szeged"],
    ".umszki.hu": ["BMSZC Újpesti Két Tanítási Nyelvű Műszaki Technikum"],
    ".uni-bge.hu": ["Budapest Business School"],
    ".uni-corvinus.hu": ["Corvinus University of Budapest"],
    ".uni-eszterhazy.hu": ["Eszterházy Károly University"],
    ".phd.uni-mate.hu": [
        "Magyar Agrár és Élettudományi egyetem",
        "Hungarian University of Agriculture and Life Sciences",
    ],
    ".stud.uni-mate.hu": [
        "Magyar Agrár- és Élettudományi Egyetem",
        "Hungarian University of Agriculture and Life Sciences",
    ],
    ".uni-mate.hu": [
        "Magyar Agrár- és Élettudományi Egyetem ",
        "Hungarian University of Agriculture and Life Sciences",
    ],
    ".uni-miskolc.hu": ["University of Miskolc"],
    ".uni-neumann.hu": ["John von Neumann University"],
    ".uni-nke.hu": ["National University of Public Service"],
    ".uni-obuda.hu": ["Óbuda University"],
    ".uni-pannon.hu": ["University of Pannonia"],
    ".uni-sopron.hu": ["University of Sopron"],
    ".hallgato.uni-szie.hu": ["Szent István Egyetem", "Szent István University"],
    ".unibge.hu": ["Budapest Business School"],
    ".unideb.hu": [
        "Debrecen University of Agricultural Sciences",
        "University of Debrecen ",
    ],
    ".uniduna.hu": ["University of Dunaújváros"],
    ".univet.hu": ["University of Veterinary Science"],
    ".vargaszolnok.hu": [
        "Varga Katalin Gimnázium Szolnok",
        "Varga Katalin Secondary School Szolnok",
    ],
    ".verebelyszki.hu": [
        "BMSZC Verebély László Technikum",
        "Budapest Center of Technical Vocational Training, László Verebély Vocational School",
    ],
    ".vhf.hu": [
        "Veszprémi Érseki Hittudományi Főiskola",
        "Archepiscopal's Theological College of Veszprem",
    ],
    ".aisyahuniversity.ac.id": ["Aisyah University", "Aisyah University"],
    ".akakom.ac.id": ["STMIK Akakom Yogyakarta"],
    ".mhs.akba.ac.id": [
        "STMIK AKBA",
        "College of Informatics and Computer Management, AKBA",
    ],
    ".aknpacitan.ac.id": ["AKN Pacitan", "Pacitan Public Community College"],
    ".aknsumenep.ac.id": ["Akademi Komunitas Negeri Sumenep"],
    ".akprind.ac.id": ["Institut Sains &amp; Teknologi Akprind"],
    ".alfath.ac.id": ["Sekolah Tinggi Manajemen dan Ilmu Komputer Al-Fath"],
    ".almaata.ac.id": ["Universitas Alma Ata Yogyakarta"],
    ".amikmahaputra.ac.id": ["amikmahaputra.ac.id", "AMIK Mahaputra Riau"],
    ".amikom.ac.id": ["Universitas AMIKOM Yogyakarta"],
    ".mhs.amikompurwokerto.ac.id": [
        "Universitas AMIKOM Purwokerto",
        "AMIKOM Purwokerto University",
    ],
    ".students.amikompurwokerto.ac.id": [
        "Universitas Amikom Purwokerto",
        "Amikom Purwokerto University",
    ],
    ".atmajaya.ac.id": ["Universitas Katolik Indonesia Atma Jaya"],
    ".atmaluhur.ac.id": ["ISB Atma Luhur"],
    ".atmi.ac.id": ["Politeknik ATMI Surakarta", "ATMI Surakarta Polytechnic"],
    ".bakrie.ac.id": ["Universitas Bakrie"],
    ".stmik.banisaleh.ac.id": ["STMIK BANI SALEH"],
    ".binadarma.ac.id": ["Universitas Bina Darma"],
    ".binawan.ac.id": ["Universitas Binawan"],
    ".binus.ac.id": ["Binus University"],
    ".borobudur.ac.id": [
        "Universitas Borobudur Jakarta",
        "BOROBUDUR UNIVERSITY JAKARTA",
    ],
    ".bsi.ac.id": ["Bina Sarana Informatika"],
    ".budiluhur.ac.id": ["Universitas Budi Luhur"],
    ".bunghatta.ac.id": ["Universitas Bung Hatta"],
    ".calvin.ac.id": [
        "Calvin Institute of Technology",
        "Calvin Institute of Technology",
    ],
    ".cendekia.ac.id": ["Universitas Cendekia Abditama"],
    ".ciputra.ac.id": ["Universitas Ciputra"],
    ".darmajaya.ac.id": ["Institut Informatika dan Bisnis Darmajaya"],
    ".del.ac.id": ["Institut Teknologi Del"],
    ".dinamika.ac.id": ["Universitas Dinamika", "Dinamika University"],
    ".dinus.ac.id": ["Universitas Dian Nuswantoro"],
    ".dipanegara.ac.id": [
        "STMIK Dipanegara",
        "College of Informatics and Computer Management, Dipanegara",
    ],
    ".esaunggul.ac.id": ["Universitas Indonusa Esa Unggul"],
    ".fisip-untirta.ac.id": [
        "Fakultas Ilmu Sosial dan Politik Universitas Sultan Ageng Tirtayasa",
        "Social and Polotical Sciences Sultan Ageng Tirtayasa University",
    ],
    ".ftumj.ac.id": ["universitas muhammadiyah jakarta"],
    ".mhs.unida.gontor.ac.id": ["Universitas Darussalam Gontor"],
    ".gunadarma.ac.id": ["Universitas Gunadarma"],
    ".student.handayani.ac.id": [
        "Sekolah Tinggi Manajemen Informatika Komputer Handayani"
    ],
    ".iailm.ac.id": [
        "Institut Agama Islam Latifah Mubarokiyah",
        "Latifah Mubarokiyah Islamic Institute",
    ],
    ".ibik.ac.id": [
        "Institut Bisnis dan Informatika Kesatuan",
        "Kesatuan Institute of Business and Informatics",
    ],
    ".ids.ac.id": ["STMIK IDS"],
    ".ipb.ac.id": ["Bogor Agricultural University"],
    ".ipem.ac.id": ["STMIK Insan Pembangunan"],
    ".isi.ac.id": [
        "Institut Seni Indonesia Yogyakarta",
        "Indonesia Institute of Arts Yogyakarta",
    ],
    ".ista.ac.id": ["Institut Sains dan Teknologi Al Kamal"],
    ".istts.ac.id": ["Institut Sains & Teknologi Terpadu Surabaya"],
    ".itats.ac.id": ["Institut Teknologi Adhi Tama Surabaya"],
    ".itb.ac.id": ["Institut Teknologi Bandung"],
    ".iteba.ac.id": ["Institut Teknologi Batam (ITEBA)"],
    ".itenas.ac.id": ["Institut Teknologi Nasional (ITENAS)"],
    ".itera.ac.id": ["Institut Teknologi Sumatera"],
    ".itg.ac.id": ["Institut Teknologi Garut", "Garut Institute of Technology"],
    ".ithb.ac.id": ["Institut Teknologi Harapan Bangsa"],
    ".itk.ac.id": ["Institut Teknologi Kalimantan"],
    ".itnb.ac.id": ["ITNB", "Institut Bisnis IT&B"],
    ".itpln.ac.id": ["Institut Teknologi PLN Jakarta", "Institute Of Technology PLN"],
    ".its.ac.id": ["Institut Teknologi Sepuluh Nopember"],
    ".ittelkom-pwt.ac.id": [
        "Institut Teknologi Telkom Purwokerto",
        "Telkom Institute of Technology Purwokerto",
    ],
    ".iuli.ac.id": ["International University Liaison Indonesia"],
    ".janabadra.ac.id": ["Universitas Janabadra"],
    ".jayabaya.ac.id": ["Universitas Jayabaya"],
    ".kalbis.ac.id": ["Kalbis Institute"],
    ".kallabs.ac.id": ["Institut Teknologi dan Bisnis Kalla"],
    ".kharisma.ac.id": ["STMIK KHARISMA Makassar"],
    ".kwikkiangie.ac.id": [
        "Institut Bisnis dan Informatika Kwik Kian Gie",
        "Kwik Kian Gie Institute of Business and Informatics",
    ],
    ".likmi.ac.id": ["STMIK LIKMI", "STMIK LIKMI Bandung"],
    ".fellow.lpkia.ac.id": ["STIMIK & POLITEKNIK KOMPUTER BISNIS LPKIA"],
    ".machung.ac.id": ["Universitas Ma Chung"],
    ".maranatha.ac.id": ["Universitas Kristen Maranatha"],
    ".mdp.ac.id": ["STMIK Global Informatika MDP"],
    ".mercubuana-yogya.ac.id": ["Universitas Mercubuana Yogyakarta"],
    ".mercubuana.ac.id": ["Universitas Mercu Buana"],
    ".mikroskil.ac.id": ["STMIK - STIE Mikroskil"],
    ".mmtc.ac.id": ["STMM MMTC", "MultiMedia Training Center"],
    ".moestopo.ac.id": ["Universitas Dr. R. Moestopo"],
    ".narotama.ac.id": ["Universitas Narotama"],
    ".nurulfikri.ac.id": ["STT Nurul Fikri"],
    ".nusamandiri.ac.id": ["STMIK Nusamandiri"],
    ".nusaputra.ac.id": ["Universitas Nusa Putra", "Nusa Putra University"],
    ".pancabudi.ac.id": ["Universitas Pembangunan Panca Budi"],
    ".paramadina.ac.id": ["Universitas Paramadina Mulya"],
    ".mahasiswa.pcr.ac.id": ["Politeknik Caltex Riau"],
    ".mhs.pelitabangsa.ac.id": ["Pelita Bangsa University"],
    ".pelitabangsa.ac.id": ["Universitas Pelita Bangsa"],
    ".student.pelitaindonesia.ac.id": [
        "Institut Bisnis dan Teknologi Pelita Indonesia",
        "Institute of Business and Technology Pelita Indonesia",
    ],
    ".pens.ac.id": ["Politeknik Elektronika Negeri Surabaya"],
    ".perbanas.ac.id": ["Stie Perbanas Surabaya"],
    ".perbanasinstitute.ac.id": ["Abfi Institute Perbanas Jakarta"],
    ".petra.ac.id": ["Universitas Kristen Petra"],
    ".pknstan.ac.id": ["Sekolah Tinggi Akuntansi Negara (STAN)"],
    ".plb.ac.id": ["Politeknik LP3I Bandung"],
    ".pmbs.ac.id": ["Prasetiya Mulya Business School"],
    ".pmsbe.ac.id": ["Universitas Prasetiya Mulya"],
    ".pnb.ac.id": ["Politeknik Negeri Bali", "Bali State Polytechnic"],
    ".pnj.ac.id": ["Politeknik Negeri Jakarta"],
    ".pnk.ac.id": ["Politeknik Negeri Kupang", "Kupang Polytechnic"],
    ".polban.ac.id": ["Politeknik Negeri Bandung"],
    ".polije.ac.id": ["Politeknik Negeri Jember", "State Polytechnic Of Jember"],
    ".student.polindra.ac.id": ["Politeknik Negeri Indramayu"],
    ".polinema.ac.id": ["Politeknik Negeri Malang"],
    ".polines.ac.id": ["Politeknik Negeri Semarang"],
    ".polinpdg.ac.id": ["Politeknik Negeri Padang"],
    ".politala.ac.id": ["Politeknik Negeri Tanah Laut"],
    ".politap.ac.id": ["Politeknik Negeri Ketapang", "Polytechnic state of Ketapang"],
    ".poliupg.ac.id": [
        "Politeknik Negeri Ujung Pandang",
        "State Polytechnic of Ujung Pandang",
    ],
    ".polka.ac.id": ["politeknik krakatau", " krakatau polytechnic"],
    ".polmed.ac.id": ["Politeknik Negeri Medan"],
    ".polnep.ac.id": ["Politeknik Negeri Pontianak"],
    ".poltekbangsby.ac.id": ["POLTEKBANG SURABAYA"],
    ".poltekkesbandung.ac.id": ["Poltekkes Kemenkes Bandung"],
    ".poltekkesjkt2.ac.id": ["Politeknik kesehatan kementrian kesehatan jakarta 2"],
    ".poltekpos.ac.id": ["Politeknik Pos Indonesia"],
    ".poltektedc.ac.id": ["Politeknik TEDC Bandung", "Polytechnic TEDC Bandung"],
    ".poltektegal.ac.id": ["Politeknik Harapan Bersama", "Harapan Bersama Polytechnic"],
    ".prasetiyamulya.ac.id": ["Universitas Prasetiya Mulya"],
    ".president.ac.id": ["President University"],
    ".puterabatam.ac.id": ["Universitas Putera Batam"],
    ".radenfatah.ac.id": ["Universitas Negeri Islam Radenfatah"],
    ".radenintan.ac.id": ["University Raden Intan Lampung"],
    ".sbm-itb.ac.id": [
        "School of Business and Management - Institut Teknologi Bandung"
    ],
    ".sgu.ac.id": ["Swiss German University"],
    ".sinus.ac.id": [
        "STMIK Sinar Nusantara Surakarta",
        "STMIK Sinar Nusantara Surakarta",
    ],
    ".staindirundeng.ac.id": [
        "Islamic State College Teungku Dirundeng Meulaboh",
        "Sekolah Tinggi Agama Islam Teungku Dirundeng Meulaboh",
    ],
    ".stan.ac.id": ["Sekolah Tinggi Akuntansi Negara (STAN)"],
    ".learning.stiebankbpdjateng.ac.id": [
        "Sekolah Tinggi Ilmu Ekonomi Bank BPD Jateng"
    ],
    ".stiemj.ac.id": ["STIE Muhammadiyah Jakarta"],
    ".stiki-indonesia.ac.id": ["STMIK STIKOM Indonesia"],
    ".stiki.ac.id": ["Sekolah Tinggi Informatika dan Komputer Indonesia"],
    ".stikom-bali.ac.id": ["Institut Teknologi Dan Bisnis STIKOM Bali"],
    ".stimednp.ac.id": ["STIMED Nusa Palapa"],
    ".stis.ac.id": ["Politeknik Statistika STIS", "STIS Polytechnic of Statistics"],
    ".stiteknas.ac.id": ["Sekolah Tinggi Teknologi Nasional Jambi"],
    ".stkip-pgri-sumbar.ac.id": ["STKIP PGRI Sumatera Barat"],
    ".stkipahsingaraja.ac.id": ["STKIP Agama Hindu Singaraja"],
    ".stmik-amikbandung.ac.id": [
        "Sekolah Tinggi Manajemen dan Ilmu Komputer AMIKBANDUNG"
    ],
    ".stmik-indonesia-banjarmasin.ac.id": ["STMIK Indonesia Banjarmasin"],
    ".stmikbumigora.ac.id": [
        "STMIK Bumigora",
        "STMIK Bumigora University",
        "STMIK Bumigora Mataram",
    ],
    ".stmikibbi.ac.id": ["Universitas IBBI", "IBBI University"],
    ".stmikjabar.ac.id": ["STMIK Jabar"],
    ".stmkg.ac.id": ["STMKG Sekolah Tinggi Meteorologi Klimatologi dan Geofisika"],
    ".stp-bandung.ac.id": ["Sekolah Tinggi Pariwisata Bandung"],
    ".stpi-pajak.ac.id": ["Sekolah Tinggi Perpajakan Indonesia"],
    ".stptrisakti.ac.id": ["Trisakti Institute of Tourism "],
    ".sttdumai.ac.id": ["Sekolah Tinggi Teknologi Dumai"],
    ".sttgarut.ac.id": [
        "Sekolah Tinggi Teknologi Garut",
        "Garut High School of Technology",
    ],
    ".sttpln.ac.id": ["Institut Teknologi PLN"],
    ".surya.ac.id": ["Universitas Surya"],
    ".student.tau.ac.id": ["student.tau.ac.id", "Tanri Abeng University"],
    ".tazkia.ac.id": [
        "Institut Agama Islam Tazkia",
        "Tazkia Islamic University College",
    ],
    ".teknokrat.ac.id": ["Universitas Teknokrat Indonesia"],
    ".telkomuniversity.ac.id": ["Institut Teknologi Telkom"],
    ".triatmamulya.ac.id": ["Universitas Triatma Mulya", "Triatma Mulya University"],
    ".trilogi.ac.id": ["Universitas Trilogi"],
    ".trisakti.ac.id": ["Universitas Trisakti"],
    ".student.trunojoyo.ac.id": [
        "Universitas Trunojoyo Madura",
        "Trunojoyo Madura University",
    ],
    ".uad.ac.id": ["Universitas Ahmad Dahlan"],
    ".uajy.ac.id": ["Universitas Atma Jaya Yogyakarta"],
    ".ub.ac.id": ["Universitas Brawijaya"],
    ".ubaya.ac.id": ["Universitas Surabaya"],
    ".ubhara.ac.id": ["Universitas Bhayangkara Surabaya"],
    ".ubharajaya.ac.id": ["Universitas Bhayangkara Jakarta Raya"],
    ".ubl.ac.id": ["Universitas Bandar Lampung", "Bandar Lampung University"],
    ".ubm.ac.id": ["Universitas Bunda Mulia"],
    ".ubpkarawang.ac.id": ["Universitas Buana Perjuangan"],
    ".uc.ac.id": ["Universitas Ciputra"],
    ".udb.ac.id": ["Universitas Duta Bangsa"],
    ".ugm.ac.id": ["Universitas Gadjah Mada"],
    ".uho.ac.id": ["Universitas Haluoleo"],
    ".ui.ac.id": ["Universitas Indonesia"],
    ".uid.ac.id": ["Universitas Islam Jakarta"],
    ".uii.ac.id": ["Universitas Islam Indonesia"],
    ".uin-alauddin.ac.id": ["Universitas Islam Alauddin"],
    ".uin-malang.ac.id": ["Universitas Islam Negeri Maulana Malik Ibrahim Malang"],
    ".student.uin-suka.ac.id": [
        "UIN Sunan Kalijaga",
        "State Islamic University Sunan Kalijaga",
    ],
    ".uin-suska.ac.id": ["Universitas Islam Negeri Sultan Syarif Kasim Riau"],
    ".uinjkt.ac.id": ["Universitas Islam Negeri Syarif Hidayatullah Jakarta"],
    ".uinmataram.ac.id": ["UIN Mataram"],
    ".student.uinsby.ac.id": [
        "Universitas Islam Negeri Sunan Ampel",
        "State Islamic University Sunan Ampel",
    ],
    ".uinsgd.ac.id": ["UIN Sunan Gunung Jati Bandung"],
    ".uinsu.ac.id": [
        "Univeristas Islam Negeri Sumatera Utara",
        "North Sumatra State Islamic University",
    ],
    ".uir.ac.id": ["Universitas Islam Riau"],
    ".student.uisi.ac.id": ["Universitas Internasional Semen Indonesia"],
    ".uisi.ac.id": ["Universitas Internasional Semen Indonesia"],
    ".uisu.ac.id": ["Universitas Islam Sumatera Utara"],
    ".ukdw.ac.id": ["Universitas Kristen Duta Wacana"],
    ".uki.ac.id": ["Universitas Kristen Indonesia"],
    ".ukim.ac.id": [
        "Universitas Kristen Indonesia Maluku",
        "Indonesian Christian University in the Moluccas",
    ],
    ".ukrida.ac.id": ["Universitas Kristen Krida Wacana"],
    ".ukwms.ac.id": ["Universitas Katolik Widya Manadala"],
    ".ulm.ac.id": ["Universitas Lambung Mangkurat", "Lambung Mangkurat University"],
    ".um.ac.id": ["Universitas Negeri Malang"],
    ".staff.uma.ac.id": ["Universitas Medan Area", "University of Medan Area"],
    ".umaha.ac.id": ["Universitas Maarif Hasyim Latif"],
    ".umc.ac.id": [
        "Universitas Muhammadiyah Cirebon",
        "Muhammadiyah University of Cirebon",
    ],
    ".umi.ac.id": ["Universitas Muslim Indonesia"],
    ".umj.ac.id": ["Universitas Muhammadiyah Jakarta"],
    ".umk.ac.id": ["Universitas Muria Kudus"],
    ".umkt.ac.id": ["Universitas Muhammadiyah Kalimantan Timur"],
    ".umm.ac.id": ["Universitas Muhammadiyah Malang"],
    ".ummgl.ac.id": ["Universitas Muhammadiyah Magelang"],
    ".ummi.ac.id": ["Universitas Muhammadiyah Sukabumi"],
    ".umn.ac.id": ["Universitas Multimedia Nusantara"],
    ".ump.ac.id": ["Universitas Muhammadiyah Purwokerto"],
    ".ums.ac.id": ["Universitas Muhammadiyah Surakarta"],
    ".umsida.ac.id": [
        "Universitas Muhammadiyah Sidoarjo",
        "University Muhammadiyah Sidoarjo",
    ],
    ".umsu.ac.id": ["Universitas Muhammadiyah Sumatra Utara"],
    ".umy.ac.id": ["Universitas Muhammadiyah Yogyakarta"],
    ".unair.ac.id": ["Universitas Airlangga"],
    ".unama.ac.id": ["Universitas Dinamika Bangsa", "Dinamika Bangsa University"],
    ".unand.ac.id": ["Universitas Andalas"],
    ".unas.ac.id": ["Universitas Nasional Jakarta"],
    ".undana.ac.id": ["Universitas Nusa Cendana"],
    ".undiknas.ac.id": ["undiknas university", "undiknas university"],
    ".undiksha.ac.id": [
        "Universitas Pendidikan Ganesha",
        "Ganesha University of Education",
    ],
    ".undip.ac.id": ["Universitas Diponegoro"],
    ".undira.ac.id": ["Universitas Dian Nusantara", "Dian Nusantara University"],
    ".unej.ac.id": ["Universitas Jember"],
    ".unesa.ac.id": ["Universitas Negeri Surabaya"],
    ".ung.ac.id": ["Universitas Negeri Gorontalo"],
    ".unhamzah.ac.id": ["Universitas Amir Hamzah"],
    ".unhas.ac.id": ["Universitas Hasanuddin"],
    ".unib.ac.id": ["Universitas Bengkulu"],
    ".unibamadura.ac.id": ["Universitas Bahauddin Mudhary Madura"],
    ".mhs.unibi.ac.id": [
        "Universitas Informatika dan Bisnis Indonesia",
        "Indonesian University of Informatics and Business",
    ],
    ".unigamalang.ac.id": ["Universitas Gajayana Malang"],
    ".unigoro.ac.id": ["Universitas Bojonegoro"],
    ".unik-kediri.ac.id": ["Universitas Kediri"],
    ".unika.ac.id": ["Universitas Katolik Soegijapranoto"],
    ".unikadelasalle.ac.id": ["Universitas Katolik De La Salle Manado"],
    ".unikal.ac.id": ["Universitas Pekalongan"],
    ".unikom.ac.id": ["Universitas Komputer Indonesia"],
    ".uniku.ac.id": ["Universitas Kuningan", "Kuningan University"],
    ".unila.ac.id": ["Universitas Lampung"],
    ".unilak.ac.id": ["Universitas Lancang Kuning"],
    ".unima.ac.id": ["Universitas Negeri Manado"],
    ".mhs.unimal.ac.id": ["Universitas Malikussaleh", "Universitas Malikussaleh"],
    ".unimed.ac.id": ["Universitas Negeri Medan"],
    ".unindra.ac.id": ["Universitas Indraprasta", "Indraprasta University"],
    ".uninus.ac.id": ["Universitas Islam Nusantara"],
    ".unipasby.ac.id": ["Universitas PGRI Adi Buana"],
    ".unipdu.ac.id": ["Universitas Pesantren Darul Ulum Jombang"],
    ".unirow.ac.id": [
        "Universitas PGRI Ronggolawe",
        "UNIROW Tuban",
        "Ronggolawe University",
    ],
    ".unisayogya.ac.id": ["Universitas 'Aisyiyah Yogyakarta"],
    ".unisba.ac.id": ["Universitas Islam Bandung"],
    ".unisbank.ac.id": ["Universitas Stikubank Semarang"],
    ".unisma.ac.id": ["Universitas Islam Malang"],
    ".unismuh.ac.id": ["Universitas Muhammadiyah Makassar"],
    ".unisnu.ac.id": ["Universitas Islam Nahdlatul Ulama Jepara"],
    ".unisri.ac.id": ["Universitas Slamet Riyadi Surakarta"],
    ".unissula.ac.id": ["Universitas Islam Sultan Agung"],
    ".unitomo.ac.id": ["Unitomo Surabaya"],
    ".universitasbumigora.ac.id": ["Universitas Bumigora"],
    ".universitasmulia.ac.id": ["Universitas Mulia", "Mulia University"],
    ".universitaspahlawan.ac.id": ["Universitas Pahlawan Tuanku Tambusai"],
    ".universitaspertamina.ac.id": ["Universitas Pertamina"],
    ".univpancasila.ac.id": ["Universitas Pancasila"],
    ".unj.ac.id": ["Universitas Negeri Jakarta"],
    ".unja.ac.id": ["Universitas Jambi"],
    ".unjani.ac.id": ["Universitas Jenderal Achmad Yani"],
    ".unkhair.ac.id": ["Universitas Khairun"],
    ".student.unklab.ac.id": ["Universitas Klabat", "Klabat University"],
    ".unkris.ac.id": ["Universitas Krisnadwipayana"],
    ".unm.ac.id": ["Universitas Negeri Makassar"],
    ".unmer-madiun.ac.id": ["Universitas Merdeka Madiun"],
    ".unmer.ac.id": ["Universitas Merdeka Malang"],
    ".unmermadiun.ac.id": ["Universitas Merdeka Madiun"],
    ".unmuhjember.ac.id": ["Universitas Muhammadiyah Jember"],
    ".unmuhpnk.ac.id": ["Universitas Muhammadiyah Pontianak"],
    ".unmul.ac.id": ["Universitas Mulawarman"],
    ".unmus.ac.id": ["Universitas Musamus Merauke"],
    ".unnes.ac.id": ["Universitas Negeri Semarang"],
    ".unp.ac.id": ["Universitas Negeri Padang"],
    ".unpacti.ac.id": ["Universitas Pancasakti", "Pancasakti University"],
    ".unpad.ac.id": ["Universitas Padjadjaran"],
    ".unpak.ac.id": ["Universitas Pakuan"],
    ".unpam.ac.id": ["Universitas Pamulang"],
    ".unpar.ac.id": ["Universitas Katolik Parahyangan"],
    ".unpas.ac.id": ["Universitas Pasundan"],
    ".unpatti.ac.id": ["Universitas Pattimura"],
    ".unper.ac.id": ["Universitas Perjuangan Tasikmalaya"],
    ".unr.ac.id": ["Universitas Ngurah Rai"],
    ".unram.ac.id": ["Universitas Mataram"],
    ".student.unri.ac.id": ["Universitas Negri Riau", "University of Riau"],
    ".uns.ac.id": ["Universitas Sebelas Maret"],
    ".unsada.ac.id": ["Universitas Darma Persada"],
    ".unsera.ac.id": ["universitas serang raya", "serang raya university"],
    ".unsia.ac.id": ["*.unsia.ac.id", "universitas siber asia"],
    ".unsika.ac.id": ["Universitas Singaperbangsa Karawang"],
    ".unsil.ac.id": ["Universitas Siliwangi"],
    ".unsoed.ac.id": ["Universitas Jenderal Soedirman"],
    ".unsrat.ac.id": ["Universitas Sam Ratulangi"],
    ".unsri.ac.id": ["Universitas Sriwijaya"],
    ".unswagati.ac.id": ["Universitas Swadaya Gunung Djati"],
    ".unsyiah.ac.id": ["Universitas Syiah Kuala"],
    ".untad.ac.id": ["Universitas Tadulako"],
    ".untag-banyuwangi.ac.id": ["Universitas 17 Agustus 1945 Banyuwangi"],
    ".untag-sby.ac.id": ["Universitas 17 Agustus 1945 Surabaya"],
    ".untag-smd.ac.id": ["Universitas 17 Agustus 1945 Samarinda"],
    ".untagsmg.ac.id": ["Universitas 17 Agustus 1945 Semarang"],
    ".untan.ac.id": ["Universitas Tanjungpura"],
    ".untar.ac.id": ["Universitas Tarumanagara"],
    ".untirta.ac.id": ["Universitas Sultan Ageng Tirtayasa"],
    ".unu-jogja.ac.id": [
        "Universitas Nahdlatul Ulama Yogyakarta",
        "Yogyakarta Nahdlatul Ulama University",
    ],
    ".unud.ac.id": ["Universitas Udayana"],
    ".unwiku.ac.id": ["Universitas Wijaya Kusuma Purwokerto"],
    ".uny.ac.id": ["Universitas Negeri Yogyakarta"],
    ".up45.ac.id": ["Universitas Proklamasi 45"],
    ".upbatam.ac.id": ["Universitas Putera Batam"],
    ".upgris.ac.id": ["Universitas PGRI Semarang"],
    ".upnjatim.ac.id": ["Universitas Pembangunan Nasional Veteran East Java"],
    ".upnvj.ac.id": ["Universitas Pembangunan Nasional Veteran Jakarta"],
    ".upnyk.ac.id": ["Universitas Pembangunan Nasional Veteran Yogyakarta"],
    ".upr.ac.id": ["Universitas Palangka Raya"],
    ".upri.ac.id": [
        "Universitas Pejuang Republik Indonesia",
        "Pejuang University of Republic of Indonesia",
    ],
    ".upstegal.ac.id": ["Universitas Pancasakti Tegal"],
    ".usahid.ac.id": ["universitas sahid jakarta", "sahid university jakarta"],
    ".usd.ac.id": ["Universitas Sanata Dharma"],
    ".usi.ac.id": ["Universitas Simalungun"],
    ".usm.ac.id": ["Universitas Semarang"],
    ".ustjogja.ac.id": ["Universitas Sarjanawiyata Tamansiswa"],
    ".usu.ac.id": ["Universitas Sumatera Utara"],
    ".ut.ac.id": ["Universitas Terbuka Indonesia"],
    ".utm.ac.id": ["Universitas Tidar Magelang"],
    ".utp.ac.id": ["Universitas Tunas Pembangunan"],
    ".uty.ac.id": ["Universitas Teknologi Yogyakarta"],
    ".uwks.ac.id": ["Universitas Wijaya Kusuma Surabaya"],
    ".uwp.ac.id": ["Universitas Wijaya Putra", "Wijaya Putra University"],
    ".student.walisongo.ac.id": ["UIN Walisongo Semarang"],
    ".walisongo.ac.id": ["UIN Walisongo Semarang"],
    ".wicida.ac.id": ["STMIK Widya Cipta Dharma Samarinda"],
    ".widyadharma.ac.id": [
        "Universitas Widya Dharma Pontianak",
        "Widya Dharma Pontianak University",
    ],
    ".widyagama.ac.id": ["Universitas Widya Gama Malang"],
    ".widyakarya.ac.id": ["Universitas Katolik Widya Karya"],
    ".widyatama.ac.id": ["Universitas Widyatama"],
    ".wima.ac.id": ["Universitas Katolik Widya Manadala"],
    ".wisnuwardhana.ac.id": ["Universitas Wisnuwardhana"],
    ".yai.ac.id": ["Universitas Persada Indonesia Y.A.I"],
    ".yarsi.ac.id": ["Universitas Yarsi"],
    ".alqudwah.id": ["alqudwah.id", "Al-Qudwah Boarding School"],
    ".belajar.id": [
        "belajar.id",
        "Official Webmail from Indonesian Ministry of Education and Culture (for students and teachers)",
    ],
    ".alghifaribatanghari.or.id": ["Muhammadiyah Boarding School Abudzar Al-Ghifari"],
    ".bisedu.or.id": ["Bandung Independent School"],
    ".jisedu.or.id": ["Jakarta Intercultural School"],
    ".perbanas.id": ["perbanas.id", "Perbanas Institute"],
    ".citraberkat.sch.id": ["Sekolah Citra Berkat"],
    ".citrakasih.sch.id": ["Sekolah Citra Kasih"],
    ".sman1serangbarujuara.sch.id": [
        "sman1serangbarujuara.sch.id",
        "SMA Negeri 1 Serang Baru",
    ],
    ".sman1tegal.sch.id": ["SMA Negeri 1 Tegal", "High School 1 Tegal"],
    ".sman2balige.sch.id": [
        "sman2balige.sch.id",
        "Yayasan Soposurung/SMA Negeri 2 Balige",
    ],
    ".sman4tegal.sch.id": ["SMA Negeri 4 Tegal", "High School 4 Tegal"],
    ".smkn7-smr.sch.id": [
        "SMK Negeri 7 Samarinda",
        "Vocational High School 7 Samarinda",
    ],
    ".sekolahmuridmerdeka.id": ["sekolahmuridmerdeka.id", "Sekolah Murid Merdeka"],
    ".ait.ie": ["Athlone Institute of Technology"],
    ".bfei.ie": ["blackrock further education institute"],
    ".carndonaghcs.ie": ["Carndonagh Community School"],
    ".cbcg.ie": ["Coláite Bhaile Chláir"],
    ".student.ccathlone.ie": ["Coláiste Chiaráin", "St Ciaran's College"],
    ".cct.ie": ["CCT College Dublin"],
    ".chanelcollege.ie": ["Chanel College"],
    ".cit.ie": ["Cork Institute of Technology"],
    ".clonkeencollege.ie": ["Clonkeen Collage"],
    ".cmetb.ie": ["Cavan Institute"],
    ".coccork.ie": ["College of Commerce", "Cork College of Commerce"],
    ".corketb.ie": ["Carrigtwohill Community College", ".group"],
    ".dbs.ie": ["Dublin Business School"],
    ".dcu.ie": ["Dublin City University"],
    ".dfei.ie": ["Dun Laoghaire Further Education Institute"],
    ".dias.ie": ["Dublin Institute for Advanced Studies"],
    ".dit.ie": ["Dublin Institute of Technology"],
    ".dkit.ie": ["Dundalk Institute of Technology"],
    ".student.dorset-college.ie": ["Dorset College"],
    ".fingalcc.ie": ["Fingal Community College"],
    ".gcd.ie": ["Griffith College"],
    ".gmit.ie": ["Galway Mayo Institute of Technology"],
    ".griffith.ie": ["Griffith College"],
    ".iadt.ie": ["Dún Laoghaire Institute of Art, Design and Technology"],
    ".itb.ie": ["Institute of Technology, Blanchardstown"],
    ".itcarlow.ie": ["Carlow Institute of Technology"],
    ".itsligo.ie": ["Institute of Technology, Sligo"],
    ".ittd.ie": ["Institue of Technology, Tallaght (legacy email accounts)"],
    ".ittdublin.ie": ["Institute of Technology, Tallaght"],
    ".ittralee.ie": ["Institue of Technology, Tralee"],
    ".lit.ie": ["Limerick Institute of Technology"],
    ".lmetb.ie": [
        "Louth and Meath Education and Training Board",
        "https://www.lmetb.ie/",
        ".group",
    ],
    ".lsb.ie": ["LSB College"],
    ".lyit.ie": ["Letterkenny Institute of Technology"],
    ".may.ie": ["National University of Ireland, Maynooth"],
    ".mtu.ie": ["Munster Technological University"],
    ".mu.ie": ["Maynooth University"],
    ".mumail.ie": ["Maynooth University"],
    ".mycit.ie": ["Cork Institute of Technology"],
    ".mydbs.ie": ["Dublin Business School"],
    ".mydit.ie": ["Dublin Institute of Technology"],
    ".mytudublin.ie": ["TU Dublin - Blanchardstown Campus"],
    ".ncad.ie": ["National College of Art and Design"],
    ".ncirl.ie": ["National College of Ireland"],
    ".nui.ie": ["National University of Ireland"],
    ".nuigalway.ie": ["National University of Ireland, Galway"],
    ".nuim.ie": ["National Univerisity of Ireland, Maynooth"],
    ".palmerstowncs.ie": ["Palmerstown Community School"],
    ".rcpi.ie": ["Royal College of Physicians of Ireland"],
    ".rcsi.ie": ["Royal College of Surgeons"],
    ".sanctamaria.ie": ["Sanctamaria College Louisburgh"],
    ".students.st-andrews.ie": [
        "St. Andrew's College Dublin",
        "St. Andrew's College Dublin",
    ],
    ".stconleths.ie": ["St. Conleth's College"],
    ".stjohnscollege.ie": ["St John's Central College, Cork, Ireland"],
    ".stlouishighschool.ie": ["St Louis High School"],
    ".stmc.ie": ["St. Michael's College", "www.stmc.ie"],
    ".stmunchinscollege.ie": ["St. Munchin's College"],
    ".tcd.ie": ["University of Dublin, Trinity College"],
    ".terenurecollege.ie": ["Terenure College"],
    ".tudublin.ie": ["Technological University Dublin"],
    ".tyndall.ie": ["Tyndall National Institute"],
    ".ucc.ie": ["University College Cork"],
    ".ucd.ie": ["University College Dublin"],
    ".ucdconnect.ie": ["University College Dublin"],
    ".ucg.ie": ["National University of Ireland, Galway"],
    ".ul.ie": ["University of Limerick"],
    ".wit.ie": ["Waterford Institute Of Technology"],
    ".afeka.ac.il": ["Afeka Tel Aviv Academic College of Engineering"],
    ".ariel.ac.il": ["Ariel University Center of Samaria"],
    ".bezalel.ac.il": ["Bezalel Academy of Art and Design"],
    ".bgu.ac.il": ["Ben-Gurion University of the Negev"],
    ".biu.ac.il": ["Bar-Ilan University"],
    ".braude.ac.il": ["ORT Braude College"],
    ".colman.ac.il": ["College of Management"],
    ".galilcol.ac.il": ["Galillee College"],
    ".haifa.ac.il": ["University of Haifa"],
    ".hit.ac.il": ["Holon Institute of Technology"],
    ".huji.ac.il": ["Hebrew University of Jerusalem"],
    ".idc.ac.il": ["The Interdisciplinary Center Herzliya"],
    ".post.jce.ac.il": ["Azrieli College of Engineering Jerusalem"],
    ".jce.ac.il": ["Azrieli College of Engineering Jerusalem"],
    ".jct.ac.il": ["Jerusalem College of Technology-Machon Lev"],
    ".mta.ac.il": [
        "The Academic College of Tel Aviv-Yaffo",
        "The Academic College of Tel Aviv-Yaffo (MTA)",
        "המכללה האקדמית תל אביב-יפו",
    ],
    ".ono.ac.il": ["Ono Academic College"],
    ".openu.ac.il": ["Open University of Israel"],
    ".sce.ac.il": ["Sami Shamoon College of Engineering"],
    ".shenkar.ac.il": ["Shenkar School of Engineering &amp; Design"],
    ".mail.tau.ac.il": ["Tel Aviv University"],
    ".tau.ac.il": ["Tel Aviv University"],
    ".campus.technion.ac.il": [
        "Russell Berrie Nanotechnology Institute",
        "Technion - Israel Institute of Technology",
        "Official Website - https://www.technion.ac.il/",
    ],
    ".technion.ac.il": [
        "Russell Berrie Nanotechnology Institute",
        "Technion - Israel Institute of Technology",
    ],
    ".weizmann.ac.il": ["Weizmann Institute of Science"],
    ".wgalil.ac.il": ["Western Galilee College"],
    ".yvc.ac.il": ["Emeq Yizrael College"],
    ".kdror.co.il": ["קרית חינוך דרור", "Kiryat Education Dror"],
    ".misgavhs.co.il": ["אסיף משגב", "asif misgav"],
    ".nhs.co.il": ["אמית נחשון", "AMIT NAHSHON"],
    ".volcani.agri.gov.il": ["Agricultural Research Organisation(ARO), Volcani Center"],
    ".hd.amalnet.k12.il": [
        "הרב תחומי למדעים ואומניות עמל חדרה",
        "school website: http://hd.amalnet.k12.il/",
    ],
    ".na.amalnet.k12.il": [
        "Multidisciplinary science and arts Amal Nahariya",
        "הרב תחומי עמל מדעים ואומנויות נהריה",
    ],
    ".nb.amalnet.k12.il": ["Amal Shakim Nahariya High School"],
    ".amirimvrd.org.il": ["amirim"],
    ".big.atid.org.il": ["Atid Cramim Binyamina-Giv'at Ada High School"],
    ".cts.org.il": [
        "Technological and Engineering Education Center",
        "http://www.cts.org.il/english",
    ],
    ".edu-haifa.org.il": ["Amal Hadera", "Amal Hadera"],
    ".educ.org.il": [
        "Israeli Ministry of Education provided email for all high-schools teachers"
    ],
    ".amirim.edum.org.il": ["Amirim Eroni Heh Rishon Lezion"],
    ".gsh.edum.org.il": ["תיכון גבעת שמואל", "Giv'at Shmuel High School"],
    ".mekifh.edum.org.il": ["Mekifh H Rishon Letsiyon"],
    ".hadash-holon.org.il": ["Campus Peres", "HTH"],
    ".hayovel.org.il": [" חטיבת היובל מבשרת ציון", "Hayovel Middle School, Israel"],
    ".iasa-school.org.il": [
        'י"אסא - התיכון הישראלי למדעים ולאמנויות',
        "IASA - Israeli Arts and Science Academy",
    ],
    ".ironialef.org.il": ["Ironi Alef Modiin"],
    ".bialik.ort.org.il": ["אורט ביאליק", "Ort Bialik"],
    ".ebin.ort.org.il": ["Ort Ebin High School"],
    ".guttman.ort.org.il": ["אורט גוטמן", "ORT GUTTMAN"],
    ".holon.ort.org.il": ["אורט חולון", "Ort Holon", "https://holon.ort.org.il/"],
    ".kramim.ort.org.il": ["ORT Kramin", "ORT Kramin"],
    ".kshapira.ort.org.il": ["אורט שפירא", "Ort Shapira"],
    ".ortarad.ort.org.il": ["Ort Arad High School"],
    ".rehovot.ort.org.il": ["אורט רחובות", "Ort Rehovot"],
    ".shapira.ort.org.il": ["Ort Shapira High School"],
    ".yalon.ort.org.il": ["אורט יוקנעם", "ort yokneam"],
    ".rhedu.org.il": ["רוטברג", "Rotberg"],
    ".ironihei.tad.org.il": ["Ironi Hei High School Tel Aviv"],
    ".thadash.tad.org.il": ["New High School Tel Aviv"],
    ".taded.org.il": ["תיכון שמעון בן צבי", "Shimon Ben Zvi High School"],
    ".tlvedu.org.il": ["עירוני ה", "Ironi H"],
    ".tzfonet.org.il": ["tzafonet", ".group"],
    ".zzv.org.il": ["College of Engineering"],
    ".iomc.ac.im": ["Isle of Man College"],
    ".ucm.ac.im": ["University College Isle of Man"],
    ".online.sch.im": ["Ballakermeen High School"],
    ".zjj.im": ["Hubei Industrial Polytechnic, Shiyan City"],
    ".abesit.in": ["ABES Institute of Technology, Ghaziabad"],
    ".stu.UPES.ac.in": ["University of Petroleum and Energy Studies (UPES), Dehradun"],
    ".abes.ac.in": ["ABES Engineering College, Ghaziabad"],
    ".allenhouse.ac.in": ["Allenhouse Institute of Technology"],
    ".amu.ac.in": ["Aligarh Muslim University, Aligarh"],
    ".bbit.ac.in": [
        "Bhailalbhai & Bhikhabhai Institute of Technology - BBIT, Vallabh Vidya Nagar, Anand, Gujarat"
    ],
    ".becs.ac.in": ["Bengal Engineering and Science University"],
    ".bitmesra.ac.in": ["Birla Institute of Technology - Mesra"],
    ".dubai.bits-pilani.ac.in": [
        "Birla Institute of Technology and Science, Pilani – Dubai Campus"
    ],
    ".goa.bits-pilani.ac.in": [
        "Birla Institute of Technology and Science, Pilani – K K Birla Goa Campus"
    ],
    ".hyderabad.bits-pilani.ac.in": [
        "Birla Institute of Technology and Science, Pilani – Hyderabad Campus"
    ],
    ".pilani.bits-pilani.ac.in": [
        "Birla Institute of Technology and Science, Pilani – Pilani Campus"
    ],
    ".wilp.bits-pilani.ac.in": [
        "Birla Institute of Technology and Science, Pilani – WILP Campus"
    ],
    ".bmsce.ac.in": ["BMS College of Engineering (BMSCE), Bangalore"],
    ".cet.ac.in": ["College of Engineering, Trivandrum"],
    ".charusat.ac.in": ["Charotar University Of Science And Technology"],
    ".ciem.ac.in": ["Calcutta Institute of Engineering and Management, Kolkata"],
    ".cmi.ac.in": ["Chennai Mathematical Institute"],
    ".coer.ac.in": ["College of Engineering Roorkee"],
    ".continental.ac.in": ["Continental Institute for International Studies"],
    ".daiict.ac.in": [
        "Dhirubhai Ambani Institute of Information and Communication Technology"
    ],
    ".djsce.ac.in": ["Dwarkadas Jamnadas Sanghvi College of Engineering"],
    ".dsvv.ac.in": ["Dev Sanskriti Vishwavidyalaya"],
    ".dtu.ac.in": ["Delhi Technological University"],
    ".ganpatuniversity.ac.in": ["Ganpat University, Mehsana, Gujarat"],
    ".gauhati.ac.in": ["Gauhati University, Guwahati, Assam"],
    ".gcek.ac.in": ["Government College of Engineering Kannur"],
    ".gecbh.ac.in": ["Government Engineering College Barton Hill"],
    ".gecskp.ac.in": ["Government Engineering College, Sreekrishnapuram"],
    ".gectcr.ac.in": ["Government Engineering College, Thrissur"],
    ".gehu.ac.in": ["Graphic Era Hill University, Dehradun"],
    ".gkv.ac.in": ["Gurukula Kangri"],
    ".gmit.ac.in": [
        "GM Institute of Technology a hi-tech & Top Engineering college in Davangere"
    ],
    ".gtu.ac.in": ["Gujarat Technological University"],
    ".iare.ac.in": ["Institute of Aeronautical Engineering, Hyderabad"],
    ".iiit-bh.ac.in": [
        "INTERNATIONAL INSTITUTE OF INFORMATION TECHNOLOGY, BHUBANESHWAR",
        "IIIT-BBSR",
        "IIIT BHUBANESHWAR",
        "The email we use is xyz@iiit-bh.ac.in",
        "Official College Website: (https://www.iiit-bh.ac.in/)",
        "URL of a page on the official website where a long-term (>1 year) IT related course is offered by the university: (https://www.iiit-bh.ac.in/admissions)",
        "URL of a page or some other proof (.pdf or a screenshot are OK) showing that the university recognizes the domain which you are submitting as an official email domain for the enrolled students: (https://docs.google.com/spreadsheets/d/1SpdPVOukm7BDEOY7X-Rr-HSlBBy5WKjkVEAqWu9YC_o/edit#gid=0)",
    ],
    ".iiit.ac.in": ["International Institute of Information Technology, Hyderabad"],
    ".iiita.ac.in": ["Indian Institute of Information Technology Allahabad"],
    ".iiitb.ac.in": ["International Institute of Information Technology, Bangalore"],
    ".iiitd.ac.in": ["Indraprastha Institute of Information Technology Delhi"],
    ".iiitdmj.ac.in": ["Indian Institute of Information Technology"],
    ".iiitdwd.ac.in": ["Indian Institute of Technology Dharwad"],
    ".iiitg.ac.in": ["Indian Institute of Information Technology Guwahati"],
    ".iiitp.ac.in": ["Indian Institute of Information Technology, Pune"],
    ".iima.ac.in": ["Indian Institute of Management Ahmedabad"],
    ".iiml.ac.in": ["IIM Lucknow"],
    ".iiserkol.ac.in": ["Indian Institute of Science Education and Research, Kolkata"],
    ".iiserpune.ac.in": ["Indian Institute of Science Education and Research Pune"],
    ".iitb.ac.in": ["Indian Institute of Technology Bombay"],
    ".iitbbs.ac.in": ["Indian Institute of Technology Bhubaneswar"],
    ".iitbhu.ac.in": ["Indian Institute of Technology (Banaras Hindu University)"],
    ".iitd.ac.in": ["Indian Institute of Technology, Delhi"],
    ".iitg.ac.in": ["Indian Institute of Technology Guwahati"],
    ".iitgn.ac.in": ["Indian Institute of Technology Gandhinagar"],
    ".iith.ac.in": ["Indian Institute of Technology Hyderabad"],
    ".iiti.ac.in": ["Indian Institute of Technology Indore"],
    ".iitj.ac.in": ["Indian Institute of Technology Jodhpur"],
    ".iitjammu.ac.in": ["Indian Institute of Technology Jammu"],
    ".iitk.ac.in": ["Indian Institute of Technology Kanpur"],
    ".iitkgp.ac.in": ["Indian Institute of Technology Kharagpur"],
    ".iitm.ac.in": ["Indian Institute of Technology Madras"],
    ".iitmandi.ac.in": ["Indian Institute of Technology Mandi"],
    ".iitp.ac.in": ["Indian Institute of Technology Patna"],
    ".iitpkd.ac.in": ["Indian Institute of Technology Palakkad"],
    ".iitr.ac.in": ["Indian Institute of Technology, Roorkee"],
    ".iitrpr.ac.in": ["Indian Institute of Technology Ropar"],
    ".iittp.ac.in": ["Indian Institute of Technology, Tirupati"],
    ".ipu.ac.in": ["Guru Govind Singh Indra Prastha University"],
    ".isical.ac.in": ["Indian Statistical Institute"],
    ".ismdhanbad.ac.in": [
        "Indian Institute of Technology (Indian School of Mines), Dhanbad"
    ],
    ".itbhu.ac.in": ["Indian Institute of Technology (Banaras Hindu University)"],
    ".jgec.ac.in": [
        "jgec.ac.in",
        "Jalpaiguri Government Engineering College, Jalpaiguri, West Bengal, India",
    ],
    ".jiit.ac.in": [
        "Jaypee Institute of Information Technology, Noida ",
        "https://www.jiit.ac.in/btech-information-technology",
    ],
    ".jmi.ac.in": ["Jamia Millia Islamia, New Delhi"],
    ".jssaten.ac.in": ["JSS Academy of Technical Education, Noida"],
    ".kce.ac.in": ["Karpagam College of Engineering"],
    ".kct.ac.in": ["Kumaraguru college of Technology, Coimbatore"],
    ".kiit.ac.in": [
        "KIIT University, Bhubaneswar",
        "Kalinga Institute of Industrial Technology, Bhubaneswar",
    ],
    ".knit.ac.in": ["KNIT Sultanpur"],
    ".kongu.ac.in": ["Kongu Engineering College, Perundurai"],
    ".kuk.ac.in": ["Kurukshetra University, Kurukshetra"],
    ".lnmiit.ac.in": ["The LNM Institute Of Information Technology, Jaipur"],
    ".mace.ac.in": [
        "Mar Athanasius College of Engineering",
        "MACE",
        "MA College of Engineering",
    ],
    ".mait.ac.in": ["Maharaja Agrasen Institute of Technology, Delhi"],
    ".manit.ac.in": ["Maulana Azad National Institute of Technology , Bhopal , India"],
    ".mctrgit.ac.in": [
        "Manjara Charitable Trust's Rajiv Gandhi Institute of Technology, Mumbai",
        "aka Rajiv Gandhi Institute of Technology, Mumbai",
        "aka RGIT",
    ],
    ".mec.ac.in": ["Govt. Model Engineering College"],
    ".mgit.ac.in": [
        "www.mgit.ac.in",
        "Mahatma Gandhi Institute of Technology in Hyderabad, Telangana State, India",
    ],
    ".mitaoe.ac.in": ["MIT Academy of Engineering - Pune"],
    ".mnit.ac.in": ["Malaviya National Institute of Technology, Jaipur"],
    ".mnmjec.ac.in": ["Misrimal Navajee Munoth Jain Engineering College"],
    ".mnnit.ac.in": [
        "Motilal Nehru National Institute of Technology Allahabad, Prayagraj"
    ],
    ".mrcet.ac.in": ["Malla Reddy College of Engineering and Technology"],
    ".myamu.ac.in": ["Aligarh Muslim University, Aligarh"],
    ".niecdelhi.ac.in": [" Northern India Engineering College, New Delhi"],
    ".nirmauni.ac.in": ["Nirma University"],
    ".nita.ac.in": ["National Institute Of Technology Agartala"],
    ".nitandhra.ac.in": ["National Institute of Technology, Andhra Pradesh"],
    ".nitc.ac.in": ["National Institute Of Technology Calicut"],
    ".nitdelhi.ac.in": ["National Institute of Technology, Delhi"],
    ".nith.ac.in": ["National Institute of Technology, Hamirpur"],
    ".nitj.ac.in": ["Dr B R Ambedkar National Institute of Technology, Jalandhar"],
    ".nitjsr.ac.in": ["National Institute of Technology, Jamshedpur"],
    ".nitkkr.ac.in": ["National Institute of Technology Kurukshetra"],
    ".nitm.ac.in": ["National Institute of Technology, Meghalaya"],
    ".nitp.ac.in": ["National Institute of Technology, Patna"],
    ".nitrkl.ac.in": ["National Institute Of Technology Rourkela"],
    ".nitrr.ac.in": ["National Institute of Technology, Raipur"],
    ".nitsikkim.ac.in": ["National Institute Of Technology Sikkim"],
    ".nmit.ac.in": [
        "NITTE Meenakshi Institute of Technology, Bangalore, Karnataka, India"
    ],
    ".nsit.ac.in": ["Netaji Subhas Institute Of Technology"],
    ".ptu.ac.in": ["Punjab Technical University"],
    ".royalschool.ac.in": ["Royal School of Management & Technology"],
    ".sastra.ac.in": ["Shanmugha Arts"],
    ".sathyabama.ac.in": [
        "Sathyabama Institute of Science and Technology",
        "Sathyabama University",
        "sathyabama.ac.in",
    ],
    ".sicsr.ac.in": ["Symbiosis Institute of Computer Studies and Research"],
    ".sit.ac.in": ["Siddaganga Institute of Technology"],
    ".sjc.ac.in": ["St Joseph's College (Autonomous) in Bengaluru, Karnataka"],
    ".sjce.ac.in": ["JSS Science and Technology University, Mysore"],
    ".smvdu.ac.in": ["Shri Mata Vaishno Devi University"],
    ".spit.ac.in": ["Bharatiya Vidya Bhavans Sardar Patel Institute Of Technology"],
    ".srec.ac.in": ["Sri Ramakrishna Engineering College"],
    ".srmuniv.ac.in": ["SRM University"],
    ".srmuniversity.ac.in": ["SRM University, Sonipat", "aka SRM University, Haryana"],
    ".tkmce.ac.in": ["TKM College of Engineering, Kollam"],
    ".uktech.ac.in": ["Uttarakhand Technical University,Dehradun"],
    ".unipune.ac.in": ["University of Pune"],
    ".utu.ac.in": ["Uka Tarsadia University"],
    ".velsuniv.ac.in": [
        "Vels Institute of Science, Technology & Advanced Studies(VISTAS)",
        "Vels University",
        "velsuniv.ac.in",
    ],
    ".ves.ac.in": ["Vivekanand Education Society"],
    ".vit.ac.in": ["Vellore Institute of Technology"],
    ".vitap.ac.in": ["VIT-AP University"],
    ".vjti.ac.in": ["Veermata Jijabai Technological Institute, Mumbai", "aka VJTI"],
    ".vnsgu.ac.in": ["Veer Narmad South Gujarat University"],
    ".vvpedulink.ac.in": ["VVP Engineering College"],
    ".walchandsangli.ac.in": ["Walchand College Of Engineering Sangli"],
    ".acropolis.in": ["Acropolis Institute Of Technology and Research"],
    ".adcet.in": ["Annasaheb Dange College of Engineering and Technology,ashta"],
    ".adhiyamaan.in": ["Adhiyamaan College of Engineering"],
    ".ajce.in": ["Amal Jyothi College of Engineering, Kanjirappally"],
    ".alpha-cet.in": ["Alpha College Of Engneering"],
    ".amceducation.in": ["AMC Engineering College"],
    ".aryacollege.in": ["Arya College of Engineering and I.T."],
    ".aryagurukul.in": ["Arya Gurukul"],
    ".axiscolleges.in": [
        "Axis Institute of Technology and Management",
        "Axis Institute of Technology and Management",
    ],
    ".banasthali.in": ["Banasthali Vidyapith"],
    ".bmsit.in": ["BMS Institute of Technology and Management, Bengaluru"],
    ".bnmit.in": ["B. N. M. Institute of Technology"],
    ".bvicam.in": [
        "Bharati Vidyapeeth's Institute of Computer Applications and Management"
    ],
    ".bvmcollege.in": [
        "Birla Vishvakarma Mahavidyalaya Engineering College",
        "BVM Engineering College",
    ],
    ".campusuvce.in": ["Univerity Visvesvaraya College of Engineering"],
    ".christuniversity.in": ["Christ University, Bangalore"],
    ".backstagepass.co.in": ["Backstage Pass Institute of Gaming and Technology"],
    ".birlainstitute.co.in": ["Birla Institute of Applied Sciences, Bhimtal"],
    ".cdckids.co.in": ["Child Development Centre", "Child Development Centre"],
    ".ggct.co.in": ["Gyan Gang College of Technology"],
    ".kvsrodehradun.co.in": ["KV ", "Kendriya Vidhyalaya"],
    ".lpu.co.in": ["Lovely Professional University"],
    ".niet.co.in": ["Noida Institute of Engineering and Technology"],
    ".piet.co.in": ["Panipat Institute of Engineering & Technology"],
    ".blr.silveroaks.co.in": ["Silver Oaks International School"],
    ".hyd.silveroaks.co.in": ["Silver Oaks International School"],
    ".sjcet.co.in": ["St John College of Engineering and Management"],
    ".wmoenglishacademy.co.in": ["WMO english academy"],
    ".coet.in": [
        "Mahatma Gandhi Mission's College of Engineering and Technology, Noida"
    ],
    ".csiriicb.in": ["CSIR-Indian Institute of Chemical Biology"],
    ".csitgeu.in": ["Department of Computer Science and Information Technology, GEU"],
    ".ctuniversity.in": ["Chandigarh Technical University"],
    ".cuchd.in": ["Chandigarh University "],
    ".cumail.in": ["Chandigarh University"],
    ".cumminscollege.in": ["Cummins College [Pune]"],
    ".dbit.in": [
        "Don Bosco Institute of Technology, Mumbai, Premier Automobiles Road Opp. HDIL Premier Exotica, Kurla, Mumbai, Maharashtra 400070"
    ],
    ".e-p-s.in": ["Eastern Public School"],
    ".annauniv.edu.in": [
        "Anna University",
        "Anna University, Chennai",
        "அண்ணா பல்கலைக்கழகம்",
    ],
    ".aot.edu.in": ["Academy Of Technology, Adisaptagram"],
    ".cambridge.edu.in": ["Cambridge Insitute of Technology"],
    ".cet.edu.in": ["College Of Engineering and Technology, Bhubaneswar"],
    ".charusat.edu.in": ["Charotar University Of Science And Technology"],
    ".dituniversity.edu.in": ["DIT University,Dehradun"],
    ".djsce.edu.in": ["Dwarkadas Jamnadas Sanghvi College of Engineering"],
    ".flame.edu.in": ["Flame University"],
    ".gtu.edu.in": ["Gujarat Technological University"],
    ".haps.edu.in": ["Holy Angels Public School"],
    ".karunya.edu.in": ["Karunya University"],
    ".mandsauruniversity.edu.in": ["Mandsaur University"],
    ".mitwpu.edu.in": ["MIT-World Peace University, Pune."],
    ".mmit.edu.in": ["Marathwada Mitra Mandal's Institute of Technology"],
    ".mvn.edu.in": ["MVN University Palwal, India"],
    ".nitk.edu.in": ["National Institute of Technology Karnataka"],
    ".niu.edu.in": ["Noida International University (NIU)"],
    ".rajagiri.edu.in": ["Rajagiri School of Engineering and Technology"],
    ".rvce.edu.in": ["R V College of Engineering"],
    ".sbjit.edu.in": [
        "S. B. Jain Institute of Technology, Management & Research, Nagpur"
    ],
    ".gst.sies.edu.in": ["South Indian Education Society (sies)"],
    ".skpec.edu.in": ["SKP Engineering College"],
    ".sowdambikaengg.edu.in": ["Sree Sowdambika College of Engineering"],
    ".srmap.edu.in": ["SRM University, AP - Amaravati", "SRM AP"],
    ".srmist.edu.in": ["SRM Institute of Science and Technology"],
    ".srmuniv.edu.in": ["SRM University"],
    ".svvv.edu.in": [
        "Shri Vaishnav Vidyapeeth Vishwavidyalaya, Indore",
        "Shri Vaishnav Institute of Technology and Science, Indore",
    ],
    ".iimahd.ernet.in": ["Indian Institute of Management, Ahmedabad"],
    ".iimb.ernet.in": ["Indian Institute of Management - Bangalore"],
    ".iisc.ernet.in": ["Indian Institute of Science"],
    ".iitd.ernet.in": ["Indian Institute of Technology - Delhi"],
    ".iitg.ernet.in": ["Indian Institute of Technology - Guwahati"],
    ".iitkgp.ernet.in": ["Indian Institute of Technology Kharagpur"],
    ".iitr.ernet.in": ["Indian Institute of Technology - Roorkee"],
    ".tezu.ernet.in": ["Tezpur University"],
    ".gitam.in": ["GITAM University"],
    ".hetic.in": ["HETIC-India"],
    ".hindustanschools.in": [
        "Hindustan International School",
        "Hindustan International School",
        "https://hindustanschools.in/",
    ],
    ".igib.in": ["CSIR Institute of Genomics and Integrative Biology"],
    ".iiits.in": [
        "Indian Institute of Information Technology, Sri City",
        "Indian Institute of Information Technology, Bangalore",
    ],
    ".iict.indusuniversity.in": [
        "Institute of Information & Communication Technology, Ahmedabad"
    ],
    ".iite.indusuniversity.in": ["Indus University", "Indus University"],
    ".jadavpuruniversity.in": ["Jadavpur University"],
    ".jssstuniv.in": ["JSS Science And Technology University, Mysore, India"],
    ".juetguna.in": [
        "Jaypee University of Engineering and Technology",
        "JUET, Guna",
        "juet.ac.in",
    ],
    ".juitsolan.in": [
        "jaypee university of information technology , solan , himachal pradesh "
    ],
    ".kazirangauniversity.in": ["Kaziranga University"],
    ".kluniversity.in": ["KL University"],
    ".kvberhampur.in": ["Kendriya Vidyalaya Brahmapur"],
    ".kvsroguwahati.in": ["kendriya Vidyalaya Namrup"],
    ".lpu.in": ["Lovely Professional University"],
    ".mcet.in": ["Dr.Mahalingam College of Engineering and Technology, Pollachi."],
    ".mcka.in": ["Marian College"],
    ".mespune.in": ["MES's IMCC"],
    ".micamail.in": ["MICA"],
    ".mietjammu.in": ["miet jammu"],
    ".mitmysore.in": ["Maharaja Institute of Technology Mysore"],
    ".msajce-edu.in": ["Mohamed Sathak A.J college of engineering"],
    ".msit.in": ["Maharaja Surajmal Institute of Technology"],
    ".mtmcollege.in": ["MTM Arts, Science and commerce of India"],
    ".gkmims.net.in": ["GKM institute of marine sciences and technology"],
    ".iimtindia.net.in": ["IIMT"],
    ".nsit.net.in": ["Netaji Subhas Institute of Technology"],
    ".saicloudschool.net.in": ["SAI International School"],
    ".niituniversity.in": ["NIIT UNIVERSITY"],
    ".nmamit.in": ["NMAM Institute of Technology"],
    ".nsitonline.in": ["Netaji Subhas Institute of Technology"],
    ".cbit.org.in": ["Chaitanya Bharathi Institute of Technology, Hyderabad."],
    ".dpsn.org.in": ["Delhi Public School Newtown"],
    ".git.org.in": ["Gandhinagar Institute of Technology"],
    ".global.org.in": ["Global Nature Care Sangathan Group of Institution"],
    ".hsct.org.in": ["High School of Computer and Technology"],
    ".ipec.org.in": ["Inderprastha Engineering College"],
    ".pravaraengg.org.in": ["Pravara Rural Engineering College"],
    ".sce.org.in": ["Shivalik College of Engineering Dehradun"],
    ".sitcoe.org.in": [
        "Sharad Institute of Technology College of Engineering, Ichalkaranji (Kolhapur)"
    ],
    ".svhce.org.in": [
        "Daita Madhusudana Sastry Sri Venkateswara Hindu College of Engineering, Machilipatnam "
    ],
    ".pathways.in": ["Pathways World School Aravali"],
    ".presidencyuniversity.in": ["Presidency University"],
    ".puibm.in": [
        "IBM-Innovation Centre for Education, People's University, Bhopal (MP)"
    ],
    ".csiriicb.res.in": ["CSIR-Indian Institute of Chemical Biology"],
    ".dcb.res.in": [
        "Department of Computational Biology and Bioinformatics, University of Kerala"
    ],
    ".hri.res.in": ["Harish-Chandra Research Institute"],
    ".iiap.res.in": ["Indian Institute of Astrophysics "],
    ".iicb.res.in": ["CSIR-Indian Institute of Chemical Biology"],
    ".ils.res.in": ["DBT- Institute of Life Sciences, India"],
    ".imsc.res.in": ["The Institute of Mathematical Sciences Chennai "],
    ".ncbs.res.in": ["The National Centre for Biological Sciences (NCBS)"],
    ".sdmit.in": [
        "Sri Dharmasthala Manjunatheshwara Institute of Technology",
        "SDM Institute of Technology",
    ],
    ".sgsitsindore.in": ["Shri Govindram Seksaria Institute of Technology and Science"],
    ".siom.in": ["Symbiosis Institute of Operations Management"],
    ".sjissonipat.in": [
        "Shreejee International School",
        "Shreejee International School",
    ],
    ".sjmsom.in": ["Shailesh J. Mehta School of Management"],
    ".slrtce.in": ["Shree LR Tiwari College of Engineering"],
    ".snuindia.in": ["Sister Nivedita University", "Sister Nivedita University"],
    ".sode-edu.in": ["Shri Madhwa Vadiraja Institute of Technology and Management"],
    ".sxconlineclass.in": ["St. Xavier's College(Autonomous), Kolkata"],
    ".tcetmumbai.in": ["Thakur College of Engineering and Technology"],
    ".teamfuture.in": [
        "Future Institute of Engineering and management, Sonarpur, Kolkata"
    ],
    ".terii.in": [
        "TECHNOLOGY EDUCATION AND RESEARCH INTEGRATED INSTITUTE",
        "TECHNOLOGY EDUCATION AND RESEARCH INTEGRATED INSTITUTE",
    ],
    ".theglocaluniversity.in": ["Glocal University"],
    ".timscdrmumbai.in": [
        "Thakur Institute of Management Studies, Career Development & Research"
    ],
    ".tnu.in": ["THE NEOTIA UNIVERSITY"],
    ".veckavali.in": ["Visvodaya Engineering College"],
    ".vnrvjiet.in": ["VNR Vignana Jyothi Inst. of Eng. and Tech."],
    ".128sou-sofia.info": [
        None,
        "\x00",
        '\x00"\x00A\x00l\x00b\x00e\x00r\x00t\x00 \x00E\x00i\x00n\x00s\x00t\x00e\x00i\x00n\x00"\x00 \x00S\x00e\x00c\x00o\x00n\x00d\x00a\x00r\x00y\x00 \x00s\x00c\x00h\x00o\x00o\x00l\x00',
    ],
    ".bcltedu.info": ["Bangladesh College of Leather Technology"],
    ".blathy.info": ["\ufeffBláthy Ottó Titusz Informatikai Szakközépiskola"],
    ".cfvw-gymnasium.info": ["Carl Friedrich von Weizsäcker-Gymnasium, Ratingen"],
    ".diit.info": ["Daffodil Institute of Information & Technology"],
    ".dronacharya.info": ["DRONACHARYA COLLEGE OF ENGINEERING"],
    ".fshnstudent.info": ["Faculty of Natural Sciences at University of Tirana"],
    ".gymsob.info": ["Gymnasium Schrobenhausen"],
    ".hf-ict.info": [
        "Höhere Fachschule für Informations- und Kommunikationstechnologie"
    ],
    ".infomila.info": ["Milà i Fontanals"],
    ".oldcolony.info": ["Old Colony Regional Vocational Technical High School"],
    ".phw.info": ["Fachhochschule Pur"],
    ".pmit.info": ["Chernivtsi Polytechnic College"],
    ".raharja.info": ["Perguruan Tinggi Raharja"],
    ".rswol-iserv.info": ["Realschule Wolbeck"],
    ".sgma.info": ["Smolensk State Medical Academy", "Smolensk State Medical Academy"],
    ".southern-bd.info": ["Southern University Bangladesh"],
    ".stamforduniversity.info": ["Stamford University"],
    ".turgot-paris.info": [
        "Lycée TURGOT - BTS SIO",
        "TURGOT high school - SIO higher technician certificate (IT services to organizations)",
    ],
    ".ucna.info": ["University College of Nabi Akram"],
    ".unisilvaner.info": ["University of Silvaner"],
    ".untagcirebon.info": ["Universitas 17 Agustus 1945 Cirebon"],
    ".usfx.info": ["Universidad San Francisco Xavier"],
    ".vsma.info": ["Voronezh State Medical Academy", "Voronezh State Medical Academy"],
    ".whsg.info": ["Westcliff Highschool for Girls"],
    ".edu.dsti.institute": ["Data ScienceTech Institute (DSTI) "],
    ".3wa.io": ["3w Academy"],
    ".laplateforme.io": ["LaPlatforme Coding School"],
    ".oclock.io": ["Ecole O'clock"],
    ".albayan.edu.iq": ["Al-Bayan University"],
    ".alfarabiuc.edu.iq": ["كلية الفارابي الجامعة", "Al-Farabi University College"],
    ".alkafeel.edu.iq": ["جامعة الكفيل", "University of Alkafeel"],
    ".alsafwa.edu.iq": ["AlSafwa University College"],
    ".atu.edu.iq": [
        "Al Furat Al-Awsat Technical University",
        "Al Furat Al-Awsat Technical University",
    ],
    ".cihanuniversity.edu.iq": ["Cihan University"],
    ".coie-nahrain.edu.iq": [
        "coie-nahrain",
        "Al Nahrain University college of information  engineering ",
    ],
    ".duc.edu.iq": ["Dijlah University College", "Dijlah University College"],
    ".epu.edu.iq": ["ERBIL POLYTECHNIC UNIVERSITY"],
    ".esraa.edu.iq": ["Esraa University", "https://www.esraa.edu.iq/"],
    ".huc.edu.iq": ["كلية الهادي الجامعة", "Al-Hadi University College"],
    ".komar.edu.iq": ["Komar University of Science and Technology"],
    ".muc.edu.iq": ["Mansour University College"],
    ".mustaqbal-college.edu.iq": ["Al mustaqbal College"],
    ".nahrainuniv.edu.iq": ["Al Nahrain University"],
    ".qu.edu.iq": ["جامعة القادسية ", "Qadisiyah University"],
    ".soran.edu.iq": ["Soran University"],
    ".spu.edu.iq": ["Sulaimaniya Polytechnic University"],
    ".tiu.edu.iq": [" Tishk International University (TIU)"],
    ".uhd.edu.iq": ["Univercity of human development", "UHD"],
    ".uniq.edu.iq": ["Qaiwan International University - UTM Franchise"],
    ".univsul.edu.iq": ["University of Sulaimani"],
    ".uoanbar.edu.iq": ["University of Anbar"],
    ".uob.edu.iq": ["University of Baghdad"],
    ".uobabylon.edu.iq": ["Uinversity of Babylon"],
    ".uobaghdad.edu.iq": ["University of Baghdad"],
    ".uobasrah.edu.iq": ["University of Basrah"],
    ".uodiyala.edu.iq": ["Diyala University"],
    ".uoh.edu.iq": ["University of Halabja"],
    ".uoitc.edu.iq": ["University of Information Technology and Communications"],
    ".uokerbala.edu.iq": ["Kerbala University"],
    ".uokirkuk.edu.iq": ["University of Kirkuk"],
    ".uokufa.edu.iq": ["University of Kufa"],
    ".uomisan.edu.iq": ["Misan University"],
    ".uomosul.edu.iq": ["University of Mosul"],
    ".uomustansiriyah.edu.iq": ["University of Mustansiriyah"],
    ".stu.uoninevah.edu.iq": [
        "University Of Ninevah",
        "College Of Information Technology",
    ],
    ".uotechnology.edu.iq": ["University of Technology - Iraq"],
    ".uowa.edu.iq": ["University of Warith Alanbiyaa"],
    ".uowasit.edu.iq": ["University of Wassit"],
    ".acmt.ac.ir": ["Amirkabir College of Managmant &amp; Technology"],
    ".adiban.ac.ir": ["Adiban Higher Education Institue"],
    ".ajums.ac.ir": ["Ahwaz Jondishapour University of Medical Sciences"],
    ".aliabadiau.ac.ir": ["Islamic Azad University, Aliabad "],
    ".arakmu.ac.ir": ["Arak University of Medical Sciences"],
    ".araku.ac.ir": ["Arak University"],
    ".art.ac.ir": ["Art University"],
    ".arums.ac.ir": ["Ardabil University of Medical Sciences"],
    ".atu.ac.ir": ["Allameh Tabatabaie University"],
    ".aut.ac.ir": ["Amirkabir University of Technology"],
    ".azad.ac.ir": ["Islamic Azad University, Tehran South"],
    ".basu.ac.ir": ["Bu Ali Sina University"],
    ".birjand.ac.ir": ["Birjand University"],
    ".bmsu.ac.ir": ["Baghyatoolah Medical Sciences University"],
    ".bojnourdiau.ac.ir": ["Islamic Azad University, Bojnourd"],
    ".bpums.ac.ir": ["Bushehr University of Medical Sciences"],
    ".bums.ac.ir": ["Birjand University of Medical Sciences"],
    ".fasau.ac.ir": ["Fasa University"],
    ".fums.ac.ir": ["Fasa Faculty of Medical Sciences"],
    ".gau.ac.ir": ["Gorgan University of Agricultural Sciences and Natural Resources"],
    ".gmu.ac.ir": ["Gonabad University of Medical Sciences"],
    ".goums.ac.ir": ["Golestan University of Medical Sciences"],
    ".guilan.ac.ir": ["Guilan University"],
    ".gums.ac.ir": ["Guilan University of Medical Sciences"],
    ".hormozgan.ac.ir": ["University of Hormozgan"],
    ".hums.ac.ir": ["Hormozgan University of Medical Sciences"],
    ".iasbs.ac.ir": ["Zanjan Institute for Advanced Studies in Basic Sciences"],
    ".iau-ahar.ac.ir": ["Islamic Azad University, Ahar"],
    ".iau-arak.ac.ir": ["Islamic Azad University, Arak"],
    ".iau-boukan.ac.ir": ["Islamic Azad University, Boukan"],
    ".iau-garmsar.ac.ir": ["Islamic Azad University, Garmsar"],
    ".iau-saveh.ac.ir": ["Islamic Azad University, Saveh"],
    ".iau-shahrood.ac.ir": ["Islamic Azad University, Shahrood"],
    ".iau-shirvan.ac.ir": ["Islamic Azad University, Shirvan"],
    ".iau-tnb.ac.ir": ["Islamic Azad University, North Tehran"],
    ".iauardabil.ac.ir": ["Islamic Azad University, Ardabil"],
    ".iauba.ac.ir": ["Islamic Azad University, Bandar Abbas"],
    ".iaubos.ac.ir": ["Islamic Azad University, Bostanabad"],
    ".iauctb.ac.ir": ["Islamic Azad University, Central Tehran Branch"],
    ".iauh.ac.ir": ["Islamic Azad University, Hamedan"],
    ".iauk.ac.ir": ["Islamic Azad University, Kerman"],
    ".iaumajlesi.ac.ir": ["Islamic Azad University, Majlesi"],
    ".iaun.ac.ir": ["Islamic Azad University, Najaf Abad"],
    ".iauq.ac.ir": ["Islamic Azad University, Quchan"],
    ".iausdj.ac.ir": ["Islamic Azad University, Sanandaj"],
    ".iaushab.ac.ir": [
        "Azad University of Shabestar",
        "Islamic Azad University, Shabestar",
    ],
    ".iaushiraz.ac.ir": ["Islamic Azad University, Shiraz"],
    ".iausr.ac.ir": ["Islamic Azad University, Shahr-e-rey Branch"],
    ".iaut.ac.ir": ["Islamic Azad University, Tabriz"],
    ".iautb.ac.ir": ["Islamic Azad University, Tafresh"],
    ".iautmu.ac.ir": ["Islamic Azad University, Tehran Medical"],
    ".iauvaramin.ac.ir": ["Islamic Azad University, Varamin"],
    ".iauyazd.ac.ir": ["Islamic Azad University, Yazd"],
    ".ikiu.ac.ir": ["Imam Khomeini International University"],
    ".ilam.ac.ir": ["Ilam University"],
    ".imamreza.ac.ir": ["Imam Reza University"],
    ".isu.ac.ir": ["Imam Sadiq University"],
    ".iums.ac.ir": ["Iran University of Medical Sciences"],
    ".iut.ac.ir": ["Isfahan University of Technology"],
    ".jami.ac.ir": ["Jami Institute of Technology"],
    ".jums.ac.ir": ["Jahrom University of Medical Sciences"],
    ".kashanu.ac.ir": ["Kashan University"],
    ".kau.ac.ir": ["Islamic Azad University, Kazeron"],
    ".khu.ac.ir": ["Kharazmi University of Tehran"],
    ".khuisf.ac.ir": ["Islamic Azad University, Khorasgan"],
    ".kiau.ac.ir": ["Islamic Azad University, Karaj"],
    ".kish.ac.ir": ["Sharif University of Technology, Kish Campus"],
    ".kmu.ac.ir": ["Kerman University of Medical Sciences"],
    ".kntu.ac.ir": ["K.N.Toosi University of Technology"],
    ".kums.ac.ir": ["Kermanshah University of Medical Sciences"],
    ".lu.ac.ir": ["Lorestan University"],
    ".lums.ac.ir": ["Lorestan University of Medical Sciences"],
    ".malayeru.ac.ir": ["Malayer University"],
    ".mamasaniiau.ac.ir": ["Mamasani University of Technology"],
    ".mau.ac.ir": ["Islamic Azad University, Mobarakeh"],
    ".medsab.ac.ir": ["Sabzevar School of Medical Sciences"],
    ".miu.ac.ir": ["Mustafa International University"],
    ".modares.ac.ir": ["Tarbiat Modares University"],
    ".mofidu.ac.ir": ["Mofid University"],
    ".mshdiau.ac.ir": ["Islamic Azad University, Mashhad"],
    ".mubabol.ac.ir": ["Babol University of Medical Sciences"],
    ".mui.ac.ir": ["Isfahan University of Medical Sciences"],
    ".muk.ac.ir": ["Kurdistan University of Medical Sciences"],
    ".mums.ac.ir": ["Mashhad University of Medical Sciences"],
    ".nit.ac.ir": ["Babol Noshirvani University of Technology"],
    ".pgu.ac.ir": ["Persian Gulf University"],
    ".piau.ac.ir": ["Islamic Azad University, Parand"],
    ".pnu.ac.ir": ["Payame Noor University"],
    ".pnum.ac.ir": ["University of Mashhad Pnu"],
    ".put.ac.ir": ["Petroleum University of Technology"],
    ".qom.ac.ir": ["Qom University"],
    ".qums.ac.ir": ["Qazvin University of Medical Sciences"],
    ".razi.ac.ir": ["Razi University"],
    ".rums.ac.ir": ["Rafsanjan University of Medical Sciences"],
    ".sadjad.ac.ir": ["Sadjad Institute of Technology"],
    ".sadra.ac.ir": ["Sadra University"],
    ".sbmu.ac.ir": ["Shaheed Beheshti University of Medical Sciences"],
    ".sbu.ac.ir": ["Shahid Beheshti University"],
    ".semnan.ac.ir": ["Semnan University"],
    ".semnaniau.ac.ir": ["Islamic Azad University, Semnan"],
    ".shahed.ac.ir": ["Shahed University"],
    ".shahroodut.ac.ir": ["Shahrood University of Technology"],
    ".shahryariau.ac.ir": ["Islamic Azad University, Shahryar"],
    ".shbu.ac.ir": ["Sheikhbahaee University"],
    ".shirazu.ac.ir": ["Shiraz University"],
    ".shomal.ac.ir": ["Shomal University"],
    ".sku.ac.ir": ["Shahrekord University"],
    ".skums.ac.ir": ["Shahrekord University of Medical Sciences"],
    ".spnu.ac.ir": ["Shiraz Payamnoor University"],
    ".srbiau.ac.ir": ["Islamic Azad University, Tehran Science &amp; Research Branch"],
    ".ssu.ac.ir": ["Yazd Medical University"],
    ".sums.ac.ir": ["Shiraz University of Medical Sciences"],
    ".sut.ac.ir": ["Sahand University of Technology"],
    ".sutech.ac.ir": ["Shiraz University of Technology"],
    ".tabriziau.ac.ir": ["Tabriz Islamic Art University"],
    ".tabrizu.ac.ir": ["Tabriz University"],
    ".tbzmed.ac.ir": ["Tabriz University of Medical Sciences"],
    ".tct.ac.ir": ["Tabriz College of Technology"],
    ".tiau.ac.ir": ["Takestan Islamic Azad University"],
    ".tums.ac.ir": ["Tehran University of Medical Sciences"],
    ".uast.ac.ir": ["University of Applied Science and Technology"],
    ".ui.ac.ir": ["Isfahan University"],
    ".uk.ac.ir": ["Shahid Bahonar University of Kerman"],
    ".um.ac.ir": ["Ferdowsi University of Mashhad"],
    ".uma.ac.ir": ["University of Mohaghegh"],
    ".umsha.ac.ir": ["Hamadan University of Medical Sciences"],
    ".umsu.ac.ir": ["Urmia University of Medical Sciences"],
    ".umz.ac.ir": ["Mazandaran University of Iran"],
    ".uok.ac.ir": ["University of Kurdistan"],
    ".uoz.ac.ir": ["Zabol University"],
    ".urmia.ac.ir": ["Urmia University"],
    ".usb.ac.ir": ["Sistan &amp; Balouchestan University"],
    ".usc.ac.ir": ["University of Science and Culture"],
    ".ustmb.ac.ir": ["Mazandaran University of Science &amp; Technology"],
    ".uswr.ac.ir": ["University of Social Welfare and Rehabilitation Scinences"],
    ".ut.ac.ir": ["University of Tehran"],
    ".uut.ac.ir": ["Urmia University of Technology"],
    ".vru.ac.ir": ["Vali-e-Asr University"],
    ".yu.ac.ir": ["Yasuj University"],
    ".yums.ac.ir": ["Yasuj University of Medical Sciences"],
    ".znu.ac.ir": ["Zanjan University"],
    ".zums.ac.ir": ["Zanjan University of Medical Sciences"],
    ".hbi.ir": ["Ilam University of Medical Sciences"],
    ".mrl-spl.ir": [
        "Mechatronics Research Laboratory, Islamic Azad University, Qazvin"
    ],
    ".bifrost.is": ["Bifrost School of Business"],
    ".fss.is": ["Fjölbrautaskóli Suðurnesja"],
    ".hi.is": ["University of Iceland"],
    ".holar.is": ["Holar University College"],
    ".hsvest.is": ["University Centre of the Westfjords"],
    ".hvanneyri.is": ["Hvanneyri Agricultural University"],
    ".iti.is": ["Technological University of Iceland"],
    ".khi.is": ["Iceland University of Education"],
    ".lhi.is": ["Iceland Academy of the Arts"],
    ".ru.is": ["Reykjavík University"],
    ".tskoli.is": ["Tækniskólinn"],
    ".unak.is": ["University of Akureyri"],
    ".ababrera.it": ["Accademia di Belle Arti di Brera, Milan, Italy"],
    ".accademiasantagiulia.it": [
        "Accademia Di Belle Arti di Santa Giulia",
        "SantaGiulia Fine Arts Academy",
    ],
    ".studenti.alberghetti.it": ["Alberghetti IIS"],
    ".studenti.apuliadigitalmaker.it": ["ITS Apulia Digital Maker"],
    ".avbo.it": ["Aldini Valeriani", "Aldini Valeriani"],
    ".bearzi.it": ['Istituto Tecnico Industriale "G. Bearzi", Udine'],
    ".belluzzifioravanti.it": ["IIS Belluzzi Fioravanti"],
    ".itis.biella.it": ["ITIS Q. SELLA"],
    ".luxemburg.bo.it": ["Istituto Tecnico Commerciale Statale Rosa Luxemburg"],
    ".chilesotti.it": ["ITT G. Chilesotti"],
    ".ciusa.it": ["Istituto Istruzione Superiore Francesco Ciusa"],
    ".cobianchi.it": ["IIS L. Cobianchi"],
    ".consalerno.it": ['Conservatorio di Musica "G. Martucci", Salerno (Italia)'],
    ".copernicopasoli.it": ["Copernico Pasoli"],
    ".curiepergine.it": ['Istituto di istruzione "Marie Curie"'],
    ".davincifascetti.it": ["I.I.S L. da Vinci - Fascetti"],
    ".donboscosandona.it": ["CFP don Bosco"],
    ".1circolopozzuoli.edu.it": [
        "I Circolo Didattico G. Marconi",
        "I Circolo Didattico G. Marconi",
    ],
    ".barsanti.edu.it": [
        "ITT E. Barsanti Castelfranco Veneto",
        "ITT E. Barsanti Castelfranco Veneto",
    ],
    ".battaglini.edu.it": [" Liceo Scientifico di Stato G. Battaglini"],
    ".calvino.edu.it": ["Istituto Italo Calvino"],
    ".capellinisauro.edu.it": [
        "Istituto di Istruzione Superiore G. Capellini N. Sauro"
    ],
    ".corridoni-campana.edu.it": [None],
    ".fermibassano.edu.it": ["ITIS E.Fermi, Bassano del Grappa"],
    ".fermilecce.edu.it": [
        'Istituto Tecnico Industriale Statale "Enrico Fermi" - Lecce',
        'Industrial Technical Institute "Enrico Fermi" - Lecce',
    ],
    ".galileilivorno.edu.it": [
        "I.T.I.S. Galileo Galilei, Livorno",
        "Technical-Industrial Institute Galileo Galilei, Leghorn",
    ],
    ".giua.edu.it": ['Istituto di Istruzione Superiore "Michele Giua"'],
    ".ic-rosmini.edu.it": ["IC Antonio Rosmini"],
    ".icmolassanaeprato.edu.it": ["I.C. Molassana e Prato"],
    ".icsmarconipalermo.edu.it": [
        "Istituto Comprensivo Guglielmo Marconi Palermo",
        "Comprehensive Institute Guglielmo Marconi Palermo",
    ],
    ".icstoppaniseregno.edu.it": [
        "S.M.I.M. Don Milani Seregno",
        "Don Milani Secondary School Seregno",
    ],
    ".ictassolatina.edu.it": ["Istituto Compressivo n.5 Torquato Tasso Latina"],
    ".iis-silva-ricci.edu.it": [
        'Istituto di Istruzione Superiore "Giovanni Silva - Matteo Ricci"'
    ],
    ".iisbadoni.edu.it": ["Istituto di Istruzione Tecnico Antonio Badoni - IIS Badoni"],
    ".iislagrange.edu.it": ["I.I.S. Giuseppe Luigi Lagrange"],
    ".iismajoranamoncalieri.edu.it": ["Liceo Majorana Moncalieri"],
    ".iispaciolobracciano.edu.it": ["IIS Luca Paciolo", "Scientific high school"],
    ".iisvicodevivo.edu.it": ["Istituto Istruzione superiore Vico-De Vivo"],
    ".iisvoltapescara.edu.it": ["IIS A. Volta Pescara, Italy"],
    ".ilpitagora.edu.it": ["Il pitagora liceo scientifico RC"],
    ".alu.isfalcone.edu.it": [
        'Istituto d\'Istruzione Secondaria Superiore "Giovanni Falcone" Loano'
    ],
    ".isfermiguttuso.edu.it": ['IIS "Fermi-Guttuso" Giarre(CT) -Italy'],
    ".isfrancescoredi.edu.it": [
        "I.I.S.S Francesco Redi Paternò",
        "I.I.S.S Francesco Redi Paternò",
    ],
    ".isisbernocchi.edu.it": ["ITIS A. Bernocchi", "High school"],
    ".isisfacchinetti.edu.it": ['I.S.I.S. "C. Facchinetti"'],
    ".isissacilebrugnera.edu.it": [
        "Istituto Statale Istruzione Superiore Sacile Brugnera"
    ],
    ".isisvarchi.edu.it": ["I.S.I.S. Benedetto Varchi, Montevarchi"],
    ".isisvirgilio.edu.it": ["ISIS Virgilio"],
    ".isrosselliaprilia.edu.it": ["Carlo e Nello Rosselli"],
    ".istitutoeuropaunita.edu.it": [
        "Istituto Istruzione Superiore Europa Unita Chivasso"
    ],
    ".istitutofortuny.edu.it": ["I.I.S. Mariano Fortuny", "I.I.S. Mariano Fortuny"],
    ".istitutoinsolera.edu.it": ["IISS Filadelfo Insolera"],
    ".istitutolevi.edu.it": ["Istituto di Istruzione Superiore 'Primo Levi'"],
    ".istitutomontani.edu.it": ["Istituto Tecnico Industriale Montani"],
    ".istitutomoreschi.edu.it": [
        'Istituto di Istruzione Superiore "Nicola Moreschi"',
        '"Nicola Moreschi" High School',
    ],
    ".iti-marconi.edu.it": ['ITST "G. Marconi" Campobasso'],
    ".itifaraday.edu.it": ['Istituto Tecnico Industriale "Michael Faraday"'],
    ".itiseveripadova.edu.it": ["ITI Franceso Severi", "ITI Franceso Severi"],
    ".itisgrassi.edu.it": [
        "===> itis 'Carlo grassi' Mechatronics\\Informatics <===",
        "- Address : VIA VERONESE 305, 10100 TORINO (TO)",
        "- official website : https://www.itisgrassi.edu.it/pvw/app/TOIT0017/pvw_sito.php",
    ],
    ".itisravenna.edu.it": ["ITIS N.Baldini, Ravenna"],
    ".itisvallauri.edu.it": ['Istituto Tecnico Industriale Statale "G.VALLAURI"'],
    ".itiszuccante.edu.it": ['ITIS "C. Zuccante", Mestre (VE)'],
    ".itive3pa.edu.it": ["Istituto Tecnico Industriale Vittorio Emanuele III Palermo"],
    ".itivolta.edu.it": [
        "ISTITUTO TECNICO TECNOLOGICO STATALE ALESSANDRO VOLTA",
        "official website https://itivolta.edu.it",
        "Long term (3 yrs) computer science course information: https://www.itivolta.edu.it/offerta-formativa-itts-volta/",
    ],
    ".ittsrimini.edu.it": [
        "Istituto Tecnico Tecnologico Statale “O. Belluzzi – L. da Vinci”"
    ],
    ".ittsscalfaro.edu.it": ['ISTITUTO TECNICO INDUSTRIALE "E.SCALFARO"'],
    ".ittvt.edu.it": ['ITT "LEONARDO DA VINCI" - VITERBO'],
    ".liceochinimichelangelo.edu.it": [
        "Istituto Istruzione Superiore Chini-Michelangelo - https://www.liceochinimichelangelo.edu.it/"
    ],
    ".liceodesio.edu.it": [
        'Liceo Statale Scientifico e Classico "Ettore Majorana" Desio'
    ],
    ".liceoeinsteinmilano.edu.it": ["Liceo Scientifico Statale Einstein Milano"],
    ".liceofedericoquercia.edu.it": ["Liceo Federico Querica | Marcianise CE, Italy"],
    ".liceogalileicatania.edu.it": [
        "Liceo Scientifico Statale Galileo Galilei - http://www.liceogalileicatania.edu.it/"
    ],
    ".liceoischia.edu.it": ['Liceo Statale "Ischia"'],
    ".liceomonti.edu.it": [
        "Liceo Augusto Monti, Chieri (TO)",
        "Liceo Augusto Monti, Chieri (TO)",
    ],
    ".liceopepecalamo.edu.it": ['Liceo Scientifico "Pepe Calamo"'],
    ".luigidellerba.edu.it": [
        'I.I.S.S. "Luigi Dell\'Erba", Castellana Grotte (BA), Italy'
    ],
    ".magistricumacini.edu.it": ["I.T.I.S. Magistri Cumacini"],
    ".studenti.marconiverona.edu.it": [
        "Istituto Tecnico Industriale Statale G. Marconi Verona VRIT0007 - P.le R. Guardini 1, 37138 Verona"
    ],
    ".messedaglia.edu.it": ['Liceo Scientifico "A. Messedaglia"'],
    ".nerviferrari.edu.it": ['LICEO "P. NERVI - G. FERRARI" - Morbegno (SO)'],
    ".newtonpertini.edu.it": [
        "Istituto di Istruzione Superiore Newton-Pertini",
        "Upper secondary school Newton-Pertini",
    ],
    ".pacinottitaranto.edu.it": ['Istituto Tecnico Industriale Statale "A. Pacinotti"'],
    ".panettipitagora.edu.it": ["ITT Panetti - Pitagora"],
    ".paolosarpi.edu.it": ["ISIS Paolo Sarpi"],
    ".paschinilinussio.edu.it": ["ISIS Paschini-Linussio, Tolmezzo"],
    ".poloagroindustriale.edu.it": [
        '"Itis Galileo Galilei" High school - http://poloagroindustriale.edu.it/'
    ],
    ".silvioceccato.edu.it": ["IIS Silvio Ceccato"],
    ".tulliobuzzi.edu.it": ["ITS Tullio Buzzi di Prato"],
    ".einaudicorreggio.it": [
        'ISTITUTO TECNICO STATALE "LUIGI EINAUDI"',
        "Luigi Einaudi secondary school",
    ],
    ".embl.it": [
        "EMBL, Rome",
        "European Molecular Biology Laboratory",
        "URL: https://www.embl.it",
        "Courses: https://www.embl.org/training/",
    ],
    ".fermielearning.it": [
        "Istituto Tecnico Tecnologico Enrico Fermi",
        " Enrico Fermi Technological Technological Institute",
    ],
    ".cellini.fi.it": ["Istituto di Istruzione Superiore Benvenuto Cellini di Firenze"],
    ".isiadesign.fi.it": ["Istituto Superiore per le Industrie Artistiche di Firenze"],
    ".fossatidapassano.it": [
        "Istituto Tecnico Commerciale e Tecnologico Fossati-Da Passano",
        "Technical Commercial and Technological Institute Fossati-Da Passano",
    ],
    ".accademiabellearti.fr.it": ["Frosinone Academy of Fine Arts"],
    ".galileo.galileicrema.it": ["IIS Galileo Galilei Crema"],
    ".galileimirandola.it": ["Istituto Superiore Statale Galileo Galilei Mirandola"],
    ".calvino.ge.it": ["Istituto Italo Calvino"],
    ".barsanti.gov.it": [
        '"ITT Eugenio Barsanti" High school - http://www.barsanti.gov.it/'
    ],
    ".fossatidapassano.gov.it": [
        "Istituto Tecnico Commerciale e Tecnologico Fossati-Da Passano"
    ],
    ".studenti.gobettivolta.gov.it": ["I.S.I.S P.Gobetti-A.Volta"],
    ".icstoppaniseregno.gov.it": [
        "S.M.I.M. Don Milani Seregno",
        "Don Milani Secondary School Seregno",
    ],
    ".iisgiorgimilano.gov.it": [
        '"IIS Giovanni Giorgi Milano" High School - http://iisgiorgimilano.gov.it/'
    ],
    ".isisfacchinetti.gov.it": ["ISIS Cipriano Facchinetti"],
    ".ispascalcomandini.gov.it": [
        "Isituto Superiore Statale Pascal-Comandini - https://www.ispascalcomandini.gov.it/"
    ],
    ".issgreppi.gov.it": [
        '"Alessandro Greppi" High School - http://www.issgreppi.gov.it/'
    ],
    ".itiszuccante.gov.it": ["ITIS Carlo Zuccante"],
    ".liceovinci.gov.it": [
        "Liceo Leonardo Da Vinci Casalecchio di Reno Bologna Italy",
        "High Scool Leonardo Da Vinci Casalecchio di Reno Bologna Italy",
        "-----",
        "Via Cavour, 6 - 40033 Casalecchio di Reno • Tel. 051 591868 - Fax 051 6130834",
        "Via Panfili, 17/3 - 40133 Bologna • Tel. 051 6194857 - Fax 051 3519779",
        "-----",
        "https://www.liceovinci.edu.it/",
        "https://www.liceovinci.gov.it/",
    ],
    ".paciolo-dannunzio.gov.it": [
        "IISS Paciolo D'Annunzio - http://www.paciolo-dannunzio.gov.it"
    ],
    ".poloagroindustriale.gov.it": [
        '"Itis Galileo Galilei" High school - http://poloagroindustriale.gov.it/'
    ],
    ".racchettidavinci.gov.it": [
        '"Liceo Racchetti da Vinci"  https://www.racchettidavinci.gov.it'
    ],
    ".gssi.it": ["Gran Sasso Science Institute"],
    ".iaad.it": ["Istituto d'Arte Applicata e Design"],
    ".icatt.it": ["Catholic University of the Sacred Heart"],
    ".ictp.it": ["International Centre for Theoretical Physics"],
    ".iisaltierospinelli.it": [
        "Institute of Higher Education Altiero Spinelli (IIS Altiero Spinelli)",
        "Institute of Higher Education Altiero Spinelli (IIS Altiero Spinelli)",
    ],
    ".iiscuriesraffa.it": ["IIS Curie Sraffa Milano"],
    ".iisenzoferrari.it": ["IIS Ferrari-Hertz"],
    ".iistorriani.it": ["IIS Janello Torriani"],
    ".iisve.it": ["IIS Volterra Elia", "Volterra Elia Education Institute"],
    ".iit.it": ["Istituto Italiano di Tecnologia"],
    ".imtlucca.it": ["Institute for Advanced Studies Lucca"],
    ".isii.it": ["Istituto Superiore di Istruzione Industriale Guglielmo Marconi "],
    ".isiltp.it": ["Istruzione Liceale Tecnica e Professionale"],
    ".isissacilebrugnera.it": ["Istituto Statale Istruzione Superiore Sacile Brugnera"],
    ".ispascalcomandini.it": ["Istituto Superiore Pascal Comandini "],
    ".issgreppi.it": [
        ' "Alessandro Greppi" High School  -  http://www.issgreppi.gov.it/'
    ],
    ".istitutoacerbo.it": ['Istituto Tecnico "Tito Acerbo", Pescara'],
    ".istitutofortuny.it": ["I.I.S. Mariano Fortuny", "I.I.S. Mariano Fortuny"],
    ".istitutolevi.it": ["Istituto di Istruzione Superiore 'Primo Levi'"],
    ".istitutopilati.it": ['Istituto Tecnico "Carlo Antonio Pilati"'],
    ".aldini.istruzioneer.it": ["Aldini Valeriani ", "Aldini Valeriani"],
    ".berenini.istruzioneer.it": [
        "Domain of IISS Agostino Berenini | e-mail example: studlsa-<last_name>-<birth_year>@berenini.istruzioneer.it"
    ],
    ".cattaneodallaglio.istruzioneer.it": [
        "IIS Cattaneo Dall' Aglio",
        "https://www.cattaneodallaglio.edu.it/",
        "https://www.cattaneodallaglio.edu.it/tecnici-informatica-e-telecomunicazioni/",
        "https://www.cattaneodallaglio.edu.it/wp-content/uploads/2020/11/Indirizzi-e-mail-istituzionali-Docenti-a.s.20-21.pdf",
    ],
    ".lsoriani.istruzioneer.it": ["Liceo Scientifico Alfredo Oriani"],
    ".paciunzio.istruzioneer.it": [
        "Domain of IISS Paciolo Dannunzio | e-mail example: <last_name>.<first_name>@paciunzio.istruzioneer.it"
    ],
    ".itimedi.it": ["Istituto Tecnico Industriale, E. Medi"],
    ".itimonaco.it": [
        'Istituto Tecnico Industriale "Monaco", Cosenza',
        '"Monaco" Industrial Technical Institute, Cosenza',
    ],
    ".itisandria.it": ['ITIS "Sen. O. Jannuzzi" Andria', "ITIS Jannuzzi"],
    ".studenti.itisavogadro.it": ["IIS Amedeo Avogadro"],
    ".itiscastelli.it": ["ITIS Castelli, Brescia"],
    ".itispaleocapa.it": ["ITIS PALEOCAPA"],
    ".itispascal.it": ["ITIS Biagio Pascal, Roma (RM)"],
    ".itispininfarina.it": ["ITIS Pininfarina, Moncalieri (TO)"],
    ".itisravenna.it": ["ITIS N.Baldini, Ravenna"],
    ".itisurbino.it": ['ITIS "E. Mattei"'],
    ".its-ictpiemonte.it": ["ITS for ICT Piemonte"],
    ".stud.itsaltoadriatico.it": ["ITS Alto Adriatico"],
    ".itsjobs.it": ['Fondazione Istituto Tecnico Superiore "Steve Jobs" '],
    ".itsos-mariecurie.it": [
        "Istituto Tecnico Itsos Marie Curie,via Masaccio,20063 Cernusco sul Naviglio (Milan Area)",
        "Institutional mail : info@itsos-mariecurie.it",
        "Institutional code : MITD400008",
    ],
    ".edu.itspiemonte.it": ["ITS for ICT Piemonte"],
    ".itsrizzoli.it": ["ITS Angelo Rizzoli"],
    ".iuav.it": ["University IUAV of Venice"],
    ".iue.it": ["European University Institute"],
    ".iulm.it": ["University Institute of Modern Languages"],
    ".iuo.it": ["University Institute of Oriental Studies"],
    ".iusspavia.it": ["Istituto Universitario di Studi Superiori"],
    ".jhubc.it": ["Johns Hopkins University, SAIS Bologna Center"],
    ".liceocaronapoli.it": [
        'LLICEO SCIENTIFICO STATALE "TITO LUCREZIO CARO" Napoli   '
    ],
    ".liceoconegliano.it": [
        'Liceo "Guglielmo Marconi", Conegliano',
        'High school "Guglielmo Marconi", Conegliano',
    ],
    ".studenti.liceofermipadova.it": ["Liceo Scientifico Enrico Fermi Padova"],
    ".liceokennedy.it": ["Liceo Scientifico Statale J. F. Kennedy"],
    ".liceomelipalermo.it": [
        'Liceo Classico Internazionale "G.Meli"',
        '"G.Meli" International Classical High School',
    ],
    ".liceorighi.it": ["Liceo Scientifico Augusto Righi"],
    ".liceosabin.it": ["Liceo Scientifico Statale Albert Bruce Sabin"],
    ".liceoscacchibari.it": ["Liceo Scacchi Bari", "Scacchi"],
    ".linkstudents.it": ["Link Campus University", "Link Campus University"],
    ".liuc.it": ["Free University Institute Carlo Cattaneo"],
    ".lsamaldi.it": ["Liceo Scientifico E. Amaldi"],
    ".luiss.it": ["Free International University of Social Studies"],
    ".studenti.lum.it": [
        'Università LUM "Giuseppe Degennaro"',
        'LUM University "Giuseppe Degennaro"',
    ],
    ".lum.it": [
        'Università LUM "Giuseppe Degennaro"',
        'LUM University "Giuseppe Degennaro"',
    ],
    ".lumsa.it": ["Free University Maria Santissima Assunta"],
    ".lumsastud.it": ["Libera Università Maria Santissima Assunta (LUMSA)"],
    ".magistricumacini.it": ["Istituto Tecnico Industriale Statale Magistri Cumacini"],
    ".marconigorgonzola.it": ["Istituto Guglielmo Marconi"],
    ".marconirovereto.it": ["Istituto Tecnico Tecnologico Guglielmo Marconi"],
    ".maxplanck.it": ["I.T.I.S Max Planck"],
    ".mcurie.it": [
        'Istituto di Istruzione Secondaria Superiore "Marie Curie", Via Togliatti 5, 47039 Savignano sul Rubicone (FC)',
        "Institutional mail : fois001002@istruzione.it",
        "Institutional code : FOIS001002",
        "Official website: https://www.mcurie.gov.it/",
        "URL of courses with IT: https://www.mcurie.gov.it/quadro-orario-liceo.html (The second table)",
        "PDF about official email domain for students: https://www.mcurie.gov.it/component/k2/item/download/3351_a9700b4d7736f885529319f0c15520e0.html",
    ],
    ".maxwell.mi.it": ["IIS J.C. Maxwell Milano"],
    ".fermi.mo.it": ['Istituto Tecnico Industriale "Enrico Fermi" - Modena'],
    ".itivinci.mo.it": [
        'Istituto Tecnico Industriale "Leonardo Da Vinci", Carpi (MO), Italia'
    ],
    ".unisob.na.it": ["University Institute of Teacher Training Suor Orsola Benincasa"],
    ".naba.it": ["NABA - Nuova Accademia di Belle Arti, Milan"],
    ".olivelliputelli.it": [
        'Istituto d\'istruzione superiore "Olivelli Putelli"',
        'Institute of Higher Education "OLIVELLI Putelli"',
        "School official website: https://www.olivelliputelli.edu.it",
        "IT related course offered by the school: https://www.olivelliputelli.edu.it/indirizzi-di-studio/indirizzo-tecnologico",
        " ",
    ],
    ".poliba.it": ["Polytechnic Institute of Bari"],
    ".polimi.it": ["Polytechnic Institute of Milan"],
    ".polito.it": ["Polytechnic Institute of Turin"],
    ".itis.pr.it": ["ITIS Leonardo da Vinci"],
    ".pul.it": [
        "Pontificia Università Lateranense",
        "Pontifcia Universitas Lateranensis",
    ],
    ".pusc.it": ["Pontificia Università della Santa Croce"],
    ".sissa.it": ["International Higher School for Advanced Studies Trieste"],
    ".snets.it": ["Schulnetz Südtirol"],
    ".sns.it": ["School of Education Pisa"],
    ".sssup.it": ["Higher School of University and Advanced Studies Pisa"],
    ".studbocconi.it": ["Bocconi University"],
    ".studentipinin.it": ["ITIS Pininfarina, Moncalieri (TO)"],
    ".schule.suedtirol.it": ["Oberschulzentrum J. Ph. Fallmerayer"],
    ".tecnicosuperiorekennedy.it": ["Istituto Tecnico Superiore Kennedy"],
    ".artigianelli.tn.it": ["Istituto Pavoniano Artigianelli"],
    ".buonarroti.tn.it": ["Istituto Tecnico Tecnologico Buonarroti-Pozzo"],
    ".ictp.trieste.it": ["Abdus Salam international centre for theoretical physics"],
    ".univ.trieste.it": ["University of Trieste"],
    ".tuascuola.it": ['Centro Scolastico "TuaScuola"'],
    ".studenti.malignani.ud.it": ["ISIS A.Malignani"],
    ".malignani.ud.it": ["ISIS Arturo Malignani"],
    ".unian.it": ["University of Ancona"],
    ".uniba.it": ["University of Bari"],
    ".unibas.it": ["Basilicata University Potenza"],
    ".unibg.it": ["University of Bergamo"],
    ".unibo.it": ["University of Bologna"],
    ".unibocconi.it": ['Università Commerciale "L. Bocconi"', "Bocconi University"],
    ".unibs.it": ["University of Brescia"],
    ".unibz.it": ["Free University of Bozen"],
    ".unica.it": ["University of Cagliari"],
    ".unical.it": ["University of Calabria"],
    ".unicam.it": ["University of Camerino"],
    ".unicampania.it": ['University of Campania "Luigi Vanvitelli"'],
    ".unicampus.it": ["Campus Bio-Medico University of Rome"],
    ".unicas.it": ["University of Cassino"],
    ".unicatt.it": ["Catholic University of the Sacred Heart"],
    ".unich.it": ["University of Chieti"],
    ".unict.it": ["University of Catania"],
    ".unicz.it": ["University Magna Graecia of Catanzaro"],
    ".studenti.uniecampus.it": ["Università E-Campus", "E-Campus University"],
    ".uniecampus.it": ["Università degli Studi eCampus"],
    ".uniese.it": ["European School of Economics"],
    ".unife.it": ["University of Ferrara"],
    ".unifg.it": ["University of Foggia"],
    ".unifi.it": ["University of Florence"],
    ".unige.it": ["University of Genoa"],
    ".unigre.it": ["Pontifica Università Gregoriana"],
    ".unikore.it": ['Università degli Studi di Enna "Kore"'],
    ".unikorestudent.it": ['Università degli Studi di Enna "Kore"'],
    ".unile.it": ["University of Lecce"],
    ".unilink.it": ["Link Campus University of Malta"],
    ".unimarconi.it": ["University  Guglielmo Marconi"],
    ".unimc.it": ["University of Macerata"],
    ".unime.it": ["University of Messina"],
    ".unimi.it": ["University of Milan"],
    ".unimib.it": ["University of Milan - Bicocca"],
    ".unimo.it": ["University of Modena"],
    ".unimol.it": ["University of Molise"],
    ".unimore.it": ["University of Modena and Reggio Emilia"],
    ".unina.it": ["University of Naples Federico II"],
    ".unina2.it": ["Second University of Naples"],
    ".uninav.it": ["University Institute of Naval Studies"],
    ".uninsubria.it": ["University of Insubria"],
    ".unipa.it": ["University of Palermo"],
    ".uniparthenope.it": ['Università degli studi di Napoli "Parthenope"'],
    ".unipd.it": ["University of Padua"],
    ".unipg.it": ["University of Perugia"],
    ".studenti.unipi.it": ["Università di Pisa", "University of Pisa"],
    ".unipi.it": ["University of Pisa"],
    ".unipmn.it": ["University of Piemonte Orientale"],
    ".unipr.it": ["University of Parma"],
    ".unipv.it": ["University of Pavia"],
    ".unirc.it": ["University of Reggio Calabria"],
    ".uniroma1.it": ["University of Roma La Sapienza"],
    ".uniroma2.it": ["University of Roma Tor Vergata"],
    ".uniroma3.it": ["Third University of Rome"],
    ".uniroma5.it": ["Università telematica san raffaele"],
    ".unisa.it": ["University of Salerno"],
    ".unisal.it": ["Università Pontificia Salesiana"],
    ".unisalento.it": ["University of Salento"],
    ".unisannio.it": ["University of Sannio"],
    ".unisg.it": ["University of Gastronomic Sciences"],
    ".unisi.it": ["University of Siena"],
    ".studenti.unisr.it": [
        "Universita' Vita-Salute San Raffaele",
        "San Raffaele Vita-Salute University",
    ],
    ".uniss.it": ["University of Sassari"],
    ".unistrapg.it": ["University of Italian Studies for Foreigners of Perugia"],
    ".unistrasi.it": ["University of Italian Studies for Foreigners of Siena"],
    ".unite.it": ["University of Teramo"],
    ".studenti.unitelmasapienza.it": ["Università telematica UNITELMA Sapienza"],
    ".unitn.it": ["University of Trento"],
    ".unito.it": ["University of Turin"],
    ".units.it": ["University of Trieste"],
    ".unitus.it": ["Viterbo State University"],
    ".uniud.it": ["University of Udine"],
    ".studenti.uniupo.it": [
        'Università del Piemonte Orientale "Amedeo Avogadro", Alessandria - Novara - Vercelli, Italia'
    ],
    ".uniupo.it": [
        'Università del Piemonte Orientale "Amedeo Avogadro", Alessandria - Novara - Vercelli, Italia'
    ],
    ".uniurb.it": ["University of Urbino"],
    ".univaq.it": ["University of Aquila"],
    ".univda.it": ["University of Valle d'Aosta"],
    ".stud.unive.it": ["Università Ca' Foscari", "Ca' Foscari University"],
    ".unive.it": [
        "University Institute of Architecture Venice",
        "University of Venice",
    ],
    ".universitadipavia.it": ["University of Pavia"],
    ".univpm.it": ["Marche Politecnic University"],
    ".univr.it": ["University of Verona"],
    ".urbe.it": [
        "Pontificio Istituto Orientale",
        "Pontifcia Università Gregoriana",
        "Pontifcia Universitas a S.Thomas Aquinate in Urbe",
        "Università Pontifcia Salesiana",
    ],
    ".itisrossi.vi.it": ["ISTITUTO TECNICO INDUSTRIALE STATALE A.ROSSI"],
    ".voltaweb.it": ['LICEO SCIENTIFICO STATALE "A. VOLTA"'],
    ".ncu.edu.jm": ["Northern Caribbean University"],
    ".utech.edu.jm": ["University of Technology Jamaica"],
    ".uwimona.edu.jm": ["University of the West Indies, Mona"],
    ".aabu.edu.jo": ["Al al-Bayt University"],
    ".aau.edu.jo": ["Amman Arab University for Higher Studies"],
    ".ahu.edu.jo": ["Al Hussein Bin Talal University"],
    ".aou.edu.jo": ["Arab Open University"],
    ".asu.edu.jo": ["Applied Science University"],
    ".bau.edu.jo": ["Al-Balqa Applied University", "Balqa Applied University"],
    ".gju.edu.jo": ["German Jordanian University"],
    ".hu.edu.jo": ["Hashemite University"],
    ".inu.edu.jo": ["Irbid National University"],
    ".jadara.edu.jo": ["Jadara University"],
    ".jam.edu.jo": ["Jordan Academy of Music / Higher Institute of Music"],
    ".ju.edu.jo": ["Jordan University"],
    ".just.edu.jo": ["Jordan University of Science and Technology"],
    ".meu.edu.jo": ["Middle East University"],
    ".mutah.edu.jo": ["Mu' tah University"],
    ".philadelphia.edu.jo": ["Philadelphia University"],
    ".psut.edu.jo": ["Princess Sumaya University for Technology"],
    ".ttu.edu.jo": ["Tafila Technical University "],
    ".uop.edu.jo": ["University of Petra"],
    ".wise.edu.jo": ["The World Islamic Sciences &amp; Education University"],
    ".yu.edu.jo": ["Yarmouk University"],
    ".zpu.edu.jo": ["Zarka Private University"],
    ".student.42tokyo.jp": ["42tokyo"],
    ".aasa.ac.jp": ["Aichi Shukutoku University"],
    ".abu.ac.jp": ["Aichi Bunkyo University"],
    ".aichi-edu.ac.jp": ["Aichi University of Education"],
    ".aichi-fam-u.ac.jp": ["Aichi Prefectural University of Fine Arts &amp; Music"],
    ".aichi-gakuin.ac.jp": ["Aichi Gakuin University"],
    ".aichi-med-u.ac.jp": ["Aichi Medical University"],
    ".aichi-pu.ac.jp": ["Aichi Prefectural University"],
    ".aichi-u.ac.jp": ["Aichi University"],
    ".aiit.ac.jp": ["Advanced Institute of Industrial Technology"],
    ".aikoku-u.ac.jp": ["Aikoku Gakuen University"],
    ".aitech.ac.jp": ["Aichi Institute of Technology"],
    ".akita-u.ac.jp": ["Akita University"],
    ".aomori-u.ac.jp": ["Aomori University"],
    ".aomoricgu.ac.jp": ["Aomori Chuoh Gakuin University"],
    ".aoyama.ac.jp": ["Aoyama Gakuin University"],
    ".asahi-u.ac.jp": ["Asahi University"],
    ".asahikawa-med.ac.jp": ["Asahikawa Medical College"],
    ".asahikawa-u.ac.jp": ["Asahikawa University"],
    ".ashitech.ac.jp": ["Ashikaga Institute of Technology"],
    ".ashiya-u.ac.jp": ["Ashiya University"],
    ".asia-u.ac.jp": ["Asia University"],
    ".asu.ac.jp": ["Aichi Sangyo University"],
    ".atomi.ac.jp": ["Atomi College"],
    ".auhw.ac.jp": ["Aomori University of Health and Welfare"],
    ".azabu-u.ac.jp": ["Azabu University"],
    ".baika.ac.jp": ["Baika Women's College"],
    ".baiko.ac.jp": ["Baiko Women's College"],
    ".beppu-u.ac.jp": ["Beppu University"],
    ".budo-u.ac.jp": ["International Budo University"],
    ".bukkyo-u.ac.jp": ["Bukkyo University"],
    ".bunka-wu.ac.jp": ["Bunka Women's University"],
    ".bunkyo.ac.jp": ["Bunkyo University"],
    ".cgu.ac.jp": ["Chuo Gakuin University"],
    ".chiba-u.ac.jp": ["Chiba University"],
    ".chikushi.ac.jp": ["Chikushi Jogakuen University"],
    ".chubu-gu.ac.jp": ["Chubu Gakuin University &amp; Chubu Women's College"],
    ".chubu.ac.jp": ["Chubu University"],
    ".chukyo-u.ac.jp": ["Chukyo University"],
    ".chukyogakuin-u.ac.jp": ["Chukyo Gakuin University"],
    ".g.chuo-u.ac.jp": ["Chuo University"],
    ".chuo-u.ac.jp": ["Chuo University"],
    ".cku.ac.jp": ["Chiba Keizai University"],
    ".cuc.ac.jp": ["Chiba University of Commerce"],
    ".daido-it.ac.jp": ["Daido Institute of Technology"],
    ".daiichi-cps.ac.jp": ["Daiichi College of Pharmaceutical Sciences"],
    ".daiichi-koudai.ac.jp": ["Dai Ichi University, College of Technology"],
    ".daito.ac.jp": ["Daito Bunka University"],
    ".do-johodai.ac.jp": ["Hokkaido Information University"],
    ".doho.ac.jp": ["Doho University"],
    ".dohto.ac.jp": ["Dohto University"],
    ".dokkyo.ac.jp": ["Dokkyo University"],
    ".dokkyomed.ac.jp": ["Dokkyo University School of Medicine"],
    ".doshisha.ac.jp": [
        "Doshisha University",
        "Doshisha Women's College of Liberal Arts",
    ],
    ".edogawa-u.ac.jp": ["Edogawa University"],
    ".ehime-u.ac.jp": ["Ehime University"],
    ".eiyo.ac.jp": ["Kagawa Institute of Nutrition"],
    ".eum.ac.jp": ["Elisabeth University of Music"],
    ".fdcnet.ac.jp": ["Fukuoka Dental College"],
    ".ferris.ac.jp": ["Ferris University"],
    ".fit.ac.jp": ["Fukuoka Institute of Technology"],
    ".fmu.ac.jp": ["Fukushima Medical College"],
    ".fpu.ac.jp": ["Fukui Prefectural University"],
    ".fujijoshi.ac.jp": ["Fuji Women's College"],
    ".fujita-hu.ac.jp": ["Fujita Health University"],
    ".fukui-med.ac.jp": ["Fukui Medical School"],
    ".fukui-ut.ac.jp": ["Fukui University of Technology"],
    ".fukuoka-edu.ac.jp": ["Fukuoka University of Education"],
    ".fukuoka-int-u.ac.jp": ["Fukuoka International University"],
    ".fukuoka-pu.ac.jp": ["Fukuoka Prefectural University"],
    ".fukuoka-u.ac.jp": ["Fukuoka University"],
    ".fukushima-u.ac.jp": ["Fukushima University"],
    ".fukuyama-u.ac.jp": ["Fukuyama University"],
    ".fwu.ac.jp": ["Fukuoka Women's University"],
    ".gakusen.ac.jp": ["Aichi Gakusen University"],
    ".gakushuin.ac.jp": ["Gakushuin University"],
    ".gifu-keizai.ac.jp": ["Gifu Keizai University"],
    ".gifu-pu.ac.jp": ["Gifu Pharmaceutical University"],
    ".gifu-u.ac.jp": ["Gifu University"],
    ".gijodai.ac.jp": ["Gifu Women's University"],
    ".gpwu.ac.jp": ["Gunma Prefectural Women's University"],
    ".gunma-u.ac.jp": ["Gunma University"],
    ".h-bunkyo.ac.jp": ["Hiroshima Bunkyo Women's University"],
    ".hachinohe-u.ac.jp": ["Hachinohe University"],
    ".hakodate-u.ac.jp": ["Hakodate University"],
    ".hakuoh.ac.jp": ["Hakuoh University"],
    ".hal.ac.jp": ["Hal Tokyo"],
    ".hama-med.ac.jp": ["Hamamatsu University School of Medicine"],
    ".hanazono.ac.jp": ["Hanazono University"],
    ".hannan-u.ac.jp": ["Hannan University"],
    ".ca.harada-gakuen.ac.jp": ["Kagoshima Career Design College"],
    ".heisei-u.ac.jp": ["Fukuyama Heisei University"],
    ".hi-tech.ac.jp": ["Hachinohe Institute of Technology"],
    ".hijiyama-u.ac.jp": ["Hijiyama University"],
    ".himeji-du.ac.jp": ["Himeji Dokkyo University"],
    ".hirogaku-u.ac.jp": ["Hirosaki Gakuin University"],
    ".hirokoku-u.ac.jp": ["Hiroshima International University"],
    ".hirosaki-u.ac.jp": ["Hirosaki University"],
    ".hiroshima-cu.ac.jp": ["Hiroshima City University"],
    ".hiroshima-u.ac.jp": ["Hiroshima University"],
    ".hit-u.ac.jp": ["Hitotsubashi University"],
    ".hit.ac.jp": ["Hokkaido Institute of Technology"],
    ".hiu.ac.jp": ["Heisei International University"],
    ".hju.ac.jp": ["Hiroshima Jogakuin University"],
    ".hkg.ac.jp": ["Hiroshima Kokusai Gakuin University"],
    ".hokkai-s-u.ac.jp": ["Hokkaigakuen University"],
    ".hokkyodai.ac.jp": ["Hokkaido University of Education"],
    ".hoku-iryo-u.ac.jp": ["Hokkaido University of Health Sciences"],
    ".hokudai.ac.jp": ["Hokkaido University"],
    ".hokuriku-u.ac.jp": ["Hokuriku University"],
    ".hokusei.ac.jp": ["Hokusei Gakuen University"],
    ".hokuyakudai.ac.jp": ["Hokkaido Institute of Pharmaceutical Sciences"],
    ".hosei.ac.jp": ["Hosei University"],
    ".hoshi.ac.jp": ["Hoshi University"],
    ".hue.ac.jp": ["Hiroshima University of Economics"],
    ".hus.ac.jp": ["Hokkaido University of Science"],
    ".hyo-med.ac.jp": ["Hyogo College of Medicine"],
    ".hyogo-dai.ac.jp": ["Hyogo University"],
    ".hyogo-u.ac.jp": ["Hyogo University of Education"],
    ".ibaraki.ac.jp": ["Ibaraki University"],
    ".icc.ac.jp": ["Ibaraki Christian College"],
    ".icu.ac.jp": ["International Christian University"],
    ".ipu.ac.jp": ["Ibaraki Prefectural University of Health Sciences"],
    ".isenshu-u.ac.jp": ["Ishinomaki Senshu University"],
    ".it-chiba.ac.jp": ["Chiba Institute of Technology"],
    ".it-hiroshima.ac.jp": ["Hiroshima Institute of Technology"],
    ".iuhw.ac.jp": ["International University of Health and Welfare"],
    ".iuj.ac.jp": ["International University of Japan"],
    ".iuk.ac.jp": ["International University of Kagoshima"],
    ".iwakimu.ac.jp": ["Iwaki Meisei University"],
    ".iwate-med.ac.jp": ["Iwate Medical University"],
    ".iwate-pu.ac.jp": ["Iwate Prefectural University"],
    ".iwate-u.ac.jp": ["Iwate University"],
    ".jaist.ac.jp": ["Japan Advanced Institute of Science and Technology"],
    ".jichi.ac.jp": ["Jichi Medical School"],
    ".jikei.ac.jp": ["Jikei University School of Medicine"],
    ".jissen.ac.jp": ["Jissen Women's University"],
    ".jiu.ac.jp": ["Josai International University"],
    ".jobu.ac.jp": ["Jobu University"],
    ".josai.ac.jp": ["Josai University"],
    ".juen.ac.jp": ["Joetsu University of Education"],
    ".juntendo.ac.jp": ["Juntendo University"],
    ".jwu.ac.jp": ["Japan Women's University"],
    ".k-junshin.ac.jp": ["Kagoshima Immaculate Heart University"],
    ".kagawa-u.ac.jp": ["Kagawa University"],
    ".kagoshima-u.ac.jp": ["Kagoshima University"],
    ".kamakura-u.ac.jp": ["Kamakura Women's College"],
    ".kanagawa-it.ac.jp": ["Kanagawa Institute of Technology"],
    ".kanazawa-bidai.ac.jp": ["Kanazawa College of Art"],
    ".kanazawa-gu.ac.jp": ["Kanazawa Gakuin University"],
    ".kanazawa-it.ac.jp": ["Kanazawa Institute of Technology"],
    ".kanazawa-med.ac.jp": ["Kanazawa Medical University"],
    ".kanazawa-u.ac.jp": ["Kanazawa University"],
    ".kansai-u.ac.jp": ["Kansai University"],
    ".kanto-gakuen.ac.jp": ["Kanto Gakuen University"],
    ".kanto-gakuin.ac.jp": ["Kanto Gakuin University"],
    ".kawasaki-m.ac.jp": [
        "Kawasaki Medical School",
        "Kawasaki University of Medical Care",
    ],
    ".kbu.ac.jp": ["Kyoto Bunkyo University"],
    ".kcua.ac.jp": ["Kyoto City University of Arts"],
    ".keio.ac.jp": ["Keio University"],
    ".keisen.ac.jp": ["Keisen Jogaku-en College"],
    ".keiwa-c.ac.jp": ["Keiwa College"],
    ".kgwu.ac.jp": ["Kawamura Gakuen Woman's University"],
    ".kindai.ac.jp": ["Kinki University"],
    ".kinjo-u.ac.jp": ["Kinjo Gakuin University"],
    ".kit.ac.jp": ["Kyoto Institute of Technology"],
    ".kitakyu-u.ac.jp": ["Kitakyushu University"],
    ".kitami-it.ac.jp": ["Kitami Institute of Technology"],
    ".kitasato-u.ac.jp": ["Kitasato University"],
    ".kiu.ac.jp": ["Kyushu International University"],
    ".kiui.ac.jp": ["Kibi International University"],
    ".kms.ac.jp": ["Kagawa Medical School"],
    ".kmu.ac.jp": ["Kansai Medical University"],
    ".kobe-c.ac.jp": ["Kobe Jogakuin University"],
    ".kobe-cufs.ac.jp": ["Kobe City University of ForeignStudies"],
    ".kobe-du.ac.jp": ["Kobe Design University"],
    ".kobe-kiu.ac.jp": ["Kobe International University"],
    ".kobe-shinwa.ac.jp": ["Kobe Shinwa Women's University"],
    ".kobe-u.ac.jp": ["Kobe University"],
    ".kobe-wu.ac.jp": ["Kobe Women's University"],
    ".kobedenshi.ac.jp": ["Kobe Institute of Computing"],
    ".kobegakuin.ac.jp": ["Kobe Gakuin University"],
    ".kobepharma-u.ac.jp": ["Kobe Pharmaceutical University"],
    ".kochi-ms.ac.jp": ["Kochi Medical School"],
    ".kochi-tech.ac.jp": ["Kochi University of Technology"],
    ".kochi-u.ac.jp": ["Kochi University"],
    ".kogakkan-u.ac.jp": ["Kogakkan University"],
    ".kogakuin.ac.jp": ["Kogakuin University"],
    ".koka.ac.jp": ["Koka Women's College"],
    ".kokugakuin.ac.jp": ["Kokugakuin University"],
    ".kokushikan.ac.jp": ["Kokushikan University"],
    ".komazawa-u.ac.jp": ["Komazawa University"],
    ".konan-u.ac.jp": ["Konan University"],
    ".konan-wu.ac.jp": ["Konan Women's University"],
    ".korea-u.ac.jp": ["Korea University"],
    ".koriyama-kgc.ac.jp": ["Koriyama Women's University and College"],
    ".koshien.ac.jp": ["Koshien University"],
    ".koyasan-u.ac.jp": ["Koyasan University"],
    ".kpu-m.ac.jp": ["Kyoto Prefectural University of Medicine"],
    ".kpu.ac.jp": ["Kyoto Prefectural University"],
    ".ksu.ac.jp": ["Kurashiki Sakuyo University"],
    ".kufs.ac.jp": ["Kyoto University of Foreign Studies"],
    ".kuins.ac.jp": ["Kansai University of International Studies"],
    ".kuis.ac.jp": ["Kanda University of International Studies"],
    ".kumagaku.ac.jp": ["Kumamoto Gakuen University"],
    ".kumamoto-u.ac.jp": ["Kumamoto University"],
    ".kunitachi.ac.jp": ["Kunitachi College of Music"],
    ".kurume-it.ac.jp": ["Kurume Institute of Technology"],
    ".kurume-u.ac.jp": ["Kurume University"],
    ".kusa.ac.jp": ["Kurashiki University of Science and the Arts"],
    ".kushiro-pu.ac.jp": ["Kushiro Public University of Economics"],
    ".kusw.ac.jp": ["Kansai University of Social Welfare"],
    ".kwansei.ac.jp": ["Kwansei Gakuin University"],
    ".kwassui.ac.jp": ["Kwassui Women's College"],
    ".kwuc.ac.jp": ["Kyushu Women's University"],
    ".kyokyo-u.ac.jp": ["Kyoto University of Education"],
    ".kyorin-u.ac.jp": ["Kyorin University"],
    ".kyoritsu-wu.ac.jp": ["Kyoritsu Woman's University"],
    ".kyoto-art.ac.jp": ["Kyoto University of Art and Design"],
    ".kyoto-phu.ac.jp": ["Kyoto Pharmaceutical University"],
    ".kyoto-seika.ac.jp": ["Kyoto Seika University"],
    ".kyoto-su.ac.jp": ["Kyoto Sangyo University"],
    ".kyoto-u.ac.jp": ["Kyoto University"],
    ".kyoto-wu.ac.jp": ["Kyoto Women's University"],
    ".kyotogakuen-u.ac.jp": ["Kyoto Gakuen University"],
    ".kyu-dent.ac.jp": ["Kyushu Dental College"],
    ".kyukyo-u.ac.jp": ["Kyushu Kyoritsu University"],
    ".kyusan-u.ac.jp": ["Kyushu Sangyo University"],
    ".kyushu-ns.ac.jp": ["Kyushu University of Nursing and SocialWelfare"],
    ".kyushu-u.ac.jp": ["Kyushu University"],
    ".kyutech.ac.jp": ["Kyushu Institute of Technology"],
    ".matsuyama-u.ac.jp": ["Matsuyama University"],
    ".mdu.ac.jp": ["Matsumoto Dental University"],
    ".meiji-u.ac.jp": ["Meiji University of Oriental Medicine"],
    ".meiji.ac.jp": ["Meiji University"],
    ".meijigakuin.ac.jp": ["Meiji Gakuin University"],
    ".meijo-u.ac.jp": ["Meijo University"],
    ".meikai.ac.jp": ["Meikai University"],
    ".meikei.ac.jp": ["Meikei High School"],
    ".meio-u.ac.jp": ["Meio University"],
    ".meisei-u.ac.jp": ["Meisei University"],
    ".mejiro.ac.jp": ["Mejiro University"],
    ".metro-cit.ac.jp": ["Tokyo Metropolitan College of Industrial Technology"],
    ".mgu.ac.jp": ["Miyagi Gakuin Women's College"],
    ".mie-u.ac.jp": ["Mie University"],
    ".mimasaka.ac.jp": ["Mimasaka Women's College"],
    ".miyakyo-u.ac.jp": ["Miyagi University of Education"],
    ".miyazaki-med.ac.jp": ["Miyazaki Medical College"],
    ".miyazaki-mu.ac.jp": ["Miyazaki Municipal University"],
    ".miyazaki-u.ac.jp": ["Miyazaki University"],
    ".morioka-u.ac.jp": ["Morioka College"],
    ".mpu.ac.jp": ["Miyazaki Prefectural Nursing University"],
    ".mukogawa-u.ac.jp": ["Mukogawa Women's University"],
    ".muroran-it.ac.jp": ["Muroran Institute of Technology"],
    ".musabi.ac.jp": ["Musashino Art University"],
    ".musashi.ac.jp": ["Musashi University"],
    ".musashino-music.ac.jp": ["Musashino Academy of Music"],
    ".musashino-u.ac.jp": ["Musashino University"],
    ".my-pharm.ac.jp": ["Meiji College of Pharmacy"],
    ".myu.ac.jp": ["Miyagi University"],
    ".nagano.ac.jp": ["Nagano University"],
    ".nagaokaut.ac.jp": ["Nagaoka University of Technology"],
    ".nagasaki-u.ac.jp": ["Nagasaki University"],
    ".nagasakipu.ac.jp": ["Nagasaki Prefectural University"],
    ".nagoya-cu.ac.jp": ["Nagoya City University"],
    ".nankyudai.ac.jp": ["Minamikyushu University"],
    ".nebuta.ac.jp": ["Aomori Public College"],
    ".nias.ac.jp": ["Nagasaki Institute of Applied Science"],
    ".numazu-vtc.ac.jp": ["Numazu Vocational Training Center"],
    ".osaka-cu.ac.jp": ["Osaka City University"],
    ".osaka-u.ac.jp": ["Osaka University"],
    ".ouj.ac.jp": ["The Open University of Japan"],
    ".pu-kumamoto.ac.jp": ["Kumamoto Prefectural University"],
    ".redcross.ac.jp": ["Japanese Red Cross College of Nursing"],
    ".y.seijo.ac.jp": ["Seijo University"],
    ".shibaura-it.ac.jp": ["Shibaura Institute of Technology"],
    ".shinshu-u.ac.jp": ["Shinshu University"],
    ".shitennoji.ac.jp": ["International Buddhist University"],
    ".shoin.ac.jp": ["Kobe Shoin Women's University"],
    ".shotoku.ac.jp": ["Gifu Shotoku Gakuen University"],
    ".shudo-u.ac.jp": ["Hiroshima Shudo University"],
    ".soken.ac.jp": ["Graduate University for Advanced Studies"],
    ".sophia.ac.jp": ["Sophia University"],
    ".tachibana-u.ac.jp": ["Kyoto Tachibana Women's University"],
    ".titech.ac.jp": ["Tokyo Institute of Technology"],
    ".tmu.ac.jp": ["Tokyo Metropolitan University"],
    ".tohoku.ac.jp": ["Tohoku University", ".group"],
    ".tokuyama.ac.jp": ["National Institute of Technology, Tokuyama College"],
    ".tonichi-kokusai-u.ac.jp": ["Higashi Nippon International University"],
    ".tsukuba.ac.jp": ["University of Tsukuba"],
    ".tut.ac.jp": ["Toyohashi University of Technology"],
    ".u-gakugei.ac.jp": ["Tokyo Gakugei University"],
    ".u-keiai.ac.jp": ["Keiai University"],
    ".u-tokai.ac.jp": ["Hokkaido Tokai University"],
    ".u-tokyo.ac.jp": ["University of Tokyo"],
    ".uec.ac.jp": ["電気通信大学", "The University of Electro-Communications"],
    ".ynu.ac.jp": ["Yokohama National University"],
    ".aoyama.jp": ["Aoyama Gakuin University"],
    ".c-league.jp": ["NSG college league"],
    ".chiba-u.jp": ["Chiba University"],
    ".p.chibakoudai.jp": ["Chiba Institute of Technology"],
    ".s.chibakoudai.jp": ["Chiba Institute of Technology."],
    ".termnet.co.jp": ["Fuji University"],
    ".spec.ed.jp": ["Saitama Prefecture Schools", ".group"],
    ".hgu.jp": ["Hokkai Gakuen University"],
    ".it-neec.jp": ["Japan Institute of Technology"],
    ".jc-21.jp": ["東北電子専門学校", "Tohoku Computer College", ".group"],
    ".jindai.jp": ["Kanagawa University"],
    ".kadai.jp": ["Kagoshima University"],
    ".kansaigaidai.jp": [],
    ".keio.jp": ["Keio University"],
    ".fukui.kosen-ac.jp": ["National Institute of Technology, Fukui College"],
    ".fukushima.kosen-ac.jp": ["National Institute of Technology, Fukushima College"],
    ".gunma.kosen-ac.jp": ["National Institute of Technology, Gunma College"],
    ".hachinohe.kosen-ac.jp": ["National Institute of Technology, Hachinohe College"],
    ".hakodate.kosen-ac.jp": [
        "函館工業高等専門学校",
        "National Institute of Technology, Hakodate College.",
    ],
    ".kagawa.kosen-ac.jp": ["National Institute of Technology, Kagawa College"],
    ".kisarazu.kosen-ac.jp": ["National Institute of Technology, Kisarazu College"],
    ".kumamoto.kosen-ac.jp": [
        "National Institute of Technology, Kumamoto College",
        "- http://www.kumamoto-nct.ac.jp/ (Homepage)",
        "- @g.kumamoto-nct.ac.jp and @kumamoto.kosen-ac.jp (Student's email address)",
    ],
    ".kurume.kosen-ac.jp": ["National Institute of Technology, Kurume College"],
    ".nara.kosen-ac.jp": [
        "奈良工業高等専門学校",
        "National Institute of Technology, Nara College",
    ],
    ".niihama.kosen-ac.jp": ["National Institute of Technology, Niihama College"],
    ".numazu.kosen-ac.jp": ["National Institute of Technology, Numazu College"],
    ".oyama.kosen-ac.jp": [
        "小山工業高等専門学校",
        "National Institute of Technology (Kosen), Oyama College",
    ],
    ".toba.kosen-ac.jp": ["National Institute of Technology, Toba College"],
    ".tokuyama.kosen-ac.jp": [
        "徳山工業高等専門学校",
        "National Institute of Technology, Tokuyama College",
    ],
    ".tokyo.kosen-ac.jp": ["National Institute of Technology, Tokyo College"],
    ".tomakomai.kosen-ac.jp": ["National Institute of Technology, Tomakomai College"],
    ".toyota.kosen-ac.jp": ["National Institute of Technology, Toyota College"],
    ".tsuyama.kosen-ac.jp": ["National Institute of Technology, Tsuyama College"],
    ".yuge.kosen-ac.jp": ["National Institute of Technology, Yuge College"],
    ".kyoto-u.jp": ["Kyoto University"],
    ".kyudai.jp": ["Kyushu University"],
    ".mail.kyutech.jp": ["Kyushu Institute of Technology"],
    ".nagoya-u.jp": ["Nagoya University"],
    ".naist.jp": ["Nara Institute of Science and Technology"],
    ".nitech.jp": ["Nagoya Institute of Technology"],
    ".npoksk-nagano.jp": ["Nagano Kyoiku College"],
    ".oecu.jp": ["Osaka Electro-Communication University"],
    ".oic.jp": ["Osaka Information and Computer Science College"],
    ".oist.jp": ["Okinawa Institute of Science and Technology"],
    ".oiu.jp": ["Osaka International University"],
    ".ous.jp": ["Okayama University of Science"],
    ".reitaku.jp": ["University of Reitaku"],
    ".seian.jp": ["Seian University of Art and Design"],
    ".seig-boys.jp": ["Seigakuin Junior and Senior High School"],
    ".sendai-nct.jp": ["Sendai National College of Technology"],
    ".senshu-u.jp": ["Senshu University"],
    ".soka-u.jp": ["Soka University", "創価大学"],
    ".sophia.jp": ["Sophia University"],
    ".mail.tokai-u.jp": ["TOKAI Univercity"],
    ".tokai-u.jp": ["TOKAI University"],
    ".tokai.jp": ["TOKAI University"],
    ".toyo.jp": ["Toyo University"],
    ".tut.jp": ["豊橋技術科学大学", "Toyohashi University of Technology"],
    ".uwcisak.jp": ["United World Colleges ISAK Japan"],
    ".waseda.jp": ["WASEDA University"],
    ".ynu.jp": ["Yokohama National University"],
    ".anu.ac.ke": ["Africa Nazarene University"],
    ".daystar.ac.ke": ["Daystar University"],
    ".egerton.ac.ke": ["Egerton University"],
    ".jkuat.ac.ke": ["Jomo Kenyatta University of Agriculture and Technology"],
    ".jooust.ac.ke": ["Jaramogi Oginga Odinga University of Science and Technology"],
    ".kabarak.ac.ke": ["Kabarak University"],
    ".kemu.ac.ke": ["Kenya Methodist University"],
    ".kmtc.ac.ke": ["Kenya Medical Training College"],
    ".ku.ac.ke": ["Kenyatta University"],
    ".kwust.ac.ke": ["Kiriri Womens University of Science and Technology"],
    ".maseno.ac.ke": ["Maseno University"],
    ".mku.ac.ke": ["Mount Kenya University"],
    ".mmust.ac.ke": ["Masinde Muliro University of Science and Technology"],
    ".mu.ac.ke": ["Moi University"],
    ".pu.ac.ke": ["Pwani University College", "PU"],
    ".ueab.ac.ke": ["University of Eastern Africa, Baraton"],
    ".uonbi.ac.ke": ["University of Nairobi"],
    ".usiu.ac.ke": ["United States International University"],
    ".kism.or.ke": [
        "Kenya Institute of Supplies Management",
        "Kenya Institute of Supplies Management",
    ],
    ".auca.kg": ["American University of Central Asia"],
    ".adam.edu.kg": ["Adam University", "Adam University"],
    ".alatoo.edu.kg": ["Ala-Too International University "],
    ".bafe.edu.kg": [
        "Bishkek Academy of Finance end Economics",
        "Bishkek Academy of Finance end Economics",
    ],
    ".iaau.edu.kg": ["International Ataturk Alatoo University"],
    ".krsu.edu.kg": ["Kyrgyz Russian Slavic University"],
    ".manas.edu.kg": ["Kyrgyz Turkish Manas University"],
    ".pk.edu.kg": [
        "Professional College at the Kyrgyz National University named after Zhusup Balasagyn",
        "Профессиональный колледж при Кыргызском Национальном университете имени Жусупа Баласагына",
        "Professional'nyy kolledzh pri Kyrgyzskom Natsional'nom universitete imeni Zhusupa Balasagyna",
    ],
    ".sapat.edu.kg": ["Tokmok high school “Umut”", "Tokmok high school “Umut”"],
    ".inai.kg": [
        "Кыргызско-Германский институт прикладной информатики",
        "Kyrgyz-German Institute of Applied Informatics",
    ],
    ".intuit.kg": [
        "международный университет инновационных технологий",
        "international university innovative technologies",
    ],
    ".iuca.kg": ["International University of Cental Asia"],
    ".iuk.kg": ["International University of Kyrgyzstan"],
    ".kiu.kg": [
        "Islamic Unversity of Kyrgystan (Исламский университет Кыргызстана)",
        "Islamic Unversity of Kyrgystan",
    ],
    ".knau.kg": ["Kyrgyz National Agrarian University"],
    ".knu.kg": ["Jusup Balasagyn Kyrgyz National University"],
    ".ksmu.kg": ["Kyrgyz State University of Geology"],
    ".kstu.kg": [
        "Кыргызский Государственный Технический Университет имени Исхака Раззакова",
        "Kyrgyz State Technical University named after I. Razzakov",
    ],
    ".ksucta.kg": [
        "Кыргызский государственный университет строительства, транспорта и архитектуры",
        "Kyrgyz State University of Construction, Transportation and Architecture",
    ],
    ".manas.kg": ["Kyrgyz Turkish  Manas University"],
    ".university.kg": ["Jusup Balasagyn Kyrgyz National University"],
    ".aeu.edu.kh": ["Asia Europe University"],
    ".angkor.edu.kh": ["Angkor University"],
    ".bbu.edu.kh": ["Build Bright University"],
    ".cup.edu.kh": ["Chamreun University of Poly Technology"],
    ".cus.edu.kh": ["Cambodia University of Specialties"],
    ".iu.edu.kh": ["International University"],
    ".mekong.edu.kh": ["Cambodian Mekong University"],
    ".num.edu.kh": ["National University of Management"],
    ".puc.edu.kh": ["Pannnasatra University of Cambodia"],
    ".rua.edu.kh": ["Royal University of Agriculture"],
    ".rufa.edu.kh": ["Royal University of Fine Arts"],
    ".rule.edu.kh": ["Royal University of Law and Economics"],
    ".rupp.edu.kh": ["Royal University of Phnom Penh"],
    ".sru.edu.kh": ["Svey Reong University"],
    ".uc.edu.kh": ["University of Cambodia"],
    ".western.edu.kh": ["Western University"],
    ".uni.kn": ["University of Konstanz"],
    ".schule.koeln": [
        "Georg-Simon-Ohm-Berufskolleg",
        "Georg-Simon-Ohm-Vocational College",
    ],
    ".student.42seoul.kr": ["42 서울 (이노베이션 아카데미)", "42 Seoul"],
    ".ajou.ac.kr": ["Ajou University"],
    ".andong.ac.kr": ["Andong National University"],
    ".cataegu.ac.kr": ["Catholic University of Taegu-Hyosung"],
    ".cau.ac.kr": ["Chung-Ang University"],
    ".changwon.ac.kr": ["Changwon National University"],
    ".cheju.ac.kr": ["Cheju National University"],
    ".chodang.ac.kr": ["Chodang University"],
    ".chonbuk.ac.kr": ["Chonbuk National University"],
    ".chongju.ac.kr": ["Chongju University"],
    ".chonnam.ac.kr": ["Chonnam National University"],
    ".chosun.ac.kr": ["Chosun University"],
    ".chungbuk.ac.kr": ["Chungbuk National University"],
    ".chungnam.ac.kr": ["Chungnam National University"],
    ".g.cnu.ac.kr": ["Chungnam National University", "충남대학교"],
    ".mail.cnu.ac.kr": ["Chungnam National University", "충남대학교"],
    ".o.cnu.ac.kr": ["Chungnam National University", "충남대학교"],
    ".cnu.ac.kr": ["Chungnam National University", "충남대학교"],
    ".cu.ac.kr": ["Daegu Catholic University"],
    ".cuk.ac.kr": ["Catholic University of Korea"],
    ".daegu.ac.kr": ["daegu university"],
    ".dankook.ac.kr": ["Dankook University"],
    ".dhu.ac.kr": ["\ufeffDaegu Haany University"],
    ".dju.ac.kr": ["Daejeon University"],
    ".donga.ac.kr": ["Dong-A University"],
    ".dongduk.ac.kr": ["Dongduk Women's University"],
    ".dongeui.ac.kr": ["Dong Eui University"],
    ".dongguk.ac.kr": ["Dongguk University"],
    ".dongseo.ac.kr": ["Dongseo University"],
    ".dongshinu.ac.kr": ["Dongshin University"],
    ".dongyang.ac.kr": ["Dongyang University"],
    ".duksung.ac.kr": ["Duksung Women's University"],
    ".dytc.ac.kr": ["Dong Yang University of Technology"],
    ".ewha.ac.kr": ["Ewha Women's University"],
    ".gachon.ac.kr": ["Gachon University"],
    ".gsnu.ac.kr": ["Gyeongsang National University"],
    ".hallym.ac.kr": ["Hallym University"],
    ".hanbat.ac.kr": ["Hanbat National University"],
    ".hangkong.ac.kr": ["Hankuk Aviation University"],
    ".hannam.ac.kr": ["Hannam University"],
    ".hansei.ac.kr": ["Hansei University"],
    ".hanseo.ac.kr": ["Hanseo University"],
    ".hanshin.ac.kr": ["Hanshin University"],
    ".hansung.ac.kr": ["Hansung University Seoul"],
    ".hanyang.ac.kr": ["Hanyang University"],
    ".honam.ac.kr": ["Honam University"],
    ".hongik.ac.kr": ["Hongik University"],
    ".hoseo.ac.kr": ["Hoseo University"],
    ".howon.ac.kr": ["Chonbuk Sanup University of Technology (Howon University)"],
    ".hufs.ac.kr": ["Hankuk University of Foreign Studies"],
    ".hycu.ac.kr": ["Hanyang Cyber University"],
    ".hyupsung.ac.kr": ["Hyupsung University"],
    ".icu.ac.kr": ["Information and Communications University"],
    ".incheon.ac.kr": ["Incheon National University"],
    ".inha.ac.kr": ["Inha University"],
    ".oasis.inje.ac.kr": ["Inje University"],
    ".inje.ac.kr": ["Inje University"],
    ".inu.ac.kr": ["Incheon National University"],
    ".jeonju.ac.kr": ["Jeonju University"],
    ".jnu.ac.kr": ["Chonnam National University"],
    ".kaist.ac.kr": ["Korea Advanced Institute of Science &amp; Technology"],
    ".kangnam.ac.kr": ["Kangnam University"],
    ".kangnung.ac.kr": ["Kangnung National University"],
    ".kangwon.ac.kr": ["Kangwon National University"],
    ".kaya.ac.kr": ["Kaya University"],
    ".kdischool.ac.kr": ["KDI School of Public Policy and Management"],
    ".keimyung.ac.kr": ["Keimyung University"],
    ".kimpo.ac.kr": ["Kimpo University"],
    ".kmaritime.ac.kr": ["Korea Maritime University"],
    ".knou.ac.kr": ["Korea National Open University"],
    ".knu.ac.kr": ["Kyungpook National University"],
    ".knua.ac.kr": ["Korea National University of Arts"],
    ".knue.ac.kr": ["Korea National University of Education"],
    ".knupe.ac.kr": ["Korea National University of Physical Education"],
    ".kongju-e.ac.kr": ["Kongju National University of Education"],
    ".konkuk.ac.kr": ["Konkuk University"],
    ".konyang.ac.kr": ["Konyang University"],
    ".kookmin.ac.kr": ["Kookmin University"],
    ".korea.ac.kr": ["Korea University"],
    ".kosin.ac.kr": ["Kosin University"],
    ".kpu.ac.kr": ["Korea Polytechnic University"],
    ".kumoh.ac.kr": ["Kumoh National Institute of Technology"],
    ".kunsan.ac.kr": ["Kunsan National Universiy"],
    ".kwangju.ac.kr": ["Kwangju University"],
    ".kwangwoon.ac.kr": ["Kwangwoon University"],
    ".kyonggi.ac.kr": ["Kyonggi University"],
    ".kyunghee.ac.kr": ["Kyunghee University"],
    ".kyungnam.ac.kr": ["Kyungnam University"],
    ".kyungpook.ac.kr": ["Kyungpook National University"],
    ".kyungsung.ac.kr": ["Kyungsung University"],
    ".kyungwon.ac.kr": ["Kyungwon University"],
    ".mmu.ac.kr": ["Mokpo National Maritime University"],
    ".mokpo.ac.kr": ["Mokpo National University"],
    ".mokwon.ac.kr": ["Mokwon University Taejon"],
    ".myongji.ac.kr": ["Myongji University"],
    ".paichai.ac.kr": ["Paichai University"],
    ".pknu.ac.kr": ["Pukyong National University"],
    ".postech.ac.kr": ["Pohang University of Science and Technology"],
    ".pufs.ac.kr": ["Pusan University of Foreign Studies"],
    ".pusan.ac.kr": ["Pusan National University"],
    ".sangji.ac.kr": ["Sang Ji University"],
    ".sch.ac.kr": ["Soonchunhyang University"],
    ".sejong.ac.kr": ["Sejong University"],
    ".semyung.ac.kr": ["Semyung University"],
    ".seoultech.ac.kr": ["Seoul National University of Science and Technology"],
    ".seowon.ac.kr": ["Seowon University"],
    ".silla.ac.kr": ["Silla University"],
    ".skhu.ac.kr": ["SungKongHoe University"],
    ".skku.ac.kr": ["Sung Kyun Kwan University"],
    ".skuniv.ac.kr": ["Seokyeong University"],
    ".snu.ac.kr": ["Seoul National University"],
    ".snut.ac.kr": ["Seoul National University of Technology"],
    ".sogang.ac.kr": ["Sogang University"],
    ".sookmyung.ac.kr": ["Sookmyung Women's University"],
    ".soongsil.ac.kr": ["Soongsil University"],
    ".ssu.ac.kr": ["Soongsil University"],
    ".stu.ac.kr": ["Seoul Teological University"],
    ".sungkyul.ac.kr": ["Sungkyul University"],
    ".sungshin.ac.kr": ["Sungshin Women's University"],
    ".sunmoon.ac.kr": ["Sunmoon University"],
    ".suwon.ac.kr": ["Suwon University"],
    ".swu.ac.kr": ["Seoul Women's University"],
    ".syu.ac.kr": ["Sahmyook University"],
    ".taegu.ac.kr": ["Taegu University"],
    ".ulsan.ac.kr": ["Ulsan University"],
    ".unist.ac.kr": ["Ulsan National Institute of Science and Technology"],
    ".uos.ac.kr": ["Seoul City University"],
    ".wonkwang.ac.kr": ["Wonkwang University"],
    ".woosuk.ac.kr": ["Woosuk University"],
    ".yeungnam.ac.kr": ["Yeungnam University"],
    ".yonsei.ac.kr": ["Yonsei University"],
    ".chosun.kr": ["Chosun University"],
    ".djwondang.cneo365.kr": ["원당중학교", "wondang middle school"],
    ".cnu.kr": ["Chungnam National University", "충남대학교"],
    ".gpms.dje365.kr": ["대전관평중학교", "Daejeong Gwanpyeong Middle School"],
    ".dshs.kr": ["대전대신고등학교", "Daejeon Daeshin High School"],
    ".dsu.kr": ["dongshin university"],
    ".dulwich-seoul.kr": ["Dulwich College Seoul"],
    ".haman-h.gne.go.kr": ["함안고등학교", "Haman High School"],
    ".aybuheungm.goe.go.kr": ["안양부흥중학교", "AnyangBuheung Middle School"],
    ".bojeongh.goe.go.kr": ["보정고등학교", "Bojeong High School"],
    ".changhyunh.goe.go.kr": ["창현고등학교", "Changhyun High School"],
    ".daepyonge.goe.go.kr": ["대평초등학교", "daepyung elementary school"],
    ".daepyongm.goe.go.kr": ["대평중학교", "daepyong middle school"],
    ".dshangangm.goe.go.kr": ["다산한강중학교", "Dasan Hangang Middle School"],
    ".ggh.goe.go.kr": ["경기도교육청", "Gyeonggi Province Office of Education", ".group"],
    ".gghsm.goe.go.kr": ["광교호수중학교", "Gwanggyo Hosu Middle School"],
    ".mae-wone.goe.go.kr": ["매원초등학교", "Maewon elementary School"],
    ".pjwadonge.goe.go.kr": ["파주와동초등학교", "Paju Wadong Elementary School"],
    ".suwondasanm.goe.go.kr": ["수원다산중학교", "Suwon Dasan Middle School"],
    ".hifive.go.kr": ["선린인터넷고등학교", "Sunrin Internet High School"],
    ".gclass.ice.go.kr": ["인천광역시교육청", "Incheon Metropolitan Office of Education"],
    ".ice.go.kr": ["인천기계공업고등학교"],
    ".o365.pen.go.kr": ["부산광역시교육청"],
    ".sen.go.kr": ["SUNGSU TECHNICAL HIGH SCHOOL"],
    ".hanma.kr": ["\ufeff경남대학교", "Kyungnam University"],
    ".dimigo.hs.kr": ["Korea Digital Media High School", "한국디지털미디어고등학교"],
    ".dolma.hs.kr": ["Dolma High School", "돌마고등학교"],
    ".dsm.hs.kr": ["Daedeok Software Meister Highschool", "대덕소프트웨어마이스터고등학교"],
    ".e-mirim.hs.kr": ["Mirim Meister Highschool"],
    ".ksa.hs.kr": ["Korea Science Academy of KAIST", "한국과학기술원 부설 한국과학영재학교"],
    ".gyeongseong.sen.hs.kr": ["Gyeongseong High School", "경성고등학교"],
    ".iasa.icehs.kr": ["인천과학예술영재학교", "Incheon Academy of Science and Arts"],
    ".muan.hs.jne.kr": ["무안고등학교", "Muan Highschool"],
    ".kau.kr": ["Korea Aerospace University"],
    ".kiu.kr": ["Kyungill University"],
    ".liveuou.kr": ["Ulsan University"],
    ".bakhyun.ms.kr": ["백현중학교", "Bakhyun Middle School"],
    ".socialwork.or.kr": ["Korea Nazarene University"],
    ".sangmyung.kr": ["Sang Myung University"],
    ".xavier.sc.kr": ["LYCEE INTERNATIONAL XAVIER"],
    ".skhu.kr": ["SungKongHoe University"],
    ".smit.kr": ["서울미디어대학원대학교", "Seoul Media Institute of Technology"],
    ".sungil-i.kr": ["성일정보고등학교", "Sungil Information High School"],
    ".ynu.kr": ["영남대학교", "Yeungnam University"],
    ".auis.edu.krd": ["American University of Iraq, Sulaimani"],
    ".dpu.edu.krd": ["Duhok Polytechnic University"],
    ".duhokcihan.edu.krd": ["Cihan University - Duhok", "Cihan University - Duhok"],
    ".hmu.edu.krd": ["Hawler Medical University"],
    ".hsti.edu.krd": [
        "په\u200c\u200cيمانگاى ته\u200cكنيكى هه\u200cيبه\u200cت سوڵتان",
        "Haibat Sultan Technical Institute",
    ],
    ".kissr.edu.krd": [
        "Kurdistan Institution for strategic studies and scientific research"
    ],
    ".kti.edu.krd": ["Kurdistan Technical Institute"],
    ".su.edu.krd": ["Salahaddin University"],
    ".ue.edu.krd": ["International University of Erbil"],
    ".ukh.edu.krd": ["University of Kurdistan Hawler"],
    ".uor.edu.krd": ["University of Raparin"],
    ".uoz.edu.krd": ["University of Zakho"],
    ".aou.edu.kw": ["Arab Open University, Kuwait Branch"],
    ".auk.edu.kw": ["American University of Kuwait "],
    ".gust.edu.kw": ["Gulf University for Science and Technology"],
    ".kuniv.edu.kw": ["Kuwait University"],
    ".icci.edu.ky": ["International College of the Cayman Islands"],
    ".60edu.kz": ["School #60 Nur Sultan"],
    ".adilet.kz": ["Adilet Higher Law School"],
    ".almaty.kz": ["Kazak State University of Agriculture"],
    ".aues.kz": ["Almaty University of Power Engineering and Telecommunications"],
    ".bgtk.kz": [
        "Балхашский гуманитарно-технический колледж имени Алихана Мусина",
        "Balkhash Humanitarian and Technical College named after Alikhan Musina",
    ],
    ".kkat.edu.kz": ["Kostanay College of Automobile Transport"],
    ".sdu.edu.kz": ["Suleyman Demirel University"],
    ".ektu.kz": ["East Kazakstan State Technical University"],
    ".enu.kz": ["Eurasia National University"],
    ".etonhouse.kz": ["EtonHouse Kazakhstan International School"],
    ".eurazir.kz": ["Eurasian Institute of market"],
    ".fizmat.kz": [
        "Республиканская физико математическая школа",
        "Republican Physics and Mathematics School",
    ],
    ".iitu.kz": ["International IT University Kazakhstan"],
    ".kau.kz": ["Kazak American University"],
    ".kazatu.kz": [
        "Казахский агротехнический университет имени С.Сейфуллина",
        "S.Seifullin Kazakh Agro Technical University",
    ],
    ".kazguu.kz": [
        "Казахский государственный юридический университет имени М.С. Нарикбаева ",
        "M. Narikbayev KAZGUU University",
    ],
    ".kazntu.kz": ["Kazakh National Technical University"],
    ".kaznu.kz": ["Al-Farabi Kazakh National University"],
    ".kbtu.kz": ["Kazakh British Technical University"],
    ".keu.kz": ["Karaganda Economic University"],
    ".kgu.kz": ["Кокшетауский университет им. Ш.Уалиханова", "Ualikhanov University"],
    ".kimep.kz": [
        "Kazakhstan Institute of Management, Economics, and Strategic Research"
    ],
    ".kst.kz": ["Kostanai State University"],
    ".kstu.kz": ["Karaganda State Technical University"],
    ".ksu.kz": ["Karaganda State Buketov University"],
    ".kuef.kz": ["Kazakh University of Economics, Finance and International Trade"],
    ".narxoz.kz": ["Narxoz University"],
    ".nkzu.kz": ["North Kazakhstan State University"],
    ".okmpu.kz": [
        "Южно-Казахстанский государственный педагогический институт",
        "South Kazakhstan State Pedagogical Institute",
    ],
    ".psu.kz": ["Pavlodar State University"],
    ".sci.kz": ["Almaty Abai State University", "Kazak National Technical University"],
    ".semgu.kz": ["Shakarim University"],
    ".sfek.kz": ["RSBE Semey financial-economic college named after Rymbek Baiseitov"],
    ".tarsu.kz": ["Taraz State University", "Тараз Мемлекеттік Университеті"],
    ".turan-edu.kz": ["Turan University"],
    ".uib.kz": ["University of international business"],
    ".vkgu.kz": ["East Kazakhstan State University"],
    ".wkau.kz": ["Western Kazakhstan Agricultural University"],
    ".zhez.kz": ["Zhezkazgan Baikonurov University"],
    ".zti.kz": [
        "Институт интеллектуальных технологий",
        "Institute of Intelligent Technologies",
    ],
    ".nuol.edu.la": ["National University of Laos"],
    ".aou.edu.lb": ["Arab Open University"],
    ".arabou-lb.edu.lb": ["Arab Open University"],
    ".aub.edu.lb": ["American University of Beirut"],
    ".aul.edu.lb": ["Arts, Sciences and Technology University"],
    ".aust.edu.lb": ["American University of Science and Technology"],
    ".students.b-iu.edu.lb": ["The International University of Beirut"],
    ".balamand.edu.lb": ["Balamand University"],
    ".bau.edu.lb": ["Beirut Arab University"],
    ".cut.edu.lb": ["Centre Universitaire de Technologie"],
    ".gu.edu.lb": ["Global University"],
    ".haigazian.edu.lb": ["Haigazian University"],
    ".isae.edu.lb": ["Conservatoire national des arts et métiers (CNAM)"],
    ".iul.edu.lb": ["Islamic University Of Lebanon", "Islamic University Of Lebanon"],
    ".jinan.edu.lb": ["Jinan University"],
    ".lau.edu.lb": ["Lebanese American University"],
    ".liu.edu.lb": ["Lebanese International University"],
    ".matnu.edu.lb": ["Matn University"],
    ".mu.edu.lb": ["al maaref university"],
    ".mubs.edu.lb": [
        "Modern University for Business and Science",
        "Modern University for Business and Science",
    ],
    ".muc.edu.lb": ["Matn University College"],
    ".mut.edu.lb": ["Al-Manar University"],
    ".ndu.edu.lb": ["Notre Dame University"],
    ".pu.edu.lb": [" Phoenicia University"],
    ".rhu.edu.lb": ["Rafik Hariri University", "جامعة رفيق الحريري"],
    ".theonest.edu.lb": ["Near East School of Theology"],
    ".ua.edu.lb": ["UA Université Antonine"],
    ".ul.edu.lb": ["Lebanese University"],
    ".student.uls.edu.lb": ["Université La Sagesse", "Sagesse University"],
    ".usal.edu.lb": ["University of Sciences and Arts in Lebanon"],
    ".usek.edu.lb": ["Holy Spirit University of Kaslik"],
    ".usj.edu.lb": ["St. Joseph University Beirut"],
    ".iap.li": ["Internationle Akademie für Philosophie"],
    ".schulen.li": ["BMS Liechtenstein"],
    ".uni.li": ["Universität Liechtenstein"],
    ".accimt.ac.lk": ["Arthur C Clarke Institute of Modern Technologies"],
    ".bpu.ac.lk": ["Buddhist and Pali University of Sri Lanka"],
    ".busl.ac.lk": ["Buddhasravaka Bhiksu University"],
    ".cmb.ac.lk": ["University of Colombo"],
    ".esn.ac.lk": ["Eastern University, Sri Lanka"],
    ".iit.ac.lk": ["Informatics Institute of Technology, Sri Lanka"],
    ".jfn.ac.lk": ["University of Jaffna"],
    ".kdu.ac.lk": ["General Sir John Kotelawala Defence University"],
    ".kln.ac.lk": ["University of Kelaniya"],
    ".mrt.ac.lk": ["University of Moratuwa"],
    ".nsbm.ac.lk": ["NSBM Green University"],
    ".ou.ac.lk": ["Open University of Sri Lanka"],
    ".pdn.ac.lk": ["University of Peradeniya"],
    ".pgia.ac.lk": ["Postgraduate Institute of Agriculture (PGIA)"],
    ".rjt.ac.lk": ["Rajarata University of Sri Lanka"],
    ".ruh.ac.lk": ["University of Ruhuna"],
    ".sab.ac.lk": ["Sabaragamuwa University of Sri Lanka"],
    ".seu.ac.lk": ["South Eastern University of Sri Lanka"],
    ".sjp.ac.lk": ["University of Sri Jayewardenepura"],
    ".slgti.ac.lk": ["Sri Lanka-German Training Institute"],
    ".sliate.ac.lk": ["Sri Lanka Institute of Advanced Technological Education"],
    ".sltc.ac.lk": ["Sri Lanka Technological Campus"],
    ".uwu.ac.lk": ["Uva Wellassa University"],
    ".vpa.ac.lk": ["University of the Visual and Performing Arts"],
    ".wyb.ac.lk": [
        "Wayamba Univarsity of Sri Lanka",
        "Wayamba Univarsity of Sri Lanka",
    ],
    ".acbt.lk": ["Australian college of business and technology"],
    ".apiit.lk": ["Asia Pacific Institute of Information Technology (APIIT)"],
    ".bcas.lk": ["BCAS CITY CAMPUS", "BCAS CITY CAMPUS"],
    ".csacolombo.edu.lk": ["City School of Architecture, Colombo Sri Lanka"],
    ".hardyati.edu.lk": ["Hardy Advanced Technological Institute"],
    ".javainstitute.edu.lk": ["Java Institute For Advanced Technology"],
    ".saegis.edu.lk": ["Saegis Campus ", "Saegis Campus "],
    ".sltc.edu.lk": ["SLTC", "Sri Lanka Technological Campus"],
    ".esoft.lk": ["ESOFT Metro Campus"],
    ".dtet.gov.lk": ["Department of Technical Education & Training, Sri Lanka"],
    ".ijse.lk": [
        "Institute of Software Engineering (IJSE)",
        "Institute of Java and Software Engineering",
    ],
    ".lnbti.lk": ["Lanka Nipon BizTech Institute"],
    ".lyceum.lk": ["Lyceum International Schools"],
    ".nibm.lk": ["National Institute of Business Management"],
    ".nsbm.lk": ["NSBM Green University of Sri Lanka"],
    ".ousl.lk": ["Open University of Sri Lanka"],
    ".sliit.lk": ["Sri Lanka Institute of Information Technology (SLIT)"],
    ".ucl.lk": ["Universal College Lanka", "UCL"],
    ".stu.ucsc.lk": [
        "University of Colombo School of Computing",
        "University of Colombo School of Computing",
    ],
    ".uom.lk": ["University of Moratuwa"],
    ".wesleycollege.lk": ["Wesley College, Sri Lanka"],
    ".limkokwing.ac.ls": ["Limkokwing University of Creative Technology"],
    ".asu.lt": ["Aleksandro Stulginskio university"],
    ".azuolynogimnazija.lt": ["Klaipėdos Ąžuolyno gimnazija"],
    ".student.ehu.lt": [
        "Europos humanitarinis universitetas",
        "European Humanities University",
    ],
    ".erudito.lt": [
        "Erudito Licejus",
        "Erudito High School",
        "Erudito licejus is an IB world school",
    ],
    ".ftmc.lt": [
        "Center for Physical Sciences and Technology ",
        "Center for Physical Sciences and Technology ",
    ],
    ".ism.lt": ["International School of Management"],
    ".kauko.lt": ["Kauno Kolegija Univrsity of Applied Sciences"],
    ".kitm.lt": ["Kaunas information technology school"],
    ".klpvm.lt": ["Klaipeda service and business school"],
    ".kma.lt": ["Kaunas Medical Academy"],
    ".ktu.lt": ["Kaunas University of Technology"],
    ".ku.lt": ["Klaipeda University"],
    ".kvk.lt": ["Klaipėda State College"],
    ".kvkedu.lt": [
        "Klaipėdos valstybinė kolegija",
        "Klaipeda State University of Applied Sciences",
    ],
    ".lcc.lt": ["Lithuania Christian College"],
    ".leu.lt": ["Lithuanian University Of Educational Sciences"],
    ".lka.lt": ["Military academy of Lithuania"],
    ".lkka.lt": ["Lithunian Institute of Physical Education"],
    ".lmta.lt": ["Lithunian Academy of Music and Theatre"],
    ".lsmuni.lt": [
        "Lietuvos sveikatos mokslų universitetas",
        "Lithuanian University of Health Sciences",
    ],
    ".lva.lt": ["Lithunian Veterinary Academy"],
    ".lzua.lt": ["Lithunian University of Agriculture"],
    ".mii.lt": ["Vilnius Academy of Arts"],
    ".mmgimnazija.lt": [
        "Marijampolės marijonų gimnazija",
        "Marijampolė marian gymnasium",
    ],
    ".panko.lt": ["Panevezys college"],
    ".smarttech.lt": ["Smart tech academy", "Smart tech academy"],
    ".smk.lt": ["University of Applied Social Sciences"],
    ".spindulioprogimnazija.lt": ["Spndulio Progimnazija"],
    ".su.lt": ["Siauliai University"],
    ".svako.lt": ["Šiauliai State College"],
    ".vdu.lt": ["Vytautas Magnus University"],
    ".vgtu.lt": ["Vilnius Gediminas Technical University"],
    ".viko.lt": ["Vilniaus kolegija/University of Applied Sciences "],
    ".stud.vilniustech.lt": ["Vilnius Tech", "Vilnius Tech"],
    ".vpu.lt": ["Vilnius Pedagogical University"],
    ".vtmc.lt": ["Vilnius Vocational Training Centre of Technologies"],
    ".vu.lt": ["Vilnius University"],
    ".vvk.lt": ["Vilniaus Verslo Kolegija ", "Vilnius Business College"],
    ".vydmantugimnazija.lt": ["Vydmantų gimnazija", "Vydmantai High School"],
    ".btsgp.lu": ["Lycee des Arts et Metiers"],
    ".btsi.lu": ["Lycee des Arts et Metiers"],
    ".education.lu": ["Education Luxembourg"],
    ".iuil.lu": ["International University Institute of Luxembourg"],
    ".school.lu": ["Students Emails Education Luxembourg"],
    ".uni.lu": ["University of Luxemburg"],
    ".aml.lv": ["Medical Academy of Latvia"],
    ".du.lv": ["Daugavpils University"],
    ".bsa.edu.lv": ["Baltic International Academy"],
    ".liepu.edu.lv": ["Liepaja University"],
    ".lka.edu.lv": ["Latvian Academy of Culture"],
    ".polak.edu.lv": ["Police Academy of Latvia"],
    ".rsu.edu.lv": [
        "Riga Stradiņš University",
        "https://www.rsu.lv/",
        "https://www.rsu.lv/studiju-iespejas",
        "https://sts.rsu.lv/adfs/ls/?wa=wsignin1.0&wtrealm=https%3a%2f%2fwebmail.rsu.lv%2fowa%2f&wctx=rm%3d0%26id%3dpassive%26ru%3d%252fowa%252f&wct=2019-04-12T17%3a00%3a58Z",
    ],
    ".sseriga.edu.lv": ["Stockholm School of Economics in Riga"],
    ".lama.lv": ["Latvian Maritime Academy"],
    ".lanet.lv": ["Latvian Academy of Sports Education"],
    ".liepu.lv": ["Liepaja University"],
    ".llu.lv": ["Latvia University of Life Sciences and Technologies"],
    ".lma.lv": ["Latvian Academy of Arts"],
    ".lmuza.lv": ["Latvian Academy of Music"],
    ".lpu.lv": ["Liepaja Pedagogical Higher School"],
    ".lu.lv": ["University of Latvia"],
    ".www.mil.lv": ["National Defence Academy of Latvia"],
    ".ozolniekuvsk.lv": ["Ozolnieku vidusskola"],
    ".psy.lv": ["Higher School of Psychology"],
    ".rau.lv": ["Riga Aviation University"],
    ".rezeknestehnikums.lv": ["Rezekne Polytechnic"],
    ".edu.riga.lv": ["Riga Schools"],
    ".riseba.lv": ["Riseba school"],
    ".rpiva.lv": ["Riga Teacher Training and Educational Management Academy"],
    ".rta.lv": ["Rēzeknes Tehnoloģiju akadēmija", "Rezekne Academy of Technologies"],
    ".rtu.lv": ["Riga Technical University"],
    ".ru.lv": ["Rezekne Higher School"],
    ".rvt.lv": ["\ufeffRīgas Valsts tehnikums"],
    ".s1vsk.lv": ["Salaspils 1. vidusskola"],
    ".tsi.lv": ["Transport and Telecommunication Institute"],
    ".turiba.lv": ["Turiba University"],
    ".va.lv": ["Vidzeme University College"],
    ".venta.lv": ["Ventspils University College"],
    ".academy.edu.ly": ["Academy of Graduate Studies"],
    ".alacademia.edu.ly": ["Academy of Graduate Studies"],
    ".asmarya.edu.ly": ["Asmarya University for Islamic Studies"],
    ".elmergib.edu.ly": ["Elmergib University"],
    ".jgu.edu.ly": ["Al-Jabal Al-Gharbi University"],
    ".limu.edu.ly": ["Libyan International Medical University (LIMU)"],
    ".omu.edu.ly": ["Omar Al-Mukhtar University"],
    ".sebhau.edu.ly": ["Sebha University"],
    ".student.1337.ma": ["1337 School"],
    ".archi.ac.ma": ["Ecole Nationale d'Architecture"],
    ".emi.ac.ma": ["Ecole Mohammadia d'Ingénieurs"],
    ".enameknes.ac.ma": ["Ecole National d'Agriculture de Meknes"],
    ".ensat.ac.ma": ["École nationale des sciences appliquées de Tanger"],
    ".esta.ac.ma": ["Université Ibn Zohr Agadir"],
    ".fstm.ac.ma": ["Faculté des Sciences et Techniques de Mohammedia"],
    ".hec.ac.ma": ["Ecole des Hautes Etudes Commerciales MAROC"],
    ".hem.ac.ma": ["Institut des Hautes Etudes de Management"],
    ".iihem.ac.ma": ["International Institute for Higher Education"],
    ".inpt.ac.ma": ["Institut National des Postes et Télécommunications"],
    ".isfort.ac.ma": ["ISFORT - Institut de Formation en Technologie Alimentaire"],
    ".matci.ac.ma": ["Institut Supérieur de Management et de Technologie (MATCI)"],
    ".uae.ac.ma": ["Université Abdelmalek Essadi"],
    ".ucam.ac.ma": ["Université Cadi Ayyad"],
    ".ucd.ac.ma": ["Université Chouaib Doukkali"],
    ".uic.ac.ma": ["Universite Internationale de Casablanca"],
    ".uir.ac.ma": ["Université Internationale de Rabat"],
    ".uit.ac.ma": ["University of Ibn Tofail"],
    ".um5.ac.ma": ["Université Mohammed V", "Mohammed V University"],
    ".um5a.ac.ma": ["Université Mohammed V - Agdal"],
    ".um5s.ac.ma": ["Université Mohammed V - Souissi"],
    ".umi.ac.ma": ["Université Moulay Ismaïl", "Moulay Ismail University"],
    ".ump.ac.ma": ["University Mohammed First"],
    ".univ-ibntofail.ac.ma": ["Université Ibn Toufail"],
    ".univ-oujda.ac.ma": ["Université Mohammed Ier"],
    ".usmba.ac.ma": ["Université Sidi Mohammed Ben Abdellah"],
    ".aiac.ma": [
        "ACADEMIE INTERNATIONAL D'AVIATION CIVILE",
        "INTERNATIONAL ACADEMY OF CIVILE AVIATION",
    ],
    ".aiacingenieur.ma": [
        "ACADEMIE INTERNATIONAL D'AVIATION CIVILE",
        "INTERNATIONAL ACADEMY OF CIVILE AVIATION",
    ],
    ".aui.ma": ["Al Akhawayn University"],
    ".centrale-casablanca.ma": [
        "Ecole Centrale Casablanca",
        "Ecole Centrale Casablanca",
    ],
    ".e-polytechnique.ma": ["Ecole Polytechnqiue Universiapolis Agdir "],
    ".emsi-edu.ma": [
        "École Marocaine des Sciences de l'Ingénieur",
        "Moroccan School of Engineering Sciences",
        "Marokkanische Hochschule der Ingenieurwissenschaften",
        "EMSI",
    ],
    ".emsi.ma": [
        "École Marocaine des Sciences de l'Ingénieur",
        "Moroccan School of Engineering Sciences",
        "Marokkanische Hochschule der Ingenieurwissenschaften",
        "EMSI",
    ],
    ".enstetouan.ma": [
        "École Normale Supérieure de Tétouan",
        "ENS Tétouan",
        "contact@enstetouan.ma",
    ],
    ".iga-marrakech.ma": ["ISGA Marrakech"],
    ".imbt.ma": ["Institute of Management and Business Technology"],
    ".ine.inpt.ma": [
        "inpt -institut national des postes et télécommunications-",
        "National Institute of Posts and Telecommunications",
    ],
    ".isiam.ma": [
        "Université Internationale d'Agadir",
        "International University of Agadir",
    ],
    ".mundiapolis.ma": ["Mundiapolis University"],
    ".um5s.net.ma": ["Université Mohammed 5 - Rabat"],
    ".ofppt-edu.ma": [
        "Office de la Formation Professionnelle et de la Promotion du Travail",
        "OFPPT",
        "Berufsbildung und Arbeitsförderungs Büro",
    ],
    ".ofppt.ma": [
        "L'Office de la formation professionnelle et de la promotion du travail (OFPPT), Morocco"
    ],
    ".ordiciel.ma": ["Ordiciel Institute"],
    ".taalim.ma": [
        "Ministere de l'education nationale et de la formation professionnelle"
    ],
    ".uca.ma": ["Université Cadi Ayyad"],
    ".ucd.ma": ["Université Chouaib Doukkali", "Chouaib Doukkali University"],
    ".emines.um6p.ma": [
        "EMINES-Mohammed VI Polytechnic University",
        "Université Mohammed VI Polytechnique (UM6P)",
    ],
    ".um6p.ma": ["Mohamed 6 Polytechnic University"],
    ".ensao.ump.ma": ["National School of Applied Sciences Oujda"],
    ".ump.ma": ["University Mohammed First"],
    ".univcasa.ma": ["UNIVERSITE HASSAN II DE CASABLANCA"],
    ".univh2c.ma": ["UNIVERSITE HASSAN II DE CASABLANCA"],
    ".usms.ma": [
        "Université Sultan Moulay Slimane",
        "sultan moulay slimane university",
    ],
    ".student.youcode.ma": ["YouCode"],
    ".ase.md": ["Academy of Economic Studies of Moldova"],
    ".ceiti.md": [
        "Centrul de Excelență în Informatică și Tehnologii Informaționale",
        "Center of Excellence in Informatics and Information Technologies",
    ],
    ".kdu.md": ["Comrat State University"],
    ".moldnet.md": ["Pedagogical State University Ion Creanga"],
    ".uasm.md": ["Moldova State Agricultural University"],
    ".uccm.md": ["Moldova Cooperative Trade University"],
    ".ulim.md": ["Free International University of Moldova"],
    ".upsc.md": ["Pedagogical State University Ion Creanga from Chisinau"],
    ".usarb.md": ["Balti State University Alecu Russo"],
    ".usm.md": ["Moldova State University"],
    ".usmf.md": ["Moldova State University of Medicine and Pharmacy N. Testemitsanu"],
    ".ust.md": ["Tiraspol State University"],
    ".ia.utm.md": [
        "Universitatea Tehnica din Republica Moldova",
        "Technical University from Republic of Moldova",
    ],
    ".utm.md": ["Moldova Technical University"],
    ".mediaschool.me": [
        "L’IRIS, L’ECOLE SUPÉRIEURE D’INFORMATIQUE",
        "IRIS, THE HIGHER SCHOOL OF COMPUTING",
        "IRIS Mediaschool",
    ],
    ".urfu.me": ["Ural Federal University"],
    ".uspu.me": [" Уральский государственный педагогический университет"],
    ".esti.mg": ["ESTI Madagascar", "Graduate School of Information Technology"],
    ".univ-antananarivo.mg": ["Université d'Antananarivo"],
    ".univ-fianar.mg": ["Université de Fianarantsoa"],
    ".univ-mahajanga.mg": ["Université de Mahajanga"],
    ".univ-toamasina.mg": ["Université de Toamasina"],
    ".univ-toliara.mg": ["Université de Toliary"],
    ".af.mil": ["United States Air Force Academy", "Air Force Institute of Technology"],
    ".navy.mil": ["Naval Postgraduate School"],
    ".usuhs.mil": ["Uniformed Services Universty of the Health Sciences"],
    ".eccfp.edu.mk": [
        "Универзитет Св. Климент Охридски - Битола, Економски Факултет - Прилеп"
    ],
    ".fon.edu.mk": ["FON University"],
    ".ibu.edu.mk": ["International Balkan University"],
    ".seeu.edu.mk": ["See University at Tetovo"],
    ".uacs.edu.mk": ["University of American College", "UACS"],
    ".ugd.edu.mk": ["University Goce Delcev"],
    ".uist.edu.mk": [
        "University for Information Science and Technology  St. Paul The Apostle "
    ],
    ".ukim.edu.mk": ["St.Cyril and Methodius University"],
    ".uklo.edu.mk": ["St.Kliment Ohridski University"],
    ".unite.edu.mk": ["State University of Tetova"],
    ".unt.edu.mk": ["Mother Teresa University"],
    ".fon.mk": ["FON University"],
    ".ukim.mk": ["St.Cyril and Methodius University"],
    ".hbtu.edu.mm": ["Technological Univerity of Hmawbi"],
    ".kbtc.edu.mm": ["KBTC university"],
    ".kyauksetu.edu.mm": ["Technological University of Kyaukse"],
    ".miit.edu.mm": [
        "မြန်မာသတင်းအချက်အလက်နည်းပညာတက္ကသိုလ်",
        "Myanmar Institute of Information Technology",
    ],
    ".mtu.edu.mm": ["Mandalay Technological University"],
    ".mu.edu.mm": ["Mandalay University"],
    ".tukalay.edu.mm": ["Technological University of Kalay"],
    ".tumlm.edu.mm": ["\ufeffTechnological University of Mawlamyine"],
    ".tupku.edu.mm": ["Technological University Pakokku"],
    ".tutaunggyi.edu.mm": ["Technological University Taunggyi"],
    ".tutoungoo.edu.mm": [
        "Technological University (Toungoo)",
        "Technological University (Toungoo)",
    ],
    ".ucsh.edu.mm": ["University of Computer Studies, Hinthada"],
    ".ucsmgy.edu.mm": [
        "University of Computer Studies (Magway),Myanmar",
        "University of Computer Studies (Magway),Myanmar",
    ],
    ".ucstaungoo.edu.mm": [
        "University of Computer Studies, Taungoo",
        "University of Computer Studies, Taungoo",
    ],
    ".ucstt.edu.mm": ["University of Computer Studies (Thaton)"],
    ".ucsy.edu.mm": ["University of Computer Studies, Yangon (UCSY)"],
    ".uit.edu.mm": ["University of Information Technology (UIT)"],
    ".um1ygn.edu.mm": ["University of Medicine 1, Yangon"],
    ".ummg.edu.mm": ["University of Medicine Magway"],
    ".utycc.edu.mm": ["University of Technology ( Yatanarpon Cyber City )", "UTYCC"],
    ".uy.edu.mm": ["University of Yangon (UY)"],
    ".ytu.edu.mm": ["Yangon Technological University"],
    ".most.gov.mm": [
        "Dawei Technological University",
        "Hinthada Technological University",
        "Hpaan Technological University",
        "Kalay Technological University",
        "Kyaukse Technological University",
        "Loikaw Technological University",
        "Magway Technological University",
        "Mandalay Technological University",
        "Maubin Technological University",
        "Mawlamyaing Technological University",
        "Meikhtila Technological University",
        "Monywa Technological University",
        "Myeik Technological University",
        "Myitkyina Technological University",
        "Pakokku Technological University",
        "Pathein Technological University",
        "Pyay Technological University",
        "Sittwe Technological University",
        "Taunggyi Technological University",
        "Taungoo Technological University",
        "Yangon Technological University",
    ],
    ".itbmu.org.mm": ["International Theravada Buddhist Missionary University"],
    ".icb.edu.mn": ["Institute of Commerce and Business"],
    ".msue.edu.mn": ["Mongolian State University of Education"],
    ".must.edu.mn": ["Mongolian University of Science and Technology"],
    ".num.edu.mn": ["Mongolian National University"],
    ".orkhon.edu.mn": ["Orkhon University"],
    ".ulaanbaatar.edu.mn": ["Ulaanbaatar University"],
    ".humanities.mn": ["University of the Humanities"],
    ".khan-uul.mn": ["Khan-Uul Institute"],
    ".cityu.mo": ["澳門城市大學", "City University of Macau"],
    ".ipm.edu.mo": ["Macau Polytechnic Institute"],
    ".usj.edu.mo": ["University of Saint Joseph"],
    ".umac.mo": ["University of Macau"],
    ".clrchs.mobi": ["Cardinal Langley RC High School & Sixth Form College"],
    ".jamsa.mobi": ["Jämsän sivistyspalvelukeskus"],
    ".mcag.moscow": [
        'Государственное бюджетное профессиональное образовательное учреждение города Москвы "Московский колледж архитектуры и градостроительства"',
        "Gosudarstvennoe byudzhetnoe professional'noe obrazovatel'noe uchrezhdenie goroda Moskvy \"Moskovskij kolledzh arhitektury i gradostroitel'stva\"",
    ],
    ".iup.e-una.mr": ["Institut Universitaire Professionnel"],
    ".esp.mr": [
        "Ecole Supérieure Polytechnique de Nouakchott",
        " Higher Polytechnic School of Nouakchott",
    ],
    ".iscae.mr": [
        "Institut Supérieur de Comptabilité et d'administration des Entreprises"
    ],
    ".univ-nkc.mr": ["University of Nouakchott"],
    ".um.edu.mt": ["University of Malta"],
    ".open.ac.mu": ["Open University of Mauritius"],
    ".poly.ac.mu": ["Polytechnics Mauritius"],
    ".student.udm.ac.mu": ["University of Mascareignes"],
    ".uom.ac.mu": ["University of Mauritius"],
    ".utm.ac.mu": ["University of Technology"],
    ".mzuni.ac.mw": ["Mzuzu University"],
    ".unima.mw": ["University of Malawi"],
    ".Inecol.mx": [
        "Instituto de Ecología, AC",
        "Institute of Ecology, (non-profit civil association)",
    ],
    ".anahuac.mx": ["Universidad Anáhuac", "Universidad Anáhuac"],
    ".anahuacmayab.mx": ["Universidad Anáhuac Mayab"],
    ".aulamexiquense.mx": ["Centro de Bachillerato Tecnológico Atizapan de Zaragoza"],
    ".buap.mx": [
        "Benemerita Universidad Autónoma de Puebla",
        "Benemerita Universidad Autónoma de Puebla",
    ],
    ".ceti.mx": [
        "Centro de Enseñanza Técnica Industrial",
        "Centro de Enseñanza Técnica Industrial",
    ],
    ".cetys.mx": ["CETYS Universidad", "CETYS Universidad"],
    ".ceux.mx": [
        "Centro de Estudios Universitarios Xochicalco",
        "Centro de Estudios Universitarios Xochicalco",
    ],
    ".chapingo.mx": [
        "Universidad Autónoma de Chapingo",
        "Universidad Autónoma de Chapingo",
    ],
    ".cimat.mx": ["Centro de Investigación en Matemáticas"],
    ".cinvestav.mx": [
        "Centro de Investigación y de Estudios Avanzados del Instituto Politécnico Nacional"
    ],
    ".cio.mx": ["Centro de Investigaciones en Óptica"],
    ".ciqa.mx": ["Centro de Investigación en Química Aplicada"],
    ".colmex.mx": ["El Colegio de México", "El Colegio de México"],
    ".colpos.mx": ["Colegio de Postgraduados", "Postgraduate College"],
    ".ceunix.com.mx": [
        "Centro Universitario Ixtlahuaca",
        "Centro Universitario Ixtlahuaca",
    ],
    ".motolinia.com.mx": [
        "Universidad Motolinía del Pedregal",
        "Universidad Motolinía del Pedregal",
    ],
    ".myunitec.com.mx": ["Universidad Tecnológica de México"],
    ".prepacusac.com.mx": ["Colegio Universitario de Saltillo"],
    ".umma.com.mx": ["Universidad Mundo Maya", "Universidad Mundo Maya, México"],
    ".ebc.mx": ["Escuela Bancaria y Comercial", "Escuela Bancaria y Comercial"],
    ".cecytec.edu.mx": [
        "Colegio de Estudios Cientificos y Tecnologicos del Estado de Coahuila",
        "Colegio de Estudios Cientificos y Tecnologicos del Estado de Coahuila",
    ],
    ".ceu.edu.mx": [
        "Centro de Estudios Universitarios Monterrey",
        "Centro de Estudios Universitarios Monterrey",
    ],
    ".champagnat.edu.mx": ["Universidad Champagnat", "Universidad Champagnat"],
    ".conalep.edu.mx": ["Colegio Nacional de Educacion Profesional Tecnica"],
    ".cuauhtemoc.edu.mx": ["Universidad Cuauhtémoc", "Universidad Cuauhtémoc"],
    ".frayluca.edu.mx": [
        "Universidad Fray Luca Paccioli",
        "Universidad Fray Luca Paccioli",
    ],
    ".i.edu.mx": ["Universidad Itaca", "Universidad Itaca"],
    ".ijm.edu.mx": ["Instituto Jefferson de Morelia"],
    ".ipn.edu.mx": ["Instituto Politécnico Nacional", "Instituto Politécnico Nacional"],
    ".itdurango.edu.mx": [
        "Instituto Tecnologico de Durango",
        "Durango Institute of Technology ",
    ],
    ".itmina.edu.mx": [
        "Instituto Tecnologico de Minatitlan",
        "Instituto Tecnologico de Minatitlan",
    ],
    ".itmorelia.edu.mx": [
        "Instituto Tecnológico de Morelia",
        "Instituto Tecnológico de Morelia",
    ],
    ".itoaxaca.edu.mx": [
        "Instituto Tecnológico de Oaxaca",
        "Instituto Tecnológico de Oaxaca",
    ],
    ".itq.edu.mx": [
        "Instituto Tecnológico de Querétaro",
        "Instituto Tecnológico de Querétaro",
    ],
    ".itslp.edu.mx": [
        "Instituto Tecnológico de San Luis Potosí",
        "Instituto Tecnológico de San Luis Potosí",
    ],
    ".ittepic.edu.mx": [
        "Instituto Tecnológico de Tepic",
        "Instituto Tecnológico de Tepic",
    ],
    ".olmeca.edu.mx": ["Universidad Olmeca", "Universidad Olmeca"],
    ".tecdecintalapa.edu.mx": [
        "Instituto Tecnológico Superior de Cintalapa",
        "Instituto Tecnológico Superior de Cintalapa",
    ],
    ".tepeyac.edu.mx": ["Universidad del Tepeyac", "Universidad del Tepeyac"],
    ".uabc.edu.mx": ["Universidad Autonoma de Baja California"],
    ".uacm.edu.mx": [
        "Universidad Autónoma de la Ciudad de México",
        "Universidad Autónoma de la Ciudad de México",
    ],
    ".uad.edu.mx": [
        "Universidad Autonoma  de Durango",
        "Universidad Autonoma  de Durango",
    ],
    ".uaed.edu.mx": [
        "Universidad Autonoma España de Durango",
        "Universidad Autonoma España de Durango",
    ],
    ".uane.edu.mx": [
        "Universidad Autónoma del Noreste",
        "Universidad Autónoma del Noreste",
    ],
    ".uaz.edu.mx": [
        "Universidad Autónoma de Zacatecas",
        "Universidad Autonoma de Zacatecas",
    ],
    ".ubac.edu.mx": ["Universidad del Bajío", "Universidad del Bajío"],
    ".ucem.edu.mx": [
        "Universidad del Centro de México",
        "Universidad del Centro de México",
    ],
    ".uclah.edu.mx": [
        "Universidad Cientifica Latinoamericana de Hidalgo",
        "Universidad Cientifica Latinoamericana de Hidalgo",
    ],
    ".udec.edu.mx": ["Universidad de Celaya", "Universidad de Celaya"],
    ".udeh.edu.mx": ["Universidad de Hermosillo", "Universidad de Hermosillo"],
    ".udem.edu.mx": ["Universidad de Monterrey", "Universidad de Monterrey"],
    ".udv.edu.mx": ["Universidad Don Vasco", "Universidad Don Vasco"],
    ".ufram.edu.mx": ["Universidad Franco-Mexicana", "Universidad Franco-Mexicana"],
    ".uic.edu.mx": ["Universidad Intercontinental", "Universidad Intercontinental"],
    ".ula.edu.mx": ["Universidad Latinoamericana", "Universidad Latinoamericana"],
    ".ulsa.edu.mx": ["Universidad La Salle", "Universidad La Salle"],
    ".ulsab.edu.mx": [
        "Universidad Lasallista Benavente",
        "Universidad Lasallista Benavente",
    ],
    ".ulsac.edu.mx": [
        "Universidad La Salle Cuernavaca",
        "Universidad La Salle Cuernavaca",
    ],
    ".umad.edu.mx": ["Universidad Madero", "Universidad Madero"],
    ".uman.edu.mx": [
        "Universidad México Americana del Norte",
        "Universidad México Americana del Norte",
    ],
    ".umi.edu.mx": [
        "Universidad México Internacional",
        "Universidad México Internacional",
    ],
    ".umla.edu.mx": [
        "Universidad Metropolitana Latin Campus",
        "Universidad Metropolitana Latin Campus",
    ],
    ".umm.edu.mx": [
        "Universidad Metropolitana de Monterrey",
        "Universidad Metropolitana de Monterrey",
    ],
    ".umontemorelos.edu.mx": [
        "Universidad de Montemorelos",
        "Universidad de Montemorelos",
    ],
    ".umsa.edu.mx": [
        "Universidad Mesoamericana de San Agustín",
        "Universidad Mesoamericana de San Agustín",
    ],
    ".un.edu.mx": ["Universidad del Norte", "Universidad del Norte"],
    ".une.edu.mx": ["Universidad del Noreste", "Universidad del Noreste"],
    ".unes.edu.mx": ["Universidad España de Durango", "Universidad España de Durango"],
    ".unica.edu.mx": [
        "Universidad de Comunicación Avanzada",
        "Universidad de Comunicación Avanzada",
    ],
    ".unimayab.edu.mx": ["Universidad del Mayab", "Universidad del Mayab"],
    ".unimex.edu.mx": ["Universidad Mexicana", "Universidad Mexicana"],
    ".univas.edu.mx": ["Universidad Jóse Vasconcelos", "Universidad Jóse Vasconcelos"],
    ".alumnos.univer-gdl.edu.mx": ["Univer University, Mexico"],
    ".universidaddeleon.edu.mx": ["Universidad de León", "Universidad de León"],
    ".universidadlaconcordia.edu.mx": [
        "Universidad la Concordia",
        "Universidad la Concordia",
    ],
    ".universidadmotolinia.edu.mx": [
        "Universidad Motolinía del Pedegral",
        "Universidad Motolinía del Pedegral",
    ],
    ".universidadmundomaya.edu.mx": [
        "Universidad Mundo Maya",
        "Universidad Mundo Maya",
    ],
    ".universidadsalesiana.edu.mx": ["Universidad Salesiana", "Universidad Salesiana"],
    ".unla.edu.mx": ["Universidad Latina", "Universidad Latina"],
    ".uom.edu.mx": ["Universidad Obrera de Mexico", "Universidad Obrera de Mexico"],
    ".upchiapas.edu.mx": ["Universidad Politecnica de Chiapas"],
    ".urmh.edu.mx": [
        "Universidad Regional Miguel Hidalgo",
        "Universidad Regional Miguel Hidalgo",
    ],
    ".urse.edu.mx": [
        "Universidad Regional del Sureste",
        "Universidad Regional del Sureste",
    ],
    ".usac.edu.mx": ["Universidad de la Sierra A.C.", "Universidad de la Sierra A.C."],
    ".usb.edu.mx": ["Universidad Simón Bolivar", "Universidad Simón Bolivar"],
    ".uteg.edu.mx": ["Universidad Tecnologica De Guadalajara"],
    ".utel.edu.mx": [" Universidad Tecnológica Latinoamericana"],
    ".uteq.edu.mx": [
        "Universidad Tecnológica de Querétaro",
        "Technological University of Querétaro",
    ],
    ".utez.edu.mx": ["Universidad Tecnológica Emiliano Zapata del Estado de Morelos"],
    ".utneza.edu.mx": [
        "Universidad Tecnologica de Nezahualcoyotl",
        "Universidad Tecnologica de Nezahualcoyotl",
    ],
    ".uttt.edu.mx": [
        "Universidad Tecnológica de Tula-Tepeji",
        "Technological University of Tula-Tepeji",
    ],
    ".uvb.edu.mx": [
        "Universidad del Valle del Bravo",
        "Universidad del Valle del Bravo",
    ],
    ".uvt.edu.mx": [
        "Universidad del Valle de Toluca",
        "Universidad del Valle de Toluca",
    ],
    ".uxac.edu.mx": ["Universidad Xicotepetl", "Universidad Xicotepetl"],
    ".westhill.edu.mx": ["Westhill University", "Westhill University"],
    ".esimez.mx": [
        "Escuela Superior de Ingeniería Mecánica y Eléctrica Unidad Zacatenco",
        "School of Mechanical and Electrical Engineering, Zacatenco",
    ],
    ".ibero.mx": ["UNIVERSIDAD IBEROAMERICANA", "IBEROAMERICAN UNIVERSITY"],
    ".iberopuebla.mx": [
        "Universidad Iberoamericana Puebla",
        "Universidad Iberoamericana Puebla",
        "IBERO Puebla",
    ],
    ".ifp.mx": ["Instituto Francisco Possenti", "Instituto Francisco Possenti"],
    ".inaoep.mx": ["Instituto Nacional de Astrofísica, Óptica y Electrónica"],
    ".infotec.mx": [
        "Dirección General de Institutos Tecnológicos",
        "Dirección General de Institutos Tecnológicos",
    ],
    ".ipn.mx": ["National Polytechnic Institute"],
    ".ita.mx": [
        "Instituto Tecnológico de Aguascalientes",
        "Instituto Tecnológico de Aguascalientes",
    ],
    ".itam.mx": [
        "Instituto Tecnológico Autonómo de México",
        "Instituto Tecnológico Autonómo de México",
    ],
    ".itc.mx": ["Instituto Tecnológico de Celaya", "Instituto Tecnológico de Celaya"],
    ".itesm.mx": [
        "Instituto Tecnológico y de Estudios Superiores de Monterrey (ITESM)",
        "Instituto Tecnológico y de Estudios Superiores de Monterrey (ITESM)",
    ],
    ".iteso.mx": [
        "Instituto Tecnológico y de Estudios Superiores de Occidente",
        "Instituto Tecnológico y de Estudios Superiores de Occidente",
    ],
    ".ith.mx": ["Instituto Tecnológico de Hermosillo"],
    ".itson.mx": ["Instituto Tecnológico de Sonora", "Instituto Tecnológico de Sonora"],
    ".lasallep.mx": ["Universidad La Salle Pachuca", "La Salle Pachuca University"],
    ".lasallistas.org.mx": ["Universidad La Salle"],
    ".reduaeh.mx": [
        "Universidad Autónoma del Estado de Hidalgo",
        "Universidad Autónoma del Estado de Hidalgo",
    ],
    ".reduaz.mx": [
        "Universidad Autónoma de Zacatecas",
        "Universidad Autónoma de Zacatecas",
    ],
    ".saei.mx": ["SAE School of Audio Engineering México"],
    ".tec.mx": [
        "Instituto Tecnológico de Estudios Superiores de Monterrey",
        "Monterrey Institute of Technology and Higher Education",
    ],
    ".tecbc.mx": [
        "Tecnologico de Baja California, Universidad",
        "Tecnologico de Baja California, Universidad",
    ],
    ".tecmilenio.mx": ["Universidad TecMilenio", "Universidad TecMilenio"],
    ".tecmor.mx": ["Instituto tecnológico de morelia"],
    ".nlaredo.tecnm.mx": ["Instituto Tecnlogico de Nuevo Laredo"],
    ".piedad.tecnm.mx": ["Instituto Tecnologico de La Piedad"],
    ".toluca.tecnm.mx": ["Instituto Tecnológico de Toluca"],
    ".tecnm.mx": [
        "Tecnológico Nacional de México (TecNM)",
        "National Institute of Technology of Mexico",
    ],
    ".tecvalles.mx": [
        "Tecnológico Nacional de México Campus Instituto Tecnológico de Ciudad Valles"
    ],
    ".teczamora.mx": [
        "Instituto Tecnologico de Estudios Superiores de Zamora",
        "Technological Institute of Superior Studies of Zamora",
    ],
    ".u-erre.mx": ["Universidad Regiomontana"],
    ".correo.uaa.mx": ["Universidad Autónoma de Aguascalientes"],
    ".edu.uaa.mx": ["Universidad Autónoma de Aguascalientes"],
    ".uaaan.mx": [
        "Universidad Autónoma Agraria Antonio Narro",
        "Universidad Autónoma Agraria Antonio Narro",
    ],
    ".uabc.mx": [
        "Universidad Autónoma de Baja California",
        "Universidad Autónoma de Baja California",
    ],
    ".uabcs.mx": [
        "Universidad Autónoma de Baja California Sur",
        "Universidad Autónoma de Baja California Sur",
    ],
    ".uabjo.mx": [
        "Universidad Autónoma Benito Juárez de Oaxaca",
        "Universidad Autónoma Benito Juárez de Oaxaca",
    ],
    ".uacam.mx": [
        "Universidad Autónoma de Campeche",
        "Universidad Autónoma de Campeche",
    ],
    ".uach.mx": [
        "Universidad Autónoma de Chihuahua",
        "Universidad Autónoma de Chihuahua",
    ],
    ".uacj.mx": [
        "Universidad Autónoma de Ciudad Juárez",
        "Universidad Autónoma de Ciudad Juárez",
    ],
    ".uadec.mx": [
        "Universidad Autónoma de Coahuila",
        "Universidad Autónoma de Coahuila",
    ],
    ".uady.mx": ["Universidad Autónoma de Yucatán", "Universidad Autónoma de Yucatán"],
    ".uaem.mx": [
        "Universidad Autónoma del Estado de Morelos",
        "Universidad Autónoma del Estado de Morelos",
    ],
    ".uaemex.mx": [
        "Universidad Autónoma del Estado de México",
        "Universidad Autónoma del Estado de México",
    ],
    ".uaf.mx": [
        "Universidad Autónoma de Fresnillo",
        "Universidad Autónoma de Fresnillo",
    ],
    ".uag.mx": [
        "Universidad Autónoma de Guadalajara",
        "Universidad Autónoma de Guadalajara",
    ],
    ".uagro.mx": [
        "Universidad Autónoma de Guerrero",
        "Universidad Autónoma de Guerrero",
    ],
    ".ual.mx": [
        "Universidad Autónoma de la Laguna",
        "Universidad Autónoma de la Laguna",
    ],
    ".uam.mx": [
        "Universidad Autónoma Metropolitana",
        "Universidad Autónoma Metropolitana - Azcapotzalco",
        "Universidad Autónoma Metropolitana - Iztapalapa",
        "Universidad Autónoma Metropolitana - Xochimilco",
        "Universidad Autónoma Metropolitana",
        "Universidad Autónoma Metropolitana - Azcapotzalco",
        "Universidad Autónoma Metropolitana - Iztapalapa",
        "Universidad Autónoma Metropolitana - Xochimilco",
    ],
    ".uan.mx": ["Universidad Autónoma de Nayarit", "Universidad Autónoma de Nayarit"],
    ".uanl.mx": [
        "Universidad Autónoma de Nuevo León",
        "Universidad Autónoma de Nuevo León",
    ],
    ".uaq.mx": [
        "Universidad Autónoma de Querétaro",
        "Universidad Autónoma de Querétaro",
    ],
    ".uas.mx": ["Universidad Anáhuac del Sur", "Universidad Anáhuac del Sur"],
    ".uaslp.mx": [
        "Universidad Autónoma de San Luis Potosí",
        "Universidad Autónoma de San Luis Potosí",
    ],
    ".uasnet.mx": [
        "Universidad Autónoma de Sinaloa",
        "Universidad Autónoma de Sinaloa",
    ],
    ".uat.mx": [
        "Universidad Autónoma de Tamaulipas",
        "Universidad Autónoma de Tamaulipas",
    ],
    ".uatx.mx": [
        "Universidad Autónoma de Tlaxcala",
        "Universidad Autónoma de Tlaxcala",
    ],
    ".ucc.mx": ["Universidad Cristóbal Colón", "Universidad Cristóbal Colón"],
    ".ucol.mx": ["Universidad de Colima", "Universidad de Colima"],
    ".udg.mx": ["Universidad de Guadalajara", "Universidad de Guadalajara"],
    ".udladf.mx": ["Universidad de las Américas"],
    ".udlap.mx": [
        "Universidad de las Américas - Puebla",
        "Universidad de las Américas - Puebla",
    ],
    ".udo.mx": ["Universidad de Occidente", "Universidad de Occidente"],
    ".ues.mx": ["Universidad Estatal de Sonora", "Universidad Estatal de Sonora"],
    ".ugto.mx": ["Universidad de Guanajuato", "Universidad de Guanajuato"],
    ".uia.mx": ["Universidad Iberoamericana", "Universidad Iberoamericana"],
    ".ujat.mx": [
        "Universidad Juárez Autónoma de Tabasco",
        "Universidad Juárez Autónoma de Tabasco",
    ],
    ".ujed.mx": [
        "Universidad Juárez del Estado de Durango",
        "Universidad Juárez del Estado de Durango",
    ],
    ".ujsierra.mx": ["Universidad Justo Sierra", "Universidad Justo Sierra"],
    ".umar.mx": ["Universidad del Mar", "Universidad del Mar"],
    ".umich.mx": [
        "Universidad Michoacana de San Nicolás de Hidalgo",
        "Universidad Michoacana de San Nicolás de Hidalgo",
    ],
    ".un.mx": ["Universidad de Norteamerica", "Universidad de Norteamerica"],
    ".unacar.mx": [
        "Universidad Autónoma del Carmen",
        "Universidad Autónoma del Carmen",
    ],
    ".unach.mx": ["Universidad Autónoma de Chiapas", "Universidad Autónoma de Chiapas"],
    ".nube.unadmexico.mx": ["Universidad Abierta y a Distancia de México"],
    ".unadmexico.mx": ["Universidad Abierta y a Distancia de México"],
    ".unam.mx": [
        "Universidad Nacional Autónoma de México",
        "Universidad Nacional Autónoma de México",
    ],
    ".red.unid.mx": ["Universidad Interamericana para el Desarrollo"],
    ".unikino.mx": ["Universidad Kino", "Universidad Kino"],
    ".unison.mx": ["Universidad de Sonora"],
    ".unitec.mx": [
        "Universidad Tecnológica de México",
        "Universidad Tecnológica de México",
    ],
    ".univa.mx": [
        "Universidad del Valle de Atemajac",
        "Universidad del Valle de Atemajac",
    ],
    ".univillarica.mx": [
        "Universidad Autónoma de Veracruz Villa Rica",
        "Universidad Autónoma de Veracruz Villa Rica",
    ],
    ".up.mx": ["Universidad Panamericana", "Universidad Panamericana"],
    ".upaep.mx": [
        "Universidad Popular Autonóma del Estado de Puebla",
        "Universidad Popular Autonóma del Estado de Puebla",
    ],
    ".upgch.mx": [
        "Universidad Pablo Guardado Chávez",
        "Pablo Guardado Chavez University",
    ],
    ".upn.mx": ["Universidad Pedagógica Nacional", "Universidad Pedagógica Nacional"],
    ".upq.mx": ["Universidad Politecnica de Queretaro"],
    ".uqroo.mx": ["Universidad de Quintana Roo", "Universidad de Quintana Roo"],
    ".ur.mx": ["Universidad Regiomontana", "Universidad Regiomontana"],
    ".uson.mx": ["Universidad de Sonora", "Universidad de Sonora"],
    ".edu.utc.mx": ["UNIVERSIDAD TRES CULTURAS", "THREE CULTURES UNIVERSITY"],
    ".utcancun.mx": [
        "Crear la Universidad Tecnológica de Cancún ",
        "url de la universidad: ",
        "http://utcancun.edu.mx",
        "Dominio de correo: ",
        "@ utcancun.mx",
    ],
    ".utm.mx": [
        "Universidad Tecnologica de la Mixteca",
        "Universidad Tecnologica de la Mixteca",
    ],
    ".uttn.mx": ["Universidad Tecnologica de Tamaulipas Norte"],
    ".uv.mx": ["Universidad Veracruzana", "Universidad Veracruzana"],
    ".1utar.my": ["Universiti Tunku Abdul Rahman"],
    ".aeu.edu.my": ["Asia E University"],
    ".aimst.edu.my": ["Aimst University"],
    ".aiu.edu.my": ["Al-Bukhari International University"],
    ".apiit.edu.my": ["Asia Pacific Institute of Information Technology (APIIT)"],
    ".apu.edu.my": ["Asia Pacific University of Technology & Innovation (APU)"],
    ".asb.edu.my": ["Asia School of Business"],
    ".aswara.edu.my": [
        "Akademi Seni Budaya Dan Warisan Kebangsaan",
        "National Academy Of Art Culture And Heritage",
    ],
    ".atc2u.edu.my": ["Advance Tertiary College"],
    ".bac.edu.my": ["Brickfields Asia College"],
    ".binary.edu.my": [
        "Binary University College of Managemant &amp; Entrepreneurship"
    ],
    ".britishschool.edu.my": ["The British International School of Kuala Lumpur"],
    ".cempaka.edu.my": ["Cempaka International School Damansara Heights"],
    ".chonghwa-kuantan.edu.my": ["SEKOLAH MENENGAH CHONG HWA KUANTAN"],
    ".city.edu.my": ["City University College of Science and Technology"],
    ".cosmopointcollege.edu.my": [
        "Cosmopoint College Seremban",
        "Cosmopoint College Seremban",
    ],
    ".curtin.edu.my": ["Curtin University of Technology, Sarawak Campus"],
    ".cybermed.edu.my": ["Cyberjaya University College of Medical Science"],
    ".djzhlc.edu.my": ["New Era Institute of Vocational and Continuing Education"],
    ".firstcity.edu.my": ["First City University College"],
    ".foonyew.edu.my": ["新山宽柔中学", "FOON YEW HIGH SCHOOL JOHOR BAHRU"],
    ".student.gmi.edu.my": ["German-Malaysian Institute", "German-Malaysian Institute"],
    ".help.edu.my": ["HELP University College", "HELP University "],
    ".helplive.edu.my": ["HELP University"],
    ".hikmah.edu.my": ["Darul Hikmah Islamic College"],
    ".iact.edu.my": ["Iact College"],
    ".iic.edu.my": ["International Islamic College"],
    ".iiu.edu.my": ["International Islamic University"],
    ".iium.edu.my": ["International Islamic University Malaysia"],
    ".imas.edu.my": ["International Modern Arabic School, Malaysia"],
    ".imu.edu.my": ["International Medical University"],
    ".inhouse.edu.my": ["IHM College", "IHM College"],
    ".instedt.edu.my": ["Darul Takzim Institute of Technology"],
    ".intec.edu.my": ["INTEC Education College"],
    ".ipb.edu.my": ["Baitulmal Management Institute (IPB)"],
    ".ipbl.edu.my": ["Institute of Teachers Education, Batu Lintang"],
    ".ipda.edu.my": ["Institute of Teachers Education, Darul Aman"],
    ".ipgkrajang.edu.my": ["Institute of Teachers Education, Rajang"],
    ".ipgkti.edu.my": ["Institute of Teachers Education, Temenggong Ibrahim"],
    ".ipgmksm.edu.my": ["Institute of Teachers Education, Sultan Mizan"],
    ".ipik.edu.my": ["Institute of Teachers Education, Ilmu Khas"],
    ".ipislam.edu.my": ["Institute of Teachers Education, Islamic Education"],
    ".ipkent.edu.my": ["Institute of Teachers Education, Kent"],
    ".ipsah.edu.my": ["Institute of Teachers Education, Sultan Abdul Halim"],
    ".iptho.edu.my": ["Institute of Teachers Education, Tun Hussein Onn"],
    ".iptips.edu.my": ["Perlis Islamic Higher Learning Institute"],
    ".iuctt.edu.my": [
        "International University College of Technology Twintech (IUCTT)"
    ],
    ".s.iukl.edu.my": ["Infrastructure University"],
    ".iumw.edu.my": [
        "International University of Malaya-Wales",
        "International University of Malaya-Wales",
    ],
    ".kbu.edu.my": ["KBU International College"],
    ".kdu.edu.my": ["KDU College Sdn Bhd"],
    ".student.kdupg.edu.my": ["UOW Malaysia KDU - UOW Malaysia KDU Penang"],
    ".kias.edu.my": ["Sultan Ismail Petra International Islamic College"],
    ".kist.edu.my": ["Islamic College for Sciences and Technologies"],
    ".kitab.edu.my": ["International Islamic College of Penang"],
    ".mjii.kktm.edu.my": ["MARA Japan Industrial Institute"],
    ".klmu.edu.my": ["Kuala Lumpur Metropolitan University"],
    ".kolejypc.edu.my": ["YPC-iTWEB College"],
    ".kptm.edu.my": ["Mara Poly-Tech College"],
    ".ktd.edu.my": ["Darul Naim College of Technology"],
    ".kuim.edu.my": ["Melaka Islamic University College"],
    ".kuin.edu.my": ["Kolej Universiti Insaniah"],
    ".kuis.edu.my": ["Selangor Islamic University College"],
    ".kuptm.edu.my": ["Kolej Universiti Poly-Tech Mara Kuala Lumpur"],
    ".limkokwing.edu.my": ["Limkokwing University College of Creative Technology"],
    ".linton.edu.my": ["Linton University College"],
    ".mahsa.edu.my": ["Mahsa University College for Health and Medical Science"],
    ".mahsastudent.edu.my": ["玛莎大学", "MAHSA University"],
    ".mediu.edu.my": ["Al Madinah International University"],
    ".mmu.edu.my": ["Multimedia University"],
    ".moe-dl.edu.my": ["SMK Tinggi Batu Pahat", "High School Batu Pahat"],
    ".monash.edu.my": ["Monash University, Malaysia Campus"],
    ".msu.edu.my": ["Management and Science University"],
    ".murni.edu.my": ["Murni Nursing College"],
    ".must.edu.my": ["Malaysia University of Science and Technology (MUST)"],
    ".mykwanghua.edu.my": ["巴生光华独立中学", "Kwang Hua Private High School"],
    ".neivce.edu.my": ["New Era Institute of Vocational and Continuing Education"],
    ".newera.edu.my": ["New Era University College"],
    ".newinti.edu.my": ["INTI International University & Colleges"],
    ".nilai.edu.my": ["Nilai University College"],
    ".nottingham.edu.my": ["University of Nottingham, Malaysia Campus"],
    ".olympia.edu.my": ["Olympia College"],
    ".oum.edu.my": ["Open University Malaysia"],
    ".pbu.edu.my": ["POLITEKNIK BALIK PULAU"],
    ".perdanauniversity.edu.my": ["Perdana University - School for Data Sciences"],
    ".pidc.edu.my": ["Penang International Dental College"],
    ".pine.edu.my": ["Institut Prima Bestari - Pine Academy "],
    ".pkb.edu.my": ["Kota Bharu Polytechnic"],
    ".pmm.edu.my": ["Merlimau Polytechnic"],
    ".pmu.edu.my": ["Politeknik Mukah Sarawak"],
    ".poliku.edu.my": ["Kuching Polytechnic"],
    ".polimas.edu.my": ["Sultan Abdul Halim Muadzam Shah Polytechnic"],
    ".polimelaka.edu.my": ["Melaka City Polytechnic"],
    ".polipd.edu.my": ["Port Dickson Polytechnic"],
    ".polisas.edu.my": ["Sultan Haji Ahmad Shah Polytechnic"],
    ".psa.edu.my": ["Sultan Salahuddin Abdul Aziz Shah Polytechnic"],
    ".psas.edu.my": ["Sultan Azlan Shah Polytechnic "],
    ".psis.edu.my": ["Sultan Idris Shah Polytechnic"],
    ".psmza.edu.my": ["Sultan Mizan Zainal Abidin Polytechnic"],
    ".psp.edu.my": ["Seberang Perai Polytechnic"],
    ".ptpl.edu.my": ["PTPL College"],
    ".ptsb.edu.my": ["Sultanah Bahiyah Polytechnic"],
    ".ptss.edu.my": ["Tunku Syed Sirajuddin Polytechnic"],
    ".puo.edu.my": ["Ungku Omar Premier Polytechnic"],
    ".qiu.edu.my": ["Quest International University "],
    ".qiup.edu.my": [
        "Quest International University",
        "Quest International University",
    ],
    ".saito.edu.my": ["Saito College"],
    ".segi.edu.my": ["Segi University College"],
    ".sunway.edu.my": ["Sunway University College"],
    ".swinburne.edu.my": ["Swinburne University of Technology, Sarawak Campus"],
    ".taj.edu.my": ["Taj International College"],
    ".tarc.edu.my": ["Tunku Abdul Rahman Chinese College"],
    ".taylors.edu.my": ["Taylor's University College"],
    ".toa.edu.my": ["The One Academy of Communication Design"],
    ".tpmcollege.edu.my": ["TPM College"],
    ".ucsiuniversity.edu.my": ["UCSI University"],
    ".ucti.edu.my": ["University College of Technology &amp; Innovation (UCTI)"],
    ".ucts.edu.my": ["University College of Technology Sarawak"],
    ".uitm.edu.my": ["Universiti Teknologi Mara"],
    ".ukm.edu.my": [
        "Universiti Kebangsaan Malaysia",
        "The National University of Malaysia",
    ],
    ".um.edu.my": ["Universiti Malaya"],
    ".umk.edu.my": ["Universiti Malaysia Kelantan"],
    ".ump.edu.my": ["University Malaysia Pahang"],
    ".ums.edu.my": ["Universiti Malaysia Sabah"],
    ".umt.edu.my": ["Universiti Malaysia Terengganu"],
    ".unikl.edu.my": [
        "Universiti Kuala Lumpur",
        "Universiti Kuala Lumpur Malaysian Institute of Information Technology (MIIT)",
    ],
    ".unimap.edu.my": ["Universiti Malaysia Perlis"],
    ".student.unimy.edu.my": ["University Malaysia of Computer Science & Engineering"],
    ".unirazak.edu.my": ["University Tun Abdul Razak"],
    ".unisel.edu.my": ["Universiti Industri Selangor"],
    ".putra.unisza.edu.my": ["Universiti Sultan Zainal Abidin"],
    ".uniten.edu.my": ["Universiti Tenaga Nasional"],
    ".upm.edu.my": ["Universiti Putra Malaysia"],
    ".upnm.edu.my": ["\ufeffUniversiti Pertahanan Nasional Malaysia"],
    ".upsi.edu.my": ["Universiti Pendidikan Sultan Idris"],
    ".usim.edu.my": [
        "Universiti Sains Islam Malaysia",
        "Islamic Science University of Malaysia",
    ],
    ".utar.edu.my": [
        "Tunku Abdul Rahman University (Chinese University)",
        "Universiti Tunku Abdul Rahman",
    ],
    ".utem.edu.my": ["Universiti Teknikal Malaysia Melaka"],
    ".uthm.edu.my": ["Universiti Tun Hussein Onn Malaysia"],
    ".utmspace.edu.my": ["UTMSPACE"],
    ".utn.edu.my": ["Universiti Tenaga Nasional"],
    ".utp.edu.my": ["Petronas Technology University", "Universiti Teknologi Petronas"],
    ".student.uts.edu.my": ["University of Technology Sarawak"],
    ".uum.edu.my": ["Universiti Utara Malaysia"],
    ".westminster.edu.my": ["West Minster International College"],
    ".wou.edu.my": ["Wawasan Open University"],
    ".xmu.edu.my": [
        "Xiamen University Malaysia",
        "Universiti Xiamen Malaysia",
        "厦门大学马来西亚分校",
    ],
    ".ukm.my": ["Universiti Kebangsaan Malaysia"],
    ".unimas.my": ["Universiti Malaysia Sarawak"],
    ".unisza.my": ["universiti sultan zainal abidin"],
    ".usm.my": ["Universiti Sains Malaysia"],
    ".utm.my": ["Universiti Teknologi Malaysia"],
    ".isctem.ac.mz": ["Instituto Superior de Ciências e Tecnologia de Moçambique"],
    ".isri.ac.mz": ["Instituto Superior de Relações Internacionais (ISRI) "],
    ".ucm.ac.mz": ["Universidade Católica de Moçambique"],
    ".isutc.transcom.co.mz": [
        "Instituto Superior de Transportes e Comunicações",
        " Higher Institute of Transport and Communications",
    ],
    ".www.uem.mz": ["Universidade Eduardo Mondlane"],
    ".edu.na": ["Ilsa Independent College", "International University of Management"],
    ".nust.na": ["Namibia University of Science and Technology"],
    ".unam.na": ["University of Namibia"],
    ".unc.nc": ["University of New Caledonia"],
    ".refer.ne": ["Université Abdou Moumouni de Niamey"],
    ".29zx.net": ["南京市第二十九中学", "Nanjing No.29 High School"],
    ".C2KNI.net": ["C2KNI", "C2KEN", "Dromore High School"],
    ".aab-edu.net": ["AAB University"],
    ".achievementtraining.net": [
        "Achievement Training Ltd",
        "Part of City College Plymouth",
    ],
    ".afftonschools.net": ["Affton High School"],
    ".aischool.net": ["Ahmedabad International School"],
    ".alighieripascoli.net": ["Alighieri Pascoli"],
    ".allhallows.net": ["All Hallows Catholic School"],
    ".antigua-luberri.net": ["Antigua Luberri BHI institutoa"],
    ".aptechsite.net": ["Aptech Computer Education"],
    ".aries-esi.net": ["Ecole Aries"],
    ".auamed.net": ["American University of Antigua"],
    ".audist.net": ["Anna University, Chennai"],
    ".auist.net": ["Anna University, Chennai"],
    ".avccengg.net": ["A.V.C. College of Engineering"],
    ".barnim-gymnasium.net": ["Barnim-Gymnasium Berlin"],
    ".baypath.net": ["Bay Path Regional Vocational Technical High School"],
    ".students.berkeley.net": ["Berkeley High School"],
    ".bhbl.net": ["Burnt Hills Ballston Lake"],
    ".bilgiedu.net": ["Istanbul Bilgi University"],
    ".birdvilleschools.net": ["Birdville Independent School District"],
    ".bluevalleyk12.net": ["Blue Valley School District"],
    ".bmiet.net": ["B. M. Institute Of Engineering & Technology"],
    ".bmstu.net": [
        "Bauman Moscow State Technical University",
        "Bauman Moscow State Technical University",
    ],
    ".boiseschools.net": ["Boise School District"],
    ".bracuniversity.net": ["Brac University"],
    ".brightoncollege.net": ["Brighton College"],
    ".bumail.net": ["Bangkok University"],
    ".byu.net": ["Brigham Young University"],
    ".carlsbadusd.net": ["Carlsbad Unified School District", ".group"],
    ".catholiccentral.net": ["Detroit Catholic Central High School"],
    ".student.ccboe.net": [
        "Columbia County school system of Georgia",
        "Columbia county",
        "Website:",
        "www.ccboe.net",
    ],
    ".ccsacademy.net": ["Chipping Campden School"],
    ".nv.ccsd.net": ["Charles Silvestri JHS"],
    ".cendrassos.net": [
        "Institut Cendrassos-Figueres",
        "Cendrassos-Figueres High School",
    ],
    ".stu.cfisd.net": ["Cyfair Highschool"],
    ".citchennai.net": [
        "Chennai Institute of Technology",
        "Chennai Institute of Technology",
    ],
    ".aluno.colegiomaanaim.net": ["Colégio Maanaim"],
    ".comunidadunir.net": [
        "International University of La Rioja",
        "Universidad Internacional de La Rioja",
    ],
    ".studentmail.conroeisd.net": ["The Woodlands High School "],
    ".courtmoorschool.net": ["Court Moor School"],
    ".crcmail.net": ["Champlain Regional College"],
    ".csustudent.net": ["Charleston Southern University"],
    ".ct-college.net": ["Kharkiv computer and technology college"],
    ".dadeschools.net": ["Palmetto ELementary School, Pinecrest Florida"],
    ".dallastownsd.net": ["Dallastown Area Middle School"],
    ".deegfeld.net": ["Oberschule Deegfeld"],
    ".deerparkschool.net": ["Cirencester Deerpark School"],
    ".denbigh.net": ["Denbigh School"],
    ".depinfonancy.net": [
        "DepInfoNancy.net which translate to IT Department of Mines Nancy (France).",
        "Unofficial domain for IT department, for which IT Students have an email (gmail + domain). The official email is used for alumni stuff as well thus do not meet requirements.",
        "References : http://www.depinfonancy.net/, http://www.mines-nancy.univ-lorraine.fr/content/syllabus-20152016-0 (a link from this page to www.depinfonancy.net exist in Information & Systems part)",
    ],
    ".digital-campus.net": ["ESG - Ecole de commerce"],
    ".dpsk12.net": ["Denver Public Schools"],
    ".dpsnc.net": ["Riverside High School"],
    ".dpsrkp.net": ["Delhi Public School, R.K. Puram"],
    ".go.dsdmail.net": ["Davis County School District, Utah"],
    ".dublinusd.net": ["Dublin Unified School District"],
    ".dzrtvu.net": ["DAZHOU RADIO&TV UNIVERSITY"],
    ".e-artsup.net": ["École de la Passion Créative"],
    ".eanesisd.net": ["Eanes Independent School District"],
    ".eartvic.net": [
        "Escola Superior de Disseny i d'Arts Plàstiques de Catalunya (ESDAP)",
        "Superior School of Design and Plastic Arts of Catalonia",
    ],
    ".ecole-ipssi.net": ["IPSSI - École d’Informatique, Web et Design Graphique"],
    ".ecoles-wis.net": ["Web International School"],
    ".efrei.net": [
        "École d'ingénieur généraliste en informatique et technologies du numérique"
    ],
    ".eichendorffschule.net": ["Eichendorffschule Kelkheim"],
    ".live.emvs.net": ["Ecole des Métiers du Valais"],
    ".engimtorino.net": [
        "ENGIM Piemonte – Artigianelli Torino ",
        "URL website: http://www.engimtorino.net/",
        "CERTIFICATIONS",
        "ENGIM Piemonte - Artigianelli Torino is certified according to the UNI EN ISO 9001: 2015 standard for the sectors:",
        "EA 37 (Education)",
        "EA 35 (Professional Business Services)",
        "Courses: http://www.engimtorino.net/corsi/ some in IT. ",
        "Address",
        "c.so Palestro 14 – 10122 Torino",
        "ITALIAN CODE for School (Codice meccanografico): TOCF01600C",
    ],
    ".epita.net": ["École Pour l'Informatique et les Techniques Avancées"],
    ".epmistes.net": ["ECAM EPMI - école d'ingénieurs"],
    ".esarc-evolution.net": ["ESG - Ecole de commerce"],
    ".esigetel.net": [
        "École supérieure d'ingénieurs en informatique et génie des télécommunications"
    ],
    ".esrp.net": ["Escola Superior de Relacions Públiques"],
    ".etna-alternance.net": ["École de la Nouvelle Alternance en Informatique"],
    ".etsmtl.net": ["École de technologie supérieure, Université du Québec"],
    ".ewhain.net": ["Ewha Womans University"],
    ".fapsnewdelhi.net": ["The Frank Anthony Public School"],
    ".fcpsschools.net": ["Fairfax County Schools"],
    ".fevaq.net": ['Facultad de Economia "Vasco de Quiroga"'],
    ".learn.flvs.net": ["Florida Virtual School"],
    ".fosbos.net": ["Maximilian Kolbe (Fachober- & Berufsober-) Schule Neumarkt"],
    ".franklinps.net": ["Franklin High School in Massachusetts"],
    ".fusdk12.net": ["American High School"],
    ".garfieldre2.net": ["Rifle Middle School"],
    ".gdcvi.net": [
        "广东建设职业技术学院",
        "Guangdong Construction Vocational and Technical College",
    ],
    ".oxf.gdst.net": ["Oxford High School"],
    ".por.gdst.net": ["Portsmouth High School for Girls"],
    ".wim.gdst.net": ["Wimbledon High School"],
    ".gemsdaa.net": ["GEMS Dubai American Academy"],
    ".ggusd.net": ["Pacifica High School", "Pacifica High School"],
    ".gitis.net": [
        "Russian Academy of Theatre Arts",
        "Russian Academy of Theatre Arts",
    ],
    ".gomalle.net": ["Atheneum Malle"],
    ".graphische.net": ["die Graphische"],
    ".grb-online.net": ["Gymnasium Riedberg"],
    ".guhsd.net": ["Grossmont Union High School "],
    ".guilderlandschools.net": ["Guilderland High School"],
    ".gulfuniversity.net": ["Gulf University College"],
    ".gym-leoben.net": ["BG/BRG Leoben 1 (Altes Gymnasium Leoben)"],
    ".gymbay.net": ["Staedtisches Gymnasium Bayreuther Strasse - Wuppertal"],
    ".student.gymkatzelsdorf.net": ["Gymnasium Klemens Maria Hofbauer"],
    ".gymmar.net": ["Gymnasium Mariehthal", "High school Marienthal"],
    ".gymott.net": ["Gymnasium Otterndorf"],
    ".gyo6.net": ["경상북도교육청", "Gyeongbuk Education"],
    ".gzkjxy.net": ["广州科技职业技术大学"],
    ".hadleighhigh.net": ["Hadleigh High School"],
    ".g.hayscisd.net": ["Johnson High School", "Moe & Gene Johnson High School"],
    ".hcps.net": ["Hillsborough County Public Schools", "Thomas Jefferson High School"],
    ".helmholtzschule-ffm.net": ["Helmholtzschule Frankfurt"],
    ".hetic.net": ["HETIC, la grande école d'internet"],
    ".hetperspectief.net": ["Het Perspectief PCVO - Adult Education"],
    ".hinchingbrookeschool.net": ["Hinchingbrooke School"],
    ".hindusthan.net": ["Hindusthan Educational Institutions, Coimbatore ", ".group"],
    ".hneu.net": ["Simon Kuznets Kharkiv National University of Economics"],
    ".hvf-bs.net": ["Hoffmann-von-Fallersleben-Schule Gymnasium"],
    ".hwbcymru.net": ["Cardiff High School"],
    ".hwps.net": ["George W Hewlett High School"],
    ".hwschools.net": ["Hamilton Wenham Regional High School"],
    ".iaac.net": ["Institute for advanced architecture of Catalonia"],
    ".ict-campus.net": [None],
    ".icuzambia.net": ["Information and Communications University"],
    ".iedparis8.net": ["iedparis8 foad"],
    ".iesjuandeherrera.net": ["INSTITUTO DE EDUCACIÓN SECUNDARIA JUAN DE HERRERA"],
    ".iessanclemente.net": ["IES San Clemente"],
    ".iesunamuno.net": ["Instituto de educación secundaria Miguel de Unamuno"],
    ".iiitb.net": ["International Institute of Information Technology Bangalore"],
    ".iimtindia.net": ["IIMT Group of colleges in India"],
    ".impscet.net": ["IMPS College of Engineering and Technology, Malda"],
    ".imt-atlantique.net": ["Institut Mines-Télécom Atlantique"],
    ".indianatech.net": ["Indiana Tech"],
    ".infobosccoma.net": ["Institut Bosc de la Coma"],
    ".ip-formation.net": ["IPSSI - École d’Informatique, Web et Design Graphique"],
    ".ipilyon.net": ["IPI Lyon"],
    ".ipsas-ens.net": ["institut polytechnique des sciences avancées sfax-Tunisie"],
    ".irakasle.net": [
        "Delegación de Educación del Gobierno Vasco / Eusko Jaurlaritza Hezkuntza Saila"
    ],
    ".iraquniversity.net": ["Iraq University College"],
    ".iscpalyon.net": ["ISCPA Lyon - Institut Supérieur des Médias"],
    ".ism-sabis.net": [
        "The International School of Minnesota",
        "International School of Minnesota",
        "ISM",
    ],
    ".ismreves.net": ["Institut Sainte-Marie"],
    ".ispaj.net": ["Instituto Superior Politécnico Alvorecer da Juventude"],
    ".itivoltativoliguidonia.net": [
        "ISTITUTO TECNICO TECNOLOGICO STATALE ALESSANDRO VOLTA",
        "official website https://itivolta.edu.it",
        "Long term (3 yrs) computer science course information: https://www.itivolta.edu.it/offerta-formativa-itts-volta/",
    ],
    ".iuc-univ.net": ["Institut Universitaire De La Côte"],
    ".jamesrumsey.net": ["James Rumsey Technical Institute"],
    ".jaumebalmes.net": ["Institut Jaume Balmes"],
    ".jhs.net": ["Jesuit High School"],
    ".johnabbottcollege.net": ["John Abbott College"],
    ".juanxxiii.net": ["Centro de Formación Profesional Juan XXIII"],
    ".kashmiruniversity.net": ["University of Kashmir, India"],
    ".kellerisd.net": ["Keller Center for Advanced Learning"],
    ".kes.net": ["King Edwards VI School, Stratford"],
    ".zsp2.krotoszyn.net": ["Zespół Szkół Ponadgimnazjalnych nr 2 w Krotoszynie"],
    ".kumsa.net": ["Khurasan University"],
    ".kwantlen.net": ["Kwantlen Polytechnic University"],
    ".ladueschools.net": [
        "Ladue Horton Watkins High School",
        "Ladue Horton Watkins High School",
    ],
    ".lammersvilleusd.net": ["Mountain House High School", ".group"],
    ".lasalleuniversities.net": ["La Salle Universities - International Programmes"],
    ".laschools.net": ["Los Alamos High School"],
    ".lausd.net": ["Los Angeles Unified School District"],
    ".lbschools.net": [
        "Long Beach Unified School District in Los Angeles, CA, USA",
        ".group",
    ],
    ".lcieducation.net": ["LaSalle College Montreal"],
    ".lecnam.net": ["Conservatoire national des Arts et Métiers"],
    ".leeschools.net": ["The School District of Lee County"],
    ".leobaeck.net": ["Leobaeck High School"],
    ".edu.leonschools.net": ["James S. Rickards Highschool"],
    ".eleve.leschartreux.net": ["Les Chartreux"],
    ".leyada.net": ["Hebrew University Secondary School"],
    ".lgflmail.net": ["Southborough High School "],
    ".liceolapaz.net": ["CPR Plurilingüe Liceo La Paz"],
    ".lisd.net": ["Lewisville Independent School District"],
    ".livenau.net": ["National Aviation University"],
    ".lsr7.net": ["Lee's Summit R-7 School District"],
    ".lsrhs.net": ["Lincoln-Sudbury Regional High School"],
    ".lubbockisd.net": ["Lubbock High School", "Lubbock High School"],
    ".lyndhurstschools.net": ["Lyndhurst High School"],
    ".lz95.net": ["Lake Zurich Community District"],
    ".maakhiruniversity.net": ["Maakhir University"],
    ".mabankisd.net": ["Mabank Independent School District"],
    ".manavrachna.net": [
        "Manav Rachna International Institute of Research and Studies"
    ],
    ".matc.net": ["Manhattan Area Technical College"],
    ".max-emden.net": ["Max-Windmüller-Gymnasium"],
    ".mayfieldschool.net": ["Mayfield School"],
    ".mba-esg.net": ["MBA ESG"],
    ".mbs.net": ["Morristown-Beard School"],
    ".mckinneyisd.net": ["McKinney Independent School District"],
    ".mcpsmd.net": ["Montgomery County Public Schools (Maryland)"],
    ".mcvts.net": [
        "Middlesex County Academy for Allied Health & Biomedical Sciences",
        "https://www.mcvts.net/woodbridge",
    ],
    ".msitprogram.net": [
        "Master of Science in Information Technology",
        "International Institute of Information Technology Hyderabad",
    ],
    ".msjnet.net": ["Mount Saint Joseph High School"],
    ".muwci.net": ["Mahindra United World College India"],
    ".mvla.net": ["Mountain View Los Altos High School District"],
    ".mvwsd.net": ["Isaac Newton Graham Middle School Mountain View"],
    ".myecran.net": ["ESG - Ecole de commerce"],
    ".myesg.net": ["ESG - Ecole de commerce"],
    ".mymdc.net": ["Miami Dade College"],
    ".myoneclay.net": ["Fleming Island High School"],
    ".mypisd.net": ["Plano Independent School District"],
    ".nashobatech.net": ["Nashoba Valley Technical High School"],
    ".ncvt.net": ["Nanning College For Vocational Technology", "http://www.ncvt.net"],
    ".ndoverneuil.net": ["Notre Dame les Oiseaux Verneuil / NDO Verneuil"],
    ".nicevillehighschool.net": ["Niceville High School"],
    ".nisd.net": [
        "Harlan Highschool",
        "Northside Independent School District",
        ".group",
    ],
    ".nitsri.net": ["National Institue of Technology Srinagar", "nitsri.net"],
    ".nj29jt.net": ["南京市第二十九中学", "Nanjing No.29 High School"],
    ".nsboroschools.net": [
        "Public Schools of Northborough and Southborough / Algonquin Regional High School",
        "Url: https://www.nsboro.k12.ma.us/arhs",
        "Mail: (name)@nsboroschools.net",
    ],
    ".nsd42.net": ["Nashua School District"],
    ".nspu.net": ["Novosibirsk State Pedagogical University"],
    ".ntai.net": ["\ufeffNetwork Technology Academy"],
    ".student.nths.net": ["add new trier high school"],
    ".ntschools.net": ["Casuarina Senior College"],
    ".nycstudents.net": ["Mark Twain I.S. 239"],
    ".oak-hill.net": ["Oak Hill Academy"],
    ".ocps.net": ["Orange County Public Schools (Florida)"],
    ".ofcs.net": ["Olmsted Falls City Schools"],
    ".oisbd.net": ["Oxford International School"],
    ".ontariotechu.net": ["Ontario Tech University"],
    ".msd.oregonk-12.net": ["McMinnville High School"],
    ".oregonsd.net": ["Oregon High School"],
    ".student.osceolaschools.net": ["NeoCity Academy"],
    ".palisadessd.net": ["Palisades School District"],
    ".parkschool.net": ["The Park School of Baltimore"],
    ".parkwayschools.net": ["Parkway School District"],
    ".pdsb.net": ["Peel District School Board", ".group"],
    ".pennmanor.net": ["Penn Manor School District"],
    ".pghs.net": ["Pleasant Grove High School"],
    ".pimajted.net": ["Pima JTED"],
    ".pinescharter.net": ["Pembroke Pines Charter High School"],
    ".plaiaundi.net": ["IES Plaiaundi BHI", "Plaiaundi Vocational Institute"],
    ".plainville270.net": ["Plainville USD 270"],
    ".pleasantonusd.net": ["Pleasanton Unified School District"],
    ".plus4u.net": ["Unicorn College"],
    ".polytech-lille.net": ["Ecole polytechnique universitaire de Lille"],
    ".student.pps.net": ["Metropolitan Learning Center"],
    ".ppsstudents.net": ["Pittsburgh Public Schools"],
    ".promsocatc.net": ['Collège Technique "Aumôniers du Travail"'],
    ".k12.prosper-isd.net": ["Prosper High School"],
    ".raabeschule.net": ["Gymnasium Raabeschule Braunschweig"],
    ".radyr.net": ["Radyr Comprehensive School", "Radyr Comprehensive School"],
    ".raisoni.net": ["Raisoni Group Of Institution"],
    ".rascol.net": [
        "Lycée public général et professionnel dans l'Occitanie ( 81 ) ",
        "URL : http://www.rascol.net/",
    ],
    ".student.rcschools.net": ["Rutherford County Schools", ".group"],
    ".regentghana.net": [
        "Regent University College",
        "Regent University College Of Science And Technology  ",
    ],
    ".rgsu.net": [
        "Российский государственный социальный университет",
        "Russian state social university",
    ],
    ".rgtu.net": ["Rajiv Gandhi Proudyogiki Vishwavidyalaya, Bhopal"],
    ".riinvest.net": ["Riinvest College"],
    ".ruppin365.net": ["Ruppin Academic Center"],
    ".rusoil.net": [
        "Ufa State Petroleum Technological University",
        "Ufa State Petroleum Technological University",
    ],
    ".sabauni.net": ["Saba University"],
    ".saint-louis29.net": ["Lycée Saint-Louis - Châteaulin"],
    ".saintdominique.net": ["Institut Saint-Dominique de Neuilly"],
    ".saintolaves.net": ["St. Olave's Grammar School"],
    ".saisd.net": ["CAST Tech "],
    ".saltashcloud.net": ["saltash.net community school"],
    ".sandi.net": ["San Diego Unified School District"],
    ".sandyupper.net": ["Sandy Upper School"],
    ".sarasotacountyschools.net": ["Sarasota County Schools"],
    ".sas-sd.net": ["Sudan Academy of Sciences"],
    ".school4games.net": ["School for Games"],
    ".scusd.net": ["Santa Clara High School, Santa Clara, CA 95051"],
    ".my.sduhsd.net": ["San Dieguito Union High School District"],
    ".shu-bg.net": ["Shoumen University Konstantin Preslavski"],
    ".sio-mermoz.net": ["lycée jean mermoz"],
    ".student.sisd.net": ["Americas High School"],
    ".solskicenter.net": [
        "Šola s slovenskim učnim jezikom Simon Gregorčič Primož Trubar",
        'official website: "https://www.solskicenter.net"',
    ],
    ".spulive.net": ["มหาวิทยาลัยศรีปทุม", "Sripatum University"],
    ".spumail.net": ["มหาวิทยาลัยศรีปทุม", "Sripatum University"],
    ".srvusd.net": ["San Ramon Valley Unified School District", ".group"],
    ".student.st-chris.net": ["St Christopher's School of Bahrain"],
    ".stanislascollege.net": ["Stanislascollege"],
    ".starkstate.net": ["Stark State College"],
    ".stjameslc.net": ["St. James Lutheran College", "St. James Lutheran College"],
    ".stmcougars.net": ["St. Thomas More Catholic High School"],
    ".student-jcboe.net": ["Jefferson County High School"],
    ".studentlaschools.net": ["Los Alamos High School"],
    ".suhsd.net": ["Shasta High School"],
    ".suumail.net": ["Southern Utah University"],
    ".swchs.net": [
        "Saffron Walden County High School",
        "Audley End Road",
        "Saffron Walden",
        "Essex",
        "CB11 4UH",
    ],
    ".swcta.net": ["Southwest Career and Technical Academy"],
    ".talaiabhi.net": ["Talaia "],
    ".tesdk12.net": ["Conestoga High School"],
    ".tfobz.net": ["Technologische Fachoberschule Bozen"],
    ".thammasat.net": ["Thammasat University", "Thammasat University"],
    ".thestudio-liverpool.net": ["The Studio Liverpool"],
    ".trentcollege.net": ["Trent College in Nottingham, England"],
    ".tretherras.net": ["Newquay Tretherras Academy"],
    ".tscstudents.net": ["William Henry Harrison High School West Lafayette"],
    ".edu.tversu.net": [
        "Тверской Государственный Университет",
        "Tver State University",
    ],
    ".uamcr.net": ["Universidad Americana"],
    ".uantonine.net": ["UA Universite Antonine"],
    ".ubboemmius.net": [
        "Ubbo Emmius Scholengemeenschap, The Netherlands, Students Email Domain"
    ],
    ".ubt-uni.net": ["University for Business and Technology"],
    ".ubuea.net": ["University of Buéa"],
    ".ucasal.net": ["Universidad Católica de Salta"],
    ".ucfsd.net": ["Unionville High School"],
    ".ugtu.net": ["Ukhta State Technical University"],
    ".ulatina.net": ["Universidad Latina de Costa Rica"],
    ".ulpgl.net": [
        "Université Libre des Pays des Grands Lacs",
        "Free University of Great Lakes Countries",
    ],
    ".umasd.net": ["Upper Merion Area High School"],
    ".unadeca.net": ["Universidad Adventista de Centroamerica"],
    ".unesc.net": ["Universidade do Extremo Sul Catarinense"],
    ".uni-gjilan.net": ["University Kadri Zeka"],
    ".uni-plovdiv.net": ["University of Plovdiv"],
    ".unibave.net": ["Centro Universitário Barriga Verde"],
    ".unicornuniversity.net": ["Unicorn College"],
    ".unimediteran.net": ["Univerzitet Mediteran", "Mediterranean University"],
    ".uninettunouniversity.net": ["Universita Telematica Internazionale UniNettuno"],
    ".unir.net": ["Universidad Internacional de La Rioja"],
    ".univ-mngb.net": ["University Marien Ngouabi Brazzaville"],
    ".universityofsomalia.net": ["University of Somalia"],
    ".uoit.net": ["University of Ontario Institute of Technology"],
    ".usd259.net": ["Wichita East High School"],
    ".vcpusd.net": ["Valley Center-Pauma Unified"],
    ".videndjurs.net": ["Viden Djurs"],
    ".vizja.net": ["Wyższa Szkoła Technologii Informatycznych"],
    ".vntu.net": ["Vinnytsia National Technical University"],
    ".volgatech.net": ["Volga State University of Technology"],
    ".vossie.net": ["Eduvos"],
    ".wakecoll.net": ["Wakefield College"],
    ".wcpss.net": ["Wake County Public School System"],
    ".westminster.net": ["The Westminster Schools"],
    ".westottawa.net": ["West Ottawa High School"],
    ".wilhelm-gym.net": ["Wilhelm-Gymnasium Braunschweig"],
    ".willitscharter.net": ["Willits Charter School"],
    ".wra.net": ["Western Reserve Academy"],
    ".wsfcsstudents.net": ["Winston-Salem Forsyth County Schools", ".group"],
    ".wylieisd.net": [
        "Wylie High School",
        "Wylie High",
        "WylieISD",
        "Wylie ISD",
        "Wylie ISD School District",
    ],
    ".xbhs.net": ["Xaverian Brothers High School"],
    ".zeppelin-university.net": ["Zeppelin University"],
    ".zjnu.net": ["ZheJiang Normal University"],
    ".zsnr4.net": ["Zespół Szkół nr4 w Nowym Sączu"],
    ".zszwolsztyn.net": ["Zespół Szkół Zawodowych Wolsztyn, Poland"],
    ".zib.network": [
        "TU Ilmenau - Zentralinstitut für Bildung",
        "TU Ilmenau - Central Institute for Education",
    ],
    ".aaua.edu.ng": ["Adekunle Ajasin University, Akungba-Akoko"],
    ".aauekpoma.edu.ng": ["Ambrose Alli University"],
    ".abu.edu.ng": ["Ahmadu Bello University, Zaria"],
    ".student.adelekeuniversity.edu.ng": ["Adeleke University"],
    ".alhikmah.edu.ng": ["Alhikmah University Ilorin"],
    ".aquatechcollege.edu.ng": ["Aquatech College of Agriculture and Technology"],
    ".atbu.edu.ng": ["Abubakar Tafawa Balewa University Bauchi  State Nigeria"],
    ".auk.edu.ng": ["Al-Qalam University Katsina"],
    ".student.aul.edu.ng": [
        "Anchor University Lagos",
        "Anchor University Lagos",
        "AUL",
        "Anchor University Lagos Ayobo",
        "# As added by Okorie God'sfavour Chiemerie AUL/SCI/16/0042 - Department of Computer Science and Mathematics 2016",
    ],
    ".aul.edu.ng": ["Anchor university, Lagos, Nigeria"],
    ".aun.edu.ng": ["American University of Nigeria"],
    ".aust.edu.ng": ["African University of Science and Technology [AUST], Abuja"],
    ".student.babcock.edu.ng": ["Babcock University"],
    ".basug.edu.ng": ["Bauchi State University Gadau"],
    ".bazeuniversity.edu.ng": ["Baze University Abuja"],
    ".bellsuniversity.edu.ng": ["Bells University of Technology"],
    ".binghamuni.edu.ng": ["Bingham University"],
    ".bowen.edu.ng": ["Bowen University"],
    ".buk.edu.ng": [
        "Bayero University, Kano",
        "BUK",
        "Official Website: https://www.buk.edu.ng/",
        "The student email is like   student_i@buk.edu.ng",
        "#Request made by Shamsuddeen Hassan Muhammad, Faculty of Computer Science and IT.",
    ],
    ".coedarazo.edu.ng": ["College of Education Darazo"],
    ".covenantuniversity.edu.ng": ["Covenant University"],
    ".crutech.edu.ng": ["Cross River University of Technology "],
    ".stu.cu.edu.ng": ["Covenant University"],
    ".dui.edu.ng": ["Dominican University Ibadan"],
    ".edouniversity.edu.ng": [
        "Edo State University",
        "Formerly Known as Edo University",
    ],
    ".eit.edu.ng": [
        "Elerinmosa Institute of Technology, Erin-Osun, Osun State, Nigeria.",
        "Elerinmosa Institute of Technology",
    ],
    ".eksu.edu.ng": ["Ekiti State University"],
    ".elizadeuniversity.edu.ng": ["Elizade University, Illara-Mokin"],
    ".fcahptib.edu.ng": [
        "Federal College Of Animal Health & Production Technology Ibadan"
    ],
    ".federalpolyilaro.edu.ng": ["The Federal Polytechnic, Ilaro"],
    ".fideipoly.edu.ng": ["Fidei Polytechnic Gboko, Benue state, Nigeria"],
    ".flyingdoveinstitute.edu.ng": ["Flying Dove Institute Nigeria"],
    ".fptb.edu.ng": ["The Federal Polytechnic Bauchi, Nigeria"],
    ".fud.edu.ng": ["Federal University Dutse"],
    ".fugusau.edu.ng": ["Federal University Gusau"],
    ".fukashere.edu.ng": ["Federal University of Kashere"],
    ".student.fulafia.edu.ng": [
        "Federal University Lafia,Nigeria",
        "http://www.fulafia.edu.ng",
    ],
    ".fulokoja.edu.ng": ["Federal University Lokoja"],
    ".pg.funaab.edu.ng": ["Federal University Of Agriculture Postgraduate school"],
    ".student.funaab.edu.ng": ["Federal University of Agriculture, Abeokuta."],
    ".funaab.edu.ng": ["Federal University of Agriculture, Abeoukuta", "FUNAAB"],
    ".fuoye.edu.ng": ["The Federal University of Oye Ekiti"],
    ".fupre.edu.ng": ["Federal University of Petroleum Resources, Effurun"],
    ".futa.edu.ng": ["The Federal University of Technology Akure"],
    ".st.futminna.edu.ng": [
        "Federal university of Techonology, Minna",
        "http://futminna.edu.ng",
        "The student email is like -- student_id@st.futminna.edu.ng",
    ],
    ".futo.edu.ng": [
        "FEDERAL UNIVERSITY OF TECHNOLOGY OWERRI (FUTO), NIGERIA",
        "FEDERAL UNIVERSITY OF TECHNOLOGY OWERRI (FUTO), NIGERIA",
    ],
    ".fuwukari.edu.ng": ["Federal University Wukari"],
    ".imsu.edu.ng": ["Imo State University Owerri"],
    ".interlinkpolytechnic.edu.ng": ["Interlink Polytechnic, Ijebu-Jesa, Osun State"],
    ".kasu.edu.ng": ["Kaduna State University"],
    ".kwarastatepolytechnic.edu.ng": ["Kwara State Polytechnic, Ilorin, Kwara State"],
    ".lasu.edu.ng": ["Lagos State University"],
    ".lautech.edu.ng": ["Ladoke Akintola University of Technology"],
    ".lmu.edu.ng": ["Landmark University, Omu-Aran"],
    ".mcu.edu.ng": ["McPherson University, Seriki-Sotayo, Ogun State"],
    ".mouau.edu.ng": ["micheal okpara university of agriculture "],
    ".mtu.edu.ng": ["Mountain Top University"],
    ".ndu.edu.ng": ["Niger Delta University, Nigeria"],
    ".nileuniversity.edu.ng": ["Nile University of Nigeria"],
    ".ntnu.edu.ng": ["Nigerian Turkish Nile"],
    ".oauife.edu.ng": ["Obafemi Awolowo University"],
    ".oouagoiwoye.edu.ng": [
        "OLABISI ONABANJO UNIVERSITY",
        "OLABISI ONABANJO UNIVERSITY",
    ],
    ".osustech.edu.ng": ["OSUSTECH", "Ondo State university of science and Technology"],
    ".pau.edu.ng": ["Pan-Atlantic University", "PAU"],
    ".plapoly.edu.ng": ["Plateau State Polytechnic, Barkin Ladi, Nigeria"],
    ".run.edu.ng": ["Redeemer's University"],
    ".tasued.edu.ng": [
        "Tai Solarin University of Education",
        "Tai Solarin University of Education",
    ],
    ".tsuniversity.edu.ng": ["Taraba State University"],
    ".dlc.ui.edu.ng": ["University of Ibadan DLC"],
    ".stu.ui.edu.ng": ["University of Ibadan"],
    ".umyu.edu.ng": ["Umaru Musa Yar'adua University Katsina"],
    ".unical.edu.ng": ["University Of Calabar"],
    ".unijos.edu.ng": ["University of Jos", "University of Jos, Nigeria"],
    ".unilag.edu.ng": ["University of Lagos."],
    ".unilorin.edu.ng": ["University of Ilorin"],
    ".unimaid.edu.ng": ["University of Maiduguri", "Unimaid"],
    ".uniosun.edu.ng": ["Osun State University"],
    ".uniport.edu.ng": ["Uniport Of Port Harcourt"],
    ".unizik.edu.ng": ["Nnamdi Azikiwe University"],
    ".unn.edu.ng": ["University of Nigeria"],
    ".ust.edu.ng": ["Rivers State University of Science and Technology"],
    ".yabatech.edu.ng": ["Yaba College of Technology"],
    ".yumsuk.edu.ng": ["Yusuf Maitama Sule University Kano"],
    ".uam.edu.ni": ["Universidad Americana"],
    ".uca.edu.ni": ["Universidad Centroamericana"],
    ".ucc.edu.ni": ["Universidad Ciencias Comerciales"],
    ".ucem.edu.ni": ["Universidad Centroamericana de Ciencias Empresariales (UCEM)"],
    ".ucyt.edu.ni": ["Universidad Nicaragüense de Ciencia y Tecnológica"],
    ".udem.edu.ni": ["Universidad de Managua (U de M)"],
    ".uhispam.edu.ni": ["Universidad Hispanoamericana"],
    ".ulam.edu.ni": ["Universidad de las Américas (ULAM)"],
    ".una.edu.ni": ["Universidad Nacional Agraria"],
    ".unan.edu.ni": ["Universidad Nacional Autonoma de Nicaragua"],
    ".uni.edu.ni": ["Universidad Nacional de Ingenieria"],
    ".unica.edu.ni": [
        "Universidad Catolica Redemptoris Mater",
        "Universidad Catolica Redemptoris Mater",
        "Universidad Catolica Redemptoris Mater",
    ],
    ".unicit.edu.ni": ["Universidad Iberoamericana de Ciencia y Tecnologia"],
    ".upoli.edu.ni": ["Universidad Politecnica de Nicaragua"],
    ".uponic.edu.ni": ["Universidad Popular de Nicaragua (UPONIC)"],
    ".uraccan.edu.ni": [
        "Universidad de las Regiones Autónomas de la Costa Caribe Nicaragüense"
    ],
    ".utc.edu.ni": ["Universidad Técnica de Comercio"],
    ".uam.net.ni": [
        "Universidad Americana (UAM)",
        "Universidad Americana (UAM)",
        "Universidad Americana (UAM)",
    ],
    ".st.roc.a12.nl": ["ROC A12"],
    ".a12.nl": ["ROC A12"],
    ".ad-academie.nl": ["AD Academie", "Associate degrees Academie"],
    ".ade-buas.nl": ["Breda University of Applied Sciences"],
    ".student.ahk.nl": ["Amsterdam University Of The Arts"],
    ".ahk.nl": ["Amsterdam University Of The Arts"],
    ".student.albeda.nl": ["Albeda College Rotterdam"],
    ".albeda.nl": ["Albeda College"],
    ".aletta.nl": ["dr. Aletta Jacobs College"],
    ".student.alfa-college.nl": [
        "Student subdomain for Alfa College in Hoogeveen and Groningen"
    ],
    ".alfa-college.nl": ["Alfa-college Hardenberg"],
    ".amadeuslyceum.nl": ["Amadeus Lyceum"],
    ".ambelt.nl": ["Het Ambelt in Zwolle"],
    ".amstelveencollege.nl": ["Amstelveen College"],
    ".amsterdamumc.nl": ["Amsterdam UMC", "Amsterdam UMC"],
    ".arcuscollege.nl": ["https://vistacollege.nl/"],
    ".arentheemcollege.nl": ["Arentheem College"],
    ".student.artez.nl": ["ArtEZ hogeschool voor de kunsten"],
    ".artez.nl": ["ArtEZ hogeschool voor de kunsten"],
    ".ash.nl": ["American School of the Hague", "American School of the Hague"],
    ".edu.atchilversum.nl": ["Alberdingk Thijm College"],
    ".auc.nl": ["Amsterdam University College"],
    ".avans.nl": ["Avans University of Applied Sciences"],
    ".aventus.nl": ["Aventus.nl"],
    ".edu.bartimeus.nl": ["Bartimeus REA College"],
    ".bc-enschede.nl": ["Bonhoeffer College Enschede"],
    ".beekdallyceum.nl": ["Beekdal Lyceeum"],
    ".bernardinuscollege.nl": ["Bernardinuscollege"],
    ".student.bit-academy.nl": ["Bit Academy"],
    ".bit-academy.nl": ["Bit Academy"],
    ".bonhoeffer.nl": ["Bonhoeffercollege Castricum"],
    ".bsnstudent.nl": ["The British School in The Netherlands"],
    ".buas.nl": ["Breda University of Applied Sciences"],
    ".leerling.cals.nl": ["Cals College"],
    ".calvijn.nl": ["CSG Calvijn"],
    ".calvijncollege.nl": ["Calvijn College"],
    ".candea.nl": ["Candea College"],
    ".capellen.nl": ["Van der Capellen Scholengemeenschap Zwolle Lassuslaan"],
    ".cartesius2.nl": ["Cartesius 2"],
    ".leerling.cgu.nl": ["Christelijk Gymnasium Utrecht"],
    ".cgu.nl": ["Christelijk Gymnasium Utrecht", "Christian Gymnasium Utrecht"],
    ".che.nl": ["CHE Christian University of Applied Sciences"],
    ".student.cibap.nl": ["Cibap Vakschool voor Verbeelding"],
    ".clv.nl": ["christelijk lyceum veenendaal"],
    ".clz.nl": ["Christelijk Lyceum Zeist"],
    ".student.codam.nl": ["Codam Coding College"],
    ".commanderijcollege.nl": ["Commanderij College"],
    ".corlaercollege.nl": ["Corlaer College"],
    ".csgaugustinus.nl": ["CSG Augustinus"],
    ".csgdgw.nl": ["csg de goudse waarden", "https://www.degoudsewaarden.nl/"],
    ".curio.nl": ["Curio"],
    ".davinci-leiden.nl": ["SG Leonardo Da Vinci"],
    ".davinci.nl": ["ROC Da Vinci College"],
    ".ddu.nl": ["Dutch Delta University"],
    ".degoudsewaarden.nl": ["https://www.degoudsewaarden.nl/", "csg de goudse waarden"],
    ".deltion.nl": ["Deltion College"],
    ".denassau.nl": ["De nassau", "The Nassau"],
    ".dewillem.nl": ["CSG Willem van Oranje"],
    ".dominicuscollege.nl": ["Dominicus College"],
    ".drenthecollege.nl": ["Drenthe College"],
    ".driestarcollege.nl": ["Driestar College (docenten)"],
    ".driestarleerling.nl": ["Driestar College"],
    ".edu-kw1c.nl": ["Koning Willem 1 College"],
    ".elu.nl": ["European Leadership University"],
    ".erasmuscollege.nl": ["Erasmus College"],
    ".erasmusmc.nl": ["\ufeffErasmus University Medical Center Rotterdam"],
    ".eur.nl": ["Erasmus University Rotterdam"],
    ".fclive.nl": ["Friesland College Regionaal Opleidingencentrum"],
    ".fcroc.nl": ["Friesland College"],
    ".fonsvitae.nl": ["Fons Vitae Lyceum"],
    ".fontys.nl": ["Fontys University of Applied Sciences"],
    ".gentiaancollege.nl": ["Gentiaancollege Apeldoorn"],
    ".gerritrietveldcollege.nl": ["Gerrit Rietveld College"],
    ".ghc.nl": ["Graaf Huyn College"],
    ".student.gildeopleidingen.nl": [
        "Gilde Opleidingen, Roermond",
        "http://www.gildeopleidingen.nl/",
        "http://www.gildeopleidingen.nl/opleidingen/416091-applicatieontwikkelaar/studierichting=ict",
        "https://sts.gildeopleidingen.nl/adfs/ls/?client-request-id=8f0cbc03-4a9b-4bb5-b3ba-871c7fee255b&username=&wa=wsignin1.0&wtrealm=urn%3afederation%3aMicrosoftOnline&wctx=estsredirect%3d2%26estsrequest%3drQIIAeNisFLJKCkpKLbS188vLcnJz8_Wy09Ly0xO1UvOz9XLL0rPTAGxopiBskVCXALMe3j6Z3tt9d68q12m_p1q9CxG6eKS0pTUvBK99MyclNT8gpzUzJTMvPTUPL28nFWM8rhN188vT9S_wMi4iYnd18kzPjjY5wTT5c_8t5gE_YvSPVPCi91SU1KLEksy8_MeMfGGFqcW-eflVIbkZ6fmTWLmy8lPz8yLLy5Ki0_LyS8HCgBNLEhMLokvyUzOTi3ZxaxiYJ5kYpqYZKSbmGKSomuSZmqka5FsYKlrapJilmyQlpqWZmB0gUXgBwvjIlagz06ZMc42tDPwnsNuMKN42emMU6z6iUllYR6FOempFU5Vxjk-ESYZnkk-3p6-Ud75Ya4GFtr6VT4p4cHeYf6-ybbmVoa7OH0I-Na-KDUxJ9cWT4iplaXYlqcm5SZm5gAA0",
    ],
    ".glr.nl": ["Grafisch Lyceum Rotterdam"],
    ".glu.nl": ["Grafisch Lyceum Utrecht"],
    ".graafschapcollege.nl": ["Graafschap College"],
    ".greijdanus.nl": ["Greijdanus College"],
    ".guido.nl": ["Guido"],
    ".gymnasiumarnhem.nl": ["Stedelijk Gymnasium Arnhem"],
    ".gymnasiumbeekvliet.nl": ["Gymnasium Beekvliet"],
    ".gymnasiumhilversum.nl": ["Gemeentelijk Gymnasium Hilversum"],
    ".gymnasiumnovum.nl": ["Gymnasium Novum"],
    ".haarlemmermeerlyceum.nl": ["Haarlemmermeer Lyceum"],
    ".hageveld.nl": ["Atheneum College Hageveld"],
    ".han.nl": ["HAN University of Applied Sciences"],
    ".hanze.nl": ["Hanze University Groningen"],
    ".has.nl": ["HAS Hogeschool"],
    ".helicon.nl": ["Helicon Opleidingen"],
    ".hetbaarnschlyceum.nl": ["Het Baarnsch Lyceum"],
    ".student.hetbaken.nl": ["Het Baken Stad "],
    ".hethooghuis.nl": ["Het Hooghuis"],
    ".hetnieuwelyceum.nl": ["Het Nieuwe Lyceum"],
    ".hetwesteraam.nl": ["Het Westeraam"],
    ".hhs.nl": ["The Hague University of Applied Sciences"],
    ".hku.nl": ["Hogeschool voor de Kunsten Utrecht (HKU)"],
    ".hlz.nl": ["hervormd lyceum zuid"],
    ".hondsrugcollege.nl": ["Hondsrug College"],
    ".hoornbeeck.nl": ["Hoornbeeck College"],
    ".horizoncollege.nl": ["Horizon College"],
    ".hr.nl": ["Rotterdam University"],
    ".hro.nl": ["Hogeschool Rotterdam"],
    ".hsleiden.nl": ["University of Applied Sciences Leiden"],
    ".hsmarnix.nl": ["Marnix Academie"],
    ".hu.nl": ["Hogeschool Utrecht"],
    ".hva.nl": ["Hogeschool van Amsterdam"],
    ".hvhl.nl": ["Hogeschool van Hall Larenstein"],
    ".hz.nl": ["HZ University of Applied Sciences"],
    ".leerling.ichthuskampen.nl": ["Ichthus College Kampen "],
    ".ichthuslyceum.nl": ["Ichtus Lyceum"],
    ".ictmbo.nl": ["ROC Tilburg", "School voor ICT & Mediatechnologie"],
    ".idcollege.nl": ["ROC ID College"],
    ".ijburgcollege.nl": ["IJburg College"],
    ".inholland.nl": ["Hogeschool Inholland"],
    ".insulacollege.nl": ["Insula College"],
    ".edu.ishilversum.nl": [
        "International School Hilversum",
        "International School Hilversum",
    ],
    ".islamicuniversity.nl": ["Islamic University of Rotterdam"],
    ".iss.nl": ["Institute of Social Studies"],
    ".itc.nl": [
        "International Institute for Geo - Information Science and Earth Observation"
    ],
    ".jtc-roosendaal.nl": ["Jan Tinbergen College"],
    ".student.kabk.nl": ["Koninklijke Academie van Beeldende Kunsten, Den Haag"],
    ".kabk.nl": ["Koninklijke Academie van Beeldende Kunsten, Den Haag"],
    ".leerling.kajmunk.nl": ["Kaj Munk College"],
    ".kalsbeek.nl": [
        "Kalsbeek College, Woerden",
        "https://www.kalsbeek.nl/",
        "Slideshow containing contents of computer science/informatica program: http://slideplayer.nl/slide/2213402/",
    ],
    ".kennemerlyceum.nl": ["Kennemer Lyceum"],
    ".elo.krimpenerwaardcollege.nl": ["Krimpenerwaard College"],
    ".kw1c.nl": ["Koning Willem 1 College"],
    ".landstede.nl": ["Regional Community College Landstede"],
    ".leeuwenborgh.nl": ["Leeuwenborgh"],
    ".leidenuniv.nl": ["University of Leiden"],
    ".leijgraaf.nl": ["ROC de Leijgraaf"],
    ".lekenlinge.nl": ["ORS Lek en Linge"],
    ".liacs.nl": ["Leiden Institute of Advanced Computer Science"],
    ".liemerscollege.nl": ["Liemers College"],
    ".student.lmc-vo.nl": [
        "Stichting LMC Voortgezet Onderwijs",
        "Experience College",
        "Havo/vwo voor muziek en dans",
        "Het Lyceum Rotterdam  ",
        "Het Praktijkcollege Centrum",
        "Het Praktijkcollege Charlois",
        "Het Praktijkcollege Zuidwijk",
        "Horeca Vakschool Rotterdam ",
        "Lyceum Kralingen ",
        "MT010 - De Mavo voor Theater",
        "Mavo Centraal",
        "Montessori Mavo Rotterdam",
        "Montfort College",
        "PT010 - Theater en Dans",
        "Roncalli Mavo",
        "Rotterdam Designcollege",
        "Theaterhavo/vwo",
        "TooropMavo",
        "Vak College Hillegersberg",
        "Vak College Zuidrand",
        "Veenoord ",
        "Young Business School Rotterdam en afdeling Vrijeschool de Kaap",
        "Zuiderpark College ",
        ".group",
    ],
    ".lorentzlyceum.nl": ["Lorentz Lyceeum"],
    ".lumc.nl": ["Leiden University Medical Center"],
    ".luzac.nl": ["Luzac College en Luzac Lyceum"],
    ".lyceumelst.nl": ["Lyceeum Elst"],
    ".ma-web.nl": ["Mediacollege Amsterdam"],
    ".maartenvanrossem.nl": ["Maarten van Rossum"],
    ".maastrichtuniversity.nl": ["Maastricht University"],
    ".markland.nl": ["Markland College"],
    ".martinuscollege.nl": ["Martinuscollege"],
    ".mboamersfoort.nl": ["MBO Amersfoort"],
    ".mborijnland.nl": ["Mborijnland"],
    ".mboutrecht.nl": ["Regional college of Utrecht"],
    ".mijncarmelhengelo.nl": ["Scholengroep Carmel Hengelo"],
    ".mondia.nl": ["Nehalennia SSG"],
    ".mondriaanict.nl": ["ROC mondriaan School voor ICT"],
    ".montessoriarnhem.nl": ["Montessori Arnhem"],
    ".msa.nl": ["Montessori Lyceum Amsterdam"],
    ".mydavinci.nl": ["Da Vinci College"],
    ".myloketzwijndrecht.nl": ["Loket Zwijndrechtse Waard"],
    ".dr.nassaucollege.nl": ["Dr. Nassau College"],
    ".nhl.nl": ["NHL University"],
    ".nijenrode.nl": ["University of Nijenrode"],
    ".nikhef.nl": ["National Institute for Subatomic Physics"],
    ".nki.nl": ["Netherlands Cancer Institute"],
    ".noorderpoort.nl": ["ROC Noorderpoort"],
    ".noordgouw.nl": ["Christelijk College de Noordgouw"],
    ".novacollege.nl": ["Nova College"],
    ".novi-education.nl": [
        "Hogeschool NOVI b.v.",
        "University of Applied Science NOVI",
    ],
    ".novi-youngcapital.nl": [
        "Hogeschool NOVI b.v.",
        "University of Applied Science NOVI",
    ],
    ".nyenrode.nl": ["Nyenrode Business Universiteit"],
    ".obcnet.nl": ["Over Betuwe College"],
    ".obszeester.nl": ["Basisschool Vlieland"],
    ".ogvo.nl": [
        "Onderwijsgemeenschap Venlo en Omstreken",
        "* Valuascollege",
        "* College Den Hulster",
        "* Blariacumcollege",
    ],
    ".olympuscollege.nl": ["Olympus College"],
    ".ooz.nl": ["Openbaar Onderwijs Zwolle", ".group"],
    ".openbaarlyceumzeist.nl": ["Openbaar Lyceum Zeist", "Nuovo Scholengroep"],
    ".os3.nl": ["University of Amsterdam ", "- Security and Network engineering"],
    ".osgh.nl": ["Openbare Scholengemeenschap Hengelo"],
    ".ou.nl": ["Open University of the Netherlands"],
    ".leerling.over-y.nl": ["Over-Y College"],
    ".pallasathenecollege.nl": ["Pallas Athene College"],
    ".live.pantarijn.nl": ["RSG Pantarijn"],
    ".leerling.pieterzandt.nl": ["Pieterzandt Scholengemeenschap"],
    ".pleysier.nl": ["Pleysier College"],
    ".politieacademie.nl": ["Politieacademie"],
    ".pontes.nl": ["Pontes Scholengroep"],
    ".leerling.portamosana.nl": ["Porta Mosana College"],
    ".praedinius.nl": ["Praedinius Gymnasium"],
    ".produsarnhem.nl": ["Produs Arnhem"],
    ".psg.nl": ["Purmerendse Scholen Gemeenschap"],
    ".quadraam.nl": ["Stichting Quadraam"],
    ".radboudumc.nl": ["Radboud University Medical Center"],
    ".reggesteyn.nl": ["CSG Reggesteyn"],
    ".regiocollege.nl": ["Regio College Zaandam"],
    ".reviusdoorn.nl": ["Revius Lyceum"],
    ".rijnijssel.nl": ["ROC Rijn IJssel"],
    ".rijnlandslyceum-rlo.nl": ["Rijnlands Lyceum Oegstgeest"],
    ".roac.nl": ["Roosevelt Academy University College"],
    ".student.roc-nijmegen.nl": [
        "Students subdomain domain for Regional Community College of Nijmegen."
    ],
    ".roc-nijmegen.nl": ["Regional Community College of Nijmegen"],
    ".roc-teraa.nl": [
        "Roc Ter AA",
        "Teacher domain",
        "http://www.roc-teraa.nl/opleiding/applicatie-en-mediaontwikkelaar/",
    ],
    ".roca12.nl": ["ROC A12"],
    ".rocdeleijgraaf.nl": ["ROC De Leijgraaf", "Leijgraaf"],
    ".roceindhoven.nl": ["Regional Community College of Eindhoven"],
    ".edu.rocfriesepoort.nl": ["ROC Friese Poort"],
    ".rocfriesepoort.nl": ["ROC Friese Poort"],
    ".rockopnh.nl": ["ROC Kop van Noord Holland"],
    ".rocleiden.nl": ["Regional Community College of Leiden"],
    ".edu.rocmn.nl": ["Roc Midden Nederland"],
    ".rocmn.nl": ["Roc Midden Nederland"],
    ".rocmondriaan.nl": ["Regional Community College Mondriaan of The Hague"],
    ".rocnijmegen.nl": ["Regional Community College of Nijmegen"],
    ".edu.rocrivor.nl": ["ROC RIVOR"],
    ".rocteraa-student.nl": [
        "Roc Ter AA",
        "Student domain",
        "http://www.roc-teraa.nl/opleiding/applicatie-en-mediaontwikkelaar/",
    ],
    ".roctilburg.nl": ["ROC Tilburg", "School for ICT & Mediatechnology"],
    ".rocva.nl": ["ROC van Amsterdam"],
    ".rocvantwente.nl": ["Regional Community College of Twente"],
    ".rocvf.nl": ["ROC van Flevoland"],
    ".rocwb.nl": ["ROC West-Brabant"],
    ".rsm.nl": ["Rotterdam School of Management, Erasmus University Rotterdam"],
    ".ru.nl": ["Radboud University of Nijmegen"],
    ".rug.nl": ["University of Groningen"],
    ".rythovius.nl": ["Rythovius College"],
    ".student.saxion.nl": ["Saxion University of Applied Sciences"],
    ".saxion.nl": ["Saxion University of Applied Sciences"],
    ".scalda.nl": ["Scalda Netherlands"],
    ".student.segbroek.nl": ["Segbroek College"],
    ".leerling.sghetplein.nl": ["Sint-Joriscollege"],
    ".simonvestdijk.nl": ["RSG Simon Vestdijk"],
    ".sintlucas.nl": ["SintLucas"],
    ".sintlucasedu.nl": ["SintLucas"],
    ".spinozalyceum.nl": ["Spinoza Lyceum"],
    ".leerling.stadenesch.nl": ["Stad & Esch"],
    ".stedelijkgymnijmegen.nl": ["Stedelijk Gymnasium Nijmegen"],
    ".stenden.nl": [
        "NHL Stenden Hogeschool, Leeuwarden",
        "NHL Stenden University of Applied Sciences",
    ],
    ".stgs.nl": ["Stedelijk Gymnasium Schiedam"],
    ".summacollege.nl": ["Regional Community College of Eindhoven"],
    ".ut.svpo.nl": ["School voor Persoonlijk Onderwijs in Utrecht"],
    ".symbion-vo.nl": ["Symbion VO"],
    ".talnet.nl": ["MBO Hilversum"],
    ".tcrmbo.nl": ["Techniek College Rotterdam"],
    ".teylingen-college.nl": ["Teylingen College Noordwijkerhout/Voorhout/Rijnsburg"],
    ".tilburguniversity.nl": ["Tilburg University"],
    ".tio.nl": ["TIO University"],
    ".leerling.trevianum.nl": ["Trevianum Scholengroep"],
    ".tsgzwolle.nl": [
        "Thorbecke Scholengemeenschap",
        "http://heesweg.thorbecke-zwolle.nl/ (School website)",
        "http://liters.nl/dev/webfundament/tsgheesweg/wp-content/uploads/sites/5/2015/12/Nieuwe-keuzevakken-in-de-Tweede-Fase-feb-12I.pdf (IT-related page: Page 4)",
        "https://gyazo.com/020bc662241ab9c9c0e1b2abfdeda82c (Screenshot proving the used email is correct: on the bottom of http://heesweg.thorbecke-zwolle.nl/)",
    ],
    ".tudelft.nl": ["Delft University of Technology"],
    ".tue.nl": ["Eindhoven University of Technology"],
    ".tukampen.nl": ["TU Kampen"],
    ".ubboemmius.nl": ["Ubbo Emmius Scholengemeenschap, The Netherlands"],
    ".umcutrecht.nl": ["University Medical Center Utrecht"],
    ".unimaas.nl": ["University of Maastricht"],
    ".utwente.nl": ["University of Twente"],
    ".uu.nl": ["Utrecht University"],
    ".uva.nl": ["University of Amsterdam"],
    ".uvh.nl": ["University for Humanistics (UH)"],
    ".uvt.nl": ["Tilburg University"],
    ".uwcmaastricht.nl": ["United World College Maastricht"],
    ".vathorstcollege.nl": ["Vathorst College"],
    ".vestdijk.nl": ["RSG Simon Vestdijk"],
    ".vistacollege.nl": ["VISTA College"],
    ".vmbo-venster.nl": ["VMBO Het Venster"],
    ".leerling.vova.nl": ["Voortgezet Onderwijs van Amsterdam"],
    ".vozaanstad.nl": ["OVO Zaanstad"],
    ".vu.nl": ["Free University Amsterdam"],
    ".vumc.nl": ["VU University Medical Center Amsterdam"],
    ".waerdenborch.nl": ["De Waerdenborch Holten"],
    ".wageningenuniversity.nl": ["Wageningen University"],
    ".wartburg.nl": ["Wartburg College"],
    ".windesheim.nl": ["Christelijke Hogeschool Windesheim"],
    ".windesheimflevoland.nl": ["Windesheim Flevoland"],
    ".wlg.nl": ["Willem Lodewijk Gymnasium"],
    ".wolfert.nl": ["Wolfert van Borselen Scholengroep"],
    ".wur.nl": ["Wageningen University"],
    ".zadkine.nl": ["Zadkine College"],
    ".zuyd.nl": ["Zuyd University"],
    ".zwijsencollege.nl": ["Zwijsen College Veghel"],
    ".elev.agderskolen.no": ["Aust Agder Fylkeskommune"],
    ".aho.no": ["Oslo School of Architecture"],
    ".stud.akademiet.no": ["Akademiet Student"],
    ".akershus-fk.no": ["Akershus' schools"],
    ".askerskolen.no": ["Asker Kommune"],
    ".asvg.no": ["Amalie skram vgs", "asvg.no"],
    ".bergensskolen.no": ["Åstveit skole", "Bergen kommune"],
    ".vgs.bfk.no": ["Buskerud Fylkeskommune"],
    ".bi.no": ["Norwegian School of Management BI"],
    ".gokstadakademiet.no": ["Gokstadakademiet"],
    ".hbv.no": ["Buskerud and Vestfold University College"],
    ".hia.no": ["Agder University College"],
    ".hials.no": ["Aalesund University College"],
    ".hib.no": ["Bergen University College"],
    ".hibo.no": ["Bodo Regional University"],
    ".hifm.no": ["Finnmark University College"],
    ".hig.no": ["Gjøvik University College"],
    ".hihm.no": [
        "Inland Norway University of Applied Sciences",
        "Høgskolen i Innlandet",
        "https://www.inn.no/",
    ],
    ".hil.no": [
        "Inland Norway University of Applied Sciences",
        "Høgskolen i Innlandet",
        "https://www.inn.no/",
    ],
    ".himolde.no": ["Molde University College"],
    ".hin.no": ["Narvik University College"],
    ".hint.no": ["Nord-Trøndelag University College"],
    ".stud.hioa.no": ["Oslo and Akershus University College of Applied Sciences"],
    ".hioa.no": ["Høgskolen i Oslo og Akershus"],
    ".hiof.no": ["Østfold University College"],
    ".hist.no": ["Sør-Trøndelag University College"],
    ".hit.no": ["Telemark University College"],
    ".hive.no": ["Vestfold University College"],
    ".hivolda.no": ["Volda University College"],
    ".hvl.no": ["Western Norway University of Applied Sciences"],
    ".ikrs.no": ["Holte skole"],
    ".inn.no": [
        "Inland Norway University of Applied Sciences",
        "Høgskolen i Innlandet",
        "https://www.inn.no/",
    ],
    ".iskule.no": ["Sogndal VGS"],
    ".karmoyskolen.no": ["Karmøy Kommune Skoledomene"],
    ".khio.no": ["National Academy of Fine Arts", "National College of Art and Design"],
    ".kodeklubbenflaa.no": [None],
    ".skole.trondheim.kommune.no": ["Trondheim Kommune - Skole"],
    ".kristiania.no": ["Kristiania University College, the department of technology"],
    ".larvikskolen.no": ["Langestrand Skole"],
    ".sksk.mil.no": ["Royal Norwegian Naval Academy", "Sjøkrigsskolen"],
    ".vgs.nfk.no": ["Nordland Fylkeskommune"],
    ".nhh.no": ["Norwegian School of Economics and Business Administration"],
    ".nih.no": ["Norwegian University of Sport and Physical Education"],
    ".nith.no": ["Norway's Information Technology University College"],
    ".nittedalsskolen.no": ["Li Skole"],
    ".nla.no": ["Norwegian Teacher Academy for Studies in Religion and Education"],
    ".nlh.no": ["Agricultural University of Norway"],
    ".nmbu.no": ["Norwegian University of Life Sciences"],
    ".nmh.no": ["Norwegian State Academy of Music"],
    ".nord.no": ["Nord University"],
    ".noroff.no": ["Noroff AS", "Noroff AS"],
    ".elev.ntfk.no": ["Verdal Videregående Skole"],
    ".ntnu.no": ["Norwegian University of Science and Technology"],
    ".oslomet.no": ["OsloMet – Oslo Metropolitan University"],
    ".osloskolen.no": ["Osloskolen"],
    ".ostfoldfk.no": [
        "Østfold Fylkeskommune schools. https://utdanning.ostfoldfk.no/ikbViewer/page/open/forsiden"
    ],
    ".elev.rogfk.no": ["Rogaland fylkeskommune"],
    ".skule.sfj.no": ["sogn og fjordane"],
    ".simula.no": ["Simula School of Research and Innovation"],
    ".skapfhs.no": ["\ufeffSKAP Kreativ Folkehøyskole"],
    ".sunnfolk.no": ["Sunnhordland Folkehøgskule"],
    ".elev.tffk.no": [
        "Nord-Troms Videregående Skole",
        "Nord-Troms High School",
        "\ufeffAlta Videregående Skole",
    ],
    ".tffk.no": [None],
    ".tisipfagskole.no": ["TISIP fagskole"],
    ".elev.trondelagfylke.no": ["Trondelag Fylkeskommune"],
    ".trondelagfylke.no": ["\ufeffTrøndelag Fylkeskommune"],
    ".uia.no": ["University of Agder"],
    ".uib.no": ["University of Bergen"],
    ".uin.no": ["University of Nordland"],
    ".uio.no": ["University of Oslo"],
    ".uis.no": ["University of Stavanger"],
    ".uit.no": ["University of Tromsø"],
    ".usn.no": ["Høgskolen i Sørøst-Norge / University College of Southeast Norway"],
    ".vaf.no": ["Vest-Agder fylkeskommune "],
    ".veths.no": ["Norwegian College of Veterinary Medicine"],
    ".skole.vfk.no": ["Vestfold Fylkeskommune"],
    ".Asker.vgs.no": ["Asker Videregående Skole"],
    ".Verdal.vgs.no": ["Verdal Videregående Skole"],
    ".eid.vgs.no": ["Eid Videregående Skule"],
    ".krokeide.vgs.no": ["Krokeide videregående skole"],
    ".kvadraturen.vgs.no": ["Kvadraturen vgs", "Kvadraturen technical college"],
    ".viken.no": [
        "Viken Fylkeskommune schools. https://viken.no/tjenester/skole-og-opplaring/"
    ],
    ".vtfk.no": ["Vestfold og Telemark Fylkeskommune"],
    ".student.westerdals.no": [
        "Westerdals Oslo School of Arts, Communication and Technology"
    ],
    ".westerdals.no": [
        "Westerdals Høyskole - Oslo School of Arts, Communication and Technology AS"
    ],
    ".aasthacollege.edu.np": [
        "Aastha College Of Business Studies,Damak-4, Jhapa, Nepal",
        "https://www.aasthacollege.edu.np",
    ],
    ".achsnepal.edu.np": ["Asian College of Higher Studies"],
    ".ambition.edu.np": ["Ambition College", "Ambition College"],
    ".apexcollege.edu.np": ["Apex College"],
    ".ioe.edu.np": ["IOE Pulchowk Campus", "Institute of Engineering, Nepal"],
    ".islingtoncollege.edu.np": [
        "Islington College, Kamal Marg, Kamal Pokhari, Kathmandu, Nepal"
    ],
    ".keckist.edu.np": ["Kathmandu Engineering College"],
    ".ku.edu.np": ["Kathmandu University"],
    ".lbc.edu.np": ["Lumbini Banijya Campus", "Lumbini Banijya Campus"],
    ".mbmc.edu.np": ["Madan Bhandari Memorial College"],
    ".mbmcsit.edu.np": ["Madan Bhandari Memorial College CSIT Department"],
    ".oic.edu.np": ["Orchid International College, Kathmandu, Nepal"],
    ".pcampus.edu.np": [
        "Tribhuvan University, Institute of Engineering, Pulchowk Campus"
    ],
    ".peoplescampus.edu.np": ["Peoples Campus", "Peoples Campus"],
    ".pmc.edu.np": [
        "Tribhuvan University, Institute of Science and Technology, Patan Multiple Campus"
    ],
    ".pu.edu.np": ["Pokhara University"],
    ".purbuniv.edu.np": ["Purbanchal University"],
    ".pushas.edu.np": [
        "School of Health and Allied Sciences",
        "School of Health and Allied Sciences",
    ],
    ".sagarmatha.edu.np": ["Sagarmatha Engineering College"],
    ".standardinstitute.edu.np": ["Standard Institute of Technology"],
    ".sxc.edu.np": ["St. Xavier's College"],
    ".tcmit.edu.np": ["Texas College of Management and IT", "tcmit"],
    ".tribhuvan-university.edu.np": ["Tribhuvan University Kathmandu"],
    ".ac.tu.edu.np": ["Amrit Campus", "Amrit Science Campus (ASCOL), Nepal"],
    ".memc.tu.edu.np": ["Mechi Multiple Campus TU Nepal"],
    ".mmamc.tu.edu.np": ["Mahendra Morang Adarsh Multiple Campus, Nepal"],
    ".unitedtechnicalcollege.edu.np": [
        "United Technical College, Pokhara University, Nepal"
    ],
    ".wrc.edu.np": [
        "Tribhuvan University, Institute of Engineering, Pashchimanchal Campus",
        "Tribhuvan University, Institute of Engineering, Western Regional Campus (WRC)",
    ],
    ".schueler.tsst.nrw": [
        "Technische Schule Steinfurt (tsst)",
        "Technical Schools Steinfurt (tsst)",
    ],
    ".edu.nu": ["St Clements University - Higher Education School"],
    ".futuregames.nu": ["Futuregames"],
    ".reggesteyn.nu": ["CSG Reggesteyn"],
    ".edu.tibble.nu": ["Tibble Gymnasium, students emails"],
    ".tibble.nu": ["Tibble Gymnasium"],
    ".agi.ac.nz": ["AGI", "AGI Auckland"],
    ".ais.ac.nz": ["Auckland Institute of Studies", "Auckland Institute of Studies"],
    ".ames.ac.nz": ["AMES "],
    ".amesstudent.ac.nz": ["AMES  - The Institute of IT"],
    ".ara.ac.nz": ["Ara Institute of Canterbury"],
    ".arastudent.ac.nz": ["Ara Institute of Canterbury"],
    ".aspire2student.ac.nz": ["Aspire"],
    ".ec.auckland.ac.nz": ["University of Auckland - Electronic Campus"],
    ".auckland.ac.nz": ["University of Auckland"],
    ".aucklanduni.ac.nz": ["University of Auckland"],
    ".aut.ac.nz": ["Auckland University of Technology"],
    ".autuni.ac.nz": ["Auckland University of Technology"],
    ".canterbury.ac.nz": ["University of Canterbury"],
    ".mail.computerpower.ac.nz": ["Whitecliffe Technology And Innovation"],
    ".developers.ac.nz": ["Developers Institute"],
    ".developersinstitute.ac.nz": ["Developers Institute"],
    ".eit.ac.nz": ["Eastern Institute of Technology"],
    ".garincollege.ac.nz": ["Garin College"],
    ".lincoln.ac.nz": ["Lincoln University"],
    ".massey.ac.nz": ["Massey University"],
    ".mds.ac.nz": ["Media Design School"],
    ".myop.ac.nz": ["Open Polytechnic"],
    ".myopenpolytechnic.ac.nz": ["Open Polytechnic of New Zealand"],
    ".myunitec.ac.nz": ["Unitec Institute of Technology"],
    ".myvuw.ac.nz": ["Victoria University of Wellington"],
    ".live.nmit.ac.nz": ["Nelson Marlborough Institute of Technology"],
    ".nmit.ac.nz": ["Nelson Marlborough Institute of Technology"],
    ".student.op.ac.nz": ["Otago Polytechnic "],
    ".op.ac.nz": ["Otago Polytechnic"],
    ".openpolytechnic.ac.nz": ["Open Polytechnic "],
    ".otago.ac.nz": ["University of Otago"],
    ".sit.ac.nz": ["Southern Institute of Technology, New Zealand"],
    ".techtorium.ac.nz": ["Techtorium NZIT"],
    ".tnt.ac.nz": ["Taupo nui a tia"],
    ".toiohomai.ac.nz": ["Toi Ohomai Institute of Technology"],
    ".uclive.ac.nz": ["University of Canterbury"],
    ".ucol.ac.nz": ["Universal College of Learning"],
    ".unitec.ac.nz": ["Unitec Institute of Technology"],
    ".uotago.ac.nz": ["University of Otago"],
    ".vuw.ac.nz": ["Victoria University of Wellington"],
    ".waikato.ac.nz": ["University of Waikato"],
    ".student.weltec.ac.nz": ["WelTec", "Wellington Institute Of Technology"],
    ".whitecliffe.ac.nz": [
        "Whitecliffe College",
        "over 1 year programe URL:https://www.whitecliffe.ac.nz/technology",
    ],
    ".student.wintec.ac.nz": ["Waikato Institute of Technology"],
    ".wintec.ac.nz": ["Waikato Institute of Technology"],
    ".animationcollege.co.nz": ["Animation College"],
    ".aucklanduni.co.nz": ["University of Auckland"],
    ".autuni.co.nz": ["Auckland University of technology"],
    ".grammar.net.nz": ["Auckland Grammar School"],
    ".onelearn.nz": ["Onehunga High School"],
    ".aotawhiti.school.nz": ["Ao Tawhiti Unlimited Discovery"],
    ".bdsc.school.nz": ["Botany Downs Secondary College"],
    ".burnside.school.nz": ["Burnside High School"],
    ".cashmere.school.nz": ["Cashmere High School"],
    ".hillcrest-high.school.nz": ["Hillcrest High School"],
    ".kingshigh.school.nz": ["Kings High School"],
    ".kristin.school.nz": ["Kristin school, New Zealand"],
    ".lbc.school.nz": ["Long Bay College"],
    ".lincoln.school.nz": ["Lincoln High School"],
    ".liston.school.nz": ["Liston College, Auckland, New Zealand"],
    ".lynfield.school.nz": ["Lynfield College"],
    ".marsden.school.nz": ["Samuel Marsden College"],
    ".mtaspiring.school.nz": ["Mount Aspiring College"],
    ".ohs.school.nz": ["Onehunga High School"],
    ".ormiston.school.nz": ["Ormiston Senior College"],
    ".student.pakuranga.school.nz": ["Pakuranga College"],
    ".scotscollege.school.nz": ["Scots College"],
    ".selwyn.school.nz": ["Selwyn College"],
    ".storans.school.nz": ["St Oran's College for Girls"],
    ".stpeterspn.school.nz": ["St Peter's College, Palmerston North"],
    ".taieri.school.nz": ["Taieri College"],
    ".waimea.school.nz": ["Waimea College"],
    ".wc.school.nz": ["Wellington College"],
    ".wgc.school.nz": ["Wellington Girls' College"],
    ".wgpcollege.school.nz": ["Whangaparaoa College"],
    ".whangamata.school.nz": ["Whangamata Area School"],
    ".aou.edu.om": ["Arab Open University"],
    ".buc.edu.om": ["Al-Buraimi University College"],
    ".du.edu.om": ["Dhofar University"],
    ".student.gutech.edu.om": ["German University of Technology in Oman (GUtech)"],
    ".ibrict.edu.om": ["Ibri College of Technology"],
    ".ict.edu.om": ["Ibra College of Technology"],
    ".majancollege.edu.om": ["Majan University College"],
    ".mcbs.edu.om": [
        "الكلية الحديثة للتجارة والعلوم",
        "Modern College of Business and Science",
    ],
    ".mtc.edu.om": ["Military Technological College"],
    ".muscatcollege.edu.om": ["Muscat College"],
    ".nct.edu.om": ["university of Technology and Applied Sciences-Nizwa, Oman"],
    ".nu.edu.om": ["National University, Oman"],
    ".omancollege.edu.om": ["Oman College Of Management &amp; Technology"],
    ".soharuni.edu.om": ["Sohar University"],
    ".squ.edu.om": ["Sultan Qaboos University"],
    ".suc.edu.om": ["Sur University College"],
    ".unizwa.edu.om": ["University of Nizwa"],
    ".uob.edu.om": ["University of Buraimi", "University of Buraimi"],
    ".vibrantprivateschool.edu.om": ["Vibrant Private School"],
    ".moe.om": ["Ministry of Education - Oman", "Ministry of Education - Oman"],
    ".nmu.one": ["National Mining University", "NMU"],
    ".gmiv.onl": ["הגימנסיה העברית בירושלים"],
    ".hgs-singen.online": ["Hohentwiel Gewerbeschule Singen"],
    ".titanedu.online": ["Trung tâm toán Titan Education", "Titan Education"],
    ".21cccs.org": ["21st Century Cyber Charter School"],
    ".2isa.org": [
        "Institut Informatique Sud Aveyron",
        "Website: http://www.2isa.com/",
        "student emails at @2isa.org for example sergey.epifanov@2isa.org",
    ],
    ".42network.org": ["Ecole 42", "42 School"],
    ".NeighborhoodMusicSchool.org": ["Neighborhood Music School"],
    ".OFY.org": ["Options For Youth"],
    ".aabfs.org": ["Arab Academy for Banking and Financial Sciences"],
    ".aacps.org": ["Anne Arundel County Public Schools", ".group"],
    ".acitech.org": ["Atlantic County Vocational School District"],
    ".acwhcc.org": ["Ashland County-West Holmes Career Center", "ACWHCC"],
    ".adams-central.org": ["Adams Central Jr/Sr High School"],
    ".adams12.org": ["Adams 12 Five Star Schools"],
    ".fpcoruna.afundacion.org": ["CPR Afundación A Coruña"],
    ".agora.org": ["Agora Cyber Charter School"],
    ".aims-senegal.org": [
        "AIMS Senegal",
        "African institute for mathematical sciences",
    ],
    ".aimsammi.org": ["African Institute for Mathematical Sciences"],
    ".aischool.org": ["Atlanta International School"],
    ".akfauniversity.org": ["Akfa University"],
    ".akiva.org": ["Akiva Hebrew Day School"],
    ".allenisd.org": ["Allen High School"],
    ".alpinesd.org": ["Timpanogos High"],
    ".alsionschool.org": ["Alsion Montessori Middle/High School"],
    ".altamontschool.org": ["The Altamont School"],
    ".amalnet.org": [
        "הרב תחומי עמל ב' - פתח תקווה",
        "Amal Bet  - Petah Tikva",
        ".group",
    ],
    ".amccollege.org": ["AMC College"],
    ".amityschools.org": ["Amity Regional High School "],
    ".amouduniversity.org": ["Amoud University"],
    ".anjaconline.org": ["Ayya Nadar Janaki Ammal College"],
    ".apschools.org": ["Alliance Public Schools"],
    ".archwood.org": ["Archbishop Wood High School"],
    ".ardsleyschools.org": ["Ardsley High School "],
    ".arnoldcentralschool.org": [
        "St. Arnold Central School",
        "St. Arnold Central School",
    ],
    ".arps.org": ["Amherst Regional High School"],
    ".asbindia.org": ["American School of Bombay", "asb"],
    ".asd20.org": ["Academy School District 20, Colorado Springs, CO 8920"],
    ".asdnh.org": ["Academy for Science and Design"],
    ".ashevilleschool.org": ["Asheville School"],
    ".asmadrid.org": ["American School of Madrid"],
    ".asmsa.org": [
        "Arkansas School for Mathematics, Sciences, and the Arts",
        "Arkansas School for Math, Sciences, and the Arts",
        "Arkansas School for Math, Sciences, and Arts",
        "ASMSA",
    ],
    ".association-esi.org": ["Ecole Supérieure d'Informatique Internationale"],
    ".astu.org": [
        "Astrahan State Technical University",
        "Astrahan State Technical University",
    ],
    ".asvalencia.org": ["American School Of Valencia"],
    ".aswarsaw.org": ["American School of Warsaw"],
    ".athenian.org": ["Athenian School"],
    ".atlanticcollege.org": ["United World College of Atlantic"],
    ".atljewishacademy.org": ["Atlanta Jewish Academy"],
    ".auamed.org": ["American University of Antigua"],
    ".auhsdschools.org": ["Acalanes Union High School District", ".group"],
    ".auk.org": ["RIT Kosovo (AUK) - Rochester Institute of Technology"],
    ".aurorak12.org": ["Aurora Public Schools", "APS", ".group"],
    ".ausdk12.org": ["Albany Unified School District"],
    ".austinisd.org": ["LBJ Early College High School"],
    ".avcoe.org": ["Amrutvahini College of Engineering"],
    ".avenues.org": ["Avenues: The World School"],
    ".avhsd.org": ["Eastside High School", "Eastside High School", ".group"],
    ".avu.org": ["African Virtual University"],
    ".az-npu.org": ["Nakhchivan Private University"],
    ".baisedu.org": ["Bandung Alliance Intercultural School"],
    ".bangorschools.org": ["Bangor Township Schools"],
    ".barnsley-academy.org": ["Barnsley Academy"],
    ".bartoncougars.org": ["Barton Community College"],
    ".basdschools.org": ["liberty high school"],
    ".bayschoolsohio.org": ["Bay Village Schools"],
    ".bcp.org": ["Bellarmine College Preparatory"],
    ".bcps.org": [],
    ".bearzi.org": ['Istituto Tecnico Industriale "G. Bearzi", Udine'],
    ".beckfoot.org": ["Beckfoot"],
    ".beckfootoakbank.org": [
        "Beckfoot Oakbank Academy",
        "Oakbank School",
        "Beckfoot Oakbank School",
    ],
    ".bedfordps.org": ["John Glenn Middle School"],
    ".bellinghamschools.org": ["Squalicum High School"],
    ".belmonthill.org": ["Belmont Hill School"],
    ".bentonvillek12.org": ["Bentonville Public Schools"],
    ".bergen.org": ["Bergen County Technical Schools"],
    ".bethanyschoolsheffield.org": ["Bethany School, Sheffield"],
    ".bethlehemschools.org": ["Bethlehem Central High School"],
    ".bfhsla.org": ["Benjamin Franklin High School"],
    ".bhrsd.org": ["Berkshire Hills Regional School District"],
    ".bhrsdonline.org": ["Berkshire Hills Regional School District"],
    ".bihe.org": [
        "Baha'i Institute for Higher Education",
        "The Bahá'í Institute For Higher Education (BIHE)",
    ],
    ".binusian.org": ["Binus University"],
    ".bkwschools.org": ["BERNE-KNOX-WESTERLO CENTRAL SCHOOL DISTRICT"],
    ".blindbrook.org": ["Blind Brook High School"],
    ".bloomfield.org": ["Bloomfield Hills Schools"],
    ".bluedemons.org": [
        "Kennett High School",
        "Kennett Consolidated School District",
        "300 East South Street",
        "Kennett Square, PA 19348",
    ],
    ".bluevalleyk12.org": ["Blue Valley School District"],
    ".boiseschools.org": ["Boise School District"],
    ".bolashak.org": ["Caspian College Bolashak"],
    ".bolles.org": ["The Bolles School"],
    ".bostonk12.org": ["Boston Public Schools"],
    ".bostonpublicschools.org": ["Boston Public Schools (Teachers)"],
    ".bostontrinity.org": ["Boston Trinity Academy"],
    ".student.bournemouth-school.org": ["Bournemouth School, Dorset"],
    ".bphawks.org": ["Bethel Park High School"],
    ".bps121.org": ["Burlington Public Schools"],
    ".branson.org": ["The Branson School"],
    ".brebeuf.org": ["Brebeuf Jesuit Preparatory School"],
    ".learn.brevardschools.org": [
        "Andersen Elementary",
        "Apollo Elementary",
        "Atlantis Elementary",
        "Audubon Elementary",
        "Cambridge Elementary Magnet",
        "Cape View Elementary",
        "Challenger 7 Elementary",
        "Columbia Elementary",
        "Coquina Elementary",
        "Croton Elementary",
        "Discovery Elementary",
        "Dr. W.J. Creel Elementary",
        "Endeavour Elementary",
        "Enterprise Elementary",
        "Fairglen Elementary",
        "Freedom 7 Elementary",
        "Gemini Elementary",
        "Golfview Elementary Magnet",
        "Harbor City Elementary",
        "Holland Elementary",
        "Imperial Estates Elementary",
        "Indialantic Elementary",
        "Jupiter Elementary",
        "Lewis Carroll Elementary",
        "Lockmar Elementary",
        "Longleaf Elementary",
        "Manatee Elementary",
        "McAuliffe Elementary",
        "Meadowlane Intermediate Elementary",
        "Meadowlane Primary Elementary",
        "MILA Elementary",
        "Mims Elementary",
        "Oak Park Elementary",
        "Ocean Breeze Elementary",
        "Palm Bay Elementary",
        "Pinewood Elementary",
        "Port Malabar Elementary",
        "Quest Elementary",
        "Riviera Elementary",
        "Roosevelt Elementary",
        "Roy Allen Elementary",
        "Sabal Elementary",
        "Saturn Elementary",
        "Sea Park Elementary",
        "Sherwood Elementary",
        "South Lake Elementary",
        "Stevenson Elementary",
        "Sunrise Elementary",
        "Suntree Elementary",
        "Surfside Elementary",
        "Tropical Elementary",
        "Turner Elementary",
        "University Park Elementary Magnet",
        "Viera Elementary",
        "West Melbourne School for Science",
        "Westside Elementary",
        "Williams Elementary",
        "Central Middle",
        "Cocoa Beach Jr/Sr High",
        "Cocoa High",
        "DeLaura Middle",
        "Edgewood Jr/Sr High",
        "Hoover Middle",
        "Jackson Middle",
        "Jefferson Middle",
        "Johnson Middle",
        "Kennedy Middle",
        "Madison Middle",
        "McNair Magnet Middle",
        "Southwest Middle",
        "Space Coast Jr/Sr",
        "Stone Magnet Middle",
        "West Shore Jr/Sr High",
        "Adult Education",
        "Brevard Virtual",
        "Educational Horizons",
        "Emma Jewel",
        "Imagine Schools",
        "Odyssey Charter",
        "Odyssey Preparatory Charter",
        "Palm Bay Academy Charter",
        "Pathways at Gardendale",
        "Pineapple Cove Classical Academy",
        "Pineapple Cove Classical Academy - West Melb.",
        "Royal Palm Charter",
        "Sculptor Charter",
        "South Alternative Learning",
        "Viera Charter",
    ],
    ".brevardschools.org": ["Brevard Schools"],
    ".bridgtonacademy.org": ["Bridgton Academy"],
    ".brightstarschools.org": ["Bright Star Schools (Staff)"],
    ".brightstarstudents.org": ["Bright Star Schools (Students)"],
    ".britishschoolmanila.org": ["The British School of Manila"],
    ".bronxvilleschool.org": ["Bronxville School"],
    ".brookeweston.org": ["Brooke Weston Academy"],
    ".student.brookfieldps.org": ["Brookfield High School"],
    ".brophybroncos.org": ["Brophy College Preparatory"],
    ".brunswickschool.org": ["Brunswick High School"],
    ".bsd220.org": ["Barrington School District 220"],
    ".bsd405.org": ["Bellevue School District"],
    ".bsd48.org": ["Beaverton School District"],
    ".bsdi-bd.org": ["Bangladesh Skill Development Institute"],
    ".bsu-edu.org": ["Baku Slavic University"],
    ".budapestschool.org": ["Budapest School"],
    ".burlcoschools.org": ["Burlington County Insitute of Technology"],
    ".burltwpsch.org": ["Burlington Township High School"],
    ".bvsd.org": ["Boulder Vally School District"],
    ".byerach.org": ["בית ירח", "Beit Yerach"],
    ".c-dh.org": ["Cretin-Derham Hall"],
    ".my.caddoschools.org": ["C.E. Byrd"],
    ".calallen.org": ["Calallen High School (Grades 9-12)"],
    ".caliva.org": ["California Virtual Academies"],
    ".camelotacademy.org": ["Camelot Academy"],
    ".campbellhall.org": [
        "Campbell Hall - an independent coeducational day school for grades K-12"
    ],
    ".canisiushigh.org": ["Canisius High School"],
    ".ctec.canyonsdistrict.org": ["Canyons Technical Education Center (CTEC)"],
    ".capitalcityacademy.org": ["Capital City Academy"],
    ".capousd.org": ["Capistrano Unified School District"],
    ".cavendishza.org": ["Cavendish University"],
    ".cbaalbany.org": ["Christian Brothers Academy"],
    ".cbchs.org": ["Christian Brothers College High School"],
    ".student.cbsd.org": ["Lenape Middle School"],
    ".ccaschools.org": ["Clear Creek Amana High School"],
    ".ccchs.org": [
        "Clearwater Central Catholic High School",
        "Clearwater Central Catholic",
        "CCC",
    ],
    ".stu.ccsdut.org": ["Cache County School District"],
    ".ccsdut.org": ["Cache County School District"],
    ".ceaprc.org": ["Centro de Estudios Avanzados de Puerto Rico y el Caribe"],
    ".centraliens-lille.org": ["Ecole Centrale de Lille"],
    ".centraluniversity.org": ["Central University College"],
    ".chadwickschool.org": ["Chadwick School"],
    ".challoners.org": ["Dr Challoner's Grammar School"],
    ".chaminade.org": ["Chaminade College Preparatory"],
    ".chaminet.org": ["Chaminade College Preparatory"],
    ".charlottesvilleschools.org": ["Charlottesville City Public Schools"],
    ".charmouniversity.org": ["Charmo University"],
    ".charterschool.org": ["The Charter School of Wilmington"],
    ".chatham-nj.org": ["Chatham High School"],
    ".chclc.org": ["Cherry Hill Public Schools"],
    ".cherrycreekschools.org": ["Cherry Creek School District #5"],
    ".cheshireacademy.org": ["Cheshire Academy"],
    ".chettinadvidyashram.org": ["chettinad vidyashram"],
    ".chewonki.org": ["Chewonki Foundation Semester School"],
    ".cihanuniversity.org": ["Cihan University"],
    ".clearlakeschools.org": [
        "Clear Lake Schools",
        ".group",
        "School district, Clear Lake, Iowa 50428",
    ],
    ".cobbk12.org": ["Wheeler High School", ".group", "http://www.cobbk12.org/"],
    ".coleacademy.org": ["Cole Academy"],
    ".doral.colegia.org": ["Doral Academy Charter High School"],
    ".colonialsd.org": ["Colonial School District"],
    ".columbusacademy.org": [
        "Columbus Academy",
        "website: http://www.columbusacademy.org/",
    ],
    ".g.comalisd.org": ["Canyon High School"],
    ".combertonvc.org": ["Comberton Village College"],
    ".commschool.org": ["Commonwealth School"],
    ".concordcarlisle.org": [
        "Concord-Carlisle Regional High School",
        "Concord-Carlisle Regional High School",
    ],
    ".conejousd.org": ["Conejo Valley Unified School District (CVUSD)"],
    ".cornwallhill.org": ["Cornwall Hill College"],
    ".cossali.org": ['I.I.S."G. Cossali"'],
    ".countyupper.org": [
        "County Upper School",
        "County Upper",
        "https://www.countyupper.org/",
    ],
    ".cpgoenka.org": [
        "CP Goenka international school",
        "https://www.cpgoenkainternationalschool.com/",
        "https://www.cpgoenkainternationalschool.com/boards/ibdp",
        "https://www.cpgoenkainternationalschool.com/contact-us",
    ],
    ".cpsk12.org": ["Columbia Public Schools"],
    ".cravenk12.org": ["West Craven High School"],
    ".creanlutheran.org": [
        "Crean Lutheran High School",
        "School Website: https://creanlutheran.org",
        "Staff Email Domain: creanlutheran.org",
        "Student Email Domain stu.creanlutheran.org",
        "Question: Our student email domain restricts emails outside of our domain. What email(s) from jetbrains do we need to whitelist so that they can access pycharm?",
    ],
    ".cri-paris.org": [
        "Centre de recherches interdisciplinaire de paris ( descartes + diderot )"
    ],
    ".cromptonhouse.org": ["Crompton House"],
    ".csddocs.org": ["Canyons School District"],
    ".csj-rpi.org": ["Colegio San Jose"],
    ".students.ctasd.org": ["Conemaugh Township High School"],
    ".cuhsd.org": ["Campbell Union High School District", ".group"],
    ".cusd200.org": ["Community Unit School District 200 (Wheaton, IL, USA)"],
    ".cushingisd.org": ["Cushing Independent School District", "Cushing ISD"],
    ".cvcolonials.org": ["Conewago Valley School District"],
    ".cvoantwerpen.org": ["CVO Antwerpen"],
    ".cvsd356.org": ["Central Valley School District"],
    ".cvsdvt.org": [
        "Champlain Valley School District",
        "Hinesburg Community School",
        "Champlain Valley Union High School",
        ".group",
    ],
    ".d-e.org": ["Dwight-Englewood School"],
    ".d125.org": ["Adlai E. Stevenson High School"],
    ".d155.org": ["Prairie Ridge High School"],
    ".students.d211.org": ["Township High School District 211"],
    ".d211.org": ["Township High School District 211"],
    ".stu.d214.org": ["Township High School District 214", ".group"],
    ".d219.org": ["Niles West High School"],
    ".d230.org": ["Amos Alonzo Stagg High School"],
    ".students.d303.org": ["Saint Charles East High School", ".group"],
    ".da.org": [
        "Durham Academy",
        "link to Upper School Technology Curriculum: http://www.da.org/page.cfm?p=704",
    ],
    ".dallasisd.org": [
        "Dallas Independent School District",
        "School of Science and Engineering",
        "Science and Engineering Magnet",
        "School of the Talented and Gifted",
        "Talented and Gifted Magnet",
        ".group",
    ],
    ".dalton.org": ["The Dalton School"],
    ".danielcastelao.org": ['Centro de Formacion Profesional "Daniel Castelao"'],
    ".darlingtonschool.org": ["Darlington School"],
    ".student.dasd.org": ["Downingtown S.T.E.M. Academy"],
    ".davenportschools.org": ["West High School"],
    ".davietjal.org": ["DAV Institute of Engineering & Technology"],
    ".davisonschools.org": ["Davison High School"],
    ".daystarus.org": ["Daystar University"],
    ".dcrustm.org": ["Deenbandhu Chhotu Ram University of Science and Technology"],
    ".s.dcsdk12.org": ["Douglas County School District", ".group"],
    ".dcsdk12.org": ["Douglas County School District", ".group"],
    ".denmarkroad.org": ["Denmark Road High School"],
    ".desmet.org": [
        "De Smet Jesuit High School",
        "De Smet Jesuit",
        "DeSmet Jesuit",
        "DeSmet Jesuit High School",
    ],
    ".diderot.org": ["Lycée Polyvalent Diderot"],
    ".diiage.org": ["Centre Universitaire Catholique de Bourgogne"],
    ".student.dimanregional.org": ["Diman Regional Vocational Technical High School"],
    ".dimanregional.org": ["Diman Regional Vocational Technical High School"],
    ".dist113.org": ["Deerfield High School"],
    ".district112.org": ["Independent School District 112"],
    ".district196.org": [
        "Independent School District 196 Rosemount-Apple Valley-Eagan"
    ],
    ".apps.district833.org": [
        "South Washington County School District (sowashco.org) "
    ],
    ".divini.org": ["ITIS Eustachio Divini"],
    ".student.dmschools.org": ["Des Moines Public Schools"],
    ".donntu.org": ["Donetsk National Technical University"],
    ".educ.dpcdsb.org": ["St. Roch Catholic Secondary School"],
    ".dpengineering.org": ["Dos Pueblos Engineering Academy"],
    ".dpisd.org": ["Deer Park Independent School District"],
    ".dr-ait.org": ["Dr.Ambedkar Institute of Technology"],
    ".dragonschool.org": ["Dragon School", "Dragon School"],
    ".dtechhs.org": ["Design Tech High School"],
    ".dubaicollege.org": ["Dubai College"],
    ".dupage88.org": ["DuPage High School District 88"],
    ".duvalschools.org": ["Duval County Public Schools"],
    ".dyker201.org": ["Dyker Heights Intermediate School 201"],
    ".eastsidecatholic.org": ["Eastside Catholic School"],
    ".eastsidecatholicschool.org": ["Eastside Catholic School"],
    ".ebnet.org": ["East Brunswick High School"],
    ".ebrschools.org": ["Baton Rouge Magnet High School"],
    ".ecfs.org": ["Ethical Culture Fieldston School"],
    ".ecscollege.org": ["ecscollege.org", "Evangel Christian Seminary & College"],
    ".edmonds15.org": ["Edmonds School District"],
    ".edubuzz.org": [
        "Musselburgh Grammar School",
        ".group",
        "http://www.edubuzz.org/musselburghgrammar/",
    ],
    ".kfaryarok.eduil.org": ["בית הספר הכפר הירוק", "Green Village School"],
    ".modiin.eduil.org": ["Ironi Alef Modiin High School"],
    ".raanana.eduil.org": ["Ostrovsky High School", ".group"],
    ".shoham.eduil.org": ["Yahalom Shoham High School", ".group"],
    ".rabinks.edumschool.org": ["רבין", "Rabin"],
    ".info-spsepn.edupage.org": [
        "Stredná Priemyselná Škola Elektrotechnická Piešťany",
        "High School of Electrical Engineering in Piešťany",
        "SPŠE PN",
    ],
    ".eduservices.org": ["Eduservices", ".group"],
    ".egcsd.org": ["Columbia High School"],
    ".einsteinmed.org": ["Albert Einstein College of Medicine"],
    ".elcampico.org": ["E.F.A. El Campico"],
    ".elmbrookstudents.org": [
        "Brookfield East High School",
        "Brookfield Cental High School",
        "https://www.elmbrookschools.org/brookfield-east-high-school",
        "Brookfield, Wisonsin",
        ".group",
    ],
    ".elsys-bg.org": [
        "Technological school Electronic Systems",
        "Associated with Technical University Sofia, Bulgaria",
    ],
    ".em-is.org": ["Eastern Mediterranean International School"],
    ".enfieldgrammar.org": ["Enfield Grammar School"],
    ".ens2m.org": ["École Nationale Supérieure de Mécanique et des Microtechniques"],
    ".ensta-bretagne.org": [
        "Ecole Nationale Supérieure de Techniques Avancées Bretagne"
    ],
    ".ep-student.org": ["Eden Prairie School District - Student Emails"],
    ".epcarvalhais.org": ["Escola profissional de carvalhais"],
    ".er9.org": ["Joel Barlow High School"],
    ".erpsk12.org": ["Eaton Rapids Public Schools"],
    ".esaip.org": ["École supérieure angevine en informatique et productique"],
    ".escolapiasvalencia.org": ["Colegio Escolapias Valencia"],
    ".esgis.org": ["Ecole Supérieure de Gestion Informatque et des Sciences"],
    ".esicad.org": ["ESICAD école de commerce sur Montpellier et Toulouse "],
    ".student.esmonline.org": ["Eastport South-Manor Junior Senior High School"],
    ".esmonline.org": ["Eastport South-Manor Junior Senior High School"],
    ".students.esuhsd.org": ["East Side Union High School District", ".group"],
    ".campus.euss.org": ["Escola Universitaria Salesiana Sarria (EUSS)"],
    ".student.evergreenps.org": ["Evergreen Public Schools"],
    ".exploris.org": ["The Exploris School"],
    ".fa.org": ["Friends Academy"],
    ".fairlawnsds.org": ["Memorial Middle School Fair Lawn NJ"],
    ".farberhds.org": ["Farber Hebrew Day School"],
    ".fayacademy.org": ["Fayetteville Academy"],
    ".fayerweather.org": ["Fayerweather Street School "],
    ".fccps.org": ["Falls Church County Public Schools"],
    ".research.fchampalimaud.org": ["Champalimaud Research", "Champalimaud Foundation"],
    ".fcstu.org": ["Fulton County Schools"],
    ".student.fcusd.org": ["Sutter Middle School"],
    ".fergflor.org": [
        "Ferguson-Florissant School District",
        "Ferguson-Florissant R-II",
    ],
    ".ffc8.org": ["Fountain-Fort Carson Highschool"],
    ".fjuhsd.org": ["Troy High School"],
    ".flatbush.org": ["Yeshivah of Flatbush"],
    ".florencek12.org": ["Florence High School", "Florence City Schools", ".group"],
    ".flpoly.org": ["Florida Polytechnic University"],
    ".stu.fondazionejobsacademy.org": ["FondazioneJAC JobsAcademy"],
    ".foresthillshs.org": ["Forest Hills High School"],
    ".forestinstitute.org": ["Forest Institute of Professional Psychology"],
    ".forpro-creteil.org": ["GRETA MTE 77"],
    ".forsythk12.org": ["Lambert High School"],
    ".fpsct.org": ["Farmington High School"],
    ".fpsed.org": ["Framingham Public Schools"],
    ".fracademy.org": ["Fowey River Academy"],
    ".francisparker.org": ["Francis W. Parker School"],
    ".fresnou.org": ["Edison High School"],
    ".fresnounified.org": ["Edison High School"],
    ".friendsbalt.org": ["Friends School of Baltimore"],
    ".friendscentral.org": ["Friends' Central School"],
    ".friscoisd.org": ["Centennial High School"],
    ".fromecollege.org": ["Frome College"],
    ".fryeburgacademy.org": ["Fryeburg Academy"],
    ".g.fuchsmizrachi.org": ["Fuchs Mizrachi"],
    ".fuhsd.org": ["Fremont Union High School District", ".group"],
    ".fulton58.org": ["Fulton Public Schools"],
    ".fultonschools.org": ["Fulton County Schools"],
    ".fuma.org": ["Fork Union Military Academy"],
    ".fundacion-jala.org": ["Fundación Jala", "Jala Foundation"],
    ".fwastudents.org": ["Faith West Academy"],
    ".students.fwisd.org": ["Fort Worth Independent School District"],
    ".fwparker.org": ["Francis W. Parker School of Chicago"],
    ".gannacademy.org": ["Gann Academy", "New Jewish High School of Greater Boston"],
    ".garnetvalley.org": ["Garnet Valley School District"],
    ".gbwl.org": ["The Birch Wathen Lenox School"],
    ".gcelabschool.org": ["GCE Lab School"],
    ".gcpsk12.org": ["Gwinnett County Public Schools"],
    ".gdgu.org": [
        "gdgoenka university",
        "university url: http://www.gdgoenkauniversity.com/",
        "Course url : http://www.gdgoenkauniversity.com/schoolofengineering/,http://www.gdgoenkauniversity.com/schoolofengineering/programmes-eligibility/",
        "university url: http://www.gdgoenkauniversity.com/",
        "Course url : http://www.gdgoenkauniversity.com/schoolofengineering/,http://www.gdgoenkauniversity.com/schoolofengineering/programmes-eligibility/",
        "domain Proof : http://www.gdgoenkauniversity.com/iclass2018/conference-venue/",
    ],
    ".gds.org": ["Georgetown Day School"],
    ".geneva304.org": ["Geneva Community High School", ".group"],
    ".germantownfriends.org": ["Germantown Friends School"],
    ".ges-coengg.org": [
        "Gokhale Education Society's R.H. Sapat College of Engineering, Management Studies & Research"
    ],
    ".gfacademy.org": ["Greens Farms Academy"],
    ".ggpi.org": [
        "Glazov pedagogical Institute",
        "ГЛАЗОВСКИЙ ГОСУДАРСТВЕННЫЙ ПЕДАГОГИЧЕСКИЙ ИНСТИТУТ ИМЕНИ В.Г.КОРОЛЕНКО",
        "http://www.ggpi.org/news.php",
    ],
    ".ghanacu.org": ["Ghana Christian University College"],
    ".dijaki.gimb.org": [
        "Gimnazija Bežigrad",
        "Bežigrad High School",
        "http://www.gimb.org/",
    ],
    ".gissv.org": ["German International School of Silicon Valley"],
    ".gjust.org": ["GURU JAMBHESHWAR UNIVERSITY OF SCIENCE AND TECHNOLOGY"],
    ".students.gmsdk12.org": ["Germantown Municipal School District", ".group"],
    ".gniindia.org": ["Guru Nanak Institutions"],
    ".gocommodores.org": ["Lafayette Middle School"],
    ".gouldacademy.org": ["Gould Academy"],
    ".gpsne.org": ["Gretna Public Schools"],
    ".graniteschools.org": ["Granite School District"],
    ".granitesd.org": ["Granite School District (students)"],
    ".greenhillsschool.org": ["Greenhills School"],
    ".greenwichschools.org": ["Greenwich High School"],
    ".grenoble-inp.org": ["Grenoble University of Technology"],
    ".mail.gretnadragons.org": ["Gretna Public Schools"],
    ".groupe-esigelec.org": [
        "École supérieure d'ingénieurs en génie électrique",
        "Graduate School of Engineering",
    ],
    ".gsastl.org": ["Gateway Science Academy of St Louis"],
    ".gsdwi.org": ["Germantown High School"],
    ".student.guhsdaz.org": [
        "Thunderbird High School",
        "Glendale Union High School District",
        ".group",
    ],
    ".guhsdaz.org": ["Glendale Union High School District"],
    ".student.gvsd.org": ["Great Valley Middle School"],
    ".gvvit.org": [
        "GRANDHI VARALAKSHMI VENKATA RAO INSTITUTE OF TECHNOLOGY",
        "GRANDHI VARALAKSHMI VENKATA RAO INSTITUTE OF TECHNOLOGY",
    ],
    ".gw-hs.org": ["Great Wyrley High School"],
    ".haashall.org": ["Haas Hall Academy"],
    ".haklaiph.org": [
        "בית ספר חקלאי פרדס חנה",
        "Pardes Hanna Agricultural High School",
    ],
    ".hanovernorwichschools.org": ["Dresden School District"],
    ".harker.org": ["The Harker School"],
    ".student.harmonytx.org": ["Harmony School of Advancement"],
    ".my.hartdistrict.org": [
        "William S. Hart Union High School District",
        "Hart District",
        "William S. Hart District",
        ".group",
    ],
    ".hartselletigers.org": [
        "Hartselle High School",
        "Hartselle Junior High School",
        ".group",
    ],
    ".hatboro-horsham.org": ["Hatboro-Horsham School District"],
    ".haverford.org": ["The Haverford School for Boys"],
    ".hawbridgeschool.org": ["Hawbridge School - Teacher Email"],
    ".hawbridgeschoolstudent.org": ["Hawbridge School - Student Emails"],
    ".hawlermu.org": ["Hawler Medical University"],
    ".hazelwick.org": ["Hazelwick School"],
    ".hazlet.org": ["Raritan High School"],
    ".hcdsb.org": ["Halton Catholic School Board"],
    ".hcisd.org": ["Harlingen High School South"],
    ".student.hcps.org": ["Harford County Public Schools"],
    ".inst.hcpss.org": ["Howard County Public School System", ".group"],
    ".hcpss.org": ["Howard County Public School System", ".group"],
    ".hdch.org": [
        "Hamilton District Christian High",
        "Hamilton District Christian High",
    ],
    ".hdsd.org": [
        "Hillsboro - Deering High School",
        "We are a small 9-12 school in western NH, US.  We offer AP/ college CS courses as well as a developing FRC Robotics team. ",
        "Our school website is...",
        "http://hdhs.hdsd.org/pages/Hillsboro-Deering_High_School",
        "Most of our CS classrooms communicate through Google Classroom.",
        "Our frc website (it is in its infancy) is...",
        "https://sites.google.com/hdsd.org/oscats/home ",
    ],
    ".hedmark.org": ["Hamar Katedralskole"],
    ".henricostudents.org": ["Henrico County Public Schools, Virginia"],
    ".hermits.org": ["St. Augustine Preparatory School"],
    ".hertie-school.org": ["Hertie School of Governance"],
    ".hg47.org": ["Харьковская гімназія № 47", " Kharkiv gymnasium № 47"],
    ".hgce.org": ["Hasmukh Goswami College of Engineering"],
    ".hhschools.org": ["Hasbrouck Heights HS/MS"],
    ".hickmank12.org": ["East Hickman High School"],
    ".highlandsschool.org": ["Highlands School"],
    ".hillers.org": ["Hopkinton high school"],
    ".hitam.org": ["Hyderabad Institute of Technology And Management"],
    ".hnulinton.org": ["Hannam University Linton School of Global Business"],
    ".hockaday.org": ["The Hockaday School", "The Hockaay School for Girls"],
    ".learn.hohschools.org": [
        "Hastings-on-Hudson Union Free School District",
        ".group",
    ],
    ".holychild.org": ["Connelly School of the Holy Child"],
    ".holynames-sea.org": ["Holy Names Academy "],
    ".hopedaleschools.org": ["Hopedale Jr. Sr. High School"],
    ".horacemann.org": ["Horace Mann High School"],
    ".horizonclc.org": ["Horizon Community Learning Center"],
    ".horizoncolumbus.org": ["Horizon Science Academy Columbus High School"],
    ".houstonisd.org": ["Houston Independent School District", ".group"],
    ".stu.hpisd.org": ["Highland Park ISD"],
    ".hpisd.org": ["Highland Park High School"],
    ".hprmail.org": ["High Point Regional High School"],
    ".hsestudents.org": ["Hamilton Southeastern High School"],
    ".hspu.org": [
        "Российский государственный педагогический университет им. А. И. Герцена",
        "The Herzen State Pedagogical University of Russia",
    ],
    ".hsrw.org": ["Hochschule Rhein-Waal"],
    ".hunschool.org": ["The Hun School of Princeton"],
    ".hvs.org": [
        "Huron Valley Schools",
        "Harbor High School",
        "International Academy",
        "Lakeland High School",
        "Milford High School",
        ".group",
    ],
    ".iaisiege.org": [
        "Institut Africain d'Informatique (IAI-SIEGE), Libreville, Gabon"
    ],
    ".ibsindia.org": ["ICFAI Business School, India"],
    ".ichsstudent.org": ["InTech Collegiate High School"],
    ".icstudents.org": ["Iowa City West High School"],
    ".ictuniversity.org": ["ICT UNIVERSITY", "ICT UNIVERSITY"],
    ".icu-edu.org": ["International Culture University "],
    ".ies1xabia.org": ["IES Número 1 – Xàbia"],
    ".iesalandalus.org": ["IES Al-Andalus", "IES Al-Andalus Almería, Spain"],
    ".iescelia.org": ["IES Celia Viñas"],
    ".ieschabas.org": ["IES Historiador Chabas "],
    ".iesdonana.org": ["IES Doñana (Sanlúcar de Barrameda, Cádiz, Spain)"],
    ".ieselcaminas.org": ["Spanish graduate institute of IES El Caminas"],
    ".ieselescorial.org": ["IES El Escorial", "El Escorial High School"],
    ".iesevalorpego.org": ["IES Enric Valor - Pego"],
    ".iesfbmoll.org": ["IES Francesc de Borja Moll"],
    ".ieshnosmachado.org": ["IES Hermanos Machado"],
    ".iesjoandaustria.org": ["Institut Joan d'Austria", "Institut Joan d'Austria"],
    ".ieslluissimarro.org": [
        "IES Dr. Lluis Simarro",
        "High School Dr. Lluis Simarro",
        "ieslluissimarro.org",
    ],
    ".iesmarquesdecomares.org": ["ies marques de comares "],
    ".iesmiralcamp.org": ["IES MIRALCAMP"],
    ".iesmontsia.org": ["institut montsia"],
    ".iespoblenou.org": ["Institut Poblenou"],
    ".iesportada.org": ["IES Portada Alta", "IES Portada Alta Málaga, Spain"],
    ".ifheindia.org": ["Icfai Foundation For Higher Education(IFHE)"],
    ".ifnti.org": [
        "Institut de Formation Aux Normes et Technologies de l'Informatique (IFNTI)"
    ],
    ".iiitb.org": ["International Institute of Information Technology, Bangalore"],
    ".iisbianchi.org": ["IIS Mosè Bianchi - Monza"],
    ".iitbombay.org": ["Indian Institute of Technology Bombay"],
    ".imdea.org": ["Instituto IMDEA", "IMDEA Institute"],
    ".infai.org": [
        "Institut für Angewandte Informatik e.V. an der Universität Leipzig"
    ],
    ".students.inghamisd.org": ["Ingham Intermediate School District"],
    ".inghamisd.org": ["Ingham Intermediate School District"],
    ".insa-lyon.org": ["Institut National des Sciences Appliquées de Lyon"],
    ".insideranken.org": ["Ranken Technical College"],
    ".institutoserpis.org": ["Instituto de Educación Secundaria Serpis"],
    ".intechchs.org": ["InTech Collegiate High School"],
    ".interlakes.org": ["Interlakes High School"],
    ".internationaluniversity-schoolofmedicine.org": [
        "International University School of Medicine (IUSOM)"
    ],
    ".invenio.org": ["Universidad Invenio"],
    ".invertis.org": [
        "Invertis University, Bareilly",
        "Website: https://www.invertisuniversity.ac.in/",
        "https://www.invertisuniversity.ac.in/courses/btech-computer-science-engineering-/9/",
    ],
    ".ipeindia.org": [
        "Institute Of Public Enterprise",
        "Website: http://www.ipeindia.org",
        "student emails at @ipeindia.org for example 1301007@ipeindia.org",
    ],
    ".ipiaget.org": ["Instituto Piaget"],
    ".ipsd.org": ["Indian Prarie School District 204", "ipsd.org"],
    ".iqraeducation.org": ["IQRA ENGLISH MEDIUM HIGH SCHOOL"],
    ".irvingtonschools.org": [
        "Irvington Union-Free School District",
        "Irvington Union-Free School District",
    ],
    ".isd112.org": ["Independent School District 112"],
    ".isd181.org": ["Independent School District 181"],
    ".isd194.org": [
        "Independent School District 194",
        "Lakeville North High School",
        "Lakeville South High School",
        "Kenwood Trail Middle School",
        "Miguire Middle School",
        "Century Middle School",
    ],
    ".isd361.org": ["Falls High School"],
    ".isefac.org": ["Ecole ISEFAC de Bac à Bac+5", "website : http://isefac.org"],
    ".isfce.org": ["Institut Supérieur de Formation Continue d'Etterbeek"],
    ".ishahomeschool.org": ["Isha Home School"],
    ".islahonline.org": ["Al-Islah University"],
    ".ismanila.org": ["International School Manila", "ISM"],
    ".istemghs.org": ["iSTEM Early College High School"],
    ".isticbc.org": [
        "Institut Supérieur des Technologies de l'Information et de la Communication",
        "The Higher Institute of Information Technologies and Communication",
    ],
    ".isyedu.org": ["International School Yangon"],
    ".itiangioy.org": [
        "ITI G.M. Angioy sassari",
        "industrial Technical Institute G.M. Angioy of Sassari",
    ],
    ".itlearning-settat.org": [
        "IT Learning Campus Pole Ingénierie Systèmes, Réseaux, Sécurité et Management"
    ],
    ".itstep.org": ["IT Academy Step"],
    ".iu-study.org": ["Internationale Hochschule Bad Honnef Bonn GmbH"],
    ".ivesheadschool.org": ["Iveshead School"],
    ".jamesirwin.org": ["James Irwin Charter Schools"],
    ".jec-jabalpur.org": ["Jabalpur Engineering College"],
    ".jeffcopublicschools.org": ["Jefferson County Public Schools"],
    ".jefftwp.org": [
        "Jefferson Township Public Schools",
        "Jefferson Township Public Schools",
    ],
    ".jeppiaarinstitute.org": ["Jeppiaar Institute of Technology"],
    ".jerichoapps.org": ["Jericho High School"],
    ".jesuitmail.org": [
        "Jesuit High School",
        "Url:  https://www.jesuitportland.org/",
        "IT course: https://www.jesuitportland.org/academics/academics-new-2019-clone/academics-new-2019-mathdepartment",
    ],
    ".jhncc.org": ["John Henry Newman Catholic College"],
    ".jmieti.org": [
        "Jai Parkash Mukand Lal Innovative Institue of Engineering",
        "Radur, INDIA",
    ],
    ".jmlschool.org": ["Jasudben M L school, Mumbai, India"],
    ".johnadamsacademy.org": ["John Adams Academy Roseville"],
    ".jordandistrict.org": ["Jordan School District, UT, the U.S."],
    ".jpgacademy.org": ["John Paul the Great Academy"],
    ".jpsstudents.org": ["Jenison Public Senior High"],
    ".js-student.org": ["Justin-Siena High School", "Justin-Siena High School"],
    ".jsd117.org": ["Jacksonville School District 117 (Website: https://jsd117.org/)"],
    ".k12albemarle.org": ["Albemarle High School"],
    ".k12louisa.org": ["Louisa County Public Schools"],
    ".students.katyisd.org": [
        "Katy ISD School Board",
        "Katy Independent School District",
    ],
    ".kcpupils.org": ["King's College Schools", "kingscollegeschools.org", ".group"],
    ".kearsarge.org": ["Kearsarge Regional High School"],
    ".kentdenver.org": ["Kent Denver School"],
    ".kernhigh.org": ["Kern High School District"],
    ".kew.org": ["Kew Royal Botanic Gardens", "Kew Royal Botanic Gardens"],
    ".khazar.org": ["Khazar University"],
    ".kinkaid.org": ["The Kinkaid School"],
    ".kirtlandhornet.org": ["Kirtland High School"],
    ".kjit.org": ["K.J. Institute of Engineering and Technology- savli, vadodara"],
    ".klschools.org": ["Katonah Lewisboro School District"],
    ".knoxschools.org": ["Knox County Schools"],
    ".ksd.org": ["Kennewick High School"],
    ".kua.org": ["Kimball Union Academy"],
    ".la-pmn.org": [
        "La passerelle des métiers du numérique ",
        "The gateway to digital professions",
    ],
    ".lakeflyers.org": ["Lake Local Schools"],
    ".lakesideschool.org": ["Lakeside School"],
    ".lamache.org": ["Sup'La Mache"],
    ".lancastercountryday.org": ["Lancaster Country Day School"],
    ".landmarkschool.org": ["Landmark School"],
    ".lasalle-douala.org": [
        "Ecole Supérieure Technique La Salle - Douala",
        "Higher Technical Institute La Salle - Douala",
    ],
    ".student.lavelleprep.org": ["Lavelle Preparatory Charter School"],
    ".lavelleprep.org": ["John W. Lavelle Preparatory Charter School"],
    ".lawnmanor.org": ["Lawn Manor Academy"],
    ".lawrenceville.org": ["The Lawrenceville School"],
    ".lc-ps.org": [
        "Frederick V. Pankow Center",
        "L'Anse Creuse High School",
        "L'Anse Creuse High School North",
    ],
    ".lccsnj.org": [
        "Learning Community Charter School",
        "Learning Community Charter School",
    ],
    ".students.lcisd.org": ["George Ranch High School"],
    ".lcps.org": ["Loudoun County Public Schools"],
    ".leanderisd.org": ["Leander Independent School District"],
    ".learnatwren.org": ["Wren Academy"],
    ".lendi.org": ["Lendi Institute of Engineering and Technology"],
    ".leominsterschools.org": ["Leominster Public Schools"],
    ".lexingtonma.org": ["Lexington Public Schools"],
    ".lhprep.org": ["Lake Highland Preparatory School"],
    ".lhps.org": ["Lake Highland Preparatory School"],
    ".libopenuniv-edu.org": ["Libya Open University"],
    ".liccsalsl.org": ["LICCSAL Business College"],
    ".liebenzell.org": ["Internationale Hochschule Bad Liebenzell"],
    ".lighthousecoolbridge.org": ["Lighthouse Cool Bridge Academy"],
    ".lincolncharter.org": ["Lincoln Charter"],
    ".lincolnschool.org": ["Lincoln School"],
    ".students.lindenps.org": ["Linden High School", "Linden Public Schools, NJ, US"],
    ".lios.org": ["The Leadership Institute of Seattle"],
    ".lisd.org": ["Leander Independant School District"],
    ".llanoisd.org": ["Llano Independent School District", ".group"],
    ".llwarriors.org": ["Lincoln Lutheran High School"],
    ".lmghs.org": ["Leon M. Goldstein H.S."],
    ".lmsd.org": ["Lower Merion School Discrict"],
    ".loganschools.org": ["Logan High School"],
    ".stu.lok12.org": ["Lake Orion High School"],
    ".loomis.org": ["Loomis Chaffee"],
    ".lordwandsworth.org": ["Lord Wandsworth College"],
    ".lpsk12.org": ["Arapahoe High School", "Arapahoe High School"],
    ".students.lrsd.org": ["Little Rock School District"],
    ".lrsd.org": ["Little Rock School District"],
    ".lrstudents.org": ["Lenape Regional High School District"],
    ".lschs.org": ["La Salle College High School"],
    ".lshigh.org": ["La Salle Catholic College Prepratory"],
    ".lsrhs.org": ["Lincoln-Sudbury Regional High School"],
    ".lubbockisd.org": ["Lubbock High School", "Lubbock High School"],
    ".lusherschool.org": ["Lusher Charter School"],
    ".lvjusd.org": ["Livermore Highschool"],
    ".student.lvusd.org": ["Las Virgenes Unified School District"],
    ".lw210.org": ["Lincoln Way Community High School District 210"],
    ".tesla.lwsd.org": ["Tesla Stem High School, Washington, USA"],
    ".lwsd.org": ["Lake Washington School District"],
    ".lyceexavierseoul.org": ["Xavier International School in Seoul, South KOREA"],
    ".lz95.org": ["Lake Zurich Community District"],
    ".macintyreacademies.org": ["MacIntyre Academies"],
    ".madeira.org": ["The Madeira School"],
    ".madeiracityschools.org": ["Madeira City Schools"],
    ".educa.madrid.org": [
        "Consejería de Educación, Juventud y Deporte de la Comunidad de Madrid",
        "Counsel of Education, Youth and Sports of the Community of Madrid",
        "Portal: https://correoweb.educa.madrid.org/login.php",
    ],
    ".maldenps.org": ["Malden High School"],
    ".maltingsacademy.org": ["Maltings Academy"],
    ".maltonschool.org": ["Malton Secondary School"],
    ".mariancollege.org": [" Marian College Kuttikkanam (Autonomous)"],
    ".marlboroughcollege.org": ["Marlborough College"],
    ".marsd.org": ["Matawan Regional High School"],
    ".maruapula.org": ["Maru-a-Pula School, Gaborone"],
    ".marymathacollege.org": ["Mary Matha Arts & Science College, Mananthavady"],
    ".mayatanfoundation.org": ["Mayatan Bilingual School"],
    ".mcdonogh.org": ["McDonogh School", "McDonogh "],
    ".mcps.org": ["Blacksburg Middle School (Montgomery County Public Schools)"],
    ".mcqstudent.org": ["McQuaid Jesuit"],
    ".mcquaid.org": ["McQuaid Jesuit"],
    ".mcsoxford.org": ["Magdalen College School, Oxford"],
    ".mcvts.org": [
        "Morris County Vocational School of Technology",
        "MCST",
        "MCVTS",
        "MCVSD",
        "Morris County School of Technology",
        "Morris County Vocational School District",
    ],
    ".mdanderson.org": ["University of Texas MD Anderson Cancer Center"],
    ".meltwater.org": ["Meltwater Entrepreneurial School of Technology (MEST)"],
    ".menloschool.org": ["Menlo School"],
    ".mesaschool.org": ["Mesa Union School"],
    ".mgs.org": ["The Manchester Grammar School"],
    ".mhrd.org": [
        "The Academy for Mathematics Science and Engineering at Morris Hills High School"
    ],
    ".mhusd.org": ["Morgan Hill Unified School District", ".group"],
    ".michaelhouse.org": ["Michaelhouse school, South Africa"],
    ".midlandps.org": ["H.H Dow High School"],
    ".milkenschool.org": ["Milken Community Schools"],
    ".millardps.org": ["Millard North Middle School"],
    ".millaschool.org": ["Pacific Crest Innovation Academy"],
    ".mines-ales.org": ["Ecole des Mines d'Ales"],
    ".mines-douai.org": ["Ecole des Mines de Douai"],
    ".mines-nancy.org": ["École Nationale Supérieure des Mines de Nancy"],
    ".mines-saint-etienne.org": ["Ecole des Mines de Saint-Etienne"],
    ".misd400.org": ["Mercer Island School District"],
    ".mitmuzaffarpur.org": ["Muzaffarpur Institute of Technology, Muzaffarpur"],
    ".miu.org": [
        "Maharishi International University",
        "Maharishi International University",
    ],
    ".mka.org": ["Montclair Kimberley Academy"],
    ".mkuniversity.org": ["Madurai Kamaraj University"],
    ".mlschools.org": ["Mountain Lakes High School"],
    ".moorheadschools.org": ["Moorhead High School"],
    ".moreland.org": ["Moreland School District"],
    ".morgank12.org": ["Danville High School"],
    ".motsd.org": ["Mount Olive High School"],
    ".motthallcs.org": ["Mott Hall Charter School"],
    ".moundsviewschools.org": ["Irondale High School"],
    ".mountainheightsacademy.org": ["Mountain Heights Academy"],
    ".mpi-sws.org": ["Max Planck Institute for Software Systems (MPI-SWS)"],
    ".students.mpsaz.org": ["Mesa Public Schools District"],
    ".mpspride.org": ["Manchester CT, Public Schools"],
    ".mrc-academy.org": ["Midhurst Rother College", "Midhurst Rother College"],
    ".ms447.org": [
        "The Math and Science Exploratory School ",
        "345 Dean St, Brooklyn, NY, NY, US 11217",
    ],
    ".msad11.org": [
        "Maine School Administrative District 11",
        "Serving the communities of Gardiner, Pittston, Randolph and West Gardiner Maine,USA",
        "http://www.msad11.org/",
        "All schools in our district share the same offical email domain. Elementry, middle and high school",
    ],
    ".msad49.org": ["Maine School Administrative District # 49"],
    ".msi-ggsip.org": ["Maharaja Surajmal Institute"],
    ".mssm.org": [
        "Maine School of Science and Mathematics",
        "The Maine School of Science and Mathematics",
    ],
    ".mtka.org": ["Minnetonka High School"],
    ".mtsm.org": ["Athenaeum of Ohio"],
    ".mtvidyapeeth.org": [
        "Mother Teresa Vidyapeeth",
        "Mother Teresa Vidyapeeth, Muzaffarpur",
    ],
    ".mursd.org": ["Nipmuc Regional High School"],
    ".mwschool.org": ["Meridian School"],
    ".my-digital-school.org": ["MyDigitalSchool"],
    ".mycw.org": ["Collingwood School, Morven Campus"],
    ".mydusd.org": ["Dublin High School"],
    ".myimmaculatehs.org": ["Immaculate High School"],
    ".mynbps.org": ["North Broward Prepatory School"],
    ".mysandstorm.org": ["Sandringham School"],
    ".mysbisd.org": ["Spring Branch ISD", ".group"],
    ".mysummitps.org": ["Summit Public Schools"],
    ".myunit5.org": ["Normal Community High School"],
    ".stu.naperville203.org": ["Naperville Central High School"],
    ".nasdstudents.org": ["Nazareth Area High School", "Nazareth Area High School"],
    ".students.natickps.org": ["Natick High School"],
    ".stu.nbexcellence.org": [
        "New Berlin Eisenhower Middle/High School",
        "New Berlin Eisenhower High School",
        "New Berlin Eisenhower Middle School",
        "New Berlin Eisenhower",
        "Eisenhower",
        ".group",
    ],
    ".nbexcellence.org": [
        "New Berlin Eisenhower Middle/High School",
        "New Berlin Eisenhower High School",
        "New Berlin Eisenhower Middle School",
        "New Berlin Eisenhower",
        "Eisenhower",
        ".group",
    ],
    ".nbkrist.org": ["N.B.K.R. Institute Of Science & Technology"],
    ".nbnet.org": ['СУ"НЕШО БОНЧЕВ"'],
    ".nbps.org": ["North Broward Prepatory School"],
    ".nccsk12.org": ["Shaker Middle/High School"],
    ".ncps-k12.org": ["New Canaan Public Schools"],
    ".ndfrance.org": ["Lycee Notre Dame de France"],
    ".ndpma.org": ["Notre Dame Preparatory School and Marist Academy"],
    ".neevacademy.org": ["Neev Academy"],
    ".nehrucolleges.org": [
        "Nehru institute of engineering and technology",
        "Nehru institute of engineering and technology",
    ],
    ".netherhall.org": ["The Netherhall School"],
    ".newforestacademy.org": ["New Forest Academy"],
    ".newmanboston.org": ["The Newman School"],
    ".newmanstudents.org": ["The Newman School"],
    ".nhnnext.org": ["NHN NEXT"],
    ".nkcschools.org": ["North Kansas City Schools"],
    ".nlpanthers.org": ["New Lexington High School"],
    ".nordakademie.org": [
        "NORDAKADEMIE Hochschule der Wirtschaft",
        "NORDAKADEMIE University of Applied Sciences",
    ],
    ".novaandradina.org": [
        "Federal Institute of Education, Science and Technology of South Mato Grosso - Nova Andradina Campus",
        "Instituto Federal de Educação, Ciência e Tecnologia de Mato Grosso do Sul - Câmpus Nova Andradina",
    ],
    ".npenn.org": ["North Penn School District"],
    ".npmg.org": ["National High School of Mathematics and Science"],
    ".nredlearn.org": ["New Rochelle High School"],
    ".nsbindia.org": ["National School of Business"],
    ".nscsd.org": ["North Syracuse Central Schools"],
    ".nsd.org": ["Northshore School District"],
    ".nsd131.org": ["Columbia High School", ".group"],
    ".nuast.org": ["Nottingham University Academy of Science and Technology", "NUAST"],
    ".nuevaschool.org": ["The Nueva School"],
    ".students.nusd.org": ["San Marin High School"],
    ".nutleyschools.org": ["Nutley Public School District"],
    ".nycischool.org": ["NYC iSchool"],
    ".nyulangone.org": ["NYU Grossman School of Medicine"],
    ".oasisarena.org": ["Oasis Academy Arena"],
    ".obps.org": ["Old Bridge Public Schools"],
    ".ocsi.org": ["Okinawa Christian School International"],
    ".olatheschools.org": ["Olathe Public Schools USD 233"],
    ".oldrochester.org": ["Old Rochester Regional High School"],
    ".omgau.org": ["Omsk State Agrarian University"],
    ".ops.org": ["Omaha Public Schools"],
    ".optima-osvita.org": ["Educational center Optima, Kiev, Ukraine"],
    ".orangecsd.org": ["Orange High School"],
    ".students.orchardview.org": ["Orchard View HighSchool"],
    ".ousd.org": ["Oakland Unified School District (Oakland, California)"],
    ".ovidunivconstanta-edu.org": ["University of Constanta Medical School"],
    ".apps.oxfordpublicschools.org": ["Oxford High School", "Oxford High School"],
    ".oxfordspiresacademy.org": ["Oxford Spires Academy"],
    ".pafa.org": ["Pennsylvania Academy of the Fine Arts"],
    ".paideiaschool.org": ["Paideia School"],
    ".stu.palcsmail.org": ["Pennsylvania Leadership Charter School"],
    ".pchs.palihigh.org": ["Palisades Charter Highschool"],
    ".palisadessd.org": ["Palisades School District"],
    ".stu.palmbeachschools.org": ["Palm Beach Country School District"],
    ".palmbeachschools.org": ["Palm Beach School District"],
    ".parishepiscopal.org": ["Parish Episcopal School"],
    ".park6.org": ["Park County School District #6 (K-12)"],
    ".parmacityschools.org": ["Parma City School District"],
    ".pathfinderstudents.org": ["Pathfinder Tech"],
    ".pathfindertech.org": ["Pathfinder Regional Vocational Technicial High School"],
    ".pccoepune.org": ["Pimpri Chinchwad College Of Engineering, Pune"],
    ".cat.pcsb.org": ["Center for Advanced Technologies at Lakewood High School"],
    ".pcsb.org": ["Pinellas County School Board", ".group"],
    ".pdsb.org": ["Peel District School Board", ".group"],
    ".peddie.org": ["Peddie School"],
    ".philasd.org": [
        "The School District of Philadelphia",
        "S.D.P.",
        "SDP",
        "Philadelphia School District",
        ".group",
    ],
    ".piedmontschools.org": [
        "Piedmont Independent School District #22",
        "Piedmont Public Schools",
    ],
    ".pingry.org": ["The Pingry School"],
    ".pionir.org": ["Слободна школа Пионир", "Pionir free school"],
    ".pisgahpats.org": ["Mount Pisgah Christian School"],
    ".plps-k12.org": ["Pompton Lakes High School", "Pompton Lakes High School"],
    ".plsas.org": ["Prior Lake High School"],
    ".pmlrru.org": ["PML University"],
    ".students.pmsd.org": ["Pocono Mountain School District"],
    ".polyprep.org": ["Poly Prep Country Day School"],
    ".polytechnic-kabul.org": ["Polytechnical University of Kabul"],
    ".polytechnique.org": ["École polytechnique"],
    ".poornima.org": ["poornima"],
    ".portnet.org": ["Paul D. Schreiber High School"],
    ".providenceday.org": [
        "Providence Day School",
        "Providence Day School, Charlotte NC",
        "Providence Day",
        "PDS",
    ],
    ".prsd.org": ["Pentucket Regional High School", "Pentucket Regional High School"],
    ".student.psdr3.org": ["Pattonville Highschool"],
    ".psdr3.org": ["Pattonville High School"],
    ".pusa-sy.org": ["Private University of Science and Arts"],
    ".puyallupsd.org": ["Puyallup School District"],
    ".pwcs-edu.org": [
        "Patriot High School - Prince William County, VA USA",
        "https://patrioths.pwcs.edu/",
    ],
    ".qe.org": ["Queen Ethelburga's Collegiate"],
    ".qibaodwight.org": ["Shanghai Qibao Dwight High School"],
    ".ransomeverglades.org": ["Ransom Everglades School"],
    ".rawsonsaunders.org": ["Rawson Saunders School"],
    ".rdale.org": ["Robbinsdale Area Schools"],
    ".redcad.org": [
        "Research Laboratory on Development and Control of Distributed Application",
        "teacher and student emails @redcad.org",
        "www.redcad.org",
    ],
    ".region16ct.org": [
        "Woodland Regional High School in Beacon Falls CT under the Regional School District # 16"
    ],
    ".renaissanceschool.org": ["Renaissance School"],
    ".rhsfultonschools.org": ["Roswell High School"],
    ".richland2.org": ["Richland School District 2"],
    ".rightchoice.org": ["Community College of Denver"],
    ".risd.org": ["Richardson Independent School District"],
    ".riverdell.org": ["River Dell Regional School District"],
    ".riversideunified.org": ["Riverside Unified School District", ".group"],
    ".rjit.org": [
        "Rustamji Institute of Technology",
        "Rustamji Institute of Technology",
    ],
    ".rkmshome.org": ["Ramakrishna Mission Polytechnic College"],
    ".rochester-college.org": ["Rochester Indepedent College, Rochester"],
    ".rochesterschools.org": ["Rochester Public Schools (teacher email)", ".group"],
    ".stu.rockwallisd.org": ["Rockwall Heath High School"],
    ".roeper.org": ["The Roeper School"],
    ".roundrockisd.org": ["Round Rock Indpenedent School District"],
    ".roxburylatin.org": ["The Roxbury Latin School"],
    ".rozascs.org": ["Colegio y Seminario de Rozas"],
    ".rpufsd.org": ["Rocky Point High School"],
    ".rtnj.org": ["Randolph Middle School"],
    ".rutgersprep.org": ["Rutgers Preparatory School"],
    ".rvcschools.org": ["South Side High School"],
    ".rvilleschools.org": ["Robbinsville High School", ".group"],
    ".ryecountryday.org": ["Rye Country Day School"],
    ".rzjhs.org": ["Rochelle Zelle Jewish High School"],
    ".sageschool.org": ["Sage School"],
    ".saintgits.org": [
        "Saintgits College of Engineering",
        "saintgits.org",
        "URL: http://saintgits.org/engineering-college",
    ],
    ".saintjo.org": ["Lycée Saint Joseph - Bressuire"],
    ".saintjosephregional.org": ["Saint Joseph Regional School"],
    ".saintstephens.org": ["Saint Stephen's Episcopal School"],
    ".salemkeizer.org": ["Salem Keizer School District"],
    ".sandbachschool.org": ["Sandbach School"],
    ".saratogausd.org": ["Redwood Middle School"],
    ".sasaustin.org": ["St. Andrew's Episcopal School - Austin, Texas"],
    ".saschina.org": ["Shanghai American School"],
    ".sau16.org": ["Seacoast School of Technology"],
    ".sau26.org": ["Merrimack Highschool"],
    ".sau57.org": ["Salem High School"],
    ".sawstonvc.org": ["Sawston Village College"],
    ".sbcfamily.org": ["Roanoke Valley Christian Schools"],
    ".sboajc.org": ["SBOA School & Junior College", "SBOA School & Junior College"],
    ".scarsdaleschools.org": ["Scarsdale High School", "Scarsdale High School"],
    ".sch.org": ["Springside Chestnut Hill Academy"],
    ".student.schs.org": ["Grand Rapids South Christian High School"],
    ".scicu.org": ["Allen University", "Claflin College", "Morris College"],
    ".sciencescom.org": ["SciencesCom"],
    ".scsdb.org": ["South Carolina School for the Deaf and the Blind"],
    ".student.scsk12.org": ["Shelby County Schools, TN, US"],
    ".sd62learns.org": ["École John Stubbs", "John Stubbs "],
    ".seaprep.org": ["Seattle Preparatory School"],
    ".seattlegirlsschool.org": ["Seattle Girls' School"],
    ".seattleschools.org": ["Washington Middle School", "Garfield High School"],
    ".sebrsd.org": ["David Prouty High School"],
    ".secuso.org": ["Technische Universität Darmstadt"],
    ".seq.org": ["Menlo-Atherton High School"],
    ".sesd.org": ["Sunnyvale Middle School District, CA"],
    ".sfstoledo.org": ["St. Francis De Sales"],
    ".sfuhs.org": ["San Francisco University High School"],
    ".sgei.org": ["Anand Engineering College"],
    ".sgs-wa.org": ["Seattle Girls' School: Google Apps for Education Domain"],
    ".sh44.org": [
        "Комунальний заклад “Середня загальноосвітня школа № 44” Кам’янської міської ради"
    ],
    ".shenschools.org": ["Shenendehowa High School"],
    ".shschools.org": ["Sacred Heart Schools"],
    ".siasindia.org": ["Safi Institute of Advanced Study"],
    ".sibadi.org": [
        "СИБИРСКИЙ ГОСУДАРСТВЕННЫЙ АВТОМОБИЛЬНО-ДОРОЖНЫЙ УНИВЕРСИТЕТ",
        "THE SIBERIAN STATE AUTOMOBILE AND HIGWAY UNIVERSITY",
    ],
    ".sisschools.org": ["Singapore Intercultural School (SIS) Medan"],
    ".sjb-liege.org": ["Institut Saint-Jean Berchmans Liège"],
    ".sjsm.org": ["St.James's School of Medicine, Bonaire"],
    ".sjusd.org": ["Leland High School"],
    ".sluh.org": ["St. Louis University High School"],
    ".smolny.org": ["Saint Petersburg State University"],
    ".smtexas.org": ["St. Mark's School of Texas"],
    ".smuedu.org": ["Saint Monica University"],
    ".smuhsd.org": ["San Mateo Union High School"],
    ".snsct.org": ["SNS College of Technology"],
    ".sonomaacademy.org": ["Sonoma Academy"],
    ".southasia-uni.org": ["University of South Asia"],
    ".southwestcoloradoeschool.org": ["Southwest Colorado eSchool"],
    ".spartanmed.org": ["Spartan University of Health Sciences"],
    ".spencerportschools.org": ["Spencerport Central School District"],
    ".spjain.org": ["SP Jain Institute of Management"],
    ".spjimr.org": ["S. P. Jain Institute of Management And Research, Mumbai"],
    ".sprucestreetnyc.org": ["Spruce Street School"],
    ".sps81.org": [
        "Spokane Public Schools (District 81)",
        "Spokane, Washington",
        "https://www.spokaneschools.org/ (institution site)",
        "https://www.spokaneschools.org/domain/1741 (Click on CTE. The school offers several computer sciences classes. These are college level.)",
        "https://www.spokaneschools.org/Page/2334 (Step 8 references email login)",
    ],
    ".spschools.org": [
        "St. Albert Public Schools",
        ".group",
        "http://www.spschools.org/",
    ],
    ".spxabq.org": ["Saint Pius X High School"],
    ".srastudents.org": ["Santa Rosa Academy", "Santa Rosa Academy"],
    ".srcolleges.org": ["Sulaiman AlRajhi University"],
    ".srcs.org": ["San Rafael City Schools"],
    ".srit.org": ["SRI RAMAKRISHNA INSTITUTE OF TECHNOLOGY"],
    ".ssdmo.org": ["Special School District of St. Louis County"],
    ".ssrvm.org": ["Sri Sri Ravishankar Vidya Mandir"],
    ".sstx.org": [
        "Saint Stephen's Episcopal School",
        "Saint Stephens Episcopal School",
        "St. Stephen's Episcopal School",
        "St. Stephens Episcopal School",
        "Saint Stephen's Episcopal School of Austin",
        "Saint Stephens Episcopal School of Austin",
        "St. Stephen's Episcopal School of Austin",
        "St. Stephens Episcopal School of Austin",
        "Saint Stephen's Episcopal School, Austin",
        "Saint Stephens Episcopal School, Austin",
        "St. Stephen's Episcopal School, Austin",
        "St. Stephens Episcopal School, Austin",
        "Saint Stephen's Episcopal School, Austin TX",
        "Saint Stephens Episcopal School, Austin TX",
        "St. Stephen's Episcopal School, Austin TX",
        "St. Stephens Episcopal School, Austin TX",
    ],
    ".ssvotech.org": ["South Shore Vocational Technical High School"],
    ".students.st-andrews.org": ["Saint Andrew's Episcopal School"],
    ".st-christophers.org": ["St Christopher's CE High School"],
    ".st-columbas.org": ["St Columbas School"],
    ".ebpreston.staracademies.org": ["Eden Boys’ School, Preston"],
    ".stbernards.org": ["St. Bernard's School"],
    ".stcharles-stecroix.org": [
        "Saint Charles Sainte Croix Lycee general & technologique"
    ],
    ".stcolumbscollege.org": ["St Columbs College"],
    ".stcva.org": ["St. Christopher's School "],
    ".stedmundscollege.org": ["St Edmund's College"],
    ".stemhigh.org": ["STEM School and Academy"],
    ".stevensonschool.org": ["Stevenson School"],
    ".stjacademy.org": ["St. Johnsbury Academy"],
    ".stjohnschs.org": ["St. John's College High School"],
    ".stjohnsprep.org": ["St. John's Preparatory High School"],
    ".stjschools.org": ["St. James R-1 School District"],
    ".stluc-esa-bxl.org": [
        "ESA Saint-Luc Bruxelles",
        "École Superieure des Arts Saint-Luc Bruxelles",
        "Superior School of Arts Saint-Luc Brussels",
    ],
    ".stmarksschool.org": ["St.Mark's School, Massachusets, U.S."],
    ".stmarysdelhi.org": ["St. Mary's School"],
    ".stpbb.org": ["Lycée St Paul Bourdon Blanc"],
    ".stpetershuntingdon.org": ["St Peters School", "St Peters School"],
    ".stringtheoryschools.org": ["String Theory Schools"],
    ".student158.org": ["Huntley High School"],
    ".studentasvalencia.org": ["American School Of Valencia"],
    ".stuttgartschools.org": ["Stuttgart Public Schools"],
    ".summitps.org": ["Summit Public High Schools"],
    ".stu.sumnersd.org": ["Bonney Lake High School"],
    ".sumnersd.org": [
        " Sumner-Bonney Lake School District",
        " Bonney Lake High School",
        " Sumner High School",
        " .group",
    ],
    ".sun-tech.org": ["SUN Area Technical Institute"],
    ".sunprairieschools.org": ["sun prairie high school"],
    ".suttonmail.org": ["Cheam High School"],
    ".svaschool.org": ["Silicon Valley Academy"],
    ".svcschools.org": ["Saddleback Valley Christian School"],
    ".svuonline.org": ["Syrian Virtual University"],
    ".svvsd.org": ["Niwot High School"],
    ".swceschool.org": ["Southwest Colorado eSchool"],
    ".taboracademy.org": ["Tabor Academy", "Tabor Academy"],
    ".tampaprep.org": ["Tampa Preparatory School", "Tampa Preparatory School"],
    ".tanenbaumchat.org": [
        "The Anne & Max Tanenbaum Community Hebrew Academy of Toronto"
    ],
    ".tbs-education.org": ["Toulouse Business School"],
    ".tcdsb.org": ["Toronto Catholic District School Board"],
    ".tcdupage.org": ["Technology Center of DuPage"],
    ".tcstudents.org": ["The Anne & Max Tanenbaum Community Hebrew Academy of Toronto"],
    ".technonjr.org": ["Techno India NJR"],
    ".techvalleyhigh.org": ["Tech Valley High School"],
    ".tehcoll.org": [
        'ГАПОУ "Технический колледж им. В.Д.Поташова"',
        'GAPOU "Technical College named after V.D.Potashov"',
    ],
    ".teriinc.org": ["TERI Inc."],
    ".texasonlineprep.org": ["Texas Online Preparatory School"],
    ".tggs-bangkok.org": [
        "THE SIRINDHORN INTERNATIONAL THAI-GERMAN GRADUATE SCHOOL OF ENGINEERING"
    ],
    ".thakureducation.org": ["Thakur College of Engineering and Technology"],
    ".stud.the-klu.org": [
        "Kühne Logistics University (KLU)",
        "Kuehne Logistics University",
    ],
    ".the-klu.org": ["Kühne Logistics University (KLU)", "Kuehne Logistics University"],
    ".thecoleshillschool.org": ["The Coleshill School"],
    ".thedeantrustmoodle.org": ["Dean Trust Wigan, UK"],
    ".thehill.org": ["The Hill School"],
    ".themountbattenschool.org": ["The Mountbatten School"],
    ".theoakwoodschool.org": ["The Oakwood School"],
    ".thiqaruni.org": ["Thi Qar University"],
    ".ticollege.org": ["TECHNO MAIN, SALT LAKE"],
    ".times2.org": ["Times2 STEM Academy"],
    ".tms-hl.org": ["Thomas-Mann Schule"],
    ".tmsacademy.org": ["Triangle Math and Science Academy"],
    ".tonbridge-school.org": ["Tonbridge School"],
    ".tooeleschools.org": ["Stansbury High School"],
    ".toulouse-bs.org": ["Toulouse Business School"],
    ".edu.tranemo.org": ["Tranemo gymnasieskola", "Tranemo gymnasium"],
    ".tremontschool.org": ["Tremont School"],
    ".student.trinityvalleyschool.org": ["Trinity Valley School"],
    ".trinityvalleyschool.org": ["Trinity Valley School"],
    ".triumemba.org": ["TRIUM GLOBAL EXECUTIVE MBA "],
    ".tsrs.org": ["The Shri Ram School Moulsari"],
    ".ttsdstudents.org": ["Tualatin High School"],
    ".tusol.org": ["University of Sierra Leone"],
    ".tusom.org": ["Trinity University School of Medicine"],
    ".twain239.org": ["Mark Twain is239, NY NY"],
    ".u-46.org": ["School District U-46", "School District U-46"],
    ".ubdtce.org": ["University BDT College of Engineering"],
    ".ucapanama.org": ["Universidad de Cartago"],
    ".ucentralasia.org": [
        "University of Central Asia",
        "https://ucentralasia.org/",
        "https://ucentralasia.org/Admissions/ComputerScience/EN",
        'As per the Email Use Policy: "Email accounts for all users are created upon information/authorization received from Human Resources or Student Affairs Department/Registrar/Head of SPCE respectively."',
    ],
    ".ucnh.org": ["Université Chrétienne du Nord d'Haiti"],
    ".udesmontagnes.org": ["Université des Montagnes"],
    ".stu.udsd.org": ["Upper Dublin High School"],
    ".insa.ueuromed.org": ["INSA Euro-méditérannée", "Euromed University of Fes"],
    ".uha-ky.org": ["University Heights Academy"],
    ".un-ihe.org": ["IHE Delft Institute for Water Education"],
    ".unesco-ihe.org": ["UNESCO-IHE Institute for Water Education"],
    ".unibl.org": ["University of Banja Luka"],
    ".unicaf.org": ["Unicaf University"],
    ".alunos.cv.unipiaget.org": [
        "Universidade Jean Piaget",
        "http://www.unipiaget.cv/",
    ],
    ".unis.org": ["United Nations International School"],
    ".unishanoi.org": ["United Nations International School of Hanoi"],
    ".univ-annaba.org": ["Badji Mokhtar University - Annaba"],
    ".univ-dschang.org": ["Université de Dschang"],
    ".univ-lyon.org": ["Université de Lyon"],
    ".universityliberia.org": ["University of Liberia"],
    ".universum-ks.org": ["Universum college, Kosovo"],
    ".uofdjesuit.org": ["University of Detroit Jesuit High School and Academy"],
    ".upeace.org": ["University for Peace"],
    ".upou.org": ["University of the Philippines Open University"],
    ".upra.org": ["Athenaeum Pontificium Regina Apostolorum"],
    ".urbanschool.org": ["Urban School of San Francisco"],
    ".42.us.org": ["42 USA"],
    ".usenghor-francophonie.org": ["Université Senghor d'Alexandrie"],
    ".student.ushschool.org": ["Upper Shirley High", "Upper Shirley High"],
    ".utahmilitaryacademy.org": ["Utah Military Academy"],
    ".utcportsmouth.org": ["UTC Portsmouth"],
    ".utcwarrington.org": ["UTC Warrington"],
    ".vailstudents.org": ["Empire High School, AZ, US"],
    ".student.vansd.org": ["Vancouver School District"],
    ".vardhaman.org": ["Vardhaman College of Engineering"],
    ".vcpusd.org": ["Valley Center-Pauma Unified"],
    ".vcuhealth.org": ["Virginia Commonwealth University", "vcu.edu, vcuhealth.org"],
    ".veltechmultitech.org": [
        "Vel Tech Multi Tech Dr. Rangarajan Dr. Sakunthala Engineering College"
    ],
    ".vidyavihar.org": ["Vidya Vihar Residential School"],
    ".visocloud.org": ["Vrij Instituut voor Secundair Onderwijs Mariakerke"],
    ".viva-technology.org": ["VIVA Institute of Technology"],
    ".vumc.org": ["Vanderbilt University Medical Center"],
    ".vvsaz.org": ["Verde Valley School"],
    ".wagonerps.org": ["Wagoner pubilc schools"],
    ".wakefieldschool.org": ["Wakefield School"],
    ".walkerschools.org": ["LaFayette High School", ".group"],
    ".walworthacademy.org": ["Walworth Academy"],
    ".warwickschool.org": ["Warwick School"],
    ".washk12.org": ["WASHINGTON COUNTY SCHOOL DISTRICT", ".group"],
    ".wataugaschools.org": ["Watauga Schools"],
    ".waukeeschools.org": ["Waukee Community School District"],
    ".waysideschools.org": ["Wayside Schools"],
    ".wcboe.org": ["Wicomico County Board of Education"],
    ".wctech.org": ["Warren County Technical School"],
    ".welingkar.org": [
        "Prin. L. N. Welingkar Institute of Management Development & Research"
    ],
    ".westada.org": ["Sawtooth Middle School"],
    ".student.westboroughk12.org": ["Westborough Public Schools (Westborough, MA, US)"],
    ".westerncenter.org": ["Western Montgomery Career and Technology Center"],
    ".westex.org": ["West Essex Regional High School"],
    ".westportps.org": ["Westport, CT Public Schools"],
    ".wgs.org": ["Withington Girls' School"],
    ".wheatleypark.org": ["Wheatley Park School"],
    ".wheelerschool.org": ["The Wheeler School"],
    ".students.whpfederation.org": ["White Hills Park Federation"],
    ".whpfederation.org": ["White Hills Park Federation Teachers"],
    ".whps.org": ["West Hartford Public Schools", ".group"],
    ".whrhs-stu.org": ["Watchung Hills Regional High School"],
    ".williamsvillek12.org": ["Williamsville East High School"],
    ".winchendon.org": ["The Winchendon School"],
    ".winchesterps.org": [
        "Winchester High School Teacher Domains",
        "Email domain: @winchesterps.org",
    ],
    ".wlsv.org": ["Wellsville Central School District"],
    ".woodstockacademy.org": ["The Woodstock Academy"],
    ".wpsstudent.org": [
        "Winchester High School Students",
        "Email domain: @wpsstudent.com",
        "Website: http://www.winchesterps.org",
    ],
    ".wpsstudents.org": ["Westwood Public Schools (Students)"],
    ".live.wsd1.org": ["Meadows West"],
    ".wsdr4.org": ["Wentzville School District, Wentzville, Missouri"],
    ".wsspartans.org": ["White Station High School "],
    ".wusd.org": ["Windsor Unified School District"],
    ".stu.wvusd.org": ["Suzanne Middle School"],
    ".wwcsd.org": ["Wayne-Westland Community School District"],
    ".wwprsd.org": ["West Winsdsor Plainsboro High School South"],
    ".wymondhamcollege.org": ["Wymondham College"],
    ".xrds.org": ["Crossroads School for Arts and Sciences"],
    ".y115.org": ["Yorkville High School"],
    ".yarmouthschools.org": ["Yarmouth Schools District"],
    ".yellowwoodacademy.org": ["Yellow Wood Academy", "Yellow Wood Academy"],
    ".yhsmonsey.org": ["Yeshiva Ner Torah", "Yeshiva High School of Monsey"],
    ".yisseoul.org": ["Yongsan International School of Seoul"],
    ".ymtkfas.org": ["YAUMATI KFA SHOOL"],
    ".yumingschool.org": ["Yu Ming Charter School"],
    ".zabalburu.org": ["Colegio Zabalburu"],
    ".zenithuniversitycollege.org": ["zenith university college"],
    ".oteima.ac.pa": ["Universidad Tecnológica Oteima"],
    ".udelas.ac.pa": ["Universidad Especializada de Las Americas"],
    ".ulat.ac.pa": ["Universidad Latina de Panamá"],
    ".unachi.ac.pa": ["Universidad Autonoma de Chiriqui"],
    ".unadp.ac.pa": ["Universidad Abierta y a Distancia de Panama"],
    ".up.ac.pa": ["Universidad de Panamá"],
    ".usma.ac.pa": ["Universidad Católica Santa María La Antigua"],
    ".utp.ac.pa": ["Universidad Tecnológica de Panamá"],
    ".etu-digitalschool.paris": ["Digital School of Paris"],
    ".stu-psbedu.paris": ["Paris Business School"],
    ".SENATI.pe": ["Servicio Nacional de Adiestramiento en Trabajo Industrial"],
    ".champagnat.edu.pe": ["Universidad Marcelino Champagnat"],
    ".cibertec.edu.pe": ["Cibertec"],
    ".idat.edu.pe": ["Instituto superior tecnológico IDAT"],
    ".isur.edu.pe": [
        "Instituto de Educación Superior Tecnológico Privado del Sur",
        "ISur",
    ],
    ".lamolina.edu.pe": ["Universidad Nacional Agraria La Molina"],
    ".pucp.edu.pe": ["Pontificia Universidad Católica del Perú"],
    ".sil.edu.pe": ["Universidad San Ignacio de Loyola"],
    ".uancv.edu.pe": ["Universidad Andina Nestor Caceares Velasquez"],
    ".uap.edu.pe": ["Universidad Alas Peruanas"],
    ".ucsm.edu.pe": ["Universidad Católica de Santa María"],
    ".ucsur.edu.pe": ["Universidad Cientifica del Sur"],
    ".ucv.edu.pe": ["Universidad César Vallejo"],
    ".udch.edu.pe": ["Universidad Particular de Chiclayo"],
    ".udep.edu.pe": ["Universidad de Piura"],
    ".udh.edu.pe": ["Universidad de Huánuco"],
    ".uigv.edu.pe": ["Universidad Particular Inca Garcilaso de la Vega"],
    ".uladech.edu.pe": ["Universidad Los Angeles de Chimbote"],
    ".ulima.edu.pe": ["Universidad de Lima"],
    ".unac.edu.pe": ["Universidad Nacional del Callao"],
    ".unap.edu.pe": ["Universidad Nacional del Altiplano"],
    ".unas.edu.pe": ["Universidad Nacional Agraria La Selva"],
    ".unasam.edu.pe": ["Universidad Nacional Santiago Antúnez de Mayolo"],
    ".unc.edu.pe": ["Universidad Nacional de Cajamarca"],
    ".uncp.edu.pe": ["Universidad Nacional del Centro del Perú"],
    ".une.edu.pe": ["Universidad Nacional de Educación Enrique Guzmán y Valle"],
    ".unheval.edu.pe": ["Universidad Nacional Hermilio Valdizan"],
    ".uni.edu.pe": ["Universidad Nacional de Ingeniería"],
    ".unica.edu.pe": ["Universidad Nacional San Luis Gonzaga"],
    ".unife.edu.pe": ["Universidad Femenina del Sagrado Corazón"],
    ".unitru.edu.pe": ["Universidad Nacional de La Libertad, Trujillo"],
    ".unjbg.edu.pe": ["Universidad Nacional Jorge Basadre Grohmann"],
    ".unjfsc.edu.pe": ["Universidad Nacional José Faustino Sánchez Carrión"],
    ".unmsm.edu.pe": ["Universidad Nacional Mayor de San Marcos"],
    ".unp.edu.pe": ["Universidad Nacional de Piura"],
    ".uns.edu.pe": ["Universidad Nacional de Santa - Chimbote"],
    ".unsa.edu.pe": ["Universidad Nacional de San Agustin"],
    ".unsaac.edu.pe": ["Universidad Nacional de San Antonio Abad"],
    ".unsm.edu.pe": ["Universidad Nacional de San Martín"],
    ".untumbes.edu.pe": ["Universidad Nacional de Tumbes"],
    ".unu.edu.pe": ["Universidad Nacional de Ucayali"],
    ".up.edu.pe": ["Universidad del Pacifico"],
    ".upao.edu.pe": ["Universidad Privada Antenor Orrego"],
    ".upc.edu.pe": ["Universidad Peruana de Ciencias Aplicadas"],
    ".upch.edu.pe": ["Universidad Peruana Cayetano Heredia"],
    ".upeu.edu.pe": ["Universidad Peruana Union"],
    ".upla.edu.pe": ["Universidad Privada Los Andes"],
    ".upsjb.edu.pe": ["Universidad Privada San Juan Bautista"],
    ".upt.edu.pe": ["Universidad Privada de Tacna"],
    ".urp.edu.pe": ["Universidad Ricardo Palma"],
    ".usmp.edu.pe": ["Universidad San Martin de Porres"],
    ".usp.edu.pe": ["Universidad San Pablo"],
    ".utea.edu.pe": ["Universidad Tecnológica de los Andes de Apurímac"],
    ".utp.edu.pe": ["Universidad Tecnológica del Peru"],
    ".uwiener.edu.pe": ["Universidad Norbert Wienner"],
    ".isil.pe": ["Instituto San Ignacio de Loyola", "ISIL"],
    ".rcp.net.pe": [
        "Universidad Nacional Daniel Alcides Carrion",
        "Universidad Nacional Pedro Ruíz Gallo",
    ],
    ".pucp.pe": ["Pontificia Universidad Católica del Perú"],
    ".uarm.pe": ["Universidad Antonio Ruiz de Montoya"],
    ".uch.pe": [
        "UNIVERSIDAD DE CIENCIAS Y HUMANIDADES",
        "UNIVERSITY OF SCIENCES AND HUMANITIES",
    ],
    ".ucss.pe": ["Universidad Católica Sedes Sapientiae"],
    ".udep.pe": ["Universidad de Piura"],
    ".uladech.pe": ["UNIVERSIDAD CATOLICA LOS ANGELES DE CHIMBOTE", "systems engineer"],
    ".unac.pe": ["Universidad Nacional del Callao"],
    ".uni.pe": ["Universidad Nacional de Ingenieria"],
    ".unsa.pe": ["Universidad Nacional de San Agustín de Arequipa"],
    ".upch.pe": ["Universidad Peruana Cayetano Heredia"],
    ".upn.pe": ["Universidad Privada del Norte"],
    ".upt.pe": ["Universidad Privada De Tacna", "Private University Of Tacna"],
    ".urp.pe": ["Universidad Ricardo Palma"],
    ".usil.pe": ["Universidad San Ignacio de Loyola"],
    ".usmp.pe": ["Universidad de San Martín de Porres"],
    ".ac-polynesie.pf": ["French polynesia academy"],
    ".clm.ddec.edu.pf": ["Lycée La Mennais"],
    ".upf.pf": ["Université de la Polynésie Française"],
    ".dwu.ac.pg": ["Divine Word University"],
    ".pau.ac.pg": ["Pacific Adventist University"],
    ".unitech.ac.pg": ["Papua New Guinea University of Technology"],
    ".uog.ac.pg": ["University of Goroka"],
    ".upng.ac.pg": ["University of Papua New Guinea"],
    ".globe.com.ph": ["University of the Immaculate Conception"],
    ".dlsu.ph": ["De La Salle University - Manila"],
    ".adamson.edu.ph": ["Adamson University"],
    ".addu.edu.ph": ["Ateneo de Davao University"],
    ".admu.edu.ph": ["Ateneo de Manila University"],
    ".adnu.edu.ph": ["Ateneo de Naga University"],
    ".adzu.edu.ph": ["Ateneo de Zamboanga University"],
    ".ama.edu.ph": [
        "AMA Computer University - Main Campus",
        "AMA Computer College - Branches",
    ],
    ".apc.edu.ph": ["Asia Pacific College"],
    ".arellano.edu.ph": ["Arellano University"],
    ".auf.edu.ph": ["Angeles University"],
    ".aup.edu.ph": ["Adventist University of the Philippines"],
    ".bsu.edu.ph": ["Benguet State University"],
    ".bulsu.edu.ph": ["Bulacan State University"],
    ".ceu.edu.ph": ["Centro Escolar University"],
    ".cmu.edu.ph": ["Central Mindanao University"],
    ".cu.edu.ph": ["Capitol University"],
    ".davaodoctors.edu.ph": ["Davao Doctors College"],
    ".dlsu.edu.ph": ["De La Salle University", "De La Salle University, Araneta"],
    ".dmmmsu.edu.ph": ["Don Mariano Marcos Memorial State University"],
    ".eclaro.edu.ph": ["Eclaro Academy"],
    ".featiu.edu.ph": ["Feati University"],
    ".feu.edu.ph": ["Far Eastern University"],
    ".feutech.edu.ph": ["FEU Institute of Technology"],
    ".hau.edu.ph": ["Holy Angel University"],
    ".holyspirit.edu.ph": ["College of the Holy Spirit"],
    ".isu.edu.ph": ["Isabela State University"],
    ".mcu.edu.ph": ["Manila Central University"],
    ".mlqu.edu.ph": ["Manuel L. Quezon University"],
    ".mmsu.edu.ph": ["Mariano Marcos State University"],
    ".mseuf.edu.ph": ["Manuel S. Enverga University Foundation"],
    ".msuiit.edu.ph": ["Mindanao State University - Iligan Institute of Technology"],
    ".msumain.edu.ph": ["Mindanao State University"],
    ".mvc.edu.ph": ["Mountain View College"],
    ".ndmu.edu.ph": ["Notre Dame of Marbel University"],
    ".neu.edu.ph": ["New Era University"],
    ".nu.edu.ph": ["National University"],
    ".pcu.edu.ph": ["Philippine Christian University"],
    ".phinma.edu.ph": ["University of lloilo"],
    ".plm.edu.ph": ["University of the City of Manila"],
    ".psu.edu.ph": ["Pangasinan State University"],
    ".pup.edu.ph": ["Polytechnic University of the Philippines"],
    ".sanbeda.edu.ph": ["San Beda College"],
    ".slu.edu.ph": ["Saint Louis University"],
    ".smu.edu.ph": ["Saint Mary's University"],
    ".ssu.edu.ph": ["Samar State University"],
    ".su.edu.ph": ["Silliman University"],
    ".swu.edu.ph": ["Southwestern University"],
    ".tip.edu.ph": ["Technological Institute of the Philippines"],
    ".tup.edu.ph": ["Technological University of the Philippines"],
    ".ua.edu.ph": ["University of the Assumption"],
    ".ub.edu.ph": ["University of Batangas"],
    ".ue.edu.ph": [
        "University of the East, Coloocan",
        "University of the East, Manila",
    ],
    ".uerm.edu.ph": ["University of the East, Ramon Magsaysay Memorial Medical Center"],
    ".umindanao.edu.ph": ["University of Mindanao"],
    ".unc.edu.ph": ["University of Nueva Caceres"],
    ".unep.edu.ph": ["University of Northeastern Philippines"],
    ".uno-r.edu.ph": ["University of Negros Occidental-Recoletos"],
    ".unp.edu.ph": ["University of Northern Philippines"],
    ".upb.edu.ph": ["University of the Philippines Baguio"],
    ".upd.edu.ph": ["University of the Philippines Diliman"],
    ".uplb.edu.ph": ["University of the Philippines Los Banos"],
    ".upm.edu.ph": ["University of the Philippines Manila"],
    ".upmin.edu.ph": ["University of the Philippines Mindanao"],
    ".upv.edu.ph": ["University of the Philippines Visayas"],
    ".usa.edu.ph": ["University of San Agustin"],
    ".usc.edu.ph": ["University of San Carlos"],
    ".usep.edu.ph": ["University of Southeastern Philippines"],
    ".usjr.edu.ph": ["University of San Jose Recoletos"],
    ".usm.edu.ph": ["University of Southern Mindanao"],
    ".ust.edu.ph": ["University of Santo Tomas"],
    ".uv.edu.ph": ["University of the Visayas"],
    ".vmuf.edu.ph": ["Virgen Milagrosa University Foundation"],
    ".wesleyan.edu.ph": ["Wesleyan University Philippines"],
    ".wmsu.edu.ph": ["Western Mindanao State University"],
    ".wvsu.edu.ph": ["West Visayas State University"],
    ".xu.edu.ph": ["Xavier University"],
    ".educ.ph": ["University of Eastern Philippines"],
    ".deped.gov.ph": ["JESUS DELA PEÑA NATIONAL HIGH SCHOOL"],
    ".iacademy.ph": ["Information and Communications Technology Academy"],
    ".evis.net.ph": ["Leyte Normal University"],
    ".pma.ph": ["Philippine Military Academy"],
    ".fairview.sti.ph": ["STI College Fairview"],
    ".novaliches.sti.ph": ["STI College, Philippines"],
    ".usp.ph": ["University of Southern Philippines Foundation"],
    ".cust.pk": ["Capital University of Science and Technology"],
    ".abasyn.edu.pk": ["Abasyn University Peshawar"],
    ".aiou.edu.pk": ["Allama Iqbal Open University"],
    ".ajku.edu.pk": ["Azad Jammu and Kashmir University"],
    ".aldirasat.edu.pk": ["University of Islamic Studies"],
    ".alkhair.edu.pk": ["Al-Khair University"],
    ".ami.edu.pk": ["Asian Management Institute"],
    ".apiit.edu.pk": [
        "Asia Pacific Institute of Information Technology Pakistan (APIIT PAK)"
    ],
    ".au.edu.pk": ["Air University"],
    ".aup.edu.pk": ["North West Frontier Province Agricultural University"],
    ".bahria.edu.pk": ["Bahria University"],
    ".buetk.edu.pk": ["Balochistan University of Engineering and Technology Khuzdar"],
    ".buitms.edu.pk": [
        "Balochistan University of Information Technology &amp; Management Sciences "
    ],
    ".bzu.edu.pk": ["Bahauddin Zakariya University, Multan"],
    ".case.edu.pk": ["CASE"],
    ".cecos.edu.pk": ["Cecos Univeristy of Information Technology"],
    ".ciit-attock.edu.pk": ["COMSATS Institute of Information Technology, Attock"],
    ".ciitlahore.edu.pk": ["COMSATS Institute of Information Technology, Lahore"],
    ".isbstudent.comsats.edu.pk": [
        "Comsats University Islamabad",
        "Comsats University Islamabad",
    ],
    ".student.comsats.edu.pk": [
        "Comsats University Islamabad",
        "Comsats University Islamabad",
    ],
    ".cosmiq.edu.pk": ["COSMIQ Institute of Technology"],
    ".cuiwah.edu.pk": ["COMSATS University Islamabad, Wah Cantt"],
    ".dadabhoy.edu.pk": ["Dadabhoy Institute of Higher Education"],
    ".duhs.edu.pk": ["Dow University of Health Sciences"],
    ".fast.edu.pk": ["The Fast School & Science Academy"],
    ".formanite.fccollege.edu.pk": [
        "Forman Christian College (A Chartered University)"
    ],
    ".fuuast.edu.pk": ["Federal Urdu University of Arts,Science and Technology"],
    ".gandhara.edu.pk": ["Gandhara Institute of Medical Sciences"],
    ".gcu.edu.pk": ["GC University Lahore", "Government College University Lahore"],
    ".gcuf.edu.pk": ["Government College University Faisalabad"],
    ".gift.edu.pk": ["Gift University"],
    ".giki.edu.pk": ["Ghulam Ishaq Khan Institute of Science &amp; Technology"],
    ".gist.edu.pk": ["Gangdara Institute Of Science &amp; Technology"],
    ".global.edu.pk": ["The Global College Lahore"],
    ".gu.edu.pk": ["Gomal University"],
    ".hamdard.edu.pk": ["Hamdard University"],
    ".hitecuni.edu.pk": ["Hitec University"],
    ".hu.edu.pk": ["Hazara University"],
    ".iba-suk.edu.pk": ["Institute Of Business Administration Sukkur"],
    ".iba.edu.pk": ["Institute of Business Administration (IBA)"],
    ".iiee.edu.pk": ["Institute of Industrial Electronics Engineering"],
    ".iiu.edu.pk": ["International Islamic University"],
    ".indus.edu.pk": ["Indus Institute of Higher Education"],
    ".iobm.edu.pk": ["Institute Of Business Management"],
    ".iqra.edu.pk": ["iqra university"],
    ".isra.edu.pk": ["Isra University"],
    ".itu.edu.pk": ["Information Technology University"],
    ".iub.edu.pk": ["Islamia University of Bahawalpur"],
    ".jinnah.edu.pk": ["Mohammad Ali Jinnah University"],
    ".juw.edu.pk": ["Jinnah University for Women"],
    ".kasbit.edu.pk": ["KASB Institute of Technology"],
    ".kfueit.edu.pk": [
        "Khwaja Fareed University of Engineering and Information Technology",
        "Khwaja Fareed University of Engineering and Information Technology",
    ],
    ".kiu.edu.pk": ["Karakoram International University"],
    ".kmdc.edu.pk": ["Karachi Medical and Dental College"],
    ".ksa.edu.pk": ["Karachi School of Art"],
    ".kust.edu.pk": ["Kohat University of Science and Technology  (KUST)"],
    ".lcwu.edu.pk": ["Lahore College for Women University"],
    ".lgu.edu.pk": ["Lahore Garrison University"],
    ".lumhs.edu.pk": ["Liaquat University of Medical &amp; Health Sciences Jamshoro"],
    ".lums.edu.pk": ["Lahore University of Management Sciences"],
    ".maju.edu.pk": [
        "Muhammad Ali Jinnah University",
        "Muhammad Ali Jinnah University",
    ],
    ".students.mcs.edu.pk": ["Military College of Signals"],
    ".miu.edu.pk": ["Mohi-ud-Din Islamic University"],
    ".mnsuet.edu.pk": [
        "Muhammad Nawaz Sharif University of Engineering and Technology"
    ],
    ".muet.edu.pk": ["Mehran University of Engineering &amp; Technology"],
    ".myers.edu.pk": ["Myer's College"],
    ".nca.edu.pk": ["National College of Arts"],
    ".neduet.edu.pk": ["NED University of Engineering and Technology Karachi"],
    ".student.nu.edu.pk": [
        "National Univeristy of Computer and Emerging Science (NUCES)",
        "The Foundation for Advancement of Science and Technology (FAST)",
    ],
    ".nu.edu.pk": [
        "FAST - National University of Computer and Emerging Sciences (NUCES)",
        "National University of Computer &amp; Emerging Sciences",
    ],
    ".numl.edu.pk": ["National University of Modern Languages"],
    ".numls.edu.pk": ["National University of Modern Languages", "NUML "],
    ".nust.edu.pk": ["National University of Science and Technology"],
    ".nwfpuet.edu.pk": ["University of Engineering and Technology Peshawar"],
    ".pafkiet.edu.pk": ["Karachi Institute Of Economics And Technology"],
    ".pakaims.edu.pk": ["Institute of Management Sciences, Lahore (IMS)"],
    ".pics.edu.pk": ["Punjab Institute of Computer science"],
    ".pieas.edu.pk": ["Pakistan Institute of Engineering and Applied Sciences"],
    ".pu.edu.pk": ["University of the Punjab"],
    ".pucit.edu.pk": ["Punjab University College of Information Tecnology"],
    ".pugc.edu.pk": ["University of the Punjab, Gujranwala Campus"],
    ".qau.edu.pk": ["Quaid-i-Azam University"],
    ".qurtuba.edu.pk": ["Qurtuba University of Science and Infromation Technology"],
    ".riphah.edu.pk": ["Riphah International Univeristy"],
    ".salu.edu.pk": ["Shah Abdul Latif University Khairpur"],
    ".sau.edu.pk": ["Sindh Agricultural University"],
    ".seecs.edu.pk": ["School of Electrical Engineering and Computer Science"],
    ".smme.edu.pk": [
        "School of Mechanical and Manufacturing Engineering, National University of Sciences and Technology, Islamabad, Pakistan"
    ],
    ".ssuet.edu.pk": ["Sir Syed University of Engineering and Technology"],
    ".suit.edu.pk": [
        "Sarhad University of Science &amp; Information Technology, Peshawar "
    ],
    ".superior.edu.pk": ["The Superior College "],
    ".szabist.edu.pk": [
        "Shaheed Zulifkar Ali Bhutto Institute of Science and Technology"
    ],
    ".tip.edu.pk": ["Textile Institute of Pakistan"],
    ".tuf.edu.pk": ["University of Faisalabad"],
    ".uaar.edu.pk": ["University of Arid Agriculture Rawalpindi"],
    ".uaf.edu.pk": ["University of Agriculture Faisalabad"],
    ".ucp.edu.pk": ["University of Central Punjab"],
    ".ue.edu.pk": ["University of Education"],
    ".student.uet.edu.pk": [
        "University of Engineering and Technology Lahore, Pakistan",
        "University of Engineering and Technology Lahore, Pakistan",
    ],
    ".uet.edu.pk": [
        "University of Engineering and Technology, Lahore",
        "uet lahore",
        "www.uet.edu.pk",
    ],
    ".uettaxila.edu.pk": ["University of Engineering and Technology Taxila"],
    ".umt.edu.pk": ["University of Management and Technology"],
    ".unw.edu.pk": ["University of NorthWest"],
    ".uoe.edu.pk": ["University of East"],
    ".uog.edu.pk": ["University of Gujrat"],
    ".uok.edu.pk": ["University of Karachi"],
    ".uol.edu.pk": ["The University of Lahore"],
    ".uom.edu.pk": ["University of Malakand"],
    ".uos.edu.pk": ["University of Sargodha"],
    ".usa.edu.pk": ["University of South Asia"],
    ".usindh.edu.pk": ["University of Sindh"],
    ".ustb.edu.pk": ["University of Science &amp; Technology Bannu"],
    ".uvas.edu.pk": ["University of Veterinary &amp; Animal Science"],
    ".vcomsats.edu.pk": ["Comsats University Islamabad (Virtual Campus)"],
    ".vu.edu.pk": ["Pakistan Virtual University", "Virtual University of Pakistan"],
    ".wahmedicalcollege.edu.pk": ["Wah Medical College"],
    ".wisdomhouse.edu.pk": ["Wisdom House Degree College"],
    ".zawiya.edu.pk": ["Zawiya Academy"],
    ".niab.org.pk": ["Nuclear Institute for Agriculture and Biology (NIAB)"],
    ".szabist-isb.pk": [
        "Shaheed Zulfiqar Ali Butto Institute of Information Technology"
    ],
    ".szabist.pk": [
        "Szabist - Shaheed Zulfikar Ali Bhutto Institute of Science and Technology"
    ],
    ".2lo.pl": [
        "Vocational Technical High School for Computer Science No. 2 name of Henryk Sienkiewicz in Kolobrzeg"
    ],
    ".aktywnaedukacja.pl": ["NoBell"],
    ".pb.bialystok.pl": ["Technical University of Bialystok"],
    ".ath.bielsko.pl": ["University of Bielsko-Biala"],
    ".lo5.bielsko.pl": ["V Liceum Ogólnokształcące"],
    ".wsa.bielsko.pl": ["School of Administration"],
    ".biskupiak.pl": [
        "XXI Liceum Ogólnokształcące im. św. Stanisława Kostki w Lublinie (BISKUPIAK)"
    ],
    ".amuz.bydgoszcz.pl": ["Music Academy Felix Nowowiejski in Bydgoszcz"],
    ".cdv.pl": ["Collegium Da Vinci"],
    ".cedim.pl": ["Children and Youth Programming School"],
    ".pwsz.chelm.pl": [
        "Państwowa Wyższa Szkoła Zawodowa w Chełmie",
        "The State School of Higher Education in Chełm",
    ],
    ".studenci.collegiumwitelona.pl": [
        "Collegium Witelona Uczelnia Państwowa",
        "Witelon Collegium State University",
    ],
    ".collegiumwitelona.pl": [
        "Collegium Witelona Uczelnia Państwowa",
        "Witelon Collegium State University",
    ],
    ".sp1.skawina.com.pl": ["Szkoła Podstawowa nr 1 w Skawinie"],
    ".spoleczna.com.pl": ["Group of social schools STO in Augustow"],
    ".wst.com.pl": [
        "Wyższa Szkoła Techniczna w Katowicach",
        "University of Technology, Katowice, Poland",
    ],
    ".ajd.czest.pl": ["Jan Dlugosz University in Czestochowa"],
    ".pcz.czest.pl": ["Technical University of Czestochowa"],
    ".debinka.pl": ["Kolegium Edukacyjne PSO"],
    ".live.edja.pl": [
        "Prywatna Szkoła Podstawowa i Liceum im. Królowej Jadwigi w Lublinie"
    ],
    ".afm.edu.pl": [
        "Krakowska Akademia im. Andrzeja Frycza Modrzewskiego",
        "Andrzej Frycz Modrzewski Krakow University",
    ],
    ".agh.edu.pl": ["AGH University of Science and Technology"],
    ".student.ajp.edu.pl": ["Akademia im. Jakuba z Paradyża w Gorzowie Wielkopolskim"],
    ".ajp.edu.pl": [
        "The Jacob of Paradies University in Gorzow Wielkopolski",
        "Akademia im. Jakuba z Paradyża w Gorzowie Wielkopolskim",
    ],
    ".akademeia.edu.pl": ["Akademeia Tutorial College"],
    ".akademiakaliska.edu.pl": [
        "Akademia Kaliska im. Prezydenta Stanisława Wojciechowskiego"
    ],
    ".amb.edu.pl": ["Medical Academy in Bialystok"],
    ".amu.edu.pl": ["Adam Mickiewicz University of Poznan"],
    ".amwaw.edu.pl": ["Medical Academy in Warszawa"],
    ".ap.edu.pl": ["Polonia University in Częstochowa"],
    ".aps.edu.pl": [
        "Akademia Pedagogiki Specjalnej",
        "The Academy of Special Education (The Maria Grzegorzewska University)",
    ],
    ".aspkat.edu.pl": ["Fine Arts Academy in Katowice"],
    ".at.edu.pl": ["Aleksander Zelwerowicz State Theatre Academy"],
    ".ath.edu.pl": ["University of Bielsko-Biala"],
    ".awf.edu.pl": ["Physical Education Academy Jozef Pilsudski in Warsaw"],
    ".awl.edu.pl": ["General Tadeusz Kościuszko Military University of Land Forces"],
    ".batory.edu.pl": ["Liceum im. Stefana Batorego"],
    ".brzozowa5.edu.pl": [
        "Zespół Szkół Polskiego Górnictwa Naftowego i Gazownictwa",
        "Complex of Schools of Polish Oil Mining and Gas Industry",
    ],
    ".cft.edu.pl": ["Center for Theoretical Physics, Polish Academy of Sciences"],
    ".chopin.edu.pl": ["Music Academy Fryderyk Chopin in Warszaw"],
    ".civitas.edu.pl": ["Collegium Civitas"],
    ".collegium.edu.pl": ["Collegium Civitas"],
    ".student.dsw.edu.pl": ["Dolnośląska Szkoła Wyższa", "University of Lower Silesia"],
    ".dsw.edu.pl": ["\ufeffDolnośląska Szkoła Wyższa"],
    ".eas.edu.pl": ["European Academy of Arts in Warsaw"],
    ".sluchacz.effekt.edu.pl": ["EFFEKT"],
    ".elektryk.edu.pl": ["Zespol Szkol Elektrycznych"],
    ".lo12.elodz.edu.pl": [
        "XII Liceum Ogólnokształcące im. Stanisława Wyspiańskiego w Łodzi",
        "Stanislaw Wyspianski 12th High School in Lodz",
    ],
    ".lo31.elodz.edu.pl": [
        "\ufeffXXXI Liceum Ogólnokształcące im. Ludwika Zamenhofa w Łodzi",
        "Ludwik Zamenhof 31st High School in Lodz",
    ],
    ".zsp9.elodz.edu.pl": [
        "Zespół Szkół Politechnicznych im. Komisji Edukacji Narodowej",
        "al. Politechniki 38,",
        "93-590 Łódź",
    ],
    ".europejskauczelnia.edu.pl": ["Europejska Uczelnia Ekonomiczno-Informatyczna"],
    ".ewsie.edu.pl": ["Europejska Uczelnia Informatyczno - Ekonomiczna w Warszawie"],
    ".ezn.edu.pl": ["Elektroniczne Zakłady Naukowe"],
    ".fundacjaszkolna.edu.pl": ["Liceum Fundacji Szkolnej"],
    ".fuw.edu.pl": [
        "Wydział Fizyki Uniwersytetu Warszawskiego",
        "Faculty of Physics University of Warsaw",
        "# fuw.edu.pl for teachers",
        "# okwf.fuw.edu.pl for students",
        "# https://www.fuw.edu.pl/poczta.html",
    ],
    ".gssr.edu.pl": [
        "The Graduate School for Social Research, Institute of Philosophy and Sociology Polish Academy of Sciences"
    ],
    ".gumed.edu.pl": ["Medical University of Gdansk"],
    ".icm.edu.pl": [
        "Interdyscyplinarne Centrum Modelowania Matematycznego i Komputerowego Uniwersytetu Warszawskiego",
        "Interdisciplinary Centre for Mathematical and Computational Modelling University of Warsaw",
    ],
    ".ifj.edu.pl": ["Institute of Nuclear Physics Polish Academy of Sciences"],
    ".igf.edu.pl": [
        "Instytut Geofizyki Polskiej Akademii Nauk",
        "Institute of Geophysics, Polish Academy of Sciences",
    ],
    ".student.ignatianum.edu.pl": ["Akademia Ignatianum"],
    ".ikifp.edu.pl": [
        "Instytut Katalizy i Fizykochemii Powierzchni PAN im. Jerzego Habera",
        "Jerzy Haber Institute of Catalysis and Surface Chemistry, Polish Academy of Sciences",
    ],
    ".kasprzak.edu.pl": [
        "Zespol Szkol nr 36 im. Marcina Kasprzaka w Warszawie",
        "School Complex No. 36 Marina Kasprzaka in Warsaw",
    ],
    ".kopernik.edu.pl": [
        "XXXIII Liceum Ogólnokształcące Dwujęzyczne im. Mikołaja Kopernika w Warszawie"
    ],
    ".kozminski.edu.pl": ["Akademia Leona Koźmińskiego", "Kozminski University"],
    ".ksw.edu.pl": ["Andrzej Frycz Modrzewski Cracow College"],
    ".kwspz.edu.pl": ["Krakowska Wyższa Szkoła Promocji Zdrowia"],
    ".law.edu.pl": ["Lotnicza Akademia Wojskowa"],
    ".lazarski.edu.pl": ["Uczelnia Łazarskiego", "Lazarski University"],
    ".lckziu.edu.pl": ["Lubelskie Centrum Kształcenia Zawodowego i Ustawicznego"],
    ".gsuite.pwsz.legnica.edu.pl": [
        "The Witelon State University of Applied Sciences in Legnica",
        "Państwowa Wyższa Szkoła Zawodowa im Witelona w Legnicy",
    ],
    ".stud.pwsz.legnica.edu.pl": [
        "The Witelon State University of Applied Sciences in Legnica",
        "Państwowa Wyższa Szkoła Zawodowa im Witelona w Legnicy",
    ],
    ".studenci.pwsz.legnica.edu.pl": [
        "The Witelon State University of Applied Sciences in Legnica",
        "Państwowa Wyższa Szkoła Zawodowa im Witelona w Legnicy",
    ],
    ".pwsz.legnica.edu.pl": [
        "Państwowa Wyższa Szkoła Zawodowa im. Witelona w Legnicy",
        "The Witelon State University of Applied Sciences in Legnica",
    ],
    ".uczen.liceum-andrychow.edu.pl": [
        "Liceum Ogólnokształczące im. Mari Skłodowskiej-Curie nr 1"
    ],
    ".lo49.edu.pl": [
        "XLIX Liceum Ogólnokształcące Z Oddziałami Dwujęzycznymi im. Johanna Wolfganga Goethego",
        "Johann Wolfang Goethe 49th High School in Warsaw",
    ],
    ".mateja.edu.pl": ["II Liceum Ogólnokształcące im. Jana Matejki"],
    ".mimuw.edu.pl": [
        "The University of Warsaw",
        "Uniwersytet Warszawski",
        "Faculty of Mathematics, Informatics and Mechanics",
        "Wydział Matematyki, Informatyki i Mechaniki Uniwersytetu Warszawskiego (MIMUW)",
    ],
    ".narwik.edu.pl": ["Zespół Szkół im. Bohaterów Narwiku"],
    ".nencki.edu.pl": [
        "Instytut Biologii Doświadczalnej im. M. Nenckiego PAN",
        "Nencki Institute of Experimental Biology PAS",
    ],
    ".nobell.edu.pl": ["NoBell"],
    ".pack.edu.pl": [
        "VIII Prywatne Akademickie Liceum Ogólnokształcące",
        "Private Academic High School No 8 of Krakow, Poland",
    ],
    ".pb.edu.pl": ["Bialystok University of Technology"],
    ".pbs.edu.pl": ["Bydgoszcz University of Science and Technology"],
    ".pg.edu.pl": ["Technical University of Gdansk"],
    ".pio.edu.pl": ["Katolicka Szkoła Podstawowa im. św. Ojca Pio w Zamościu"],
    ".pja.edu.pl": ["Polish-Japanese Academy of Information Technology in Warsaw"],
    ".pjwstk.edu.pl": ["Polish-Japanese Institute of Information Technology in Warsaw"],
    ".pk.edu.pl": ["Technical University of Cracow"],
    ".student.po.edu.pl": ["Opole University of Technology", "Politechnika Opolska"],
    ".pollub.edu.pl": ["Lublin University of Technology"],
    ".prz.edu.pl": ["Politechnika Rzeszowska im. Ignacego Łukasiewicza"],
    ".pspo.edu.pl": [
        "Liceum Ogólnokształcące Niepubliczne nr 43 z Oddziałami Dwujęzycznymi"
    ],
    ".student.pswbp.edu.pl": [
        "Państwowa Szkoła Wyższa im. Papieża Jana Pawła II w Białej Podlaskiej",
        "Pope John Paul II State School Of Higher Education in Biała Podlaska",
    ],
    ".ptz.edu.pl": [
        "Prywatne Technikum Zawodowe w Nowym Sączu",
        "Technical school Prywatne Technikum Zawodowe in Nowy Sącz",
    ],
    ".puls.edu.pl": ["Poznan University of Life Sciences"],
    ".pum.edu.pl": ["Pomorski Uniwersytet Medyczny w Szczecinie"],
    ".put.edu.pl": ["Technical University of Poznan"],
    ".student.puzim.edu.pl": [
        "Państwowa Uczelnia Zawodowa im. Ignacego Mościckiego w Ciechanowie"
    ],
    ".pw.edu.pl": ["Warsaw University of Technology"],
    ".pwr.edu.pl": ["Wrocław University of Technology"],
    ".pwsip.edu.pl": [
        "Państwowa Wyższa Szkoła Informatyki i Przedsiębiorczości w Łomży",
        "Lomza State University of Applied Sciences",
    ],
    ".pwste.edu.pl": [
        "Panstwowa Wyzsza Szkola Techniczno-Ekonomiczna w Jaroslawiu",
        "The State Higher School of Technology and Economics in Jaroslaw",
    ],
    ".m.student.pwsz.edu.pl": [
        "PWSZ im. J.A. Komeńskiego w Lesznie",
        "Jan Amos Komeński State School of Higher Vocational Education in Leszno",
    ],
    ".student.pwsz.edu.pl": ["PWSZ Leszno, Poland"],
    ".studenci.pwsz-gniezno.edu.pl": [
        "Państwowa Wyższa Szkoła Zawodowa im. Hipolita Cegielskiego w Gnieźnie"
    ],
    ".pwsz-kalisz.edu.pl": ["Państwowa Wyższa Szkoła Zawodowa w Kaliszu"],
    ".pwsz-ns.edu.pl": ["\ufeffPaństwowa Wyższa Szkoła Zawodowa w Nowym Sączu"],
    ".pwszchelm.edu.pl": [
        "Państwowa Wyższa Szkoła Zawodowa w Chełmie",
        "The State School of Higher Education in Chełm",
    ],
    ".student.pwsztar.edu.pl": ["Państwowa Wyższa Szkoła Zawodowa w Tarnowie"],
    ".pwsztar.edu.pl": [
        "Państwowa Wyższa Szkoła Zawodowa w Tarnowie",
        "State Higher Vocational School in Tarnów",
    ],
    ".realizacjadzwieku.edu.pl": [
        "Akademia Dziennikarstwa i Realizacji Dźwięku",
        "Academy of Journalism and Sound Editing",
    ],
    ".san.edu.pl": ["Społeczna Akademia Nauk"],
    ".sci.edu.pl": ["Szczecinskie Technikum Informatyczne SCI"],
    ".sggw.edu.pl": [
        "Szkoła Głowna Gospodarstwa Wiejskiego",
        "Warsaw University of Life Science",
    ],
    ".skarga.edu.pl": ["Katolicki Zespół Edukacyjny"],
    ".smcebi.edu.pl": ["Silesian Centre for Education and Interdisciplinary Research"],
    ".sp341.edu.pl": [
        'Szkoła Podstawowa z Oddziałami Integracyjnymi nr 341 Im. "Twórców Literatury Dziecięcej"'
    ],
    ".sp6rumia.edu.pl": [
        "Szkola Podstawowa nr 6 w Rumi",
        "Elementary School 6 in Rumia",
    ],
    ".spark.edu.pl": ["Spark Academy - Liceum Ogólnokształcące"],
    ".stonabemowie.edu.pl": [
        "Zespół Szkół STO na Bemowie (Warszawa)",
        "STO School Complex on Bemowo (Warsaw)",
    ],
    ".student-afm.edu.pl": [
        "Krakowska Akademia im. Andrzeja Frycza Modrzewskiego",
        "Andrzej Frycz Modrzewski Krakow University",
    ],
    ".sum.edu.pl": ["Śląski Uniwersytet Medyczny", "Medical University of Silesia"],
    ".swps.edu.pl": ["Warsaw School of Social Psychology"],
    ".szkolakolumba.edu.pl": [
        "Niepubliczna szkoła podstawowa nr 1 im. Krzysztofa Kolumba w Żyrardowie"
    ],
    ".teb.edu.pl": ["Technikum TEB Edukacja"],
    ".tis.edu.pl": [
        "Centrum Kształcenia Zawodowego i Ustawicznego w Strzelinie (Technikum Strzelin)"
    ],
    ".tm1.edu.pl": ["Zespół Szkół Licealnych i Technicznych nr 1 w Warszawie"],
    ".tyszkiewicz.edu.pl": [
        "Józef Tyszkiewicz College of Business and Computer Science in Bielsko-Biala"
    ],
    ".tzn.edu.pl": [
        "Technikum nr 5 w Częstochowie ",
        "Technical Secondary School No. 5 in Częstochowa",
    ],
    ".student.tzndg.edu.pl": ["Techniczne Zakłady Naukowe w Dąbrowie Górniczej"],
    ".student.uczelniaoswiecim.edu.pl": [
        "Małopolska Uczelnia Państwowa imienia rotmistrza Witolda Pileckiego w Oświęcimiu",
        "The Witold Pilecki University of Applied Sciences in Oświęcim",
    ],
    ".uekat.edu.pl": ["University of Economics in Katowice"],
    ".ug.edu.pl": ["University of Gdansk"],
    ".uj.edu.pl": ["Jagiellonian University Cracow"],
    ".student.ujk.edu.pl": [
        "Uniwersytet Jana Kochanowskiego w Kielcach",
        "Jan Kochanowski University in Kielce",
    ],
    ".ujk.edu.pl": [
        "Uniwersytet Jana Kochanowskiego w Kielcach",
        "Jan Kochanowski University (JKU) in Kielce",
    ],
    ".uksw.edu.pl": ["Cardinal Stefan Wyszynski University in Warsaw"],
    ".ukw.edu.pl": ["Kazimierz Wielki University"],
    ".umb.edu.pl": [
        "Uniwersytet Medyczny w Białymstoku",
        "Medical University of Bialystok",
    ],
    ".live.umcs.edu.pl": ["Maria Curie Skłodowska University in Lublin"],
    ".umg.edu.pl": ["Gdynia Maritime University"],
    ".ump.edu.pl": [
        "Uniwersytet Medyczny im. Karola Marcinkowskiego w Poznaniu",
        "Poznan University of Medical Sciences",
        "Domains:",
        "@ump.edu.pl ",
        "@student.ump.edu.pl - studenta, PhD candidates",
    ],
    ".student.up.edu.pl": [
        "Uniwersytet Przyrodniczy w Lublinie",
        "University of Life Science in Lublin",
    ],
    ".uph.edu.pl": [
        "Siedlce University of Natural Sciences and Humanities",
        "Uniwersytet Przyrodniczo-Humanistyczny w Siedlcach",
    ],
    ".upjp2.edu.pl": [
        "Uniwersytet Papieski Jana Pawła II w Krakowie",
        "Pontifical University of John Paul II",
    ],
    ".student.upwr.edu.pl": [
        "Uniwersytet Przyrodniczy we Wrocławiu",
        "Wrocław University of Environmental and Life Sciences",
    ],
    ".upwr.edu.pl": [
        "Uniwersytet Przyrodniczy we Wrocławiu",
        "Wroclaw University of Environmental and Life Science",
    ],
    ".ur.edu.pl": ["Uniwersytet Rzeszowski", "University of Rzeszow"],
    ".urk.edu.pl": [
        "UNIWERSYTET ROLNICZY IM. HUGONA KOŁŁĄTAJA W KRAKOWIE",
        "UNIVERSITY OF AGRICULTURE IN KRAKOW",
    ],
    ".us.edu.pl": ["University of Silesia"],
    ".usz.edu.pl": ["University of Szczecin"],
    ".uth.edu.pl": ["Helena Chodkowska University of Technology and Economics"],
    ".uw.edu.pl": ["University of Warsaw"],
    ".uwb.edu.pl": ["University of Bialystok"],
    ".uwm.edu.pl": ["University of Wamia and Masuria in Olsztyn"],
    ".uwr.edu.pl": ["University of Wroclaw"],
    ".viiipalo.edu.pl": [
        "VIII Prywatne Akademickie Liceum Ogólnokształcące",
        "VIII PALO",
        "8th Private Academic High School",
    ],
    ".vilo.edu.pl": ["\ufeffVI Liceum Ogólnokształcące w Białymstoku "],
    ".vistula.edu.pl": ["Akademia Finansow i Biznesu Vistula"],
    ".wat.edu.pl": ["Military University of Technology in Warsaw"],
    ".wit.edu.pl": [
        "Warsaw School of Information Technology",
        "Wyższa Szkoła Informatyki Stosowanej i Zarządzania",
    ],
    ".wsb-nlu.edu.pl": [
        "Higher School o Business/National Louis University(WSB/NLU) in Nowy Sacz"
    ],
    ".wsb.edu.pl": ["Akademia WSB", "WSB University"],
    ".wsei.edu.pl": [
        "Higher School of Economics and Computer Science in Krakow",
        "Wyższa Szkoła Ekonomii i Informatyki w Krakowie",
        "WSEI",
    ],
    ".wseiz.edu.pl": ["Wyższa Szkoła Ekologii i Zarządzania"],
    ".wsfip.edu.pl": ["Bielsko-Biala School of Finances and Law"],
    ".wsfiz.edu.pl": ["University of Finance and Management in Bialystok"],
    ".wsge.edu.pl": [
        "Wyższa Szkoła Gospodarki Euroregionalnej im. Alcide de Gasperi w Józefowie"
    ],
    ".wsh.edu.pl": ["Aleksander Gieysztor School of Humanities in Pultusk"],
    ".wsinf.edu.pl": ["College of Computer Science in Lodz"],
    ".wsisiz.edu.pl": ["Warsaw School of Information Technology"],
    ".wsiz.edu.pl": [
        "University of Information Technology and Management in Rzeszow",
        "Wyższa Szkoła Informatyki i Zarządzania w Rzeszowie",
    ],
    ".wsksim.edu.pl": ["\ufeffWyższa Szkoła Kultury Społecznej i Medialnej"],
    ".wsosp.edu.pl": ["Polish Air Force Academy"],
    ".wspa.edu.pl": [
        "Wyższa Szkoła Przedsiębiorczości i Administracji w Lublinie",
        "University College of Enterprise and Administration in Lublin ",
        "WSPA",
    ],
    ".wspiz.edu.pl": [
        "Leon Kozminski Academy of Entrepreneurship and Mangement",
        "Leon Kozminski Academy of Entrepreneurship and Mangement in Warsaw",
    ],
    ".wszib.edu.pl": [
        "The School of Banking and Management in Cracow",
        "Wyższa Szkoła Zarządzania i Bankowości w Krakowie",
    ],
    ".wszim.edu.pl": ["University of Management and Marketing"],
    ".student.wum.edu.pl": [
        "Warszawski Uniwersytet Medyczny",
        "Medical University of Warsaw",
    ],
    ".wum.edu.pl": ["Warszawski Uniwersytet Medyczny", "Medical University of Warsaw"],
    ".wumed.edu.pl": ["Warszawska Uczelnia Medyczna im. Tadeusza Koźluka"],
    ".wwsi.edu.pl": [
        "Warsaw School of Computer Science",
        "Warszawska Wyższa Szkoła Informatyki",
        "http://www.wwsi.edu.pl/",
    ],
    ".zamoyski.edu.pl": [
        "XVIII Liceum Ogólnokształcące im. Jana Zamoyskiego w Warszawie"
    ],
    ".zs1piekary.edu.pl": ["ZESPÓŁ SZKÓŁ NR 1"],
    ".zseil.edu.pl": [
        "Zespół Szkół Elektronicznych i Licealnych",
        "Complex of Electronic and Secondary Schools",
    ],
    ".ucn.zsem.edu.pl": [
        "Zespół Szkół Elektryczno-Mechanicznych im. gen. Józefa Kustronia"
    ],
    ".zsgdow.edu.pl": ["Zespół Szkół Gdów", "School Complex in Gdów"],
    ".zspwni.edu.pl": ["Szkoła Podstawowa w Nowej Iwicznej"],
    ".zst-ostrow.edu.pl": [
        "Zespół Szkół Technicznych w Ostrowie Wielkopolskim",
        "Technical School Complex in Ostrów Wielkopolski",
    ],
    ".zst-sopot.edu.pl": ["Zespół Szkół Technicznych w Sopocie", "ZSTSOPOT"],
    ".zstio.edu.pl": [
        "Zespół Szkół Technicznych i Ogólnokształcacych im. Jana Pawła II"
    ],
    ".zsz1.edu.pl": ["Zespół Szkół Zawodowych nr 1 w Białej Podlaskiej"],
    ".zszpultusk.edu.pl": [
        "Zespół Szkół Zawodowych im. Jana Ruszkowskiego w Pułtusku",
        "Vocational School Complex Jan Ruszkowski in Pułtusk",
    ],
    ".zut.edu.pl": ["Zachodniopomorska School of Science and Engineering"],
    ".uczen.eduwarszawa.pl": [
        "Szkoły publiczne w Warszawie (domena zbiorowa)",
        "Public schools in Warsaw (collective domain)",
    ],
    ".pwsz.elblag.pl": ["The State School of Higher Professional Education in Elbląg"],
    ".edu.erzeszow.pl": [
        "Rzeszowskie Szkoły w Chmurze Microsoft - platforma Office 365 dla edukacji",
        ".group",
    ],
    ".ezse.pl": [
        "ZESPÓŁ SZKÓŁ ELEKTRYCZNYCH W KIELCACH",
        "ZESPÓŁ SZKÓŁ ELEKTRYCZNYCH W KIELCACH",
    ],
    ".amg.gda.pl": ["Medical Academy in Gdansk"],
    ".amuz.gda.pl": ["Music Academy Stanislaw Moniuszko in Gdansk"],
    ".asp.gda.pl": ["Fine Arts Academy in Gdansk"],
    ".awf.gda.pl": ["Physical Education Academy Jedrzej Sniadecki in Gdansk"],
    ".pg.gda.pl": ["Technical University of Gdansk"],
    ".univ.gda.pl": ["University of Gdansk"],
    ".wsb.gda.pl": ["Gdansk's School of Banking"],
    ".sp61.edu.gdansk.pl": [
        "Szkoła Podstawowa nr 61 w Gdansku",
        "Primary School no 61 in Gdansk",
    ],
    ".edu.gdansk.pl": [
        ".group",
        "Technikum Szkół Łączności w Gdańsku im. Obrońców Poczty Polskiej, Gdansk, Poland",
        "Technical High School of Communication in Gdansk named after defenders of the Polish Post Office, Gdansk, Poland",
    ],
    ".amw.gdynia.pl": ["Polish Naval Academy"],
    ".lo3.gdynia.pl": [
        "III Liceum Ogólnokształcące im. Marynarki Wojennej RP w Gdyni",
        "Navy 3rd High School in Gdynia",
    ],
    ".wsb.gdynia.pl": ["Wyższa Szkoła Bankowa w Gdańsku", "WSB University in Gdańsk"],
    ".zsti.gliwice.pl": [
        "Zespół Szkół Techniczno-Informatycznych",
        "Informatics-Technical School",
    ],
    ".iimcb.gov.pl": [
        "International Institute of Molecular and Cell Biology in Warsaw (IIMCB)"
    ],
    ".ippt.gov.pl": [
        "Instytut Podstawowych Problemów Techniki Polskiej Akademii Nauk",
        "Institute of Fundamental Technological Research Polish Academy of Sciences",
    ],
    ".nencki.gov.pl": [
        "Nencki Institute of Experimental Biology, Polish Academy of Sciences"
    ],
    ".gwsh.pl": ["Katowice School of Economics"],
    ".lo1.info.pl": [
        "I Liceum Ogólnokształcące im. Marii Skłodowskiej-Curie w Ostrzeszowie"
    ],
    ".am.katowice.pl": ["Music Academy Karol Szymanowski in Katowice"],
    ".awf.katowice.pl": ["Physical Education Academy in Katowice"],
    ".slam.katowice.pl": ["Silesian Academy of Medicine in Katowice"],
    ".ue.katowice.pl": ["University of Economics in Katowice"],
    ".katowice.zdz.katowice.pl": [
        "Technikum Lotnicze w Katowicach",
        "Aviation Technical School in Katowice",
    ],
    ".tu.kielce.pl": ["Kielce University of Technology"],
    ".zsi.kielce.pl": [
        "Zespół Szkół Informatycznych im. gen. Józefa Hauke Bosaka w Kielcach",
        "Zespol Szkol Informatycznych im. gen. Jozefa Hauke Bosaka w Kielcach",
    ],
    ".zslt.klucznet.pl": ["ZSLT in Kluczbork"],
    ".kopernikus.pl": ["ZS 6 im. Mikołaja Kopernika"],
    ".tu.koszalin.pl": ["Koszalin University of Technology"],
    ".ae.krakow.pl": ["Academy of Economics in Cracow"],
    ".amuz.krakow.pl": ["Music Academy in Cracow"],
    ".ar.krakow.pl": ["Agricultural University of Cracow"],
    ".stud.asp.krakow.pl": ["Akademia Sztuk Pięknych w Krakowie"],
    ".awf.krakow.pl": ["University School of Physical Education"],
    ".lo31.krakow.pl": ["XXXI Liceum im. Romana Ingardena Kraków"],
    ".tk.krakow.pl": [
        "Technikum Komunikacyjne nr 25",
        "Technical School Of Communication 25",
    ],
    ".tl.krakow.pl": [
        "Zespół Szkół Łączności ",
        "im. Obrońców Poczty Polskiej w Gdańsku",
        "W KRAKOWIE",
    ],
    ".uek.krakow.pl": ["Cracow University of Economics"],
    ".up.krakow.pl": [
        "Pedagogical University of Cracow",
        "Uniwersytet Pedagogiczny w Krakowie",
    ],
    ".ur.krakow.pl": [
        "University of Agriculture in Cracow",
        "Uniwersytet Rolniczy w Krakowie",
    ],
    ".v-lo.krakow.pl": ["August Witkowski 5th High School"],
    ".wse.krakow.pl": ["native language Polish", "Wyższa Szkoła Europejska"],
    ".wsp.krakow.pl": ["Pedagogical University of Krakow"],
    ".wszib.krakow.pl": ["School of Banking and Management in Cracow"],
    ".zse.krakow.pl": [
        "Zespół Szkół Energetycznych nr 9 im.Tadeusza Kościuszki w Krakowie"
    ],
    ".zsel1.krakow.pl": [
        "Zespół Szkół Elektrycznych nr 1 w Krakowie",
        "Zespół Szkół Elektrycznych nr 1 w Krakowie",
    ],
    ".kpu.krosno.pl": ["Karpacka panstwowa uczelnia w krośnie"],
    ".kul.pl": ["John Paul II Catholic University of Lublin"],
    ".kwspz.pl": ["Krakowska Wyższa Szkoła Promocji Zdrowia"],
    ".lazarski.pl": ["Lazarski School of Commerce and Law"],
    ".zset.leszno.pl": ["Zespol Szkol Elektroniczno Telekomunikacyjnych w Lesznie"],
    ".liceumwchmurze.pl": ["Liceum w Chmurze"],
    ".lo-niepolomice.pl": ["Zespół Szkół im. Ojca Świętego Jana Pawła II"],
    ".lo2gdynia.pl": [
        "II Liceum Ogólnokształcące z Oddziałami Dwujęzycznymi im. Adama Mickiewicza",
        "II Secondary School with Bilingual Departments Adam Mickiewicz in Gdynia",
    ],
    ".lobiecz.pl": ["Liceum Ogólnokształcące im. Stanisława Wyspiańskiego w Bieczu"],
    ".ahe.lodz.pl": [
        "Akademia Humanistyczno-Ekonomiczna w Łodzi",
        "University of Humanities and Economics in Lodz",
    ],
    ".edu.p.lodz.pl": ["Technical University of Lodz"],
    ".p.lodz.pl": ["Lodz University of Technology"],
    ".stud.umed.lodz.pl": [
        "Uniwersytet Medyczny w Łodzi",
        "Medical University of Lodz",
    ],
    ".umed.lodz.pl": ["Uniwersytet Medyczny w Łodzi", "Medical University of Lodz"],
    ".math.uni.lodz.pl": ["Faculty of Mathematics and Computer Science"],
    ".uni.lodz.pl": ["University Of Lodz"],
    ".jadwiga.lublin.pl": [
        "Prywatna Szkola Podstawowa i Liceum im. Krolowej Jadwigi w Lublinie",
        "@jadwiga.lublin.pl",
        "@live.edja.pl",
        "@edja.pl",
    ],
    ".kul.lublin.pl": [
        "John Paul II Catholic University of Lublin",
        "@student.kul.lublin.pl",
        "@kul.lublin.pl",
        "@kul.pl",
    ],
    ".paderewski.lublin.pl": [
        "Międzynarodowe Liceum Ogólnokształcące Paderewski w Lublinie",
        "Paderewski International High School in Lublin",
    ],
    ".umcs.lublin.pl": ["Maria Curie Skłodowska University in Lublin"],
    ".wsei.lublin.pl": ["University of Economics and Innovation in Lublin"],
    ".student.akademia.mil.pl": ["Akademia Sztuki Wojennej", "War Studies University"],
    ".law.mil.pl": ["Lotnicza Akademia Wojskowa"],
    ".mojasiodemka.pl": [
        "Szkoła Podstawowa nr 7 im. Erazma z Rotterdamu, ul. Galileusza 14, 60-158 Poznań"
    ],
    ".mojcosinus.pl": ["Cosinus"],
    ".muzycznaradom.pl": ["Oskar Kolberg Music School Complex in Radom"],
    ".st.pwsz.nysa.pl": ["Państwowa Wyższa Szkoła Zawodowa w Nysie"],
    ".po.opole.pl": ["Technical University of Opole"],
    ".uni.opole.pl": ["University of Opole"],
    ".student.wsb.opole.pl": ["Wyższa Szkoła Bankowa we Wrocławiu"],
    ".eszkola.opolskie.pl": [
        "Zespół Szkół Elektrycznych  im. Tadeusza Kościuszki w Opolu "
    ],
    ".pcz.pl": ["Czestochowa University of Technology"],
    ".liceum.pijarzy.pl": [
        "Liceum Ogólnokształcące Zakonu Pijarów im. ks. Stanisława Konarskiego w Krakowie",
        "High School of the Piarist Order them. Fr. Stanisław Konarski in Krakow",
    ],
    ".pwsz.pila.pl": ["Staszic Pila College"],
    ".pollub.pl": ["Lublin University of Technology"],
    ".polsl.pl": ["Silesian University of Technology"],
    ".au.poznan.pl": ["Agricultural University of Poznan"],
    ".awf.poznan.pl": ["Physical Education Academy Eugeniusz Piasecki in Poznan"],
    ".ibch.poznan.pl": [
        "Institute of Bioorganic Chemistry, Polish Academy of Sciences"
    ],
    ".ilim.poznan.pl": ["The Institute of Logistics and Warehousing (ILiM)"],
    ".put.poznan.pl": ["Technical University of Poznan"],
    ".ue.poznan.pl": ["Poznan University of Economics"],
    ".up.poznan.pl": ["Poznan University Of Life Sciences"],
    ".usoms.poznan.pl": ["Medical Academy \x93Karol Marcinkowski\x94 in Poznan"],
    ".wsb.poznan.pl": ["Poznan School of Banking"],
    ".zsk.poznan.pl": ["Zespół Szkół Komunikacji im. Hipolita Cegielskiego"],
    ".dydaktyka.pswbp.pl": [
        "Państwowa Szkoła Wyższa im. Papieża Jana Pawła II w Białej Podlaskiej",
        "Pope John Paul II State School Of Higher Education in Biała Podlaska",
    ],
    ".student.pswbp.pl": [
        "Państwowa Szkoła Wyższa im. Papieża Jana Pawła II w Białej Podlaskiej",
        "Pope John Paul II State School Of Higher Education in Biała Podlaska",
    ],
    ".pwste.pl": [
        "The Bronisław Markiewicz State Higher School of Technology and Economics in Jarosław"
    ],
    ".pwsz.pl": [
        "The Jacob of Paradyz University of Applied Sciences in Gorzow Wielkopolski"
    ],
    ".pwszchelm.pl": [
        "Państwowa Wyższa Szkoła Zawodowa w Chełmie",
        "The State School of Higher Education in Chełm",
    ],
    ".pzsbierun.pl": ["Powiatowy Zespół Szkół w Bieruniu (PZS Bieruń)"],
    ".zss.q4.pl": ["\ufeffZespół Szkół Samochodowych we Włocławku"],
    ".2lo.radom.pl": ["Maria Konopnicka 2nd High School in Radom"],
    ".czachowski.radom.pl": ["Dionizy Czachowski 3rd High School in Radom"],
    ".man.radom.pl": ["Technical University of Radom"],
    ".1lo.rzeszow.pl": [
        "I Liceum Ogólnokształcące w Rzeszowie  im. ks. Stanisława Konarskiego"
    ],
    ".prz.rzeszow.pl": ["Technical University of Rzeszow"],
    ".urstud.rzeszow.pl": ["University of Rzeszow"],
    ".student.wsiz.rzeszow.pl": [
        "University of Information Technology and Management in Rzeszow",
        "Wyższa Szkoła Informatyki i Zarządzania w Rzeszowie",
    ],
    ".wsiz.rzeszow.pl": [
        "University of Information Technology and Management in Rzeszow",
        "Wyższa Szkoła Informatyki i Zarządzania w Rzeszowie",
    ],
    ".sggw.pl": ["Warsaw University of Life Sciences"],
    ".ap.siedlce.pl": ["Akademia Podlaska"],
    ".sbs.sniadek.pl": [
        "II LICEUM OGÓLNOKSZTAŁCĄCE IM. JANA ŚNIADECKIEGO W KIELCACH",
        "Second High comprehensive school Jana Śniadeckiego in Kielce",
    ],
    ".sp13bielsko.pl": ["Szkoła Podstawowa nr 13"],
    ".lodz.spsk.pl": ["Katolicka Szkola Lodz"],
    ".stipendium.pl": ["Institute of Science and Technology Stipendium"],
    ".studentwsei.pl": ["University of Economics and Innovation in Lublin"],
    ".zst.suwalki.pl": ["Group of Technical Schools"],
    ".am.szczecin.pl": ["Maritime University in Szczecin"],
    ".ar.szczecin.pl": ["Agricultural University of Szczecin"],
    ".tuniv.szczecin.pl": ["Technical University of Szczecin"],
    ".univ.szczecin.pl": ["University of Szczecin"],
    ".student.wsb.szczecin.pl": [
        "Wyższa Szkoła Bankowa w Szczecinie",
        "School of Banking",
    ],
    ".zpsb.szczecin.pl": ["West Pomeranian Business School in Szczecin"],
    ".szkola1.pl": [
        "Zespół Szkół Nr 1 Centrum Kształcenia Praktycznego w Aleksandrowie Kujawskim."
    ],
    ".iii-lo.tarnow.pl": ["III Liceum Ogólnokształcące"],
    ".zsme.tarnow.pl": ["Zespół Szkół Mechaniczno-Elektrycznych w Tarnowie"],
    ".technikumkreatywne.pl": ["Technikum Kreatywne w Szczecinie"],
    ".gimakad.torun.pl": ["Gimnazjum i Liceum Akademickie w Toruniu"],
    ".loiv.torun.pl": [
        "IV Liceum Ogólnokształcące im. Tadeusza Kościuszki w Toruniu",
        "General Tadeusz Kosciuszko High School #4 in Torun",
    ],
    ".student.wsb.torun.pl": ["Wyższa Szkoła Bankowa w Toruniu"],
    ".zsmeie.torun.pl": [
        "Zespół Szkół Mechanicznych Elektrycznych i Elektronicznych im. prof. Sylwestra Kaliskiego w Toruniu",
        "Professor Sylwester Kaliski Mechanical School Of Electrical And Electronic in Torun",
    ],
    ".uekat.pl": ["University of Economics in Katowice"],
    ".student.ujw.pl": ["Uczelnia Jana Wyżykowskiego", "Jan Wyżykowski University"],
    ".office.umcs.pl": [
        "Uniwersytet Marii Curie-Skłodowskiej w Lublinie",
        "Maria Curie-Skłodowska University",
    ],
    ".umk.pl": ["Nicolaus Copernicus University in Toruń"],
    ".student.umlub.pl": [
        "Medical University of Lublin",
        "@student.umlub.pl",
        "@umlub.pl",
    ],
    ".umlub.pl": ["Medical University of Lublin", "@student.umlub.pl", "@umlub.pl"],
    ".uth.pl": ["Helena Chodkowska University of Technology and Economics"],
    ".uthrad.pl": ["Technical University of Radom"],
    ".vizja.pl": [
        "Wyższa Szkoła Finansów i Zarządzania w Warszawie",
        "University of Finance aand Management in Warsaw",
    ],
    ".student.wsb.warszawa.pl": ["Wyższa Szkoła Bankowa w Warszawie"],
    ".wsm.warszawa.pl": [
        "Warsaw Management University",
        "Wyzsza Szkola Menedzerska w Warszawie",
    ],
    ".asp.waw.pl": ["Fine Arts Academy in Warsaw"],
    ".cbk.waw.pl": [
        "Centrum Badań Kosmicznych Polskiej Akademii Nauk",
        "Space Research Centre of the Polish Academy of Sciences",
    ],
    ".ibb.waw.pl": [
        "Institute of Biochemistry and Biophysics Polish Academy of Sciences"
    ],
    ".ibspan.waw.pl": [
        "Systems Research Institute Polish Academy of Sciences",
        "Instytut Badan Systemowych Polskiej Akademii Nauk",
    ],
    ".ipipan.waw.pl": ["Institute of Computer Science Polish Academy of Sciences"],
    ".lopiaseczno.waw.pl": [
        "IV Liceum Ogólnokształcące im. rtm. Witolda Pileckiego w Piasecznie",
        "Witold Pilecki 4th High School in Piaseczno",
    ],
    ".sggw.waw.pl": ["Agricultural University of Warsaw"],
    ".sgh.waw.pl": ["Warsaw School of Economics"],
    ".staszic.waw.pl": [
        "XIV Liceum Ogólnokształcące im. Stanisława Staszica w Warszawie",
        "Stanisław Staszic 14th High School in Warsaw",
    ],
    ".puz.wloclawek.pl": [
        "Państwowa Uczelnia Zawodowa we Włocławku",
        "State Vocational University in Włocławek",
    ],
    ".pwsz.wloclawek.pl": ["National Higher Vocational School of Wloclawek"],
    ".2lo.wlodawa.pl": [
        "Zespół Szkół Zawodowych Nr 1 i II Liceum Ogólnokształcące we Włodawie"
    ],
    ".wlodkowic.pl": ["Pawel Wlodkowic University College in Plock"],
    ".ZS1.wroc.pl": ["ZS nr 1 we Wrocławiu - IT specialist"],
    ".am.wroc.pl": ["Medical Academy in Wroclaw"],
    ".amuz.wroc.pl": ["Music Academy Karol Lipinski in Wroclaw"],
    ".ar.wroc.pl": ["Agricultural University of Wroclaw"],
    ".asp.wroc.pl": ["Fine Arts Academy in Wroclaw"],
    ".awf.wroc.pl": ["Physical Education Academy in Wroclaw"],
    ".lo16.wroc.pl": ["XVI Liceum Wrocław"],
    ".pwr.wroc.pl": ["Wrocław University of Technology"],
    ".ue.wroc.pl": ["Academy of Economics in Wroclaw"],
    ".umed.wroc.pl": [
        "Uniwersytet Medyczny im. Piastów Śląskich we Wrocławiu",
        "Wroclaw Medical University",
        "+Faculty of Pharmacy with Division of Laboratory Diagnostics",
    ],
    ".uni.wroc.pl": ["University of Wroclaw"],
    ".up.wroc.pl": ["Wroclaw University of Environmental and Life Sciences"],
    ".wsiz.wroc.pl": ["Wyższa Szkoła Informatyki i Zarządzania we Wrocławiu"],
    ".wsb.wroclaw.pl": ["WSB University in Wroclaw"],
    ".wroclawskaedukacja.pl": [
        "I Liceum Ogólnokształcące im. Danuty Siedzikówny „Inki” we Wrocławiu"
    ],
    ".chorzow.wsb.pl": ["Chorzow/Katowice branch of Higher School of Business"],
    ".wseh.pl": ["University of Economics and Humanities"],
    ".student.wsg.pl": ["Wyższa Szkoła Gospodarki", "University of Economy"],
    ".wsiz.pl": [
        "University of Information Technology and Management in Rzeszow",
        "Wyższa Szkoła Informatyki i Zarządzania w Rzeszowie",
    ],
    ".wsnhid.pl": ["School of Humanities and Journalism"],
    ".wsosp.pl": ["Polish Air Force Academy"],
    ".wspa.pl": ["The University College of Enterprise and Administration in Lublin"],
    ".office.wst.pl": [
        "Wyższa Szkoła Techniczna w Katowicach",
        "University of Technology, Katowice, Poland",
    ],
    ".stud.wst.pl": [
        "Wyższa Szkoła Techniczna w Katowicach",
        "University of Technology, Katowice, Poland",
    ],
    ".wst.pl": [
        "Wyższa Szkoła Techniczna w Katowicach",
        "University of Technology, Katowice, Poland",
    ],
    ".wsti.pl": ["Katowice Institute of Information Technologies"],
    ".wsz.pl": ["Gdansk Management College"],
    ".jedynka.zgora.pl": ["\ufeffI Liceum Ogólnokształcące im. Edwarda Dembowskiego"],
    ".uz.zgora.pl": ["University of Zielona Gora"],
    ".zpsb.pl": [
        "Zachodniopomorska Szkoła Biznesu w Szczecinie",
        "West Pomeranian School of Business",
    ],
    ".zs1-swarzedz.pl": ["Zespół Szkół nr 1 im. Powstańców Wielkopolskich w Swarzędzu"],
    ".zs1piaseczno.pl": ["Zespół Szkół Nr 1 w Piasecznie"],
    ".zsdil.pl": [
        "Zespół Szkół Technicznych i Leśnych w Żywcu",
        "Complex of Technical and Forest Schools in Żywiec",
    ],
    ".zsel1.pl": ["Zespół Szkół Elektrycznych nr 1 im. Powstańców Śląskich w Krakowie"],
    ".zsepoznan.pl": ["Zespół Szkół Ekonomicznych im. Stanisława Staszica w Poznaniu"],
    ".zsp2garwolin.pl": [
        "Zespol Szkol Ponadgimnazjalnych nr 2 Centrum Ksztalcenia Praktycznego w Garwolinie"
    ],
    ".zspwrzesnia.pl": ["Zespół Szkół Politechnicznych we Wrześni"],
    ".zstchelm.pl": ["Zespół Szkół Technicznych w Chełmie "],
    ".zstckziu.pl": [
        "Zespół Szkół Technicznych - Centrum Kształcenia Zawodowego i Ustawicznego"
    ],
    ".zszakrzewo.pl": ["Zespół Szkół w Zakrzewie"],
    ".zszglogow.pl": [
        "Zespół Szkół Politechnicznych w Głogowie",
        "Zespol Szkol Politechnicznych in Glogow",
    ],
    ".ucb.edu.pr": ["Universidad Central de Bayamón"],
    ".ut.pr": ["Universidad del Turabo"],
    ".alaqsa.edu.ps": ["Al-Aqsa University"],
    ".alazhar.edu.ps": ["Al-Azhar University of Gaza"],
    ".iugaza.edu.ps": ["Islamic University of Gaza"],
    ".ppu.edu.ps": [
        "Palestine Polytechnic University",
        "Palestine Polytechnic University",
    ],
    ".ptcdb.edu.ps": ["Palestine Technical College-Dier Elbalah"],
    ".ptuk.edu.ps": [
        "جامعة فلسطين التقنية - خضوري",
        "Palestine Technical University - Kadoorie",
    ],
    ".rb.edu.ps": ["\ufeffAlasra Althanwyt Llbnat Snjl School"],
    ".ucas.edu.ps": ["University College of Applied Sciences"],
    ".uou.edu.ps": ["Ummah University"],
    ".up.edu.ps": ["University of Palestine"],
    ".abs.pt": ["\ufeffAtlântico Business School"],
    ".aedah.pt": ["Escola Secundaria D. Afonso Henriques"],
    ".aeds.pt": ["Agrupamento de Escolas Domingos Sequeira"],
    ".aevf.pt": ["Vergílio Ferreira Secondary School"],
    ".atec.pt": ["ATEC - Academia de Formação"],
    ".autonoma.pt": ["Universidade Autónoma de Lisboa"],
    ".aebatalha.ccems.pt": [
        "Agrupamento de Escolas da Batalha",
        "Schools District of Batalha",
    ],
    ".cic.pt": ["\ufeffCOLÉGIO INTERNATO DOS CARVALHOS"],
    ".formandos.cinel.pt": [
        "CINEL - Centro de Formação Profissional da Indústria Electrónica, Energia, Telecomunicações e Tecnologias da Informação"
    ],
    ".colegiosaogoncalo.pt": ["Colégio de São Fgonçalo - Escola Católica"],
    ".colgaia.pt": ["Colégio de Gaia"],
    ".in.cscm-lx.pt": ["Colégio Sagrado do Coração de Maria"],
    ".ael.edu.pt": ["Agrupamento de Escolas das Laranjeiras"],
    ".espr.edu.pt": ["\ufeffEscola Secundária de Pinhal do Rei "],
    ".enautica.pt": ["Escola Nautica Infante D. Henrique"],
    ".enta.pt": ["ENTA - Escola de Novas Tecnologias dos Açores"],
    ".esad.pt": ["Escola Superior de Artes e Design"],
    ".alunos.esdacsf.pt": ["Escola Secundária Dr. Augusto César da Silva Ferreira"],
    ".esec.pt": ["ESEC - Escola Superior de Educação de Coimbra"],
    ".eshte.pt": ["Escola Superior de Hotelaria e Turismo do Estoril"],
    ".esmaior.pt": ["Santa Maria Maior School Group"],
    ".etla.pt": ["Escola Tecnológica do Litoral Alentejano"],
    ".etpsico.pt": ["Escola Tecnológica e Profissional de Sicó "],
    ".europeia.pt": ["Universidade Europeia"],
    ".ferreiradias.pt": ["\ufeffEscola Secundária Ferreira Dias"],
    ".edu.azores.gov.pt": ["Escola Secundária de Lagoa", "Lagoa High School"],
    ".iade.pt": ["Instituto de Artes Visuais, Design e Marketing - IADE"],
    ".formacao.iefp.pt": [
        "Instituto do Emprego e Formação Profissional ",
        "Institute for Employment and Vocational Training ",
    ],
    ".inp.pt": ["Instituto Superior Novas Profissões - INP"],
    ".inuaf-studia.pt": ["Instituto Superior D. Afonso III - INUAF"],
    ".ipb.pt": ["Instituto Politécnico de Bragança"],
    ".ipbeja.pt": ["Instituto Politécnico de Beja"],
    ".ipc.pt": ["Instituto Politécnico de Coimbra"],
    ".ipca.pt": ["Polytechnic Institute of Cavado and Ave"],
    ".ipcb.pt": ["Instituto Politécnico de Castelo Branco"],
    ".ipcbcampus.pt": ["Instituto Politécnico de Castelo Branco"],
    ".ipg.pt": ["Instituto Politécnico da Guarda"],
    ".isel.ipl.pt": [" Instituto Superior de Engenharia de Lisboa"],
    ".ipl.pt": ["Instituto Politécnico de Lisboa"],
    ".iplei.pt": ["Instituto Politécnico de Leiria"],
    ".ipleiria.pt": ["Polytechnic Institute of Leiria"],
    ".ipmaia.pt": ["Instituto Politécnico da Maia"],
    ".ipp.pt": ["Instituto Politecnico do Porto"],
    ".ipportalegre.pt": ["Instituto Politécnico de Portalegre"],
    ".estsetubal.ips.pt": [
        "Escola Superior de Tecnologia de Setúbal, Instituto Politécnico de Setúbal"
    ],
    ".estudantes.ips.pt": [
        "Escola Superior de Tecnologia de Setúbal, Instituto Politécnico de Setúbal"
    ],
    ".ips.pt": ["Instituto Politécnico de Setúbal"],
    ".ipsantarem.pt": ["Instituto Politécnico de Santarém"],
    ".ipt.pt": ["Instituto Politécnico de Tomar"],
    ".ipv.pt": ["Instituto Politécnico de Viseu"],
    ".ipvc.pt": ["Instituto Politécnico de Viana do Castelo"],
    ".isai.pt": ["Instituto Superior de Assistentes e Intérpretes"],
    ".isbb.pt": ["Instituto Superior Bissaya Barreto"],
    ".iscac.pt": ["Instituto Superior de Contabilidade e Administração de Coimbra"],
    ".iscet.pt": ["Instituto Superior de Ciências Empresariais e de Turismo"],
    ".iscte-iul.pt": ["ISCTE – University Institute of Lisbon"],
    ".iscte.pt": ["Instituto Superior de Ciências do Trabalho e da Empresa"],
    ".isec.pt": ["ISEC - Instituto Superior de Engenharia de Coimbra"],
    ".isel.pt": ["ISEL - Instituto Superior de Engenharia de Lisboa"],
    ".isg.pt": ["Instituto Superior de Gestão - ISG"],
    ".isla.pt": ["Instituto Superior de Línguas e Administração"],
    ".mail.islagaia.pt": [
        "ISLA - Instituto Politécnico de Gestão e Tecnologia",
        "ISLA - Polytechnic Institute of Management and Technology",
    ],
    ".ismai.pt": ["Instituto Superior da Maia"],
    ".ismat.pt": ["INSTITUTO SUPERIOR MANUEL TEIXEIRA GOMES"],
    ".ispa.pt": ["Instituto Superior de Psicologia Aplicada"],
    ".ispab.pt": ["Instituto Superior de Paços de Brandão"],
    ".ispgaya.pt": ["Instituto Superior Politécnico Gaya"],
    ".istec.pt": ["Instituto Superior de Tecnologias Avançadas - ISTEC"],
    ".istp.pt": ["Instituto Superior de Transportes e Comunicações"],
    ".novasbe.pt": ["Nova School of Business and Economics"],
    ".oml.pt": ["Academia Nacional Superior de Orquesta"],
    ".pedago.pt": ["Instituto Superior de Ciências Educativas"],
    ".ua.pt": ["Universidade de Aveiro"],
    ".uab.pt": ["Universidade Aberta Lisboa"],
    ".uac.pt": ["Universidade dos Acores"],
    ".students.ual.pt": ["Universidade Autónoma de Lisboa"],
    ".ual.pt": ["Universidade Autónoma de Lisboa"],
    ".ualg.pt": ["Universidade do Algarve"],
    ".uatlantica.pt": ["Universidade Altântica"],
    ".ubi.pt": ["Universidade da Beira Interior"],
    ".uc.pt": ["Universidade de Coimbra"],
    ".ucp.pt": ["Universidade Catolica Portuguesa"],
    ".ucpcrp.pt": ["Universidade Católica Portuguesa - Centro Regional do Porto"],
    ".uevora.pt": ["Universidade de Evora"],
    ".ufp.pt": ["Universidade Fernando Pessoa"],
    ".uinternacional.pt": ["Universidade Internacional Lisboa"],
    ".ul.pt": ["Universidade de Lisboa"],
    ".alunos.ulht.pt": ["Universidade Lusófona"],
    ".ulht.pt": ["Universidade Lusófona de Humanidades e Technologias"],
    ".ulisboa.pt": ["Universidade de Lisboa"],
    ".mso365.ulp.pt": ["Universidade Lusófona do Porto"],
    ".ulusiada.pt": ["Universidade Lusiada"],
    ".ulusofona.pt": ["Universidade Lusófona de Humanidades e Technologias"],
    ".student.uma.pt": ["Universidade da Madeira"],
    ".uma.pt": ["Universidade da Madeira"],
    ".uminho.pt": ["Universidade do Minho"],
    ".umoderna.pt": ["Universidade Moderna de Lisboa"],
    ".uni.pt": ["Universidade Independente"],
    ".universidade-autonoma.pt": [
        "Universidade Autónoma de Lisboa Luís de Camoes",
        "universidade-autonoma.pt , autonoma.pt and ual is for main site and employees",
        "students.ual.pt is for Students and teachers",
    ],
    ".universidadeeuropeia.pt": ["Universidade Europeia"],
    ".unl.pt": ["Universidade Nova de Lisboa"],
    ".up.pt": ["Universidade do Porto"],
    ".uportu.pt": ["Universidade Portucalense Infante D. Henrique"],
    ".alunos.upt.pt": ["Universidade Portucalense Infante D. Henrique"],
    ".utad.pt": ["Universidade de Tras-os-Montes e Alto Douro"],
    ".utl.pt": ["Universidade Tecnica de Lisboa"],
    ".columbia.edu.py": ["Universidad Columbia del Paraguay"],
    ".fpuna.edu.py": ["Facultad Politécnica"],
    ".uaa.edu.py": ["Universidad Autónoma de Asunción"],
    ".uamericana.edu.py": ["Universidad Americana"],
    ".uap.edu.py": ["Universidad Autónoma del Paraguay"],
    ".uc.edu.py": ["Universidad Católica Nuestra Senora de la Asunción"],
    ".uca.edu.py": ["Universidad Católica Nuestra Senora de la Asunción"],
    ".ucom.edu.py": ["Universidad Comunera"],
    ".ucsa.edu.py": ["Universidad del Cono Sur de las Américas"],
    ".uma.edu.py": ["Universidad Metropolitana de Asunción"],
    ".une.edu.py": ["Universidad Nacional del Este"],
    ".unida.edu.py": ["Universidad de la Integración de las Americas (UNIDAD)"],
    ".uninorte.edu.py": ["Universidad del Norte"],
    ".upe.edu.py": ["Universidad Privada del Este"],
    ".pol.una.py": ["Facultad Politécnica"],
    ".www.una.py": ["Universidad Nacional de Asunción"],
    ".cna-qatar.edu.qa": ["College of the North Atlantic"],
    ".qu.edu.qa": ["University of Qatar"],
    ".mila.quebec": ["Mila - Institut québécois d'intelligence artificielle"],
    ".academyplus.ro": ["Academy+Plus"],
    ".aisb.ro": ["American International School of Bucharest"],
    ".alexandrucelbun.ro": ["Colegiul Alexandru cel Bun Gura Humorului"],
    ".anmb.ro": ['Academia Navala "Mircea cel Batran"'],
    ".apizal.ro": [
        'Colegiul Tehnic "Alesandru Papiu Ilarian" Zalau, Romania',
        '"Alesandru Papiu Ilarian" Technical College from Zalau, Romania',
    ],
    ".arteiasi.ro": ["Academy of Arts George Enescu Iasi"],
    ".ase.ro": ["Academia de Studii Economice din Bucuresti"],
    ".bphasdeu.ro": [
        "Colegiul National 'Bogdan Petriceicu Hasdeu' Buzau",
        "National Collage 'Bogdan Petriceicu Hasdeu' Buzau",
    ],
    ".carabella.ro": ['Colegiul Național "Constantin Carabella"'],
    ".cndssm.ro": [
        "Colegiul Național „Doamna Stanca” Satu Mare",
        '"Doamna Stanca" National College, Satu Mare',
    ],
    ".cnelenacuza.ro": [
        "Colegiul National Elena Cuza Bucuresti",
        "Elena Cuza National College of Bucharest",
    ],
    ".cnfb.ro": ["Colegiul Național Frații Buzești", "Frații Buzești National College"],
    ".cnghsincai.ro": [
        "Colegiul National Gheorghe Sincai",
        '"Gheorghe Sincai" National College',
    ],
    ".cnhurmuzachi.ro": [
        "Colegiul Național „Eudoxiu Hurmuzachi” Rădăuți",
        '"Eudoxiu Hurmuzachi" National College, Radauti',
    ],
    ".cnimateibasarab.ro": [
        "Colegiul National de Informatica Matei Basarab",
        "National College of Informatics Matei Basarab",
    ],
    ".cnislavici.ro": [
        "Colegiul National „Ioan Slavici” Satu Mare",
        '"Ioan Slavici" National College, Satu Mare',
    ],
    ".cnivor.ro": [
        'Colegiul National "Iosif Vulcan"',
        'National College "Iosif Vulcan"',
    ],
    ".cnmv.ro": ["Colegiul National Mihai Viteazul", "Mihai Viteazul National College"],
    ".cnrv.ro": ["Colegiul National Roman Voda"],
    ".cnsm.ro": [
        "Colegiul National Stefan Cel Mare Targu-Neamt",
        'National College "Stephan the Great" Targu-Neamt',
    ],
    ".cnstefancelmare.ro": [
        'Colegiul National "Stefan cel Mare" Suceava',
        'National College "Stefan cel Mare" Suceava',
    ],
    ".cnszalau.ro": ["Colegiul National Silvania", "Silvania National College"],
    ".cnvgarad.ro": [
        "Colegiul Național „Vasile Goldiș” Arad",
        "„Vasile Goldiș” Arad National College",
    ],
    ".cnvranceanu.ro": [
        "Colegiul National Gheorghe Vranceanu Bacau",
        "Gheorghe Vranceanu National College",
    ],
    ".colegiulgib.ro": [
        'Colegiul National "Gib Mihaescu"',
        'National College "Gib Mihaescu"',
    ],
    ".utcluj.didatec.ro": ["Technical University of Cluj-Napoca"],
    ".e-racovita.ro": [
        'Colegiul Național "Emil Racoviță", Cluj-Napoca',
        'National College "Emil Racovita", Cluj-Napoca',
    ],
    ".e-uvt.ro": ["West University of Timisoara"],
    ".ecotgm.ro": [
        'Colegiul Economic "Transilvania" Târgu Mureș',
        '"Transilvania" Economic College of Târgu Mureș',
    ],
    ".elenacuza.ro": [
        "Colegiul National Elena Cuza Bucuresti",
        "Elena Cuza National College of Bucharest",
    ],
    ".emanuel.ro": ["Emanuel University"],
    ".stu.eminescusm.ro": [
        "Colegiul Național Mihai Eminescu Satu Mare",
        "C N Mihai Eminescu Satu Mare",
    ],
    ".student.faa.ro": [
        "Faculty of Administration and Business, University of Bucharest"
    ],
    ".gimi.ro": ["Liceul Teoretic Tamási Áron"],
    ".informatica.hyperion.ro": [
        '"Hyperion" Facultatea de Stiinte Exacte si Ingineresti',
        '"Hyperion" University of Exact Sciences and Engineering',
        "https://informatica.hyperion.ro/",
        "http://aei.geniu.ro/",
    ],
    ".iaim.ro": ["Institute of Architecture Ion Mincu Bucharest"],
    ".go.ibsb.ro": ["International British School Bucharest"],
    ".ibsb.ro": ["International British School Bucharest"],
    ".ichb.ro": [
        "Liceul International de Informatica Bucuresti",
        "International Informatics High School Bucharest ",
    ],
    ".idanubius.ro": ["Universitatea Danubius Galati, Romania"],
    ".kosiskola.ro": ["Liceul Tehnologic Kós Károly"],
    ".elevi.laurian.ro": [
        'Colegiul National "A.T. Laurian"',
        'National College "A.T. Laurian"',
    ],
    ".ldv.ro": [
        "Liceul Special pentru Deficienți de Vedere Cluj-Napoca",
        "Special High School for Visually Impaired Cluj-Napoca",
    ],
    ".liceulovidius.ro": [
        'Liceul Teoretic "Ovidius" Constanța',
        '"Ovidius" Theoretical Highschool',
    ],
    ".liceulprodeo.ro": [
        'Liceul Teoretic Crestin "Pro Deo", Cluj-Napoca',
        '"Pro Deo" Highschool, Cluj-Napoca',
    ],
    ".liceulsaligny-tr.ro": [
        'Liceul Tehnologic "Anghel Saligny" Roșiori de Vede',
        '"Anghel Saligny" Technological High School Roșiori de Vede',
    ],
    ".liceupetrila.ro": [
        "Colegiul Tehnic „Constantin Brâncuși” Petrila",
        '"Constantin Brâncuși" Technical College Petrila',
    ],
    ".liis.ro": [
        'Liceul Teoretic de Informatica "Grigore Moisil"',
        'High School of Computer Science "Grigore Moisil"',
    ],
    ".ltamg.ro": ['Liceul Teoretic "Adam Müller Guttenbrunn"'],
    ".ltsti.ro": [
        "Liceul Teoretic Sfintii Trei Ierarhi",
        "Three Holy Hierarchs High School",
        "http://www.ltsti.ro",
    ],
    ".moisenicoara.ro": [
        "Colegiul National Moise Nicoara",
        "Moise Nicoara National College",
    ],
    ".moisil.ro": [
        'Colegiul Național "Grigore Moisil" București',
        "Grigore Moisil National College (Bucharest)",
    ],
    ".moisilbv.ro": [
        "Colegiul Național de Informatică „Grigore Moisil” Brașov",
        'NCSC "Grigore Moisil" Brașov',
    ],
    ".mta.ro": ["Academia Tehnica Militara"],
    ".ogoga.ro": [
        'Liceul Teoretic "Octavian Goga" Huedin',
        '"Octavian Goga" Huedin Theoretical High School',
    ],
    ".onisifor-ghibu.ro": [
        'Liceul Teoretic "Onisifor Ghibu" Sibiu',
        'High School "Onisifor Ghibu" Sibiu',
    ],
    ".palloimre.ro": ["Liceul de Arte Dr. Palló Imre"],
    ".pedaudv.ro": ["Liceul Pedagogic Benedek Elek"],
    ".pub.ro": ["University POLITEHNICA of Bucharest"],
    ".rau.ro": ["Romanian-American University"],
    ".eminescu.rdsor.ro": [
        "Colegiul National Mihai Eminescu",
        "National College Mihai Eminescu",
    ],
    ".refkol.ro": ["Colegiul Reformat Baczkamadarasi Kis Gergely"],
    ".romanvoda.ro": ["Colegiul National Roman Voda"],
    ".sapientia.ro": ["Sapientia Hungarian University of Transylvania"],
    ".scoala19avramiancu-tm.ro": ["scoala gimnaziala nr 19 Timisoara"],
    ".scoala79.ro": ["Scoala Gimnaziala nr. 79", "Middle School no. 79"],
    ".scoalainformala.ro": ["Scoala Informala de IT"],
    ".scoalanr178.ro": [
        "Scoala nr 178, Bucuresti",
        "Middle School, Number 178, Bucharest, Sector 1",
    ],
    ".scoalaprincipesamargareta.ro": ["Scoala Principesa Margareta"],
    ".sibiu.ro": ["University of Sibiu"],
    ".sincaibm.ro": ["Colegiul Național „Gheorghe Șincai” Baia Mare"],
    ".snspa.ro": ["National School of Political and Administrative Studies Bucharest"],
    ".spiruharet.ro": ["Spiru Haret University"],
    ".traian-vuia.ro": ["Traian Vuia Bucuresti", "Traian Vuia Bucharest"],
    ".tuiasi.ro": ["Technical University of Iasi"],
    ".uab.ro": ["1 December University of Alba Iulia"],
    ".uaic.ro": ["University Alexandru Ioan Cuza of Iasi"],
    ".uartdcluj.ro": ["University of Art and Design Cluj-Napoca"],
    ".uat.ro": ["Targu-Mures University of Theatre"],
    ".uav.ro": ["University Aurel Vlaicu Arad"],
    ".ub.ro": ["University of Bacau"],
    ".ubbcluj.ro": ["Babes-Bolyai University of Cluj-Napoca"],
    ".ubm.ro": ["North University of Baia Mare"],
    ".ucv.ro": ["University of Craiova"],
    ".uem.ro": ["University of Resita"],
    ".student.ugal.ro": ["University of Galati"],
    ".ugal.ro": ["University of Galatzi"],
    ".ulbsibiu.ro": ['Universitatea "Lucian Blaga" din Sibiu'],
    ".umf.ro": [
        '"Carol Davila" University of Medicine and Pharmacy Bucharest',
        "Universitatea de Medicină și Farmacie „Carol Davila” București",
    ],
    ".umfcd.ro": [
        '"Carol Davila" University of Medicine and Pharmacy Bucharest',
        "Universitatea de Medicină și Farmacie „Carol Davila” București",
    ],
    ".umfcluj.ro": ["University of Medicine and Pharmacy of Cluj-Napoca"],
    ".umfcv.ro": ["University of Medicine and Pharmacy of Craiova"],
    ".umfiasi.ro": ["University of Medicine and Pharmacy of Iasi"],
    ".umfst.ro": [
        "UMFST - Universitatea de Medicină, Farmacie, Științe și Tehnologie din Târgu Mureș",
        "UMFST - University of Medicine, Pharmacy, Science and Technology of Tîrgu Mureş",
    ],
    ".umft.ro": ["University of Medicine and Pharmacy of Timisoara"],
    ".umftgm.ro": ["University of Medicine and Pharmacy of Targu Mures"],
    ".unarte.ro": ["National University of Arts"],
    ".unatc.ro": ["National University of Theater and Film Arts"],
    ".unibuc.ro": ["University of Bucharest"],
    ".student.unitbv.ro": ["Transilvania University of Brasov"],
    ".unitbv.ro": ["Transilvania University of Brasov"],
    ".univ-ovidius.ro": ["University of Constanta"],
    ".univagro-iasi.ro": ["University of Agriculture and Veterinary Medicine Iasi"],
    ".univcb.ro": ["Constantin Brancoveanu University Pitesti"],
    ".universitateamaritima.ro": ["Maritime University Constanta"],
    ".univnt.ro": ["Universitatea Nicolae Titulescu", "Nicolae Titulescu University"],
    ".unmb.ro": ["National University of Music"],
    ".uoradea.ro": ["University of Oradea"],
    ".upa.ro": ["University Petre Andrei Iasi"],
    ".upb.ro": ["University POLITEHNICA of Bucharest"],
    ".upet.ro": ["University of Petrosani"],
    ".upg-ploiesti.ro": ["University Oil- Gas Ploiesti"],
    ".upit.ro": ["University of Pitesti"],
    ".upm.ro": ["Petru Maior University of Targu Mures"],
    ".upt.ro": ["Polytechnic University of Timisoara"],
    ".usab-tm.ro": [
        "Banat's University of Agricultural Sciences",
        "University of Agriculture and Veterinary Medicine Timisoara",
    ],
    ".usab.ro": ["University of Agriculture and Veterinary Medicine Bucharest"],
    ".agro.usamv.ro": [
        "Universitatea de Științe Agronomice și Medicină Veterinară",
        "University of Agriculture and Veterinary Medicine",
    ],
    ".usamvcluj.ro": ["University of Agriculture and Veterinary Medicine Cluj-Napoca"],
    ".usm.ro": [
        "Universitatea Ștefan cel Mare Suceava",
        "Stefan cel Mare University of Suceava",
    ],
    ".usv.ro": ["University of Suceava"],
    ".utcb.ro": ["Technical University of Civil Engineering Bucharest"],
    ".utcluj.ro": ["Technical University of Cluj-Napoca"],
    ".utgjiu.ro": ["University of Targu Jiu"],
    ".utm.ro": ["University Titu Maiorescu"],
    ".utt.ro": ["Technical University of Timisoara"],
    ".uvt.ro": ["West University of Timisoara"],
    ".uvvg.ro": ['Universitatea de Vest "Vasile Goldis" din Arad'],
    ".valahia.ro": ["Valahia University of Targoviste"],
    ".wurmbrand.ro": ["Colegiul Richard Wurmbrand", "Richard Wurmbrand School"],
    ".etf.bg.ac.rs": ["University of Belgrade, School of Electrical Engineering"],
    ".matf.bg.ac.rs": ["University of Belgrade, Faculty of Mathematics"],
    ".bg.ac.rs": [
        "University of Belgrade",
        "University of Fine Arts Belgrade",
        ".group",
    ],
    ".eu.ac.rs": ["European University"],
    ".kg.ac.rs": ["University of Kragujevac"],
    ".metropolitan.ac.rs": ["Metropolitan University"],
    ".ni.ac.rs": ["University of Nis"],
    ".np.ac.rs": ["Drzavni Univerzitet u Novom Pazaru"],
    ".vps.ns.ac.rs": ["Visoka Poslovna Škola Novi Sad", "Novi Sad School Of Business"],
    ".pr.ac.rs": ["University of Priština"],
    ".singidunum.ac.rs": ["UNIVERZITET SINGIDUNUM", "Singidunum University"],
    ".vts.su.ac.rs": [
        "Subotica Tech - College of Applied Sciences",
        "Visoka tehnička škola strukovnih studija Subotica",
    ],
    ".uns.ac.rs": ["University of Novi Sad"],
    ".akademijakm.edu.rs": [
        "АКАДЕМИЈА СТРУКОВНИХ СТУДИЈА КОСОВСКО МЕТОХИЈСКА",
        "KOSOVO AND METOHIJA ACADEMY OF APPLIED STUDIES",
    ],
    ".asss.edu.rs": ["Aкадемија Струковних Студија Шумадија"],
    ".bba.edu.rs": [
        "Beogradska bankarska akademija - Fakultet za bankarstvo, osiguranje i finansije",
        "Belgrade banking academy  - faculty of banking, insurance and finance",
    ],
    ".fimek.edu.rs": [
        "Fakultet za ekonomiju i inženjerski menadžment",
        "University Business Academy in Novi Sad",
    ],
    ".fmk.edu.rs": ["Singidunum University"],
    ".ftn.edu.rs": ["Fakultet Tehnickih Nauka u Cacku"],
    ".gimnazijatvrdjava.edu.rs": ["Privatna Gimnazija Tvrđava"],
    ".ict.edu.rs": ["Visoka ICT škola (ICT College of Vocational Studies)"],
    ".iths.edu.rs": [
        "Srednja skola za informacione tehnologije, Beograd",
        "Information technology high school",
    ],
    ".its.edu.rs": [
        "ITS - Visoka škola strukovnih studija za informacione tehnologije | Beograd"
    ],
    ".loznickagimnazija.edu.rs": [
        'Gimnazija "Vuk Karadžić"',
        'High School "Vuk Karadžić"',
    ],
    ".matgim.edu.rs": ["Mathematical Grammar School, Belgrade"],
    ".metropolitan.edu.rs": ["Metropolitan University"],
    ".msstankovic.edu.rs": [
        "Музичка школа „Станковић“ Београд",
        "Stanković Musical School",
    ],
    ".osmagimnazija.edu.rs": [
        "8. beogradska gimnazija",
        "Eighth Belgrade Grammar School",
    ],
    ".osvukkaradzic-krnjevo.edu.rs": [
        "ОШ ВУК КАРАДЖИЋ",
        "VUK KARADZIC ELEMENTARY SCHOOL",
    ],
    ".pmf.edu.rs": ["Prirodno Matematicki Fakultet Nis"],
    ".privrednaakademija.edu.rs": ["Privredna Akademija (Business Academy)"],
    ".raf.edu.rs": ["Racunarski Fakultet ", "School of Computing"],
    ".rg.edu.rs": ["Racunarska gimazija"],
    ".singidunum.edu.rs": ["Singidunum University"],
    ".smart.edu.rs": [
        'Računarska gimnazija "Smart" Novi Sad',
        'Computer Science High School "Smart" Novi Sad',
    ],
    ".teslabg.edu.rs": [
        "Nikola Tesla High School for Electrical engineering, Belgrade",
        "Elektrotehnicka skola Nikola Tesla, Beograd",
    ],
    ".uninp.edu.rs": ["International University of Novi Pazar"],
    ".vhts.edu.rs": [
        "Visoka tehničko-tehnološka škola strukovnih studija - Kruševac, Srbija (College of applied technical & technological studies - Krusevac, Serbia)"
    ],
    ".ucionica.vigimnazija.edu.rs": ["Šesta beogradska gimnazija "],
    ".vipos.edu.rs": [
        "Visoka poslovna škola strukovnih studija, Valjevo",
        "Valjevo Business School of Applied Studies",
    ],
    ".gs.viser.edu.rs": [
        "Visoka škola elektrotehnike i računarstva strukovnih studija, Beograd"
    ],
    ".vsar.edu.rs": [
        "Висока школа струковних студија Аранђеловац",
        "College of Applied Technology Science Arandjelovac",
    ],
    ".vtsnis.edu.rs": [
        "College of Applied Technical Sciences Nis",
        "Visoka tehnicka skola strukovnih studija Nis",
        "Visoka tehnička škola strukovnih studija Niš",
        "Visoka thnička škola Niš",
        "Visoka tehnicka skola Ni",
    ],
    ".xiigimnazija.edu.rs": [
        "Dvanaesta beogradska gimnazija",
        "12. beogradska gimnazija",
        "The 12th Belgrade Grammar School",
        "The Twelfth Belgrade Grammar School",
    ],
    ".elfak.rs": ["University of Nis, Faculty of Electronic Engineering"],
    ".etf.rs": ["University of Belgrade, School of Electrical Engineering"],
    ".fink.rs": ["University of Kragujevac, Faculty of Engineering"],
    ".raf.rs": ["Racunarski Fakultet, Belgrade"],
    ".singimail.rs": ["Singidunum University"],
    ".tfzr.rs": [
        'University of Novi Sad - Technical faculty "Mihajlo Pupin" Zrenjanin'
    ],
    ".vtsnis.rs": [
        "College of Applied Technical Sciences Nis",
        "Visoka tehnicka skola strukovnih studija Nis",
        "Visoka tehnička škola strukovnih studija Niš",
        "Visoka thnička škola Niš",
        "Visoka tehnicka skola Nis",
    ],
    ".1514.ru": ["ГБОУ Школа №1514"],
    ".1580.ru": [
        '\ufeffГосударственное бюджетное общеобразовательное учреждение города Москвы "Бауманская инженерная школа № 1580"'
    ],
    ".1581mgtu.ru": [
        "Gosudarstvennoe obrazovatelnoe uchrezhdenie goroda Moskvy Licej N1581 "
    ],
    ".179.ru": ["Moscow Konstantinov School"],
    ".1msmu.ru": ["First Moscow State Medical University"],
    ".21-school.ru": ["Школа 21", "21 School"],
    ".239.ru": ["Physics and Mathematics Lyceum No. 239, St. Petersburg"],
    ".Ioffe.ru": [
        "Ioffe Physical-Technical Institute of the Russian Academy of Sciences "
    ],
    ".a-pet.ru": [None, "Angarskiy Promyshlenno-Ekonomicheskiy Tekhnikum"],
    ".aanet.ru": [
        "Санкт-Петербургский государственный университет аэрокосмического приборостроения",
        "St. Petersburg State University of Aerospace Instrumentation",
    ],
    ".aas.ru": ["Anglo-American School of Moscow"],
    ".ivanovo.ac.ru": ["Ivanovo State University", "Ivanovo State University"],
    ".mgul.ac.ru": [
        "Moscow State University of Forestry Engineering",
        "Moscow State University of Forestry Engineering",
    ],
    ".mpei.ac.ru": [
        "Moscow Power Engineering Institute (Technical University)",
        "Moscow Power Engineering Institute (Technical University)",
    ],
    ".novsu.ac.ru": ["Novgorod State University", "Novgorod State University"],
    ".pspu.ac.ru": [
        "Perm State Pedagogical University",
        "Perm State Pedagogical University",
    ],
    ".pstu.ac.ru": [
        "Perm State Academy of Agriculture",
        "Perm State Technical University",
        "Perm State Academy of Agriculture",
        "Perm State Technical University",
    ],
    ".ugatu.ac.ru": [
        "Ufa State Aviation Technical University",
        "Ufa State Aviation Technical University",
    ],
    ".uni-vologda.ac.ru": [
        "Vologda State Pedagogical University",
        "Vologda State Pedagogical University",
    ],
    ".uniyar.ac.ru": ["Yaroslavl State University", "Yaroslavl State University"],
    ".unn.ac.ru": [
        "Nizhny Novgorod State University",
        "Nizhny Novgorod State University",
    ],
    ".urc.ac.ru": [
        "Cheljabinsk State Institute of Teacher Training",
        "Cheljabinsk University of Agricultural Engineering",
        "Cheljabinsk State Institute of Teacher Training",
        "Cheljabinsk University of Agricultural Engineering",
    ],
    ".vspu.ac.ru": [
        "Voronezh State Pedagogical University",
        "Voronezh State Pedagogical University",
    ],
    ".yma.ac.ru": [
        "Yaroslavl State Medical Academy",
        "Yaroslavl State Medical Academy",
    ],
    ".achtng.ru": [
        "Краевое государственное автономное профессиональное образовательное учреждение «Ачинский техникум нефти и газа имени Е.А.Демьяненко»",
        "Achinsk college of oil and gas",
    ],
    ".aclic.ru": ["Tomsk Academic Lyceum", "Tomsk Academic Lyceum"],
    ".acxk.ru": ["Гбпоу Асхк", "ASHK Colledge"],
    ".adygnet.ru": ["Adygeja State University", "Adygeja State University"],
    ".ael.ru": [
        "Khabarovsk State Academy of Economics and Law",
        "Khabarovsk State Academy of Economics and Law",
    ],
    ".agatu.ru": [
        "ФЕДЕРАЛЬНОЕ ГОСУДАРСТВЕННОЕ БЮДЖЕТНОЕ ОБРАЗОВАТЕЛЬНОЕ УЧРЕЖДЕНИЕ ВЫСШЕГО ОБРАЗОВАНИЯ АРКТИЧЕСКИЙ ГОСУДАРСТВЕННЫЙ АГРОТЕХНОЛОГИЧЕСКИЙ УНИВЕРСИТЕТ",
        "Arctic State Agrotechnological University",
    ],
    ".agtu.ru": [
        "Arhangelsk State Technical University",
        "Arhangelsk State Technical University",
    ],
    ".akvt.ru": ["Astrakhan's College of Computed Technics"],
    ".almazovcentre.ru": [
        "ФГБУ «НМИЦ им. В. А. Алмазова» Минздрава России",
        "Almazov National Medical Research Centre",
    ],
    ".mail.altstu.ru": [
        "Алтайский государственный технический университет им. И.И. Ползунова",
        "Polzunov Altai State Technical University",
    ],
    ".ame.ru": [
        "Academy of Management and Entrepreneurship",
        "Academy of Management and Entrepreneurship",
    ],
    ".amursu.ru": ["Amur State University", "Amur State University"],
    ".angtu.ru": [None],
    ".ap47.ru": [
        'Regional state budgetary vocational educational institution "Amurskiy Polytechnic College"',
        "In Russian, short: КГБ ПОУ АПТ",
        "In Russian, full official: Краевое государственное бюджетное профессиональное образовательное учреждение «Амурский политехнический техникум»",
    ],
    ".aptu.ru": ["St. Petersburg Academic University"],
    ".arcotel.ru": [
        "Arkhangelsk college of telecommunications",
        "Архангельский колледж телекоммуникаций (филиал) СПбГУТ им. проф. М.А. Бонч-Бруевича ",
    ],
    ".artcollege.ru": ["Первый Московский образовательный комплекс 1-й МОК", "1st MOK"],
    ".asau.ru": [
        "Алтайский Государственный Аграрный Университет",
        "Altai State Agricultural University",
    ],
    ".aserhovo.ru": [
        "МБОУ Асерховская средняя общеобразовательная школа Собинского района"
    ],
    ".asmu.ru": ["Altai State Medical University", "Altai State Medical University"],
    ".aspc-edu.ru": [
        'ГБПОУ АО "Астраханский государственный политехнический колледж"',
        "Astrakhan State Polytechnic College",
    ],
    ".aspu.ru": ["Astrakhan State University", "Astrakhan State University"],
    ".astranet.ru": [
        "Astrahan State Medical Academy",
        "Astrahan State Medical Academy",
    ],
    ".asu.ru": ["Altai State University", "Altai State University"],
    ".asugubkin.ru": [
        "Automated Control Systems Departments of Gubkin Russian State University of Oil and Gas (National Research University)"
    ],
    ".aucu.ru": ["Astrakhan State University of Architecture and Civil Engineering"],
    ".avtlg.ru": ["Volgograd Medical Academy", "Volgograd Medical Academy"],
    ".ismu.baikal.ru": ["Irkutsk Medical University"],
    ".bashedu.ru": [
        "Bashkir State Agrarian University",
        "Bashkir State Medical University",
        "Bashkir State Pedagogical Institute",
        "Bashkir State University",
        "Birsk State Pedagogical Institute",
        "Sterlitamak State Pedagogical Institute",
        "Ufa State Institute of Arts",
        "Bashkir State Agrarian University",
        "Bashkir State Medical University",
        "Bashkir State Pedagogical Institute",
        "Bashkir State University",
        "Birsk State Pedagogical Institute",
        "Sterlitamak Branch Bashkir State University",
        "Ufa State Institute of Arts",
    ],
    ".belevbolotoschool.ru": [
        'Муниципальное общеобразовательное учреждение "Болотская средняя общеобразовательная школа" Белевского района Тульской области'
    ],
    ".bfmiit.ru": [
        "Bryansk branch Moscow State University of Railway Engineering (BfMIIT)",
        "Брянский филиал Московского государственного университета путей сообщения (БфМИИТ)",
    ],
    ".bgpu.ru": ["Blagoveshchensk State Pedagogical University"],
    ".bgu.ru": ["Байкальский Государственный Университет ", "Baikal State University"],
    ".birsk.ru": ["Bashkir State University Birsk Branch"],
    ".biysk-liceum.ru": ["Biysk Liceum"],
    ".biysk.ru": [
        "Biysk State Padagogical University after V.M. Shukshin ",
        "Biysk State Padagogical University after V.M. Shukshin ",
    ],
    ".bktis.ru": ["Baikal college of tourism and service"],
    ".blpk-uu.ru": ["Бурятский лесопромышленный колледж", "Burjat forestry college"],
    ".bmstu-kaluga.ru": ["Kaluga branch of Bauman Moscow State Technical University"],
    ".bmstu.ru": [
        "Bauman Moscow State Technical University",
        "Bauman Moscow State Technical University",
    ],
    ".britishdesign.ru": ["British Higher School of Art & Design"],
    ".brstu.ru": [
        "Bratsk State Technical University",
        "Bratsk State Technical University",
    ],
    ".bsaa.ru": [
        "Belgorod State Agricultural Academy",
        "Belgorod State Agricultural Academy",
    ],
    ".bspu.ru": [
        'Федеральное государственное бюджетное образовательное учреждение высшего образования "Башкирский государственный педагогический университет им. М.Акмуллы" (ФГБОУ ВО "БГПУ им. М.Акмуллы")',
        "Bashkir State Pedagogical University n. a. M. Akmulla",
    ],
    ".bstu.ru": [
        "Belgorod State Technical University",
        "Belgorod State Technical University",
    ],
    ".bsu.ru": ["Burjat State University"],
    ".burnet.ru": [
        "Burjat State University",
        "East-Siberian State Institute of Culture",
        "Burjat State University",
        "East-Siberian State Institute of Culture",
    ],
    ".ccfebras.ru": ["Computing Center FEB RAS"],
    ".cchgeu.ru": [
        "Воронежский государственный технический университет",
        "Voronezh State Technical University",
    ],
    ".centro.ru": [
        "Maxim Gorky Institute of Literature",
        "Maxim Gorky Institute of Literature",
    ],
    ".cfuv.ru": ["V.I. Vernadsky Crimean Federal University"],
    ".chat.ru": [
        "Moscow External University of the Humanities",
        "Moscow External University of the Humanities",
    ],
    ".chesu.ru": ["Chechen State University"],
    ".chsu.ru": ["Cherepovets State University"],
    ".chtptu.ru": ["Чайковский техникум промышленных технологий и управления"],
    ".chuvsu.ru": ["Chuvash State University", "Chuvash State University"],
    ".cit-psu.ru": ["CIT Perm State University"],
    ".collegelan.ru": ["\ufeffЛангепасский политехнический колледж"],
    ".drbit.com.ru": [
        "Novosibirsk State Academy of Economics and Mangement",
        "Novosibirsk State Academy of Economics and Mangement",
    ],
    ".compscicenter.ru": ["Computer Science Center", "Computer Science Center"],
    ".conservatoire.ru": [
        "Novosibirsk State Music Academy M. Glinka",
        "Novosibirsk State Music Academy M. Glinka",
    ],
    ".conservatory.ru": [
        "St. Petersburg State Conservatory",
        "St. Petersburg State Conservatory",
    ],
    ".cspu.ru": ["Chelyabinsk State Pedagogical University"],
    ".csu.ru": ["Cheljabinsk State University"],
    ".da.ru": ["Rostov State Medical University", "Rostov State Medical University"],
    ".dakad.ru": ["ЧОУ «ДЕТСКАЯ АКАДЕМИЯ»"],
    ".dgu.ru": ["Dagestan State University", "Dagestan State University"],
    ".donstu.ru": ["Don State Technical University", "Don State Technical University"],
    ".dvfu.ru": ["Far Eastern Federal University"],
    ".dvgu.ru": ["Far Eastern State University", "Far Eastern State University"],
    ".e-43.ru": ["Kirov State All School Network"],
    ".eastsib.ru": ["East-Siberian State University", "East-Siberian State University"],
    ".ects.ru": ["ECTS", "Yekaterinburg College Of Transport Construction"],
    ".asu.edu.ru": ["Astrakhan State University"],
    ".bsu.edu.ru": ["Belgorod State University", "Belgorod State University"],
    ".dstu.edu.ru": [
        "Don State Technical University",
        "Don State Technical University",
    ],
    ".herzen.edu.ru": [
        "Российский государственный педагогический университет им. А. И. Герцена",
        "The Herzen State Pedagogical University of Russia",
    ],
    ".kstu.edu.ru": [
        "Kostroma State Technological University",
        "Kostroma State Technological University",
    ],
    ".mstu.edu.ru": [
        "Murmansk State Technical University",
        "Murmansk State Technical University",
    ],
    ".muctr.edu.ru": [
        "Mendeleev Russian University of Chemical Technology",
        "Mendeleev Russian University of Chemical Technology",
    ],
    ".nsau.edu.ru": [
        "Novosibirsk State Agricultural University",
        "Novosibirsk State Agricultural University",
    ],
    ".pfu.edu.ru": [
        "People' s Friendship University of Russia",
        "People' s Friendship University of Russia",
    ],
    ".spmi.edu.ru": [
        "St. Petersburg State Mining Institute (Technical University)",
        "St. Petersburg State Mining Institute (Technical University)",
    ],
    ".tspu.edu.ru": [
        "Tomsk State Pedagogical University",
        "Tomsk State Pedagogical University",
    ],
    ".eduhouse.ru": [
        "Санкт–Петербургский Технический колледж управления и коммерции",
        "St. Petersburg Technical College of Management and Commerce",
    ],
    ".eetk.ru": ['ГАПОУ СО "Екатеринбургский экономико-технологический колледж"'],
    ".eimb.ru": ["Engelhardt Institute of Molecular Biology"],
    ".ekvl.ru": ["Industrial College of Energy and Communications"],
    ".eltech.ru": [
        "St. Petersburg State Electrotechnical University",
        "St. Petersburg State Electrotechnical University",
    ],
    ".stud.engec.ru": [
        "St. Petersburg State University of Economics",
        "St. Petersburg State University of Economics",
    ],
    ".engec.ru": [
        "St. Petersburg State Academy for Engineering Economics (ENGECON)",
        "St. Petersburg State University of Engineering and Economics",
        "St. Petersburg State Academy for Engineering Economics (ENGECON)",
        "St. Petersburg State University of Engineering and Economics",
    ],
    ".esstu.ru": [
        "East-Siberian State University of Technology",
        "East-Siberian State University of Technology",
    ],
    ".etu.ru": [
        "St. Petersburg State Electrotechnical University",
        "St. Petersburg State Electrotechnical University",
    ],
    ".externat1.ru": ["Первый экстернат", "First externat"],
    ".fa.ru": ["Finance Academy", "Finance Academy"],
    ".festu.ru": [
        "Far Eastern State Technical University",
        "Far Eastern State Technical University",
    ],
    ".fevschool.ru": ['МБОУ "Февральская СОШ"', "MBOU Fevralsk Middle School"],
    ".fml31.ru": [
        "Physics and Mathematics Lyceum No. 31, Chelyabinsk",
        'МБОУ "ФМЛ № 31 г. Челябинска"',
    ],
    ".fms2007.ru": [
        "State budgetary educational institution of the city of Moscow School No. 2007 FMS",
        "Государственное бюджетное общеобразовательное учреждение города Москвы Школа № 2007 ФМШ",
    ],
    ".fta-mo.ru": ["Finance and Technology Academy", "Finance and Technology Academy"],
    ".ftacademy.ru": [
        "St. Petersburg State Forest-Technical Academy",
        "St. Petersburg State Forest-Technical Academy",
    ],
    ".gagpk.ru": [
        "Горно-Алтайский государственный политехнический колледж имени М.З.Гнездилова"
    ],
    ".gasu.ru": ["Gorno-Altaisk State University", "Gorno-Altaisk State University"],
    ".gma.ru": ["State Maritine Academy", "State Maritine Academy"],
    ".gnesin-academy.ru": [
        "Gnesins Russian Academy of Music",
        "Gnesins Russian Academy of Music",
    ],
    ".gnt-oil.ru": [
        'Государственное бюджетное профессиональное образовательное учреждение "Жирновский нефтяной техникум"',
        'State budgetary professional educational institution "Zhirnovskiy oil technical college"',
    ],
    ".gourpt.ru": ["ГОУ СПО Рыбницкий политехнический техникум", "GOU SPO RPT"],
    ".goushet.ru": [
        "Государственное бюджетное профессиональное образовательное учреждение Московской области «Шатурский энергетический техникум»"
    ],
    ".gpma.ru": [
        "St. Petersburg State Pediatric Medical Academy",
        "St. Petersburg State Pediatric Medical Academy",
    ],
    ".gs8.ru": ["Gymnasium no. 8, Sochi, Russia"],
    ".gstou.ru": [
        "Грозненский государственный нефтяной технический университет имени академика М. Д. Миллионщикова",
        "Grozny State Oil Technical University named after Academician M. D. Millionshchikov",
    ],
    ".guap.ru": [
        "Saint-Petersburg State University of Aerospace Instrumentation",
        "Saint-Petersburg State University of Aerospace Instrumentation",
    ],
    ".gubkin.ru": [
        "Gubkin Russian State University of Oil and Gas",
        "Gubkin Russian State University of Oil and Gas",
    ],
    ".gukit.ru": [
        "St. Petersburg State Cinema and TV University",
        "St. Petersburg State Cinema and TV University",
    ],
    ".gumrf.ru": ["Admiral Makarov State University of Maritime and Inland Shipping"],
    ".gup.ru": ["St. Petersburg University of Humanities"],
    ".guu.ru": ["State University of Management", "State University of Management"],
    ".gym1505.ru": [
        'Государственное бюджетное общеобразовательное учреждение города Москвы "Школа № 1505 "Преображенская"',
        'The state budgetary educational institution of the city of Moscow "School No. 1505 "Preobrazhenskaya"',
    ],
    ".gymn1576.ru": ["ГБОУ Школа 1576", "ГБОУ Школа 1576"],
    ".hiik.ru": [
        "Siberian State University of Telecommunications and Information Sciences Khabarovsk Branch"
    ],
    ".hse.ru": ["Higher School of Economics", "Higher School of Economics"],
    ".hspm.ru": ["Graduate School of Press and Media Technologies SPbSUITD"],
    ".ibp-moscow.ru": [
        "Institute of Business and Politics",
        "Institute of Business and Politics",
    ],
    ".icc.ru": [
        "Институт динамики систем и теории управления",
        "Matrosov Institute for System Dynamics and Control Theory of Siberian Branch of Russian Academy of Sciences",
    ],
    ".icmm.ru": [
        "Institute of Continuous Media Mechanics of the Ural Branch of Russian Academy of Science",
        "ICMM UB RAS",
        "Федеральное государственное бюджетное учреждение науки Институт механики сплошных сред Уральского отделения Российской академии наук",
        "ИМСС УрО РАН",
    ],
    ".ieml.ru": ["Kazan Innovative University named after V. G. Timiryasov (IEML)"],
    ".iet.ru": [
        "Institute for the Economy in Transition",
        "Institute for the Economy in Transition",
    ],
    ".ifaran.ru": ["A.M. Obukhov Institute of Atmospheric Physics RAS"],
    ".ifmo.ru": [
        "St. Petersburg State University of Information Technologies, Mechanics and Optics",
        "St. Petersburg State University of Information Technologies, Mechanics and Optics",
    ],
    ".igps.ru": [
        "Санкт-Петербургский университет ГПС МЧС России",
        "Saint Petersburg university of State fire service of EMERCOM of Russia",
    ],
    ".iitp.ru": ["Institute for Information Transmission Problems"],
    ".ime.ru": [
        "Institute of Management and Economy",
        "Institute of Management and Economy",
    ],
    ".imi-samara.ru": [
        "\ufeffАНО ВО Самарский университет государственного управления «Международный институт рынка»"
    ],
    ".imiit.ru": [
        "Institute of Management and Information Technologies of RUT (MIIT)",
        "Институт Управления и Информационных Технологий РУТ (МИИТ)",
    ],
    ".indi.ru": [
        "Ivanovo State Academy of Medicine",
        "Ivanovo State Academy of Medicine",
    ],
    ".indsi.ru": ['МАУ "Институт развития стратегических инициатив"'],
    ".informatics.ru": ["Mytishy Programming School"],
    ".informika.ru": [
        'State Institute of Information Technologies and Telecommunications (SIIT&T "Informika")'
    ],
    ".inggu.ru": [
        "ФГБОУ ВО Ингушский государственный университет",
        "Ingush state university",
    ],
    ".innopolis.ru": ["Innopolis University"],
    ".interun.ru": ["International University in Moscow"],
    ".inueco.ru": [
        "South Ural Institute of Management and Economics",
        "Южно-Уральский институт Управления и Экономики",
    ],
    ".iptmuran.ru": [
        "Institute of Precision Mechanics and Control",
        "Институт проблем точной механики и управления Российской академии наук",
    ],
    ".irgups.ru": ["Irkutsk State Transport University", "IrGUPS", "IrIIT"],
    ".irk.ru": [
        "Irkutsk State Academy of Economics",
        "Irkutsk State Technical University",
        "Irkutsk State Academy of Economics",
        "Irkutsk State Technical University",
    ],
    ".irkat.ru": ["Irkutsk aviation technical school"],
    ".isea.ru": [
        "Baikal National University of Economics and Law",
        "Baikal National University of Economics and Law",
    ],
    ".ispras.ru": [
        "Ivannikov Institute for System Programming of the Russian Academy of Sciences"
    ],
    ".ispu.ru": ["Ivanovo State Power University", "Ivanovo State Power University"],
    ".istu.ru": [
        "Izhevsk State Technical University",
        "Izhevsk State Technical University",
    ],
    ".isu.ru": ["Irkutsk State University", "Irkutsk State University"],
    ".isuct.ru": [
        "Ivanovo State University of Chemistry and Technology",
        "Ivanovo State University of Chemistry and Technology",
    ],
    ".ithub.ru": ["IT HUB College"],
    ".itmo.ru": [
        "Санкт-Петербургский национальный исследовательский университет информационных технологий, механики и оптики",
        "ITMO University",
    ],
    ".iwp.ru": [
        "Институт водных проблем РАН",
        "Water Problems Institute of RAS (WPI RAS)",
    ],
    ".jum.ru": ["Jewish University in Moscow", "Jewish University in Moscow"],
    ".kaf65.ru": [
        "Kafedra 65 Concurrent systems analysis of MEPhI (Moscow Engineering Physics Institute)"
    ],
    ".kai.ru": [
        "Kazan State University of Technology",
        "Kazan State University of Technology",
    ],
    ".kait20.ru": [
        "GBPOU KAIT N 20, GBU, Moscow, Russia",
        "In Russian, short: ГБПОУ КАИТ №20",
        'In Russian, full official: Государственное бюджетное профессиональное образовательное учреждение города Москвы "Колледж автоматизации и информационных технологий № 20"',
    ],
    ".kalmsu.ru": ["Kalmyk State University", "Kalmyk State University"],
    ".kspu.kaluga.ru": [
        "Kaluga State Pedagogical University",
        "Kaluga State Pedagogical University",
    ],
    ".kamchatgtu.ru": [
        "Kamchatka State Technical University",
        "Kamchatka State Technical University",
    ],
    ".kamgu.ru": [
        "Kamchatka State University Vitus Bering",
        "Kamchatka State University Vitus Bering",
    ],
    ".kansk-tc.ru": ["Канский технологический колледж", "Kansk college of technology"],
    ".kantiana.ru": [
        "Immanuel Kant State University of Russia",
        "Immanuel Kant State University of Russia",
    ],
    ".cs.karelia.ru": ["Petrozavodsk State University, Computer Science department"],
    ".dims.karelia.ru": [
        "Petrozavodsk State University, Department of Information Measurement Systems"
    ],
    ".psu.karelia.ru": ["PetrSU", "Petrozavodsk State University"],
    ".www.karelia.ru": [
        "Petrozavodsk State University",
        "Petrozavodsk State University",
    ],
    ".kaviat.ru": [
        "Kazan Aviation of Technology College",
        "Kazan Aviation of Technology College",
    ],
    ".kazanconservatory.ru": [
        "Kazan State Music Conservatory",
        "Kazan State Music Conservatory",
    ],
    ".kbgtk07.ru": [
        "Кабардино-Балкарский гуманитарно-технический колледж",
        "Государственное бюджетное профессиональное образовательное учреждение  «Кабардино-Балкарский гуманитарно-технический колледж»",
    ],
    ".kbsu.ru": [
        "Kabardino-Balkarian State University",
        "Kabardino-Balkarian State University",
    ],
    ".kcn.ru": [
        "Kazan State University of Medicine",
        "Kazan State University of Medicine",
    ],
    ".kemerovorea.ru": [
        "РОССИЙСКИЙ ЭКОНОМИЧЕСКИЙ УНИВЕРСИТЕТ ИМЕНИ Г.В. ПЛЕХАНОВА КЕМЕРОВСКИЙ ИНСТИТУТ",
        "RUSSIAN ECONOMIC UNIVERSITY NAMED AFTER GV PLEKHANOVA KEMER INSTITUTE",
    ],
    ".kemsu.ru": [
        "Kemerovo State University",
        "Kemerovo State University",
        "Kemerovo State University",
    ],
    ".kgau.ru": [
        "Красноярский государственный аграрный университет",
        "Krasnoyarsk State Agrarian University",
    ],
    ".kgeu.ru": ["Kazan State Power Engineering University"],
    ".kgpu.ru": [
        "Kazan State Pedagogical University",
        "Kazan State Pedagogical University",
    ],
    ".kgsu.ru": ["Курганский государственный университет", "Kurgan State University"],
    ".khpk.ru": [
        "Khakas State Polytechnic College",
        "Хакасский политехнический колледж",
    ],
    ".khstu.ru": [
        "Khabarovsk State University of Technology",
        "Khabarovsk State University of Technology",
    ],
    ".khsu.ru": ["Khakas State University"],
    ".festu.khv.ru": [
        "Федеральное государственное бюджетное образовательное учреждение высшего образования «Дальневосточный государственный университет путей сообщения»",
        'Federal State Budget Educational Institution of Higher Education "Far Eastern State Transport University" ',
    ],
    ".kipu-rc.ru": [
        "Крымский инженерно-педагогический университет",
        "Crimean Engineering and Pedagogical University",
    ],
    ".kiu.ru": ["Kurgan International University", "Kurgan International University"],
    ".klgtu.ru": [
        "Kaliningrad State Technical University",
        "Kaliningrad State Technical University",
    ],
    ".knastu.ru": [
        "Komsomolsk-on-Amur State Technical University",
        "Komsomolsk-on-Amur State Technical University",
    ],
    ".kfti.knc.ru": [
        "Kazan E. K. Zavoisky Physical-Technical Institute of KSC RAS",
        "Kazan E. K. Zavoisky Physical-Technical Institute of KSC RAS",
    ],
    ".komitent.ru": [
        "Автономная некоммерческая организация профессионального образования Челябинский колледж «Комитент»",
        'Autonomous non-profit organization of vocational education Chelyabinsk College "Komient"',
    ],
    ".koziz.ru": [
        "Кафедра общественного здоровья и здравоохранения МГМСУ им. А.И. Евдокимова"
    ],
    ".kpfu.ru": ["Kazan Federal University"],
    ".krasgmu.ru": [
        "Красноярский государственный медицинский университет",
        "Krasnoyarsk State Medical University",
    ],
    ".icm.krasn.ru": [
        "ИНСТИТУТ ВЫЧИСЛИТЕЛЬНОГО МОДЕЛИРОВАНИЯ СО РАН",
        "Institute of Computational Modeling SB RAS",
    ],
    ".krstc.ru": ["Красногорский Колледж", "Krasnogorskiy College"],
    ".ksaba.ru": [
        "Kazan State Academy of Architecture and Civil Engineering",
        "Kazan State Academy of Architecture and Civil Engineering",
    ],
    ".ksfei.ru": [
        "Kazan State Finance and Economics Institute ",
        "Kazan State Finance and Economics Institute ",
    ],
    ".kspeu.ru": ["Kazan state power engineering university"],
    ".mail.kspu.ru": [
        "Krasnoyarsk state pedagogical university named after V.P. Astafyev",
        "In Russian, short: \t\tКрасноярский государственный педагогический университет имени В.П. Астафьева",
        "In Russian, full official: \tГосударственное образовательное учреждение высшего профессионального образования «Красноярский государственный педагогический университет имени В.П. Астафьева»",
    ],
    ".kspu.ru": [
        "Krasnoyarsk state pedagogical university named after V.P. Astafyev",
        "In Russian, short: \t\tКрасноярский государственный педагогический университет имени В.П. Астафьева",
        "In Russian, full official: \tГосударственное образовательное учреждение высшего профессионального образования «Красноярский государственный педагогический университет имени В.П. Астафьева»",
    ],
    ".kstu.ru": [
        "Казанский национальный исследовательский технологический университет",
        "Kazan National Research Technological University",
    ],
    ".ksu.ru": ["Kazan State University", "Kazan State University"],
    ".ktk40.ru": [
        'Государственное автономное профессиональное образовательное учреждение Калужской области "Калужский технический колледж"'
    ],
    ".kubagro.ru": [
        "Kuban State University of Agriculture",
        "Kuban State University of Agriculture",
    ],
    ".tim.kubannet.ru": [
        "ГКОУ КШИ «Тимашевский казачий кадетский корпус»",
        "GKOU KSHI «Timashevskij kazachij kadetskij korpus»",
    ],
    ".kubsau.ru": [
        "Kuban State Agrarian University",
        "Kuban State Agrarian University",
    ],
    ".kubstu.ru": [
        "Kuban State University of Technology",
        "Kuban State University of Technology",
    ],
    ".kubsu.ru": ["Kuban State University", "Kuban State University"],
    ".kstu.kursk.ru": [
        "Kursk State Technical University",
        "Kursk State Technical University",
    ],
    ".kursk-uni.ru": ["Kursk State University", "Kursk State University"],
    ".kursknet.ru": [
        "Kursk State Medical University",
        "Kursk State Medical University",
    ],
    ".kursksu.ru": ["Kursk State University", "Kursk State University"],
    ".kuzstu.ru": ["Kuzbass State Technical University"],
    ".labore.ru": ["МАОУ Гимназия № 56 г. Ижевск", "Izhevsk school №56"],
    ".letovo.ru": ['ОНАО "Школа "Летово"', "Letovo"],
    ".liceum8.ru": ["Liceum 8, Electrostal", "МОУ «Лицей 8», г. Электросталь"],
    ".licey84.ru": [
        "Liceum No. 84 named in honor of Gali Akysh, Nabarezhnye Chelny, Republic of Tatarstan",
        'Набережные Челны "Лицей-интернат №84 имени Гали Акыша" Республики Татарстан. ',
    ],
    ".linguanet.ru": ["Moscow State Linguistic University"],
    ".stu.lipetsk.ru": [
        "Lipeck State Technical University",
        "Lipeck State Technical University",
    ],
    ".lit1533.ru": [
        'Государственное бюджетное общеобразовательное учреждение города Москвы "Школа № 1533 "ЛИТ" ',
        'State Budget General Educational Institution of Moscow "School № 1533" LIT"',
        "Лицей информационных технологий 1533",
        "Lyceum of Information Technologies 1533",
        "Mail domain: lit1533.ru (scolars and teachers has e-mails at this domain)",
        "Web-site (with forward from lit1533.ru): https://www.lit.msu.ru",
        "Web-site at Moscow Department of Education and Science: https://lyc1533.mskobr.ru",
    ],
    ".lit1537.ru": ["Лицей 1537", "Lyceum 1537"],
    ".litsey2.ru": ['МАОУ "Лицей-интернат №2" г. Казани'],
    ".lkpfu.ru": [
        "Лицей имени Н.И. Лобачевского КФУ",
        "Secondary Boarding School “Lyceum named after N. Lobachevsky” of Kazan (Volga region) Federal University",
    ],
    ".lrmk.ru": [
        "Государственное бюджетное профессиональное образовательное учреждение «Лермонтовский региональный многопрофильный колледж»"
    ],
    ".lschool5.ru": ['МБОУ "Лянторская СОШ № 5"', 'MBOU "Lyantorskaya SOSh N 5"'],
    ".madi.ru": [
        "Moscow State Automobile and Road Technical University",
        "Moscow State Automobile and Road Technical University",
    ],
    ".magtu.ru": ["Magnitogorsk State Technical University"],
    ".mai.ru": ["Moscow Aviation Institute"],
    ".marstu.mari.ru": [
        "Marij State Technical University",
        "Marij State Technical University",
    ],
    ".marsu.ru": ["МарГУ", "MarSU"],
    ".s.masi.ru": ["Московский информационно-технологический университет"],
    ".mcag.ru": ["Moscow College of Architecture and Urban Planning"],
    ".mck-ktits.ru": [
        "international competence center Kazan technical school of information technologies and communications",
        'ГАПОУ "Международный Центр Компетенций - Техникум Информационных Технологий и Связи"',
        "МЦК-КТИТС",
    ],
    ".campus.mephi.ru": ['National Research Nuclear University "MEPhI"'],
    ".mephi.ru": ["National Research Nuclear University MEPhi"],
    ".mes.ru": ["Moscow Economic School"],
    ".mesi.ru": [
        "Moscow State University of Economics, Statistics and Informatics",
        "Moscow State University of Economics, Statistics and Informatics",
    ],
    ".mfmgutu.ru": [
        "Московский Государственный Университет Технологий и Управления имени К.Г. Разумовского (Первый казачий университет) Башкирский институт технологий и управления (филиал)"
    ],
    ".mfua.ru": ["Moscow Financial and Law University (MFUA)"],
    ".mgavm.ru": [
        "Skrjabin Moscow State Academy of Veterinary Medicine and Biotechnology",
        "Skrjabin Moscow State Academy of Veterinary Medicine and Biotechnology",
    ],
    ".mgimo.ru": [
        "Moscow State Institute of International Relations MFA Russia (MGIMO-University)",
        "Moscow State Institute of International Relations MFA Russia (MGIMO-University)",
    ],
    ".mgou.ru": [
        "Московский государственный областной университет (МГОУ)",
        "Moscow Region State University (MRSU)",
    ],
    ".mgppu.ru": ["Moscow city university of psychology and pedagogy"],
    ".mgpu.ru": ["Moscow City University"],
    ".mgri.ru": [
        "Российский государственный геологоразведочный университет им. Серго Орджоникидзе",
        "Sergo Ordzhonikidze Russian State University for Geological Prospecting",
    ],
    ".mgsu.ru": ["НИУ МГСУ", "MSU of civil engineering"],
    ".ba.mgubs.ru": ["Moscow State University Business school"],
    ".mgup.ru": ["Moscow State University of Printing Arts"],
    ".mgupp.ru": ["Moscow State University of Food Production"],
    ".mgutm.ru": [
        "«Московский государственный университет технологий и управления имени К.Г. Разумовского (ПКУ)»",
        "МГУТУ им. К.Г. Разумовского (ПКУ)",
        "MGUTU",
        "Moscow State University of Technology and Management named after K.G. Razumovsky (PKU)",
        "Education programm: http://www.mgutm.ru/about/chairs/it.php",
    ],
    ".edu.midis.ru": ["МИДиС", "INTERNATIONAL INSTITUTE OF DESIGN AND SERVICE"],
    ".miet.ru": ["National Research University of Electronic Technology"],
    ".miigaik.ru": [
        "Moscow State University of Geodesy and Cartography",
        "Moscow State University of Geodesy and Cartography",
    ],
    ".miit.ru": [
        "Russian University of Transport (MIIT)",
        "Российский университет транспорта (МИИТ)",
    ],
    ".mipt.ru": [
        "Moscow Institute of Physics and Technology",
        "Moscow Institute of Physics and Technology",
    ],
    ".mirbis.ru": [
        "Moscow International Higher Business School (MIRBIS)",
        "Moscow International Higher Business School (MIRBIS)",
    ],
    ".mirea.ru": [
        "Moscow State Institute of Radiotechnics, Electronics and Automation (Technical University)",
        "Moscow State Institute of Radiotechnics, Electronics and Automation (Technical University)",
    ],
    ".mirschool.ru": ['ГАНО "Школа и детский сад "МИР"'],
    ".misis.ru": [
        "Moscow State Institute of Steel and Alloys",
        "Moscow State Institute of Steel and Alloys",
    ],
    ".mitht.ru": [
        "Moscow Technologilac University (ITHT)",
        "Moscow State University of Fine Chemical Technologies",
    ],
    ".mkgtu.ru": ["Maikop State Technological University"],
    ".mma.ru": [
        "I.M. Sechenov Moscow Medical Academy",
        "I.M. Sechenov Moscow Medical Academy",
    ],
    ".mmamos.ru": ["Moscow International Academy", "Московская Международная Академия"],
    ".edu.mos.ru": ["ГБОУ Школа им.Полбина", "Hero of the Soviet Union I.S. Polbina"],
    ".mosconsv.ru": [
        "Moscow P. I. Tchaikovsky Conservatory",
        "Moscow P. I. Tchaikovsky Conservatory",
    ],
    ".mosgu.ru": [
        "Московский гуманитарный университет",
        "Moscow University for the Humanities",
    ],
    ".mosmetod.ru": [
        'State budgetary educational institution of the city of Moscow "Digital school"'
    ],
    ".mospolytech.ru": ["Moscow Polytechnic University"],
    ".mpei.ru": ["Moscow Power Engineering Institute"],
    ".mpt.ru": [
        "Moscow Instrument-Making College at the Russian Economic University named after G.V. Plekhanova"
    ],
    ".mrsu.ru": ["Mordovian State University", "Mordovian State University"],
    ".msaab.ru": [
        "Moscow State Academy of Applied Biotechnology",
        "Moscow State Academy of Applied Biotechnology",
    ],
    ".msiu.ru": [
        "Moscow State Industrial University",
        "Moscow State Industrial University",
    ],
    ".sch-mr.msk.ru": [
        'Государственное бюджетное общеобразовательное учреждение города Москвы "Школа Марьина Роща имени В.Ф. Орлова"'
    ],
    ".msmsu.ru": [
        "Moscow State University of Medicine and Dentistry",
        "Moscow State University of Medicine and Dentistry named after A.I.Evdokimov",
    ],
    ".mstuca.ru": [
        "Moscow State Technical University of Civil Aviation",
        "Moscow State Technical University of Civil Aviation",
    ],
    ".msu.ru": [
        "Moscow State University",
        "Moscow State University M.V. Lomonosov",
        "Moscow State University",
        "Moscow State University M.V. Lomonosov",
    ],
    ".msuee.ru": [
        "Moscow State University of Environmental Engineering",
        "Moscow State University of Environmental Engineering",
    ],
    ".msuie.ru": [
        "Moscow State University of Ecological Engineering",
        "Moscow State University of Ecological Engineering",
    ],
    ".msun.ru": ["Maritime State University"],
    ".mtuci.ru": [
        "Moscow Technical University of Informatics and Communication",
        "Moscow Technical University of Informatics and Communication",
    ],
    ".mubint.ru": ["Академия МУБиНТ", "Academy MUBiNT"],
    ".muctr.ru": ["Dmitry Mendeleev University"],
    ".muh.ru": [
        "Modern University for the Humanities",
        "Modern University for the Humanities",
    ],
    ".muiv.ru": ["Moscow Witte University"],
    ".nadip.ru": [
        "Novosibirsk Academy of Design and Programming",
        "Новосибирская академия дизайна и программирования",
    ],
    ".napks.ru": ["Vernadsky Academy of Constructuion and Architecture"],
    ".narfu.ru": [
        "Northern (Arctic) Federal University",
        "Northern (Arctic) Federal University",
    ],
    ".narhoz-chita.ru": [
        'Chita Institute (branch) SEI HPE "Baikal State University of Economics and Law"'
    ],
    ".ncfu.ru": [
        "Северо-Кавказский Федеральный Университет",
        "North-Caucasus Federal University",
    ],
    ".ncshta.ru": ["North-Caucasian State Humanities and Technological Academy"],
    ".ncstu.ru": [
        "Stavropol State Technical University",
        "Stavropol State Technical University",
    ],
    ".nes.ru": ["New Economic School", "New Economic School"],
    ".net-ustu.ru": ["Ural State Technical University"],
    ".neva.ru": [
        "St. Petersburg State Technical University",
        "St. Petersburg State Technical University",
    ],
    ".ngknn.ru": [
        "Нижегородский Губернский колледж",
        "Nizhny Novgorod Gubernskiy College",
    ],
    ".nieup.ru": [None],
    ".nirhtu.ru": [
        'Новомосковский институт (филиал) федерального государственного бюджетного образовательного учреждения высшего образования "Российский химико-технологический университет имени Д.И. Менделеева"',
        'Novomoskovsk Institute (branch) of the Federal state budgetary educational institution of higher education "Dmitry Mendeleev University of Chemical Technology of Russia"',
    ],
    ".niuitmo.ru": [
        "St. Petersburg State University of Information Technologies, Mechanics and Optics",
        "St. Petersburg State University of Information Technologies, Mechanics and Optics",
    ],
    ".nke.ru": [
        "Новосибирский колледж электроники и вычислительной техники",
        "Novosibirsk College of Electronics and Computer Engineering",
    ],
    ".nngasu.ru": [
        "Nizhniy Novgorod State University of Architecture and Civil Engineering"
    ],
    ".nntc.nnov.ru": ["Radio Engineering College Nizhny Novgorod"],
    ".uic.nnov.ru": ["Lobachevsky State University of Nizhni Novgorod"],
    ".nntu.ru": [
        "Nizhny Novgorod State Technical University named after R.E. Alekseev"
    ],
    ".norna.ru": [
        "Moscow State University of Civil Engineering",
        "Moscow State University of Civil Engineering",
    ],
    ".norvuz.ru": ["Norilsk State Industrial Institute"],
    ".nosu.ru": ["North Ossetian State University", "North Ossetian State University"],
    ".novsu.ru": ["Novgorod State University of Yaroslav the Wise"],
    ".npi-tu.ru": [
        "Южно-Российский государственный политехнический университет (НПИ) имени М.И. Платова",
        "Platov South-Russian State Polytechnic University (NPI)",
    ],
    ".nsc.ru": [
        "Novosibirsk State Medical Academy",
        "Novosibirsk State Medical Academy",
    ],
    ".nsmu.ru": [
        "Northern State Medical University",
        "Northern State Medical University",
    ],
    ".nspu.ru": [
        "Новосибирский государственный педагогический университет",
        "Novosibirsk State Pedagogical University",
    ],
    ".stud.nstu.ru": [
        "NSTU - Novosibirsk State Technical University",
        "username@stud.nstu.ru",
        "http://www.nstu.ru/",
    ],
    ".nstu.ru": [
        "Novosibirsk State Technical University",
        "Novosibirsk State Technical University",
    ],
    ".g.nsu.ru": [
        "Novosibirsk State University",
        "Новосибирский государственный университет",
    ],
    ".nsu.ru": ["Novosibirsk State University", "Novosibirsk State University"],
    ".nsuem.ru": ["  Novosibirsk State University of Economics and Management"],
    ".nvsu.ru": [
        "Нижневартовский государственный университет",
        "NIZHNEVARTOVSK STATE UNIVERSITY (NVSU)",
    ],
    ".nwpi.ru": [
        "North-West State Technical University",
        "North-West State Technical University",
    ],
    ".oat.ru": [
        "Омский авиационный колледж имени Н.Е.Жуковского",
        "Omsk aviation College named after N. E.Zhukovsky",
    ],
    ".obninsk.ru": [
        "Obninsk State Technical University for Nuclear Power Engineering",
        "Obninsk State Technical University for Nuclear Power Engineering",
    ],
    ".og-ti.ru": ["Orsk humanitarian-technological Institute (branch) OSU"],
    ".oiate.ru": [
        "Obninsk Institute for Nuclear Power Engineering",
        "IATE MEPHI",
        "Обнинский институт атомной энергетики (ИАТЭ)",
        "ИАТЭ НИЯУ МИФИ",
    ],
    ".oksei.ru": [
        'ГАПОУ "Оренбургский колледж экономики и информатики"',
        "Orenburg College of Economics and Informatics",
    ],
    ".oktb.ru": [
        "\ufeff«Образовательный комплекс «Точка будущего»",
        'Educational complex "Point of future"',
    ],
    ".omgau.ru": ["Omsk State Agrarian University", "Omsk State Agrarian University"],
    ".omgpu.ru": ["Omsk State Pedagogical Universtity"],
    ".omgtu.ru": ["Omsk State Technical University", "Omsk State Technical University"],
    ".omgups.ru": [
        "Omsk State Transport University",
        "Omsk State Transport University",
    ],
    ".omsk-osma.ru": ["Omsk State Medicical Academy", "Omsk State Medicical Academy"],
    ".omsu.ru": ["Omsk State University", "Omsk State University"],
    ".oreluniver.ru": ["Orel State University"],
    ".orun.ru": ["Oriental University", "Oriental University"],
    ".ostu.ru": ["Orel State Technical University"],
    ".osu.ru": ["Orenburg State University", "Orenburg State University"],
    ".pbrea.ru": [None],
    ".permaviat.ru": ["КГАПОУ «Пермский авиационный техникум им. А.Д. Швецова»"],
    ".petrocollege.ru": [None, "Petrovsky college"],
    ".petrsu.ru": ["Petrozavodsk State University"],
    ".pfncfu.ru": ["Institute of service, tourism and design in Pyatigorsk"],
    ".pfur.ru": [" People Friendship University of Russia"],
    ".pglu.ru": [
        "Pjatigorsk State Linguistic University",
        "Pjatigorsk State Linguistic University",
    ],
    ".pgups.ru": ["ST. PETERSBURG STATE TRANSPORT UNIVERSITY"],
    ".phtt.ru": [
        "ГБПОУ «Пермский химико-технологический техникум»",
        'GBPOU "Permskij himiko-tehnologicheskij tehnikum"',
    ],
    ".pktm.ru": ["Povolzhsky College of Technologies and Management Balakovo"],
    ".pl36angarsk.ru": ["Angarsk College of Advertising and Industrial Technology"],
    ".pml30.ru": ["\ufeffPhysics and Mathematics Lyceum No. 30, St. Petersburg"],
    ".pnzgu.ru": ["Penza State University"],
    ".pomorsu.ru": [
        "Pomorsk State University",
        "Pomor State University",
        "Pomorsk State University",
        "Pomor State University",
    ],
    ".prgusa.ru": ["Sholem Aleichem Amur State University"],
    ".pro-college.ru": [
        "kolledzh prava ekonomiki i upravleniya",
        "College of Economics and Management Law",
    ],
    ".protonmos.ru": [
        '\ufeffГосударственное бюджетное общеобразовательное учреждение города Москвы "Образовательный центр "Протон"'
    ],
    ".psati.ru": ["Povolzhsky State University of Telecommunications and Informatics"],
    ".psfa.ru": [
        "Perm State Pharmaceutical Academy",
        "Perm State Pharmaceutical Academy",
    ],
    ".pskgu.ru": ["Pskov state university"],
    ".psma.ru": ["Perm State Medical Academy", "Perm State Medical Academy"],
    ".psoh46.ru": ["V.P. Astafiev's Podtesovo School"],
    ".pspu.ru": ["Perm State Humanitarian-Pedagogical University"],
    ".pstu.ru": ["Perm National Research Polytechnic University"],
    ".psu.ru": ["Perm State University", "Perm State University"],
    ".psuti.ru": ["Povolzhsky State University of Telecommunications and Informatics"],
    ".kspu.ptz.ru": [
        "Karelian State Pedagogical University",
        "Karelian State Pedagogical University",
    ],
    ".pu.ru": ["Saint Petersburg State University"],
    ".pushgu.ru": [
        "Пущинский государственный естественно-научный институт",
        "Pushchino State Institute of Natural Science",
    ],
    ".rah.ru": ["Russian Academy of Arts", "Russian Academy of Arts"],
    ".ranepa.ru": [
        "Russian Presidential Academy of National Economy and Public Administration"
    ],
    ".chph.ras.ru": [
        "ФИЦ химической физики им. Н.Н. Семенова Российской академии наук (ФИЦ ХФ РАН)",
        "N. N. Semenov Institute of Chemical Physics, Russian Academy of Science",
    ],
    ".rbiu.ru": [
        "Международный Институт Дизайна и Сервиса",
        "International Institute of Design & Service",
    ],
    ".rea.ru": [
        "Plekhanov Russian Academy of Economics",
        "Plekhanov Russian Academy of Economics",
    ],
    ".rfet.ru": [
        "Профессиональная образовательная организация ассоциация «Региональный финансово-экономический техникум»",
        "РФЭТ",
    ],
    ".rgau-msha.ru": [
        "Федеральное государственное бюджетное образовательное учреждение высшего образования «Российский государственный аграрный университет – МСХА имени К.А.Тимирязева» ФГБОУ ВО РГАУ-МСХА имени К.А. Тимирязева",
        "Russian State Agrarian University - Moscow Timiryazev Agricultural Academy",
    ],
    ".rggu.ru": ["Russian State University for the Humanities"],
    ".rgsu.ru": [
        "Rostov State University of Civil Engineering",
        "Ростовский Государственный Строительный Университет",
    ],
    ".rguk.ru": [
        "Kosygin Russian State University, Moscow",
        "Российский Государственный Университет имени А.Н.Косыгина, Москва",
    ],
    ".rgups.ru": [
        'ФГБОУ ВО "Ростовский государственный университет путей сообщения"',
        "Rostov State Transport University",
    ],
    ".it.rksi.ru": [
        "Государственное бюджетное профессиональное образовательное учреждение Ростовской области «Ростовский-на-Дону колледж связи и информатики» (ГБПОУ РО «РКСИ»)",
        'State Budgetary Professional Educational Institution "Rostov-on-Don College of Communication and Informatics»',
    ],
    ".stud.rksi.ru": [
        "Государственное бюджетное профессиональное образовательное учреждение Ростовской области «Ростовский-на-Дону колледж связи и информатики» (ГБПОУ РО «РКСИ»)",
        'State Budgetary Professional Educational Institution "Rostov-on-Don College of Communication and Informatics»',
    ],
    ".rosnou.ru": ["Russian New University (RosNOU)"],
    ".rsatu.ru": [
        "Рыбинский государственный авиационный технический университет имени П. А. Соловьева",
        "Rybinsky State Aviation Technical University named after P. A. Soloviev",
    ],
    ".rshu.ru": [
        "Russian State Hydrometeorological University",
        "Russian State Hydrometeorological University",
    ],
    ".rsmu.ru": [
        "Russian State Medical University",
        "Russian State Medical University",
    ],
    ".rsreu.ru": ["Ryazan State Radio Engineering University"],
    ".rsu.ru": ["Rostov State University", "Rostov State University"],
    ".rsue.ru": ["Rostov State University of Economics"],
    ".rsuh.ru": [
        "Russian State University for the Humanities",
        "Russian State University for the Humanities",
    ],
    ".rsvpu.ru": ["Russian State Vocational Pedagogical University"],
    ".rubinst.ru": [
        "Рубцовский индустриальный институт (филиал) Алтайского государственного технического университета им. Ползунова",
        "RII AltSTU",
    ],
    ".rucoop.ru": [
        "Russian University of Cooperation",
        "Автономная некоммерческая образовательная организация высшего образования Центросоюза Российской Федерации «Российский университет кооперации»",
    ],
    ".rudn.ru": ["Университет Дружбы Народов", "RUDN University"],
    ".runnet.ru": [
        "Krasnoyarsk State Technical University",
        "Saratov State Socio-Economic University",
        "Krasnoyarsk State Technical University",
        "Saratov State Socio-Economic University",
    ],
    ".edu.rut-miit.ru": [
        "Российский университет транспорта РУТ (МИИТ)",
        "Federal State Institution of Education «Russian University of Transport»",
    ],
    ".s-vfu.ru": [
        "North-Eastern Federal University",
        "North-Eastern Federal University",
    ],
    ".s1411.ru": ["School 1411", "Школа 1411"],
    ".s146.ru": ["МАОУ СОШ №146 с УИМФИ г.Перми"],
    ".sakhgu.ru": [
        "Сахалинский государственный университет",
        "Sakhalin State University",
    ],
    ".samgk.ru": ["Самарский государственный колледж", "Samara state college"],
    ".samgtu.ru": ["Samara State Technical University"],
    ".samgups.ru": [
        "\ufeffСамарский государственный университет путей сообщения",
        "Samara State University of Railway Engineering",
    ],
    ".samiit.ru": [
        "Samara State Academy for Railway Transportation",
        "Samara State Academy for Railway Transportation",
    ],
    ".samsmu.ru": [
        "Samara State Medical University",
        "Samara State Medical University",
    ],
    ".sano.ru": ["Siberian Institute of Business and Information Technologies"],
    ".sao.ru": [
        "Специальная астрофизическая обсерватория Российской академии наук",
        "The Special Astrophysical Observatory of the Russian Academy of Sciences",
    ],
    ".sapanet.ru": [
        "Siberian Academy of Public Services",
        "Siberian Academy of Public Services",
    ],
    ".scamt-itmo.ru": [
        "SCAMT Institute of ITMO University, Saint-Petersburg",
        "https://scamt.ifmo.ru/",
    ],
    ".sch-int.ru": ['ГБОУ Школа "Интеллектуал"'],
    ".sch12.ru": ["School 12 of Petrozavodsk, Russia"],
    ".sch1349.ru": ["State Budgetary Educational Institution of Moscow School 1349"],
    ".sch1550.ru": ["школа 1550 города Москвы it"],
    ".students.sch2.ru": ["Лицей Вторая Школа", "Lyceum Second School"],
    ".sch508.ru": ["School 508, Moscow, Russia"],
    ".sch57.ru": [
        '\ufeffГосударственное бюджетное общеобразовательное учреждение города Москвы "Пятьдесят седьмая школа"',
        "School 57, Moscow, Russia",
    ],
    ".schelcol.ru": ["Schelkovsky college"],
    ".school1015.ru": [
        "ГБОУ г.Москвы Школа 1015",
        "Moscow State Budgetary Educational Institution School 1015",
    ],
    ".school548.ru": ["ГАОУ Школа №548", "Moscow School 548"],
    ".schoolmail.ru": [
        "Школьный Портал Московской области",
        "School Portal of the Moscow Region",
    ],
    ".sci-nnov.ru": [
        "Linguistic University of Nizhny Novgorod",
        "Nizhny Novgorod State Architectural - Building University",
        "Nizhny Novgorod State Technical University",
        "Volga State Academy of Water Transport",
        "Linguistic University of Nizhny Novgorod",
        "Nizhny Novgorod State Architectural - Building University",
        "Nizhny Novgorod State Technical University",
        "Volga State Academy of Water Transport",
    ],
    ".elearn.sde.ru": ["Moscow State Industrial University"],
    ".sechenov.ru": [
        "ФГАОУ ВО Первый МГМУ им. И.М. Сеченова Минздрава России (Сеченовский Университет)",
        "Federal State Autonomous Educational Institution of Higher Education I.M. Sechenov First Moscow State Medical University of the Ministry of Health of the Russian Federation (Sechenov University)",
    ],
    ".secna.ru": [
        "Altai State Technical University",
        "Altai State Technical University",
    ],
    ".sever.ru": [
        "Ukhta State Technical University",
        "Ukhta State Technical University",
    ],
    ".sevsu.ru": ["Sevastopol State University"],
    ".sfedu.ru": ["Southern Federal University"],
    ".sfek.ru": ["RSBE Semey financial-economic college named after Rymbek Baiseitov"],
    ".sfu-kras.ru": ["Siberian Federal University"],
    ".sgap.ru": ["Saratov State Academy of Law", "Saratov State Academy of Law"],
    ".sgau.ru": [
        "Saratov State Agrarian University",
        "Saratov State Agrarian University",
    ],
    ".sgspu.ru": [
        "Самарский государственный социально-педагогический университет",
        "Samara State Social and Pedagogical University",
    ],
    ".sgu.ru": [
        "Saratov State Medical University",
        "Saratov State University",
        "Saratov State Medical University",
        "Saratov State University",
    ],
    ".sgugit.ru": [
        "Сибирский государственный университет геосистем и технологий",
        "Siberian state university of geosystems and technologies",
    ],
    ".stud.sibguti.ru": [
        "Siberian State University of Telecommunications and Information Sciences"
    ],
    ".sibguti.ru": [
        "Siberian State University of Telecommunications and Information Sciences"
    ],
    ".sibsau.ru": ["Siberian State Aerospace University"],
    ".sibsiu.ru": [
        "Сибирский государственный индустриальный университет",
        "Siberian State Industrial University",
    ],
    ".edu.sibstrin.ru": [
        "NOVOSIBIRSK STATE UNIVERSITY OF ARCHITECTURE AND CIVIL ENGINEERING(SIBSTRIN) "
    ],
    ".sibsutis.ru": [
        "Siberian State University of Telecommunications and Information Sciences"
    ],
    ".skf-mtusi.ru": [
        "Северо-Кавказский филиал ордена Трудового Красного Знамени федерального государственного бюджетного образовательного учреждения высшего образования «Московский технический университет связи и информатики»",
        "North Caucasus branch of Moscow Technical University of Communications and Informatics",
    ],
    ".skolkovotech.ru": ["Skolkovo Institute of Science and Technology"],
    ".skoltech.ru": ["Skolkovo Institute of Science and Technology"],
    ".smolapo.ru": [
        "ОГБПОУ СмолАПО",
        "OGBPOU Smolensk academy of professional education",
    ],
    ".smolgu.ru": ["Smolensk State University"],
    ".smr.ru": [
        "Samara State Academy of Architecture and Civil Engineering",
        "Samara State Academy of Architecture and Civil Engineering",
    ],
    ".smtu.ru": [
        "St. Petersburg State Marine Technical University",
        "St. Petersburg State Marine Technical University",
    ],
    ".smuit.ru": [
        "Самарский государственный медицинский университет (СамГМУ)",
        "Samara State Medical University",
    ],
    ".edu-frn.spb.ru": [
        "Государственное бюджетное общеобразовательное учреждение средняя общеобразовательная школа №368 с углубленным изучением английского языка Фрунзенского района Санкт-Петербурга"
    ],
    ".eu.spb.ru": [
        "European University at St.Petersburg",
        "European University at St.Petersburg",
    ],
    ".gti.spb.ru": [
        "St. Petersburg State Institute of Technology (Technological University)",
        "St. Petersburg State Institute of Technology (Technological University)",
    ],
    ".gturp.spb.ru": [
        "St. Petersburg State Technological University of Plant Polymers",
        "St. Petersburg State Technological University of Plant Polymers",
    ],
    ".herzen.spb.ru": [
        "Российский государственный педагогический университет им. А. И. Герцена",
        "The Herzen State Pedagogical University of Russia",
    ],
    ".ibi.spb.ru": [
        "International Banking Institute, St. Petersburg",
        "International Banking Institute, St. Petersburg",
    ],
    ".nilc.spb.ru": [
        "Nevsky Institute of Language and Culture",
        "Nevsky Institute of Language and Culture",
    ],
    ".school644.spb.ru": [
        "State Free Educational Institution School No. 644, Primorsky District Of Saint-Petersburg",
        "GBOU School No. 644, Primorsky District Of Saint-Petersburg",
    ],
    ".smolny-un.spb.ru": ["Smolny University", "Smolny University"],
    ".spbgau.spb.ru": [
        "St. Petersburg State Agrarian University",
        "St. Petersburg State Agrarian University",
    ],
    ".tart.spb.ru": [
        "St. Petersburg State Theatre Arts Academy",
        "St. Petersburg State Theatre Arts Academy",
    ],
    ".spb-rtk.ru": [
        "Санкт-Петербургское государственное бюджетное профессиональное образовательное учреждение `Радиотехнический колледж`"
    ],
    ".spbau.ru": ["SPB Academic University"],
    ".spbftu.ru": [
        "Санкт-Петербургский государственный лесотехнический университет имени С.М.Кирова",
        "Saint-Petersburg forest technical university",
    ],
    ".spbgasu.ru": [
        "St. Petersburg State University of Architecture and Civil Engineering",
        "St. Petersburg State University of Architecture and Civil Engineering",
    ],
    ".spbguki.ru": [
        "St. Petersburg State University of Culture and Arts",
        "St. Petersburg State University of Culture and Arts",
    ],
    ".spbgut.ru": [
        "The Bonch-Bruevich Saint - Petersburg State University of Telecommunications"
    ],
    ".spbstu.ru": [
        "St. Petersburg State Polytechnical University",
        "St. Petersburg State Polytechnical University",
    ],
    ".spbu.ru": ["St. Petersburg State University", "St. Petersburg State University"],
    ".spbuwc.ru": [
        "St. Petersburg State University of Waterway Communications",
        "St. Petersburg State University of Waterway Communications",
    ],
    ".spcpa.ru": [
        "St. Petersburg State Chemical Pharmaceutical Academy",
        "St. Petersburg State Chemical Pharmaceutical Academy",
    ],
    ".spcras.ru": [
        "Санкт-Петербургский Федеральный исследовательский центр Российской академии наук",
        "St. Petersburg Federal Research Center of the Russian Academy of Sciences",
    ],
    ".sphti.ru": ["Снежинский физико-технический институт НИЯУ МИФИ (СФТИ НИЯУ МИФИ)"],
    ".spmi.ru": ["National Mineral Resources University"],
    ".spobip-bel.ru": [
        "ЧАСТНОЕ УЧРЕЖДЕНИЕ ПРОФЕССИОНАЛЬНАЯ ОБРАЗОВАТЕЛЬНАЯ ОРГАНИЗАЦИЯ ТЕХНИКУМ “БИЗНЕС И ПРАВО”"
    ],
    ".spsu.ru": ["ПГУ им. Т.Г. Шевченко", "SPSU"],
    ".srshb.ru": ["Siberian regional business school"],
    ".ssaa.ru": [
        "Samara State Agricultural Academy",
        "Samara State Agricultural Academy",
    ],
    ".ssau.ru": [
        "Samara State Aerospace University",
        "Samara State Aerospace University",
    ],
    ".sseu.ru": [
        "Samara State University of Economics",
        "Samara State University of Economics",
    ],
    ".ssmu.ru": [
        "Siberian State Medical University",
        "Siberian State Medical University",
    ],
    ".sssu.ru": [
        "Институт сферы обслуживания и предпринимательства (филиала) ДГТУ в г. Шахты"
    ],
    ".sstu-edu.ru": [
        "Saratov State Technical University",
        "Saratov State Technical University",
    ],
    ".sstu.ru": ["Saratov State Technical University"],
    ".ssuedu.ru": ["Syktyvkar State University"],
    ".stankin.ru": [
        "Moscow State University of Technology (Stankin)",
        "Moscow State University of Technology (Stankin)",
    ],
    ".stavsu.ru": ["Stavropol State University", "Stavropol State University"],
    ".stgau.ru": [
        "Stavropol State Agrarian University",
        "Stavropol State Agrarian University",
    ],
    ".strbsu.ru": ["Sterlitamak Branch of Bashkir State University"],
    ".stu.ru": [
        "Siberian State Transport University",
        "Siberian State Transport University",
    ],
    ".studklg.ru": [
        "Tsiolkovsky Kaluga State University",
        "Students email domain of Tsiolkovsky Kaluga State University",
    ],
    ".suai.ru": [
        "St. Petersburg State University of Aerospace Instrumentation",
        "St. Petersburg State University of Aerospace Instrumentation",
    ],
    ".suitd.ru": [
        "СПбГУПТД Высшая Школа Технологии и Энергетики",
        "SPbSUTD Higher School of Technology and Energy",
    ],
    ".surgu.ru": ["Surgut State University"],
    ".surpk.ru": ["Surgut Professional College"],
    ".sursau.ru": ["South Ural State Agrarian University"],
    ".susu.ru": ["South Ural State University"],
    ".sut.ru": [
        "St. Petersburg State University of Telecommunication",
        "St. Petersburg State University of Telecommunication",
    ],
    ".sutd.ru": [
        "St. Petersburg State University of Technology and Design",
        "St. Petersburg State University of Technology and Design",
    ],
    ".sutr.ru": [
        'ФГБОУ ВО "Сочинский государственный университет"',
        "Sochi State University",
    ],
    ".edu.swissam.ru": [
        "Swissam Hospitality Business School",
        "Swissam Hospitality Business School",
    ],
    ".syktsu.ru": ["Syktyvkar State University named after Pitirim Sorokin"],
    ".synergy.ru": ["Университет Синергия", "Synergy University"],
    ".synergyedu.ru": [
        'Московский финансово-промышленный университет "Синергия"',
        "Synergy University",
    ],
    ".taom.ru": [
        "ТАУ тольяттинская академия управления ",
        "Togliatti Academy of Management (TAOM)",
    ],
    ".edu.tatar.ru": ["Schools of Tatarstan"],
    ".tatngpi.ru": [
        "The Naberezhnye Chelny Institute of Social and Educational Technologies and Resources"
    ],
    ".tfrggu.ru": ["Branch of Russian State University of Humanity in Togliatty"],
    ".tgmu.ru": ["Pacific State Medical University"],
    ".theatrins-yar.ru": [
        "Yaroslavl State Theatre Institute",
        "Yaroslavl State Theatre Institute",
    ],
    ".tim-stud.ru": [
        "Российский государственный аграрный университет - МСХА им. К.А. Тимирязева",
        "Russian State Agrarian University - Moscow Timiryazev Agricultural Academy",
    ],
    ".timacad.ru": [
        "Timirjazev Moscow Academy of Agricultutre",
        "Timirjazev Moscow Academy of Agricultutre",
    ],
    ".tksu.ru": [
        "Tsiolkovsky Kaluga State University",
        "Tsiolkovsky Kaluga State University",
    ],
    ".tltsu.ru": ["Togliatti State University", "Togliatti State University"],
    ".tmn.ru": ["Tyumen State University", "Tyumen State University"],
    ".tolgas.ru": [
        "ПОВОЛЖСКИЙ ГОСУДАРСТВЕННЫЙ УНИВЕРСИТЕТ СЕРВИСА",
        "VOLGA REGION STATE UNIVERSITY OF SERVICE",
    ],
    ".tomintech.ru": [
        "Tomsk Industrial Technical School",
        "TomInTech",
        "Томский Индустриальный Техникум",
    ],
    ".tib.tomsk.ru": ["Tomsk Institute of Business", "Томский институт бизнеса"],
    ".tomtit.tomsk.ru": ["Tomsk College of Information Technologies"],
    ".touro.ru": ["Moscow University Touro", "Moscow University Touro"],
    ".tpu.ru": ["Tomsk Polytechnic University", "Tomsk Polytechnic University"],
    ".tsma.ru": ["Tver State Medical Academy", "Tver State Medical Academy"],
    ".tsogu.ru": [
        "Tyumen State University of Gas and Oil",
        "Tyumen State University of Gas and Oil",
    ],
    ".tstu.ru": [
        "Tambov State Technical University",
        "Tambov State Technical University",
    ],
    ".tsu.ru": ["Tomsk State University", "Tomsk State University"],
    ".tsuab.ru": [
        "Tomsk State University of Architecture and Building",
        "Tomsk State University of Architecture and Building",
    ],
    ".tsure.ru": [
        "Taganrog State University of Radioengineering",
        "Taganrog State University of Radioengineering",
    ],
    ".ttn.ru": [
        "Taganrog State Pedagogical Institute",
        "Taganrog State Pedagogical Institute",
    ],
    ".tu-bryansk.ru": [
        "Brjansk State Technical University",
        "Brjansk State Technical University",
    ],
    ".tsu.tula.ru": [
        "Tula State University",
        "Tula State University",
        "Tula State University",
    ],
    ".tusur.ru": [
        "Tomsk State University of Control Systems and Radioelectronics",
        "Tomsk State University of Control Systems and Radioelectronics",
    ],
    ".tuvsu.ru": ["Tuva State University", "Tuva State University"],
    ".tstu.tver.ru": [
        "Tver State Technical University",
        "Tver State Technical University",
    ],
    ".tversu.ru": ["Tver State University", "Tver State University"],
    ".tyuiu.ru": ["Tyumen industrial University"],
    ".uapa.ru": [
        "Ural Academy of Public Administration",
        "Ural Academy of Public Administration",
    ],
    ".uni.udm.ru": ["Udmurt State University", "Udmurt State University"],
    ".udsu.ru": ["Udmurt State University"],
    ".uef.ru": [
        "St. Petersburg State University of Economics and Finance",
        "St. Petersburg State University of Economics and Finance",
    ],
    ".uemc73.ru": ["Ulyanovsk Electromechanical College"],
    ".ugkp.ru": [
        "Ural State College named by Ivan Polzunov",
        "Уральский государственный колледж имени И. И. Ползунова",
    ],
    ".ugrafmsh.ru": [
        "Ugra Physics and Mathematics Lyceum",
        "Югорский физико-математический лицей-интернат",
    ],
    ".ugrasu.ru": ["Yugra State University"],
    ".uisi.ru": ["Ural Technical Institute of Communications and Informatics"],
    ".ukrtb.ru": [
        "Государственное бюджетное профессиональное образовательное учреждение Уфимский колледж радиоэлектроники, телекоммуникаций и безопасности",
        " State budgetary professional educational institution Ufa College of Radio Electronics, Telecommunications and Security",
    ],
    ".uksivt.ru": [
        "Уфимский колледж статистики, информатики и вычислительной техники",
        "УКСИВТ",
    ],
    ".ulstu.ru": [
        "Ulyanovsk State Technical University",
        "Ulyanovsk State Technical University",
    ],
    ".ulsu.ru": ["Ulyanovsk State University", "Ulyanovsk State University"],
    ".unecon.ru": [
        "SAINT-PETERSBURG STATE UNIVERSITY OF ECONOMICS",
        "SAINT-PETERSBURG STATE UNIVERSITY OF ECONOMICS",
    ],
    ".uni-dubna.ru": [
        "Dubna International University for Nature, Society and Man",
        "Dubna International University for Nature, Society and Man",
    ],
    ".unitech-mo.ru": ["Moscow region University of Technology"],
    ".unn.ru": ["LOBACHEVSKY STATE UNIVERSITY OF NIZHNI NOVGOROD (UNN)"],
    ".imm.uran.ru": [
        "Институт математики и механики им. Н.Н.Красовского УрО РАН",
        "N.N. Krasovskii Institute of Mathematics and Mechanics (IMM UB RAS)",
    ],
    ".urfu.ru": ["Ural Federal University"],
    ".urpc.ru": ['ГАПОУ СО "Уральский политехнический колледж - МЦК"'],
    ".ursmu.ru": [
        "Уральский Государственный Горный Университет",
        "The Ural State Mining University",
    ],
    ".urtt.ru": [
        "Уральский Радиотехнический Колледж имени А. С. Попова (УРТК)",
        "Ural Radio Technical College named after A.S. Popov (URTK)",
    ],
    ".usaaa.ru": [
        "Ural State Academy of Architecture and Arts",
        "Ural State Academy of Architecture and Arts",
    ],
    ".usart.ru": [
        "Ural State Academy of Railway Transport",
        "Ural State Academy of Railway Transport",
    ],
    ".usfea.ru": [
        "Ural State Forestry Technical Academy",
        "Ural State Forestry Technical Academy",
    ],
    ".usla.ru": ["Ural State Academy of Law", "Ural State Academy of Law"],
    ".usmga.ru": [
        "Ural State Academy of Mining and Geology",
        "Ural State Academy of Mining and Geology",
    ],
    ".ustu.ru": ["Ural State Technical University", "Ural State Technical University"],
    ".usu.ru": ["Ural Gorkij State University", "Ural Gorkij State University"],
    ".usue.ru": [
        "Ural State University of Economics",
        "Ural State University of Economics",
    ],
    ".student.usurt.ru": [
        "Уральский государственный Университет Путей Сообщения",
        "Ural State University of Railway Transport",
    ],
    ".usurt.ru": [
        "ФГБОУ ВО Уральский государственный университет путей сообщения",
        "Ural State University of Railway Transport",
    ],
    ".ut-mo.ru": ["Moscow region University of Technology"],
    ".utmn.ru": ["Tyumen State University"],
    ".uvauga.ru": [
        "Ulyanovsk Higher School of Civil Aviation",
        "Ulyanovsk Higher School of Civil Aviation",
    ],
    ".uven.ru": ["Ulyanovsk State University", "Ulyanovsk State University"],
    ".vavt.ru": ["ВАВТ Минэкономразвития РФ", "RFTA"],
    ".vemst.ru": [
        "Кировское  областное государственное профессиональное образовательное автономное учреждение  «Вятский электромашиностроительный техникум» ",
        'Kirov Regional State Vocational Educational Autonomous Institution "Vyatka Electric Engineering College"',
    ],
    ".vgafk.ru": [
        "Volgograd State Academy of Physical Education",
        "Volgograd State Academy of Physical Education",
    ],
    ".vgapkro.ru": [
        "Волгоградская государственная академия последипломного образования",
        "Volgograd state Academy Postgraduate Education",
    ],
    ".vgasa.ru": [
        "Volgograd State University of Architecture and Civil Engineering (VolgGASU)",
        "Volgograd State University of Architecture and Civil Engineering (VolgGASU)",
    ],
    ".vgppk.ru": ["Voronezh State Vocational and Pedagogical College"],
    ".vieup.ru": [
        "NGO Vladikavkaz Institute of Economics, Management, and Law",
        "NGO Vladikavkaz Institute of Economics, Management, and Law",
    ],
    ".vimvd.ru": ["Voronezh Institute of the Ministry of the Interior of Russia"],
    ".viti-mephi.ru": [
        'Volgodonsk engineering technical Institute, branch of National Research Nuclear University "MEPhI"'
    ],
    ".vivt.ru": ["Voronezh Institute of High Technologies"],
    ".vlsu.ru": ["Vladimir State University", "Vladimir State University"],
    ".voenmeh.ru": ['Baltic State Technical University "Voenmeh"'],
    ".vogu35.ru": [
        "Вологодский государственный университет",
        "Vologda State University",
    ],
    ".volgmed.ru": ["Volgograd State Medical University"],
    ".volpi.ru": ["Volzhsky Polytechnic Institute", "Volzhsky Polytechnic Institute"],
    ".volsu.ru": ["Volgograd State University", "Volgograd State University"],
    ".vgasu.vrn.ru": [
        "Voronezh State University of Architecture and Civil Engineering"
    ],
    ".vsau.ru": [
        "Voronezh State Agricultural University",
        "Voronezh State Agricultural University",
    ],
    ".vsiem.ru": [
        'НПОУ "Якутский колледж инновационных технологий"',
        'Non-state professional educational institution "Yakutsk College of Innovative Technologies"',
    ],
    ".vspu.ru": [
        "Volgograd State Pedagogical University",
        "Volgograd State Pedagogical University",
    ],
    ".vstu.ru": [
        "Volgograd State Technical University",
        "Volgograd State Technical University",
    ],
    ".vsu.ru": ["Voronezh State University", "Voronezh State University"],
    ".vtk-portal.ru": [
        "Volgograd College of Technology",
        "Волгоградский технологический колледж",
    ],
    ".vvsu.ru": [
        "Vladivostock State University of Economics",
        "Vladivostock State University of Economics",
    ],
    ".vyatsu.ru": ["Vyatka State University"],
    ".wsnet.ru": ["Surgut State University", "Surgut State University"],
    ".yakit.ru": [
        'НПОУ "Якутский колледж инновационных технологий"',
        'Non-state professional educational institution "Yakutsk College of Innovative Technologies"',
    ],
    ".do.yanao.ru": [
        "Государственное бюджетное профессиональное образовательное учреждение Ямало-Ненецкого автономного округа «Ямальский многопрофильный колледж»",
        'State Budgetary Professional Educational Institution of Yamalo-Nenets Autonomous Okrug "Yamal Multidisciplinary College"',
    ],
    ".yandexlyceum.ru": ["Yandex Lyceum", "Yandex Lyceum"],
    ".yar.ru": [
        "Yaroslavl International University of Business and New Technologies",
        "Yaroslavl State Pedagogical University",
        "Yaroslavl State Technical University",
        "Yaroslavl International University of Business and New Technologies",
        "Yaroslavl State Pedagogical University",
        "Yaroslavl State Technical University",
    ],
    ".yola15.ru": ["School 15 of Yoshkar-Ola, Russia"],
    ".ypec.ru": [
        "Ярославский промышленноэкономический колледж. ЯПЭК",
        "Yaroslavl Industrial and Economic College. YPEC",
    ],
    ".ikfia.ysn.ru": [
        "Институт космофизических исследований и аэрономии им. Ю.Г. Шафера Сибирского отделения Российской академии наук",
        "Yu.G. Shafer Institute of Cosmophysical Research and Aeronomy",
    ],
    ".ystu.ru": [
        "Yaroslavl State Technical University",
        "Yaroslavl State Technical University",
    ],
    ".ysu.ru": ["Yakutsk State University", "Yakutsk State University"],
    ".zabgc.ru": [
        "Забайкальский горный колледж им. М.И. Агошкова",
        "Zabaykalsky mining College named after M. I. Agoshkov",
    ],
    ".zabgu.ru": [
        "Забайкальский государственный университет",
        "Transbaikal State University",
    ],
    ".zau.ru": ["Zaoksky Christian Humanitarian-Economic Institute"],
    ".zhat.ru": ["ГБПОУ МО «Авиационный техникум имени В.А. Казакова»"],
    ".auca.ac.rw": ["Adventist University of Central Africa"],
    ".nur.ac.rw": ["National University of Rwanda"],
    ".uck.ac.rw": ["Kabgayi Catholic University"],
    ".ulk.ac.rw": ["Kigali Independent University"],
    ".alyamamah.edu.sa": ["Al-Yamamah College"],
    ".bmc.edu.sa": ["Batterjee Medical College"],
    ".bpc.edu.sa": ["Buraydah College for Applied Medical Sciences"],
    ".bu.edu.sa": ["Al-baha University"],
    ".cba.edu.sa": ["College of Busniess Admnistration"],
    ".cti.edu.sa": ["College of Telecommunication &amp; Information "],
    ".daralhekma.edu.sa": ["Dar al Hekma College"],
    ".dau.edu.sa": ["Dar Al-Uloom Colleges"],
    ".dcc.edu.sa": ["Dammam Community College"],
    ".effatcollege.edu.sa": ["Effat College"],
    ".fbsc.edu.sa": ["Fahad Bin Sultan University"],
    ".ibnsina.edu.sa": ["Ibn Sina National College for Medical Studies "],
    ".imamu.edu.sa": ["Al-Imam Mohamed Ibn Saud Islamic University"],
    ".ipa.edu.sa": ["Institute of Public Administration"],
    ".iu.edu.sa": ["Islamic University of Medinah"],
    ".jazanu.edu.sa": ["Jazan University"],
    ".jct.edu.sa": ["College of Technology at Jeddah"],
    ".jic.edu.sa": ["Jubail Industrial College"],
    ".ju.edu.sa": ["Aljouf University"],
    ".kau.edu.sa": ["King Abdul Aziz University"],
    ".kaust.edu.sa": ["King Abdullah University of Science and Technology "],
    ".kfsc.edu.sa": ["King Fahd Security College"],
    ".kfu.edu.sa": ["King Faisal University"],
    ".kfupm.edu.sa": ["King Fahad University of Petroleum and Minerals"],
    ".kku.edu.sa": ["King Khaled University"],
    ".ksau-hs.edu.sa": ["King Saud bin Abdulaziz University for Health Sciences "],
    ".student.ksu.edu.sa": ["king saud university"],
    ".ksu.edu.sa": ["King Saud University"],
    ".ku.edu.sa": ["Alkharj University"],
    ".mcst.edu.sa": ["Knowledge College for Science and Technology"],
    ".nauss.edu.sa": ["Naif Arab University for Security Sciences"],
    ".nbu.edu.sa": ["Northern Border University"],
    ".nu.edu.sa": ["Najran University"],
    ".pmu.edu.sa": ["Prince Mohammad Bin Fahd University"],
    ".psu.edu.sa": ["Prince Sultan University"],
    ".qc.edu.sa": ["Qassim Private College"],
    ".qu.edu.sa": ["Qassim University"],
    ".rct.edu.sa": ["College of Technology at Riyadh"],
    ".riyadh.edu.sa": ["Riyadh College of Dentistry and Pharmacy"],
    ".seu.edu.sa": ["Saudi Electronic University"],
    ".students.su.edu.sa": ["Shaqra University"],
    ".su.edu.sa": ["Shaqra University"],
    ".taibahu.edu.sa": ["Taibah University"],
    ".tu.edu.sa": ["Taif University"],
    ".ucj.edu.sa": ["Jubail University College"],
    ".ud.edu.sa": ["University of Dammam"],
    ".uoh.edu.sa": ["University of Hail"],
    ".uqu.edu.sa": ["Umm Al-Qura University"],
    ".ut.edu.sa": ["University of Tabuk"],
    ".yic.edu.sa": ["Yanbu Industrial College"],
    ".rb.moe.gov.sa": ["ثانوية الفيصل", "Al Faisal High School"],
    ".rg.moe.gov.sa": [
        "المدرسة السعودية الثانوية الحكومية",
        "Saudi Secondary Government School",
    ],
    ".tvtc.gov.sa": ["Technical and Vocational Training Corporation"],
    ".ngha.med.sa": ["College of Nursing and Allied Health Scinces"],
    ".arabou.org.sa": ["Arab Open University"],
    ".budapest.school": ["Budapest School"],
    ".students.campden.school": ["Chipping Campden School"],
    ".cchs.school": ["Clacton County High School"],
    ".cesar.school": ["CESAR School"],
    ".chepstow.school": ["Chepstow School, Chepstow"],
    ".donkey.school": ["DonkeySchool"],
    ".egs.school": ["Education Gaming School"],
    ".governors.school": ["South Carolina Governor's School For Science & Math"],
    ".horo.school": ["Horoshkola, hi.horoshkola.ru"],
    ".laclick.school": ["ADEN Formations"],
    ".millhill.school": ["Mill Hill School"],
    ".n.school": ["New School", "New School, Moscow, Russia"],
    ".norlington.school": ["Norlington", "Norlington"],
    ".optima.school": ["Educational center Optima, Kiev, Ukraine"],
    ".orleanspark.school": ["Orleans Park School, England"],
    ".wasd.school": ["Wilmington Area School District"],
    ".wilder.school": ["Wild Code School"],
    ".akbk.schule": ["Adolf Kolping Berufskolleg"],
    ".buessing.schule": [
        "Heinrich-Büssing-Schule Berufsbildende Schulen Technik Braunschweig"
    ],
    ".juventus.schule": ["Juventus Technikerschule HF"],
    ".ggb.kbs.schule": ["Goethe-Gymnasium Bensheim"],
    ".kks.kbs.schule": ["Karl Kübel Schule Bensheim", "Karl Kübel Schule Bensheim"],
    ".kgl.schule": ["KOPERNIKUS-GYMNASIUM LINTORF"],
    ".s.kkst.schule": ["Königin Katharina Stift Gymnasium"],
    ".rkm.schule": [None],
    ".rsg-cham.schule": ["Robert-Schuman Gymnasium Cham"],
    ".sge.schule": [
        "Städtisches Gymnasium Eschweiler",
        "Municipal High School Eschweiler",
    ],
    ".steinbeis.schule": [
        "Ferdinand-von-Steinbeis-Schule",
        "Ferdinand-von-Steinbeis-School",
    ],
    ".theokoch.schule": ["Theo-Koch-Schule"],
    ".aau.edu.sd": ["Al-Zaiem Al-Azhari University"],
    ".ahfad.edu.sd": ["Ahfad University for Women"],
    ".ccs.edu.sd": ["Canadian College - Sudan"],
    ".dalanjuniversity.edu.sd": ["Dalanj University"],
    ".fashir.edu.sd": ["Al Fashir University"],
    ".gaduniv.edu.sd": ["University of Gadarif"],
    ".iua.edu.sd": ["International University of Africa (IUA)"],
    ".kassalauni.edu.sd": ["Kassala University"],
    ".kordofan.edu.sd": ["University of Kordofan"],
    ".neelain.edu.sd": ["Neelain University"],
    ".nilevalley.edu.sd": ["Nile Valley University"],
    ".oau.edu.sd": ["Omdurman Ahlia University"],
    ".oiu.edu.sd": ["Omdurman Islamic University"],
    ".ous.edu.sd": ["Open University of Sudan (OUS)"],
    ".quran-unv.edu.sd": ["University of Holy Quran and Islamic Siences"],
    ".ribat.edu.sd": ["National Ribat University"],
    ".rsu.edu.sd": ["Red Sea University"],
    ".uofd.edu.sd": ["University of Dongola"],
    ".ust.edu.sd": ["University of Science and Technology"],
    ".ush.sd": ["Shendi University"],
    ".abbindustrigymnasium.se": ["ABB Industrigymnasium"],
    ".arboga.se": ["Vasagymnasiet", " Vasa High School"],
    ".student.arenakoncernen.se": ["Arena Group students, Sweden"],
    ".edu.avesta.se": ["Avesta Karlfeldtgymnasium"],
    ".edu.boras.se": [
        "Almåsgymnasiet",
        "Bäckängsgymnasiet",
        "Sven Eriksonsgymnasiet",
        "Viskastrandsgymnasiet",
        "Tullengymnasiet",
        ".group",
    ],
    ".skola.boras.se": ["Sven Eriksonsgymnasiet"],
    ".bth.se": ["Blekinge Institute of Technology"],
    ".student.chalmers.se": [None, "Chalmers University of Technology"],
    ".chalmers.se": ["Chalmers University of Technology"],
    ".chasacademy.se": ["Chas Academy"],
    ".cng.se": ["Curt Nicolin Gymnasiet"],
    ".elev.cybergymnasiet.se": ["Cybergymnasiet"],
    ".elev.danderyd.se": ["Danderyds gymnasium"],
    ".danderyd.se": ["Danderyds gymnasium"],
    ".elev.ga.dbgy.se": [
        "Drottning Blankas Gymansieskola",
        "https://www.drottningblanka.se/",
    ],
    ".du.se": ["Dalarna University College"],
    ".utb.ecutbildning.se": ["EC Utbildning"],
    ".ecutbildning.se": ["EC Utbildning"],
    ".edufalkenberg.se": ["Falkenbergs gymnasieskola", "Falkenberg high school"],
    ".edu.edugrade.se": ["Edugrade Yrkeshögskolan"],
    ".skola.engelholm.se": ["Engelholms gymnasieskola students"],
    ".engelholm.se": ["Engelholms gymnasieskola"],
    ".engelska.se": ["Internationella Engelska Skolan"],
    ".elev.enjoygroup.se": ["Handelsakademin school, Enjoy Group"],
    ".falufri.se": ["Falu Frigymnasium"],
    ".axevalla.fhsk.se": ["Axevalla Folkhögskola"],
    ".svf.fhsk.se": ["Södra Vätterbygdens Folkhögskola"],
    ".student.forsbergsskola.se": ["Forsbergs Skola"],
    ".gavle.se": ["Gymnasieskolorna i Gävle (Teachers)"],
    ".gih.se": ["The Swedish School of Sport and Health Sciences"],
    ".educ.goteborg.se": ["Yrgo", ".groups", "yh", ".humanus"],
    ".skola.goteborg.se": [
        "Göteborgs stad Utbildning, Yrgo",
        ".group",
        "Humanus Yerkeshöghskolan",
    ],
    ".grillska.se": ["Grillska Gymnasiet Eskilstuna"],
    ".gtg.se": ["Göteborgsgregionens Tekniska Gymnasium"],
    ".gti.se": ["Göteborgs Tekniska Institut", "Gothenburgs Institute of Technology"],
    ".gu.se": ["Göteborg University", "School of Design and Crafts"],
    ".edu.halmstad.se": ["Kattegattgymnasiet Halmstad"],
    ".ubf.haninge.se": [
        "Fredrika Bremergymnasiet ",
        "Kommunal gymnasieskola i Haninge",
    ],
    ".harryda.se": ["Hulebäcksgymnasiet"],
    ".hb.se": ["University College of Borås"],
    ".hgo.se": ["Gotland University College"],
    ".hh.se": ["Halmstad University College"],
    ".hhs.se": ["Stockholm School of Economics"],
    ".hig.se": ["University College of Gävle"],
    ".hik.se": ["Kalmar University College"],
    ".student.his.se": ["University of Skövde"],
    ".his.se": ["University College of Skövde"],
    ".hj.se": [
        "Jönköping University College",
        "Jönköping University College of Health Sciences",
    ],
    ".hkr.se": ["University College of Kristianstad"],
    ".htu.se": ["University College of Trollhättan/Uddevalla"],
    ".hv.se": ["University West"],
    ".hyperisland.se": ["Hyper Island"],
    ".innovationsgymnasiet.se": [
        "Thoren Innovations Gymnasiet",
        "Thoren Innovation School",
    ],
    ".it-gymnasiet.se": ["IT College Sweden"],
    ".itggot.se": ["Göteborg - IT Gymnasiet"],
    ".iths.se": ["IT-Högskolan"],
    ".jenseneducation.se": ["Jensen Education"],
    ".jgy.se": ["Added Jämtlands Gymnasium, Sweden. ", "www.jgy.se"],
    ".edu.jonkoping.se": ["Sandagymnasiet", ".group"],
    ".ju.se": ["Jönköping University"],
    ".edu.karlskoga.se": ["Teknikcollege Karlskoga/Degerfors"],
    ".skola.karlskrona.se": ["SFI"],
    ".edu.karlstad.se": [
        "Älvkullegymnasiet",
        "Sundstagymnasiet",
        "Nobelgymnasiet",
        "Tingvallagymnasiet",
    ],
    ".katedral.se": ["Katedralskolan Uppsala"],
    ".kau.se": ["Karlstad University"],
    ".ki.se": ["Karolinska Institute Stockholm"],
    ".konstfack.se": ["University College of Arts, Crafts and Design"],
    ".kth.se": ["Royal Institute of Technology"],
    ".kulturama.se": ["Kulturama"],
    ".kunskapsforbundet.se": ["Kunskapsförbundet väst"],
    ".student.kyh.se": ["KYH", "KYH"],
    ".lbs.se": ["LBS Kreativa Gymnasiet"],
    ".lhs.se": ["Stockholm Institute of Education"],
    ".adm.linkoping.se": ["linkopings kommun"],
    ".edu.linkoping.se": ["Linkopings kommun"],
    ".liu.se": ["Linköping University"],
    ".lnu.se": ["Linnaeus University"],
    ".lth.se": ["Lund University"],
    ".ltu.se": ["Luleå University of Technology"],
    ".lunduniversity.lu.se": ["Lund University"],
    ".lu.se": ["Lund University"],
    ".skola.lund.se": [
        "Polhemskolan",
        "https://www.lund.se/en/polhemskolan/om-skolan/",
        "https://www.lund.se/polhemskolan/om-skolan/",
    ],
    ".luth.se": ["Lulea University of Technology"],
    ".mah.se": ["Malmö University College"],
    ".malardalenstekniska.se": ["Mälardalens Tekniska Gymnasium"],
    ".skola.malmo.se": ["Students in Malmoe"],
    ".mau.se": ["Malmo University"],
    ".mdh.se": ["Mälardalen University"],
    ".medborgarskolan.se": ["Medborgarskolan"],
    ".medieinstitutet.se": ["The Media Institute"],
    ".miun.se": ["Mid-Sweden University"],
    ".edu.nacka.se": ["Nacka Gymnasium"],
    ".nackademin.se": ["Nackademins YH-utbildning"],
    ".nbi-handelsakademin.se": ["NBI / Handelsakademin"],
    ".edu.newton.se": ["Newton Kompetensutveckling AB"],
    ".elev.norrkoping.se": ["Mosstorpsskolan"],
    ".umea.nti.se": ["NTI-Gymnasiet Umeå"],
    ".ntig.se": ["NTI College Sweden"],
    ".edu.olofstrom.se": ["Nordenbergsskolan Olofström"],
    ".oru.se": ["Örebro University"],
    ".piggelinen.se": ["Friskolan Piggelinen"],
    ".stud.pitea.se": ["Strömbackaskolan", "Solanderskolan"],
    ".plushogskolan.se": ["Plushögskolan Higher Vocational Education school"],
    ".realgymnasiet.se": ["Realgymnasiet"],
    ".sh.se": ["Södertörns Högskola"],
    ".utb.sih.se": [
        "Stockholms Internationella Handelsskola AB",
        "Stockholm International school of commerce",
    ],
    ".skolamoa.se": ["Mora High School", "http://www.moragymnasium.se/"],
    ".skolanskurup.se": ["Skurup Kommuns Skolor", "Schools Of Skurup Municipality"],
    ".slu.se": ["Swedish University of Agricultural Sciences"],
    ".elev.snitz.se": ["Snitz Gymnasium"],
    ".snitz.se": ["Snitz Gymnasium (Teacher)"],
    ".edu.sollentuna.se": ["Rudbeck"],
    ".soltorgsgymnasiet.se": ["Soltorgsgymnasiet"],
    ".stud.sti.se": ["Stockholms Tekniska Institut"],
    ".stockholmscience.se": ["Stockholm Science & Innovation School"],
    ".su.se": ["Stockholm University"],
    ".skola.sundsvall.se": ["Sundsvalls Gymnasium"],
    ".suni.se": ["Södertörns Högskola"],
    ".student.tabyenskilda.se": ["Täby Enskilda Gymnasium"],
    ".thegameassembly.se": ["The Game Assembly"],
    ".theindiequest.se": ["The Indie Quest"],
    ".tucsweden.se": ["TUC Sweden"],
    ".utb.tyreso.se": ["TYRESÖ KOMMUN"],
    ".umu.se": ["Umea University"],
    ".uu.se": ["Uppsala University"],
    ".edu.varberg.se": [
        "Yrkeshögskolan Campus Varberg",
        "Vocational School Campus Varberg",
    ],
    ".utb.vaxjo.se": ["Växjö Technical College"],
    ".vuxutb.se": ["Plushögskolan"],
    ".wendelahebbegymnasiet.se": ["Wendela Hebbegymnasiet"],
    ".wmu.se": ["World Maritime University"],
    ".ya.se": ["YrkesAkademin"],
    ".yaelev.se": ["Yrkesakademin AB"],
    ".adsc.com.sg": ["Advanced Digital Sciences Center"],
    ".ais.edu.sg": ["Australian International School Singapore"],
    ".auston.edu.sg": ["Auston Institute of Management"],
    ".aventis.edu.sg": ["Aventis School of Management"],
    ".cis.edu.sg": ["Canadian International School Singapore"],
    ".dovercourt.edu.sg": ["Dover Court International School"],
    ".student.hci.edu.sg": ["Hwa Chong Institution"],
    ".ics.edu.sg": ["International Community School (Singapore)"],
    ".ite.edu.sg": [
        "Institute of Technical Education",
        "Institute of Technical Education",
    ],
    ".lsbf.edu.sg": [
        "London School of Business & Finance Singapore",
        "London School of Business & Finance Singapore",
    ],
    ".mdis.edu.sg": ["Management Development Institute of Singapore (MDIS)"],
    ".temasekjc.moe.edu.sg": ["Temasek Junior College"],
    ".myrp.edu.sg": ["Republic Polytechnic"],
    ".connect.np.edu.sg": ["Ngee Ann Polytechnic "],
    ".ntu.edu.sg": ["Nanyang Technological University"],
    ".nus.edu.sg": ["National University of Singapore"],
    ".nushigh.edu.sg": ["NUS High School of Math and Science"],
    ".nyjc.edu.sg": ["Nanyang Junior College"],
    ".nyp.edu.sg": ["Nanyang Polytechnic"],
    ".ofs.edu.sg": [
        "Overseas Family School Singapore",
        "OFS",
        "https://www.ofs.edu.sg/",
        "https://www.ofs.edu.sg/schools/hs/courses/descriptions/#ib-comp-science",
    ],
    ".prcss.edu.sg": ["Pasir Ris Crest Secondary School"],
    ".ri.edu.sg": ["Raffles Institution"],
    ".rp.edu.sg": ["Republic Polytechnic"],
    ".sas.edu.sg": ["Singapore American School"],
    ".sim.edu.sg": ["Singapore Institute of Management (SIM)"],
    ".sit.singaporetech.edu.sg": ["Singapore Institute of Technology"],
    ".singaporetech.edu.sg": ["Singapore Institute of Technology"],
    ".smu.edu.sg": ["Singapore Management University"],
    ".sp.edu.sg": ["Singapore Polytechnic"],
    ".sst.edu.sg": ["School of Science and Technology"],
    ".ssts.edu.sg": ["School of Science and Technology"],
    ".students.edu.sg": ["National Junior College"],
    ".suss.edu.sg": [
        "Singapore University of Social Science",
        "Singapore University of Social Science",
    ],
    ".sutd.edu.sg": ["Singapore University of Technology and Design"],
    ".student.tp.edu.sg": ["Temasek Polytechnic"],
    ".tp.edu.sg": ["Temasek Polytechnic", "Temasek Polytechnic"],
    ".gapps.uwcsea.edu.sg": ["United World College"],
    ".panasia.org.sg": [
        "Qauid-e-Awam University of Engineering Sciences &amp; Technology"
    ],
    ".vjc.sg": ["Victoria Junior College"],
    ".academia.si": [
        "Academia, Višja strokovna sola",
        "Academia, College of Short-Cycle Higher Education",
    ],
    ".academiavss.si": [
        "Academia, Višja strokovna sola",
        "Academia, College of Short-Cycle Higher Education",
    ],
    ".druga.si": ["II. gimnazija Maribor"],
    ".esnm.si": ["Ekonomska sola Novo mesto"],
    ".fm-kp.si": ["University of Primorska, Faculty of Management"],
    ".gfml.si": ["Gimnazija Franca Miklošiča Ljutomer"],
    ".gimkr.si": ["Gimnazija Kranj"],
    ".ijs.si": ["Jozef Stefan Institute"],
    ".os-hoce.si": ["Osnovna šola Dušana Flisa Hoče"],
    ".osbrod.si": ["Osnovna Šola Vižmarje-Brod"],
    ".sc-celje.si": ["School Centre Celje"],
    ".sc-nm.si": ["School Center Novo mesto"],
    ".sts.sckr.si": ["Srednja tehniška šola Kranj", "Secondary technical school Kranj"],
    ".ms.scng.si": [
        "Višja strokovna šola Nova Gorica",
        "Higher Vocational School of Nova Gorica",
    ],
    ".scng.si": ["Šolski Center Nova Gorica", "School Centre Nova Gorica"],
    ".scptuj.si": ["Šolski center Ptuj, Elektro in računalniška šola"],
    ".scsl.si": ["School Centre Skofja Loka"],
    ".scv.si": ["Šolski center Velenje"],
    ".sers.si": ["Srednja elektro-računalniška šola Maribor"],
    ".ssravne.si": ["Srednja šola Ravne"],
    ".stps-trbovlje.si": ["Srednja tehniska in poklicna sola Trbovlje"],
    ".sts.si": ["Srednja tehniška sola Koper"],
    ".student-erudio.si": ["Erudio Izobraževalni Center", "Erudio Educational Center"],
    ".um.si": ["University of Maribor"],
    ".ung.si": ["University of Nova Gorica"],
    ".uni-lj.si": ["University of Ljubljana"],
    ".uni-mb.si": ["University of Maribor"],
    ".student.fis.unm.si": ["Fakulteta za informacijske študije v Novem mestu"],
    ".upr.si": ["University of Primorska"],
    ".vegova.si": ["Vegova Ljubljana"],
    ".student.adlerka.sk": [
        "Stredná priemyselná škola elektrotechnická, K. Adlera 5, 841 02 Bratislava"
    ],
    ".akademiapz.sk": ["Police Academy in Bratislava", "Police Academy in Bratislava"],
    ".aku.sk": [
        "Academy of Arts in Banská Bystrica",
        "Academy of Arts in Banská Bystrica",
    ],
    ".aos.sk": [
        "Armed Forces Academy of General Milan Rastislav Štefánik",
        "Armed Forces Academy of General Milan Rastislav Štefánik",
    ],
    ".bilgym.sk": ["Bilingválne Gymnázium C.S. Lewisa"],
    ".bisla.sk": [
        "Bratislava International School of Liberal Arts",
        "Bratislava International School of Liberal Arts",
    ],
    ".bivs.sk": ["Bank Institute High School in Banská Bystrica"],
    ".centrumnadania.sk": ["Centrum nadania, n.o., Slovensko"],
    ".dti.sk": [
        "Technical Institute of Dubnica in Dubnica nad Váhom",
        "Technical Institute of Dubnica in Dubnica nad Váhom",
    ],
    ".gpohkk.edu.sk": ["Gymnázium P. O. Hviezdoslava v Kežmarku"],
    ".spssnina.edu.sk": [
        "Stredná priemyselná škola, Partizánska 1059/23, Snina, Slovakia"
    ],
    ".elektrohradok.sk": ["Stredná odborná škola elektrotechnická Liptovský Hrádok"],
    ".euba.sk": [
        "University of Economics in Bratislava",
        "University of Economics in Bratislava",
    ],
    ".gjh.sk": ["Gymnázium Jura Hronca, Bratislava"],
    ".gkmke.sk": ["Spojená škola sv. Košických mučeníkov in Košice, Slovakia"],
    ".gmet.sk": ["GYMNÁZIUM, Metodova 2, Bratislava"],
    ".gymnaziumceska.sk": ["\ufeffGymnázium Česká"],
    ".gympos.sk": ["Gymnázium Poštová, Košice"],
    ".gymzv.sk": ["Gymnázium Ľudovíta Štúra Zvolen"],
    ".iaeste.sk": ["IAESTE Slovakia", "IAESTE Slovakia"],
    ".ismpo.sk": [
        "International School of Management in Prešov",
        "International School of Management in Prešov",
    ],
    ".ku.sk": [
        "Catholic University in Ruzomberok",
        "Catholic University in Ružomberok",
        "Catholic University in Ruzomberok",
        "Catholic University in Ružomberok",
    ],
    ".mediamatika.sk": ["University of Žilina", "University of Žilina"],
    ".piaristi-pd.sk": [
        "Piaristická spojená škola F. Hanáka v Prievidzi",
        "Piarist school of F. Hanák in Prievidza",
    ],
    ".selyeuni.sk": ["Janos Selye University", "Janos Selye University"],
    ".sevs.sk": [
        "University of Central Europe in Skalica",
        "University of Central Europe in Skalica",
    ],
    ".sosholic.sk": [
        "Stredná odborná škola",
        "Stredná odborná škola, Námestie sv. Martina 5, Holíč",
        "SOS, Holíč",
        "SOSHolic",
        "High School Holic/Secondary school Holic",
    ],
    ".spsbj.sk": ["SPŠT Bardejov"],
    ".spsdub.sk": ["Stredná priemyselná škola v Dubnici nad Váhom, Slovakia"],
    ".spse-po.sk": ["SPŠ Elektrotechnická"],
    ".spseke.sk": [
        "SPŠ elektrotechnická v Košiciach",
        "Secondary school of electrical engineering in Kosice",
    ],
    ".spsjm.sk": ["Stredná priemyselná škola Jozefa Murgaša, Banská Bystrica"],
    ".spsknm.sk": [
        "Stredná priemyselná škola informačných technológií, Nábrežná 1325, Kysucké Nové Mesto"
    ],
    ".spstt.sk": [
        "Stredna Priemyselna Skola Technicka Trnava",
        "Stredna Priemyselna Skola Technicka Trnava",
    ],
    ".ssnd.sk": ["Spojená škola sv. Jána Bosca v Novej Dubnici"],
    ".stuba.sk": [
        "Slovak University of Technology in Bratislava",
        "Slovak University of Technology in Bratislava",
    ],
    ".svr.sk": ["Spojená škola Svätej Rodiny, Bratislava"],
    ".szu.sk": ["Slovak Medical University", "Slovak Medical University"],
    ".tnuni.sk": [
        "University of Alexandra Dubček in Trenčín",
        "University of Alexandra Dubček in Trenčín",
    ],
    ".truni.sk": ["University of Trnava", "University of Trnava"],
    ".tuke.sk": ["Technical University in Kosice", "Technical University in Kosice"],
    ".tuzvo.sk": ["Technical University in Zvolen", "Technical University in Zvolen"],
    ".tvu.sk": ["Trnavska Univerzita", "University of Trnava"],
    ".ucm.sk": [
        "University of St. Cyril and Methodius in Trnava",
        "University of SV Cyril and Methodius in Trnava",
        "University of St. Cyril and Methodius in Trnava",
        "University of SV Cyril and Methodius in Trnava",
    ],
    ".ujs.sk": ["J. Selye University"],
    ".ukf.sk": [
        "University Konstantina Filozov in Nitra",
        "University Konstantina Filozov in Nitra",
    ],
    ".umb.sk": [
        "Matej Bel University in Banská Bystrica",
        "Matej Bel University in Banská Bystrica",
    ],
    ".uniag.sk": [
        "Slovak University of Agriculture in Nitra",
        "Slovak University of Agriculture in Nitra",
    ],
    ".g.fmph.uniba.sk": [
        "Fakulta matematiky, fyziky a informatiky Univerzity Komenského v Bratislava - Google Educational Accounts"
    ],
    ".uniba.sk": [
        "Comenius University in Bratislava",
        "Comenius University in Bratislava",
    ],
    ".uninova.sk": ["Law University of Bratislava", "Law University of Bratislava"],
    ".unipo.sk": ["University of Presov", "University of Presov"],
    ".uniza.sk": ["University of Žilina", "University of Žilina"],
    ".upjs.sk": [
        "Pavol Jozef Safarik University in Kosice",
        "Pavol Jozef Safarik University in Kosice",
    ],
    ".uvm.sk": [
        "University of Veterinary Medicine in Kosice",
        "University of Veterinary Medicine in Kosice",
    ],
    ".vsm.sk": ["School of Management", "School of Management"],
    ".vsmu.sk": [
        "University of Performing Arts in Bratislava",
        "University of Performing Arts in Bratislava",
    ],
    ".vssladkovicovo.sk": ["College in Sládkovičovo", "College in Sládkovičovo"],
    ".vssvalzbety.sk": [
        "St. Elizabeth’s College of Health and Social Sciences in Bratislava",
        "St. Elizabeth’s College of Health and Social Sciences in Bratislava",
    ],
    ".vsvu.sk": [
        "Academy of Fine Arts and Design in Bratislava",
        "Academy of Fine Arts and Design in Bratislava",
    ],
    ".zsstrba.sk": ["Základná škola v Štrbe", "Primary school Strba"],
    ".unirsm.sm": ["University of San Marino"],
    ".estm.edu.sn": ["\ufeffÉcole Supérieure de Technologie et de Management, Senegal"],
    ".eua.edu.sn": [
        "Excellence Universitaire Africaine",
        "African University Excellence",
    ],
    ".isep-thies.edu.sn": [
        "institut supérieur d'enseignement professionnelle de thies",
        "institut supérieur d'enseignement professionnelle de thies",
    ],
    ".ism.edu.sn": ["Institut Supérieur de Management", "ISM"],
    ".supdeco.edu.sn": ["Groupe Ecole Supérieur de Commerce Dakar"],
    ".uadb.edu.sn": ["Université Alioune Diop de Bambey"],
    ".ucad.edu.sn": ["Université Cheikh Anta Diop"],
    ".ucao.edu.sn": ["Saint Michel"],
    ".ugb.edu.sn": ["Université Gaston Berger Saint-Louis"],
    ".uvs.edu.sn": ["Virtual University of Senegal"],
    ".ept.sn": ["Ecole Polytechnique de Thiès ", "Thies Polytechnic School "],
    ".esmt.sn": [
        "Ecole Supérieure Multinationale des Télécommunications",
        "Multinational Higher School of Telecommunications",
        "ESMT",
        "www.esmt.sn",
    ],
    ".esp.sn": [
        "Ecole Supérieure Polytechnique de dakar",
        "École Supérieure Polytechnique de dakar",
        "ESP",
    ],
    ".ucad.sn": ["Université Cheikh Anta Diop"],
    ".univ-thies.sn": ["Universite de Thies"],
    ".universityofmanagement.sn": ["University of Management"],
    ".psu.edu.so": ["Puntland State University"],
    ".simad.edu.so": ["SIMAD UNIVERSITY"],
    ".harbour.space": ["Harbour Space University"],
    ".ptc.edu.sr": ["Polytechnic College Suriname"],
    ".unasat.sr": ["University of Applied Science and Technology"],
    ".sit.study": ["Schaffhausen Institute of Technology"],
    ".kstu.su": [
        "Kamchatka State Technical University",
        "Kamchatka State Technical University",
    ],
    ".msu.su": [
        "Moscow State University",
        "Moscow State University M.V. Lomonosov",
        "Moscow State University",
        "Moscow State University M.V. Lomonosov",
    ],
    ".nsk.su": [
        "Siberian State University of Telecommunications and Informatics",
        "Siberian State University of Telecommunications and Informatics",
    ],
    ".omsk.su": ["Omsk State University", "Omsk State University"],
    ".radiotech.su": ["\ufeffЧелябинский Радиотехнический техникум"],
    ".ruc.su": [
        "Российский университет кооперации",
        "Russian University of Cooperation",
    ],
    ".ugatu.su": ["Ufa State Aviation Technical University"],
    ".uspu.su": [
        "Уральский государственный педагогический университет",
        "Ural State Pedagogical University",
    ],
    ".cdb.edu.sv": ["Universidad Don Bosco"],
    ".uae.edu.sv": ["Universidad Albert Einstein"],
    ".uca.edu.sv": ["Universidad Centroamericana José Simeón Canas"],
    ".ucad.edu.sv": ["Universidad Cristiana de las Asambleas de Dios"],
    ".uees.edu.sv": ["Universidad Evangélica de El Salvador"],
    ".ues.edu.sv": ["Universidad de El Salvador"],
    ".ufg.edu.sv": ["Universidad Francisco Gavidia"],
    ".ugb.edu.sv": ["Universidad Capitain General Gerardo Barrios"],
    ".ujmd.edu.sv": ["Universidad Dr. Jose Matias Delgado"],
    ".uls.edu.sv": ["Universidad Luterana Salvadoreña"],
    ".uma.edu.sv": ["Universidad Modular Abierta"],
    ".umoar.edu.sv": ["Universidad Monsenor Oscar Arnulfo Romeo"],
    ".unab.edu.sv": ["Universidad Dr. Andreas Bello"],
    ".unasa.edu.sv": ["Universidad Autónoma de Santa Ana"],
    ".univo.edu.sv": ["Universidad de Oriente"],
    ".unssa.edu.sv": ["Universidad Nueva San Salvador"],
    ".upan.edu.sv": ["Universidad Panamericana de San Salvador"],
    ".upes.edu.sv": ["Universidad Politécnica de El Salvador"],
    ".usam.edu.sv": ["Universidad Salvadorena Alberto Masferrer"],
    ".usonsonate.edu.sv": ["Universidad de Sonsonate"],
    ".utla.edu.sv": ["Universidad Técnica Latinoamericana"],
    ".albaath-univ.edu.sy": ["Al-Baath University"],
    ".alepuniv.edu.sy": ["University of Aleppo"],
    ".damascusuniversity.edu.sy": ["Damascus University"],
    ".hiba.edu.sy": ["Higher Institute of Business Administration"],
    ".iust.edu.sy": ["International University for Science &amp; Technology "],
    ".tishreen.edu.sy": ["Tishreen University"],
    ".uok.edu.sy": ["University of Kalamoon"],
    ".wiu.edu.sy": ["Wadi International University"],
    ".ypu.edu.sy": ["Yarmouk Private University "],
    ".uniswa.sz": ["University of Swaziland"],
    ".bts.tech": ["Barcelona Technology School"],
    ".omgtu.tech": ["Omsk State Technical University"],
    ".iai-togo.tg": [
        "Institut Africain d'Informatique.",
        "English Name :",
        "Africa Institute of Technology",
    ],
    ".univ-lome.tg": ["Université de Lomé"],
    ".acr.ac.th": ["อัสสัมชัญระยอง", "Assumption College Rayong"],
    ".acsp.ac.th": ["โรงเรียนอัสสัมชัญสมุทรปราการ", "Assumption College Samutprakarn"],
    ".aims.ac.th": ["Adventist International Mission School (AIMS)"],
    ".ait.ac.th": ["Asian Institute of Technology"],
    ".aru.ac.th": ["Phranakhon Si Ayutthaya Rajabhat University"],
    ".ayw.ac.th": ["อยุธยาวิทยาลัย", "Ayutthaya Witthayalai"],
    ".bisphuket.ac.th": ["British International School Phuket"],
    ".bsru.ac.th": ["Bansomdejchaopraya Rajabhat University"],
    ".bu.ac.th": ["Bangkok University"],
    ".buu.ac.th": ["Burapha University"],
    ".chandra.ac.th": [
        "มหาวิทยาลัยราชภัฏจันทรเกษม",
        "CHANDRAKASEM RAJABHAT UNIVERSITY",
    ],
    ".chiangkham.ac.th": ["โรงเรียนเชียงคำวิทยาคม", "Chiangkhamwittayakhom School"],
    ".chiangmai.ac.th": ["Chiang Mai University"],
    ".chula.ac.th": ["Chulalongkorn University"],
    ".cmkl.ac.th": ["CMKL University"],
    ".cmru.ac.th": ["Chiang Mai Rajabhat University"],
    ".cmu.ac.th": ["www.cmu.ac.th", "Chiang Mai University"],
    ".cmvc.ac.th": ["Chiang Mai Vocational College"],
    ".cpc.ac.th": ["Rajamangala University of Technology Tawan-ok"],
    ".cpru.ac.th": ["มหาวิทยาลัยราชภัฏชัยภูมิ", "Chaiyaphum Rajabhat University"],
    ".cpu.ac.th": ["Chaopraya University "],
    ".cra.ac.th": ["ราชวิทยาลัยจุฬาภรณ์", "chulabhorn royal academy"],
    ".crru.ac.th": ["มหาวิทยาลัยราชภัฏเชียงราย", "chiang rai rajabhat university"],
    ".dpu.ac.th": ["Dhurakijpundit University"],
    ".dru.ac.th": ["มหาวิทยาลัยราชภัฎธนบุรี", "Dhonburi Rajabhat University"],
    ".dusit.ac.th": ["Suan Dusit Rajabhat University"],
    ".eau.ac.th": ["Eastern Asia University"],
    ".hcu.ac.th": ["Huachiew Chalermprakiet University"],
    ".hu.ac.th": ["Hatyai University"],
    ".isb.ac.th": ["International School Thailand"],
    ".jv.ac.th": ["โรงเรียนจักราชวิทยา", "ChakkaratWittaya School"],
    ".kbu.ac.th": ["Kasem Bundit University"],
    ".kku.ac.th": ["Khon Kaen University"],
    ".kmitl.ac.th": ["King Mongkut's University of Technology Ladkrabang"],
    ".kmutnb.ac.th": ["King Mongkut's University of Technology North Bangkok"],
    ".kmutt.ac.th": ["King Mongkut's University of Technology Thonburi"],
    ".kpru.ac.th": [
        "\ufeffKamphaeng Phet Rajabhat University",
        "Kamphaeng Phet Rajabhat University, Mae Sot Campus",
    ],
    ".krirk.ac.th": ["Krirk University"],
    ".ku.ac.th": ["Kasetsart University"],
    ".lampangvc.ac.th": ["Lampang Vocational College   "],
    ".lcat.ac.th": ["Lamphun College of Agriculture and Technology"],
    ".lcct.ac.th": ["Lampang College of Commerce and Technology"],
    ".lpru.ac.th": ["Lampang Rajabhat University"],
    ".lru.ac.th": ["Loei Rajabhat University", "Loei Rajabhat University"],
    ".mahidol.ac.th": [
        "Mahidol University",
        "Mahidol University International College",
    ],
    ".mbu.ac.th": ["Mahamakut Buddhist University"],
    ".mcu.ac.th": ["Mahachulalongkorn Buddhist University"],
    ".mfu.ac.th": ["Mae Fah Luang University "],
    ".mju.ac.th": ["Maejo University"],
    ".msu.ac.th": ["Mahasarakham University"],
    ".mut.ac.th": ["Mahanakorn University of Technology"],
    ".mwit.ac.th": [
        "Mahidol Wittayanusorn (Public Organization)",
        "Mahidol Wittayanusorn",
        "MWIT",
        "โรงเรียนมหิดลวิทยานุสรณ์",
    ],
    ".newton.ac.th": ["Newton School, Bangkok"],
    ".nida.ac.th": ["National Institute of Development Administration"],
    ".nmu.ac.th": ["มหาวิทยาลัยนวมินทราธิราช", "navamindradhiraj university"],
    ".northbkk.ac.th": ["North Bangkok University"],
    ".northcm.ac.th": ["North - Chiang Mai University"],
    ".webmail.npru.ac.th": [
        " มหาวิทยาลัยราชภัฏนครปฐม",
        "Nakhon Pathom Rajabhat University",
    ],
    ".nrru.ac.th": ["Nakhon Ratchasima Rajabhat University"],
    ".nsru.ac.th": ["Nakhon Sawan Rajabhat University"],
    ".nu.ac.th": ["Naresuan University"],
    ".panyarathighschool.ac.th": ["Panyarat High School"],
    ".payap.ac.th": ["Payap University Chaiang Mai"],
    ".mail.pbru.ac.th": [
        "มหาวิทยาลัยราชภัฏเพชรบุรี",
        "Phetchaburi Rajabhat University",
    ],
    ".pcru.ac.th": ["Phetchabun Rajabhat University"],
    ".phothitham.ac.th": ["Phothithammasuwat School", "Phothithammasuwat School"],
    ".phuketthaihua.ac.th": [
        "โรงเรียนภูเก็ตไทยหัวอาเซียนวิทยา",
        "Phuketthaihua Asean Wittaya School",
    ],
    ".stu.pim.ac.th": [
        "สถาบันการจัดการปัญญาภิวัฒน์",
        "Panyapiwat Instutute of Management",
    ],
    ".piriyalai.ac.th": ["พิริยาลัยจังหวัดแพร่", "Piriyalai School Phrae"],
    ".pit365.pit.ac.th": [
        "สถาบันเทคโนโลยีปทุมวัน",
        " Pathumwan Institute of Technology",
    ],
    ".pkru.ac.th": ["มหาวิทยาลัยราชภัฏภูเก็ต", "Phuket rajaphat university"],
    ".pmtc.ac.th": ["Phibunmangsaharn Technical College"],
    ".pnru.ac.th": ["Phranakhon Rajabhat University"],
    ".pnu.ac.th": [
        "มหาวิทยาลัยนราธิวาสราชนครินทร์",
        "Princess of Naradhiwas University",
    ],
    ".pomnaka.ac.th": ["โรงเรียนป้อมนาคราชสวาทยานนท์"],
    ".pongsawadi.ac.th": [
        "วิทยาลัยเทคโนโลยีพงษ์สวัสดิ์",
        "Pongsawadi Technological College",
    ],
    ".psru.ac.th": ["Pibulsongkram Rajabhat university"],
    ".psu.ac.th": ["Prince of Songkla University"],
    ".psuwit.ac.th": ["มอ. วิทยานุสรณ์", "PSU Wittayanusorn"],
    ".ptu.ac.th": ["Pathumthani University"],
    ".reru.ac.th": ["Roi Et Rajabhat University"],
    ".rmu.ac.th": ["Rajabhat Maha Sarakham University"],
    ".rmuti.ac.th": [
        "Rajamangala University of Technology Isan",
        "Rajamangala University of Technology Isan",
    ],
    ".mail.rmutk.ac.th": ["Rajamangala University of Technology Krungthep"],
    ".rmutl.ac.th": [
        "Rajamangala University of Technology, Lanna Chiang Rai",
        "Rajamangala University of Technology, Lanna Nan",
    ],
    ".rmutp.ac.th": ["Rajamangala University of Technology, Phra Nakhon"],
    ".outlook.rmutr.ac.th": [
        "มหาวิทยาลัยเทคโนโลยีราชมงคลรัตนโกสินทร์",
        "Rajamangala University of Technology Rattanakosin",
    ],
    ".rmutsb.ac.th": [
        "rajamangala university of technology suvarnabhumi",
        "rajamangala university of technology suvarnabhumi",
    ],
    ".rmutsv.ac.th": ["Rajamangala University of Tecnology Srivijaya"],
    ".rmutt.ac.th": [
        "มหาวิทยาลัยเทคโนโลยีราชมงคลธัญบุรี",
        "Rajamangala University of Technology Thanyaburi ",
    ],
    ".rmutto.ac.th": ["Rajamangala University of Technology Tawan-ok"],
    ".roong-aroon.ac.th": ["Roong Aroon School", "โรงเรียนรุ่งอรุณ"],
    ".rsu.ac.th": ["Rangsit University"],
    ".rumail.ru.ac.th": ["Ramkhamhaeng University"],
    ".ru.ac.th": ["Ramkhamhaeng University"],
    ".satriwit3.ac.th": ["Nawamintrachinutit Satriwitthaya3 Putthamonton School"],
    ".sau.ac.th": ["South-East Asia University"],
    ".student.sd.ac.th": ["เซนต์ดอมินิก", "SaintDominic School"],
    ".siamtechno.ac.th": [" วิทยาลัยเทคโนโลยีสยาม", "Siam Technology College (STC)"],
    ".stu.sibs.ac.th": [
        "Satit International Bilingual School of Rangsit University Chiang Mai (SIBS)"
    ],
    ".student.sk.ac.th": ["สวนกุหลาบวิทยาลัย", "Suankularb Wittayalai School"],
    ".snru.ac.th": ["Sakon Nakhon Rajabhat University"],
    ".song.ac.th": [
        "วิทยาลัยการอาชีพสอง",
        "Song Industrial and Community Education College",
    ],
    ".southeast.ac.th": ["วิทยาลัยเซาธ์อีสท์บางกอก", "Southeast Bangkok College"],
    ".spu.ac.th": ["Sripatum University"],
    ".sriyapai.ac.th": ["โรงเรียนศรียาภัย", "SriyapaiSchool"],
    ".sru.ac.th": ["RAJABHAT UNIVERSITY", "SURATTHANI RAJABHAT UNIVERSITY"],
    ".ssru.ac.th": ["Suan Sunandha Rajabhat University"],
    ".stjohn.ac.th": ["St. John's University"],
    ".stou.ac.th": ["Sukhothai Thammathirat Open University"],
    ".su.ac.th": ["Silpakorn University"],
    ".sut.ac.th": ["Suranaree University of Technology"],
    ".swu.ac.th": ["Srinakharinwirot University"],
    ".tni.ac.th": ["สถาบันเทคโนโลยีไทย-ญี่ปุ่น", "Thai-Nichi Institute of Technology"],
    ".tsu.ac.th": ["Thaksin University"],
    ".tu.ac.th": ["Thammasat University"],
    ".ms.tup.ac.th": [
        "โรงเรียนเตรียมอุดมศึกษาพัฒนาการ",
        "Triam Udom Suksa Pattanakarn School",
    ],
    ".ubu.ac.th": ["Ubonratchathani University"],
    ".365.udru.ac.th": ["มหาวิทยาลัยราชภัฏอุดรธานี", "UDON THANI RAJABHAT UNIVERSITY"],
    ".up.ac.th": ["มหาวิทยาลัยพะเยา", "University of Phayao"],
    ".uru.ac.th": ["Uttaradit Rajabhat University"],
    ".utcc.ac.th": ["University of the Thai Chamber of Commerce"],
    ".varee.ac.th": ["Varee Chiang Mai International School"],
    ".vistec.ac.th": ["Vidyasirimedhi Institute of Science and Technology"],
    ".vu.ac.th": ["Vongchavalitkul University"],
    ".webster.ac.th": ["Webster University, Thailand"],
    ".wmk.ac.th": ["watmongkol kothawas school"],
    ".wu.ac.th": ["Walailak University"],
    ".ycpschool.ac.th": ["โรงเรียนยางชุมน้อยพิทยาคม", "Yangchumnoi Pittayakom school"],
    ".yru.ac.th": ["Yala Rajabhat University", "Yala Rajabhat University"],
    ".ytc.ac.th": ["yala technical college", "yala technical college"],
    ".ku.th": ["Kasetsart University"],
    ".dtmik.tj": ["Innovation and Technology Management Institute in Kulob City"],
    ".hgu.tj": ["Худжандский государственный университет", "Khujand State University"],
    ".kbtut.tj": ["Khujand Polytechnic Institute of Tajik Technical University"],
    ".polytech.tj": [
        "Донишкадаи политехникии Донишгоҳи техникии Тоҷикистон ба номи академик М.Осимӣ дар ш. Хуҷанд",
        "Khujand Polytechnic Institute of Tajik Technical University",
    ],
    ".tajagroun.tj": ["Tajik Agrarian University"],
    ".tajmedun.tj": [
        "Таджикский государственный медицинский университет имени Абуали ибни Сино",
        "Avicenna Tajik State Medical University",
    ],
    ".tarena.tj": ["Tajik National University"],
    ".ttu.tj": [
        "Донишгоҳи техникии Тоҷикистон  ба номи академик М.С.Осимӣ",
        "Tajik Technical University  named after academic M.S.Osimi",
    ],
    ".itit.edu.tm": ["Institute of Telecommunications and Informatics of Turkmenistan"],
    ".edu.tm": ["International Turkmen Turkish University"],
    ".SESAME.com.tn": [
        "SESAME : École supérieure des sciences appliquées et de management "
    ],
    ".episousse.com.tn": ["EPI Sousse : Ecole Pluridisciplinaire Internationale", " "],
    ".enis.tn": ["National Engineering School of Sfax"],
    ".iit.ens.tn": [
        "Institut International de Technologie",
        "North American Private University ",
    ],
    ".unat.ens.tn": ["University of Aviation and Technology"],
    ".ensi-uma.tn": ["National School of Computer Science"],
    ".esen.tn": [
        "\ufeffESEN Manouba, Ecole Supérieure d'Economie Numérique",
        "Higher School of Digital Economy, Tunisia",
    ],
    ".esprit.tn": ["Ecole Superieure Privee d'Ingenierie et de Technologies"],
    ".fsegs.tn": [
        "Faculté des Sciences Économiques et de Gestion de Sfax",
        "Faculty of Economics and Management of Sfax",
    ],
    ".iit.tn": ["Institut International de Technologie, Tunis"],
    ".infoplus.tn": ["Centre de formation privé Infoplus"],
    ".isetcom.tn": [
        "Institut supérieur des études technologiques en communications de Tunis (Iset'com)"
    ],
    ".itbs.tn": ["IT Business School, Tunisia"],
    ".medtech.tn": ["Mediterranean Institute of Technology"],
    ".pi.tn": ["Ecole Polytechnique Internationale Privée de Tunis "],
    ".polytechnicien.tn": ["Polytechnique Sousse"],
    ".polytecsousse.tn": ["Polytechnique Sousse"],
    ".bizerte.r-iset.tn": [
        "Institut Supérieur Des Etudes Technologiques De Bizerte",
        "Higher Institute Of Technological Studies Of Bizerte",
    ],
    ".charguia.r-iset.tn": ["institut supérieur des études technologiques de charguia"],
    ".gafsa.r-iset.tn": ["institut supérieur des études technologiques de Gafsa"],
    ".kelibia.r-iset.tn": [
        "Institut Supérieur des Etudes Technologiques de Kélibia",
        "Higher Institute of Technological Studies of Kélibia",
    ],
    ".rades.r-iset.tn": [
        "ISET Rades",
        " Higher Institute of Technological Studies of Rades",
    ],
    ".sfax.r-iset.tn": ["\ufeffInstituts Supérieurs des Etudes Technologiques de Sfax"],
    ".sousse.r-iset.tn": ["Institut Supérieur des Etudes Technologiques de Sousse"],
    ".zaghouan.r-iset.tn": [
        "iset Zaghouan (Institut Supérieur des Etudes Technologiques de Zaghouan)",
        "iset Zaghouan (Higher Institute of Technological Studies of Zaghouan)",
    ],
    ".disfm.rnu.tn": ["Instituts Supérieurs de Formation des Maîtres"],
    ".enicarthage.rnu.tn": [
        "École Nationale d'ingénieurs de Carthage",
        "National Engineering School of Carthage",
    ],
    ".enis.rnu.tn": ["National Engineering School of Sfax"],
    ".enit.rnu.tn": ["National Engineering School of Tunis"],
    ".fsg.rnu.tn": ["Faculty of Sciences of Gabes"],
    ".fsm.rnu.tn": [
        "Faculté des sciences de Monastir",
        "Faculty of sciences of Monastir",
    ],
    ".fss.rnu.tn": ["Faculté des Sciences de Sfax"],
    ".insat.rnu.tn": ["national institute of applied science and technology"],
    ".isbm.rnu.tn": ["Institut superieur de biotechnologie Monastir"],
    ".isetch.rnu.tn": [
        "Institut Supérieur des études Technologiques",
        "higher Institute of Technological Studies of Nabeul",
        ".group",
        "http://www.isetn.rnu.tn/fra/departements/TI/5/technologie-de-l-informatique",
        "http://www.cck.rnu.tn/newcck/index.php",
    ],
    ".isetj.rnu.tn": ["Instituts Supérieurs des Etudes Technologiques de Jendouba"],
    ".isetn.rnu.tn": [
        "Institut Supérieur des Etudes Technologiques de Nabeul",
        "Higher Institute of Technological Studies of Nabeul",
    ],
    ".isetr.rnu.tn": ["Instituts Supérieurs des Etudes Technologiques"],
    ".isetso.rnu.tn": ["Instituts Supérieurs des Etudes Technologiques de Sousse"],
    ".isg.rnu.tn": ["Institut Supérieur de Gestion de Tunis"],
    ".isim.rnu.tn": [
        "Institut Supérieur de l'Informatique de Médenine (ISIMed)",
        "Higher Institute of Informatics of Medenine",
    ],
    ".isimsf.rnu.tn": ["Institut Supérieur d'Informatique et du Multimédia de Sfax"],
    ".issatso.rnu.tn": [
        "Higher Institute of Applied Sciences and Technology of Sousse"
    ],
    ".uc.rnu.tn": ["Université du Centre, Sousse"],
    ".ugaf.rnu.tn": ["Université de Gafsa"],
    ".uj.rnu.tn": ["Université de Jendouba"],
    ".um.rnu.tn": ["Université de Monastir"],
    ".uma.rnu.tn": ["Université de la Manouba"],
    ".univ-k.rnu.tn": ["Université de Kairouan"],
    ".univgb.rnu.tn": ["Université de Gabès"],
    ".uss.rnu.tn": ["Université de Sfax"],
    ".utm.rnu.tn": ["Université de Tunis El Manar"],
    ".utunis.rnu.tn": ["Université de Tunis"],
    ".uvt.rnu.tn": [
        "Université de 7 Novembre à Carthage",
        "Université Virtuelle de Tunis",
    ],
    ".uz.rnu.tn": ["Université Ez-Zitouna"],
    ".supcom.tn": ["Ecole Supérieure des Communications de Tunis (Sup'Com)"],
    ".suptech.tn": ["Private Higher School of Technology and Management"],
    ".tek-up.tn": ["Tek-Up private higher school of technologies and ingineering"],
    ".enicar.u-carthage.tn": [
        "École Nationale d'ingénieurs de Carthage",
        "National Engineering School of Carthage",
    ],
    ".fsb.u-carthage.tn": [
        "Faculté des Sciences de Bizerte - Université de Carthage",
        "Faculty of Sciences of Bizerte  - University of Carthage",
    ],
    ".fsegn.u-carthage.tn": [
        "fseg Nabeul",
        "Faculty of Economics and Management of Nabeul",
    ],
    ".insat.u-carthage.tn": [
        "institut national des sciences appliquées et de technologie"
    ],
    ".istic.u-carthage.tn": [
        "The Higher Institute of Information Technologies and Communications",
        "The Higher Institute of Information Technologies and Communications",
    ],
    ".u-gabes.tn": [
        "Institut Superieur des Sciences Appliquees et de Technologie de Gabes"
    ],
    ".isigk.u-kairouan.tn": [
        "Institut Supérieur d'Informatique et de Gestion de Kairouan",
        "Higher Institute of Informatics and Management of Kairouan",
    ],
    ".isamm.u-manouba.tn": [
        "institut superieur d'art de multimedia de manouba",
        "ISAMM",
    ],
    ".fsm.u-monastir.tn": [
        "Faculté des sciences Monastir FSM",
        "Monastir sciences university",
    ],
    ".isima.u-monastir.tn": [
        "Higher Institute of Computer Science, Mahdia, Tunisia (ISI Mahdia)"
    ],
    ".isimm.u-monastir.tn": [
        "L'Institut Supérieur d'Informatique et de Mathématiques de l’Université de Monastir",
        "Higher Institute of Computer Science and Mathematics of Monastir",
    ],
    ".enetcom.u-sfax.tn": [
        "المدرسة الوطنية للإلكترونيك والإتصالات بصفاقس",
        "National School of Electronics and Telecoms of Sfax",
    ],
    ".isimsf.u-sfax.tn": ["Institut Supérieur d'Informatique et de Multimédia de Sfax"],
    ".eniso.u-sousse.tn": ["Ecole Nationale d'Ingénieurs de Sousse"],
    ".essths.u-sousse.tn": ["HIGHER SCHOOL OF SCIENCE AND TECHNOLOGY OF HAMMAM SOUSSE"],
    ".isitc.u-sousse.tn": [
        "L'Institut Superieur d'Informatique et des Techniques de Communication de Hammam Sousse"
    ],
    ".issatso.u-sousse.tn": [
        "Higher Institute of Applied Sciences and Technology of Sousse"
    ],
    ".ensit.u-tunis.tn": ["Higher National Engineering School of Tunis "],
    ".tbs.u-tunis.tn": ["Tunis Business School"],
    ".fsb.ucar.tn": [
        "Faculté des Sciences de Bizerte",
        "Faculty of Sciences of Bizerte",
    ],
    ".insat.ucar.tn": [
        "institut national des sciences appliquées et de technologie",
        "insat",
    ],
    ".istic.ucar.tn": [
        "Institut Supérieur des Technologies de l’Information et de la Communication",
        "The Higher Institute of Information Technologies and Communication",
    ],
    ".isamm.uma.tn": ["Institut Supérieur des Arts Multimédia de la Manouba - ISAMM "],
    ".myu.universitecentrale.tn": ["Université Centrale"],
    ".enetcom.usf.tn": [
        "Ecole nationale d'Electronique et des Télécommunications de Sfax"
    ],
    ".fsegs.usf.tn": [
        "University of Sfax, Tunisia",
        "Faculty of Economic Sciences and Management, University of Sfax, Tunisia",
    ],
    ".etudiant-enit.utm.tn": [
        "National Engineering School of Tunis",
        "Students Email Domain",
    ],
    ".etudiant-fsegt.utm.tn": [
        "faculté des sciences economiques et de gestion de tunis"
    ],
    ".etudiant-fst.utm.tn": ["Faculty of sciences of Tunis"],
    ".etudiant-isi.utm.tn": ["Institut Supérieur d'informatique"],
    ".utm.tn": ["Université de Tunis El Manar"],
    ".uvt.tn": ["Université Virtuelle de Tunis", "Virtual University Of Tunis"],
    ".student.42kocaeli.com.tr": ["42 Kocaeli"],
    ".29mayis.edu.tr": [
        "İstanbul 29 Mayıs Üniversitesi",
        "İstanbul 29 Mayıs University",
    ],
    ".acibadem.edu.tr": ["Acıbadem Üniversitesi", "Acıbadem University"],
    ".adanabtu.edu.tr": [
        "Adana Bilim ve Teknoloji Üniversitesi",
        "Adana Science and Technology University",
    ],
    ".student.adiguzel.edu.tr": ["\ufeffTC Ataşehir Adıgüzel Vocational School"],
    ".adiyaman.edu.tr": ["Adıyaman Üniversitesi", "Adıyaman University"],
    ".adu.edu.tr": ["Adnan Menderes Üniversitesi", "Adnan Menderes University"],
    ".afsu.edu.tr": [
        "Afyon Sağlık Bilimleri Üniversitesi",
        "Afyonkarahisar Health Sciences University",
    ],
    ".agri.edu.tr": [
        "Ağrı İbrahim Çeçen Üniversitesi",
        "Ibrahim Çeçen University of Ağrı",
    ],
    ".agu.edu.tr": ["Abdullah Gül Üniversitesi", "Abdullah Gül University"],
    ".ahievran.edu.tr": ["Ahi Evran Üniversitesi", "Ahi Evran University"],
    ".akdeniz.edu.tr": ["Akdeniz Üniversitesi", "Akdeniz University"],
    ".akev.edu.tr": ["Antalya Akev Üniversitesi", "Antalya Akev University"],
    ".aksaray.edu.tr": ["Aksaray Üniversitesi", "Aksaray University"],
    ".aku.edu.tr": ["Afyon Kocatepe Üniversitesi", "Afyon Kocatepe University"],
    ".akun.edu.tr": [
        "AKDENIZ KARPAZ UNIVERSITESI",
        "UNIVERSITY OF MEDITERRENEAN KARPASIA",
    ],
    ".alanya.edu.tr": [
        "Alanya Alaaddin Keykubat Üniversitesi",
        "Alanya Alaaddin Keykubat University",
    ],
    ".alparslan.edu.tr": ["Muş Alparslan Üniversitesi", "Muş Alparslan University"],
    ".altinbas.edu.tr": ["Altınbaş Üniversitesi", "Altinbas University"],
    ".amasya.edu.tr": ["T.C. Amasya Üniversitesi", "T.C. Amasya University"],
    ".anadolu.edu.tr": ["Anadolu Üniversitesi", "Anadolu University"],
    ".anka.edu.tr": ["ANKA Teknoloji Üniversitesi", "ANKA University of Technology"],
    ".ankara.edu.tr": ["Ankara Üniversitesi", "Ankara University"],
    ".ankaramedipol.edu.tr": ["Ankara Medipol University"],
    ".antalya.edu.tr": [
        "Uluslararası Antalya Üniversitesi",
        "Antalya International University",
    ],
    ".ardahan.edu.tr": ["Ardahan Üniversitesi", "Ardahan University"],
    ".arel.edu.tr": ["İstanbul Arel Üniversitesi", "Istanbul Arel University"],
    ".artuklu.edu.tr": ["Mardin Artuklu Üniversitesi", "Mardin Artuklu University"],
    ".artvin.edu.tr": ["Artvin Çoruh Üniversitesi", "Artvin Çoruh University"],
    ".asbu.edu.tr": [
        "Ankara Sosyal Bilimler Üniversitesi",
        "Ankara University of Social Sciences",
    ],
    ".asu.edu.tr": ["Aksaray Üniversitesi", "Aksaray University"],
    ".atauni.edu.tr": ["Atatürk Üniversitesi", "Atatürk University"],
    ".atilim.edu.tr": ["Atılım Üniversitesi", "Atılım University"],
    ".st.atlas.edu.tr": ["İSTANBUL ATLAS ÜNİVERSİTESİ", "ISTANBUL ATLAS UNIVERSITY"],
    ".atu.edu.tr": [
        "Adana Alparslan Türkeş Bilim ve Teknoloji Üniversitesi",
        "Adana Alparslan Türkeş Science and Technology University",
    ],
    ".avrasya.edu.tr": ["Avrasya Üniversitesi", "Avrasya University"],
    ".aydin.edu.tr": ["İstanbul Aydın Üniversitesi", "İstanbul Aydın University"],
    ".ayvansaray.edu.tr": [
        "İstanbul Ayvansaray Üniversitesi",
        "Istanbul Ayvansaray University",
    ],
    ".bahcesehir.edu.tr": ["Bahçeşehir Üniversitesi", "Bahçeşehir University"],
    ".bakircay.edu.tr": ["İzmir Bakırçay Üniversitesi", "Izmir Bakircay University"],
    ".balikesir.edu.tr": ["Balıkesir Üniversitesi", "Balıkesir University"],
    ".bandirma.edu.tr": [
        "Bandırma Onyedi Eylül Üniversitesi",
        "Bandırma Onyedi Eylül University",
    ],
    ".bartin.edu.tr": ["Bartın Üniversitesi", "Bartın University"],
    ".baskent.edu.tr": ["Başkent Üniversitesi", "Başkent University"],
    ".batman.edu.tr": ["Batman Üniversitesi", "Batman University"],
    ".alumni.bau.edu.tr": ["Bahçeşehir Üniversitesi", "BAU"],
    ".cons.bau.edu.tr": ["Bahçeşehir Üniversitesi", "Bahcesehir University"],
    ".bau.edu.tr": ["Bahcesehir University"],
    ".baucyprus.edu.tr": [
        "Bahçeşehir Kıbrıs Üniversitesi",
        "Bahçeşehir Cyprus University",
    ],
    ".bavu.edu.tr": ["Bezmialem Vakıf Üniversitesi", "Bezmialem University"],
    ".bayar.edu.tr": ["Celal Bayar Üniversitesi", "Celal Bayar University"],
    ".bayburt.edu.tr": ["Bayburt Üniversitesi", "Bayburt University"],
    ".beu.edu.tr": ["Bitlis Eren Üniversitesi", "Bitlis Eren University"],
    ".beun.edu.tr": ["Bülent Ecevit Üniversitesi", "Bülent Ecevit University"],
    ".beykent.edu.tr": ["Beykent Üniversitesi", "Beykent University"],
    ".beykoz.edu.tr": ["Beykoz Üniversitesi", "Beykoz University"],
    ".bezmialem.edu.tr": ["Bezmialem Vakıf Üniversitesi", "Bezmialem University"],
    ".bilecik.edu.tr": ["Bilecik Üniversitesi", "Bilecik University"],
    ".bilgi.edu.tr": ["İstanbul Bilgi Üniversitesi", "İstanbul Bilgi University"],
    ".bilkent.edu.tr": ["Bilkent Üniversitesi", "Bilkent University"],
    ".bingol.edu.tr": ["Bingöl Üniversitesi", "Bingöl University"],
    ".biruni.edu.tr": ["Biruni Üniversitesi", "Biruni University"],
    ".boun.edu.tr": ["Boğaziçi Üniversitesi", "Boğaziçi University"],
    ".bozok.edu.tr": ["Bozok Üniversitesi", "Bozok University"],
    ".btu.edu.tr": ["Bursa Teknik Üniversitesi", "Bursa Technical University"],
    ".cag.edu.tr": ["Çağ Üniversitesi", "Çağ University"],
    ".cankaya.edu.tr": ["Çankaya Üniversitesi", "Çankaya University"],
    ".cbu.edu.tr": ["Manisa Celal Bayar Üniversitesi", "Manisa Celal Bayar University"],
    ".ciu.edu.tr": [
        "Uluslararası Kıbrıs Üniversitesi",
        "Cyprus International University",
    ],
    ".comu.edu.tr": ["Çanakkale 18 Mart Üniversitesi", "Çanakkale 18 Mart University"],
    ".cu.edu.tr": ["Çukurova Üniversitesi", "Çukurova University"],
    ".cumhuriyet.edu.tr": ["Cumhuriyet Üniversitesi", "Cumhuriyet University"],
    ".dau.edu.tr": ["Doğu Akdeniz Üniversitesi", "Eastern Mediterranean University"],
    ".deu.edu.tr": ["Dokuz Eylül Üniversitesi", "Dokuz Eylül University"],
    ".dho.edu.tr": ["Deniz Harp Okulu", "Turkish Naval Academy"],
    ".dicle.edu.tr": ["Dicle Üniversitesi", "Dicle University"],
    ".dogus.edu.tr": ["Doğuş Üniversitesi", "Doğuş University"],
    ".dpu.edu.tr": ["Dumlupınar Üniversitesi", "Dumlupınar University"],
    ".dumlupinar.edu.tr": ["Dumlupınar Üniversitesi", "Dumlupınar University"],
    ".duzce.edu.tr": ["Düzce Üniversitesi", "Düzce University"],
    ".ogr.ebyu.edu.tr": [
        "Erzincan Binali Yıldırım Üniversitesi",
        "Erzincan Binali Yıldırım University",
    ],
    ".ege.edu.tr": ["Ege Üniversitesi", "Ege University"],
    ".emu.edu.tr": ["Doğu Akdeniz Üniversitesi", "Eastern Mediterranean University"],
    ".ogr.erbakan.edu.tr": [
        "Necmettin Erbakan Üniversitesi",
        "Necmettin Erbakan University",
    ],
    ".erbakan.edu.tr": [
        "Necmettin Erbakan Üniversitesi",
        "Necmettin Erbakan University",
    ],
    ".erciyes.edu.tr": ["Erciyes Üniversitesi", "Erciyes University"],
    ".erdogan.edu.tr": [
        "Recep Tayyip Erdoğan Üniversitesi",
        "Recep Tayyip Erdoğan University",
    ],
    ".erzincan.edu.tr": ["Erzincan Üniversitesi", "Erzincan University"],
    ".erzurum.edu.tr": ["Erzurum Teknik Üniversitesi", "Erzurum Technical University"],
    ".esenyurt.edu.tr": [
        "İstanbul Esenyurt Üniversitesi",
        "İstanbul Esenyurt University",
    ],
    ".eskisehir.edu.tr": ["\ufeffEskişehir Technical University"],
    ".etu.edu.tr": [
        "TOBB Ekonomi ve Teknoloji Üniversitesi",
        "TOBB Economics and Technology University",
    ],
    ".eul.edu.tr": ["European University of Lefke", "Lefke Avrupa Üniversitesi"],
    ".fatihsultan.edu.tr": [
        "Fatih Sultan Mehmet Vakıf Üniversitesi",
        "Fatih Sultan Mehmet Waqf University",
    ],
    ".stu.fbu.edu.tr": ["Fenerbahçe Üniversitesi", "Fenerbahce University"],
    ".firat.edu.tr": ["Fırat Üniversitesi", "Fırat University"],
    ".stu.fsm.edu.tr": [
        "Fatih Sultan Mehmet Vakıf Üniversitesi",
        "Fatih Sultan Mehmet University",
    ],
    ".fsm.edu.tr": [
        "Fatih Sultan Mehmet Vakıf Üniversitesi",
        "Fatih Sultan Mehmet Foundation University",
    ],
    ".galata.edu.tr": ["İstanbul Galata Üniversitesi", "İstanbul Galata University"],
    ".gantep.edu.tr": ["Gaziantep Üniversitesi", "Gaziantep University"],
    ".gau.edu.tr": ["Girne Amerikan Üniversitesi", "Girne American University"],
    ".gazi.edu.tr": ["Gazi Üniversitesi", "Gazi University"],
    ".student.gaziantep.edu.tr": ["Gaziantep Universitesi", "Gaziantep University"],
    ".gedik.edu.tr": ["İstanbul Gedik Üniversitesi", "İstanbul Gedik University"],
    ".gelisim.edu.tr": ["İstanbul Gelişim Üniversitesi", "İstanbul Gelişim University"],
    ".gidatarim.edu.tr": [
        "Konya Gıda ve Tarım Üniversitesi",
        "Konya Food & Agriculture University",
    ],
    ".giresun.edu.tr": ["Giresun Üniversitesi", "Giresun University"],
    ".gop.edu.tr": ["Gaziosmanpaşa Üniversitesi", "Gaziosmanpaşa University"],
    ".gsu.edu.tr": ["Galatasaray Üniversitesi", "Galatasaray University"],
    ".gtu.edu.tr": ["Gebze Teknik Üniversitesi", "Gebze Technical University"],
    ".gumushane.edu.tr": ["Gümüşhane Üniversitesi", "Gümüşhane University"],
    ".gyte.edu.tr": ["Gebze Teknik Üniversitesi"],
    ".hacettepe.edu.tr": ["Hacettepe Üniversitesi", "Hacettepe University"],
    ".hakkari.edu.tr": ["Hakkari Üniversitesi", "Hakkari University"],
    ".halic.edu.tr": ["Haliç Üniversitesi", "Haliç University"],
    ".harran.edu.tr": ["Harran Üniversitesi", "Harran University"],
    ".hbv.edu.tr": [
        "Ankara Hacı Bayram Veli Üniversitesi",
        "Ankara Haci Bayram Veli University",
    ],
    ".hho.edu.tr": ["Hava Harp Okulu", "Turkish Air Force Academy"],
    ".hitit.edu.tr": ["Hitit Üniversitesi", "Hitit University"],
    ".hku.edu.tr": ["Hasan Kalyoncu Üniversitesi", "Hasan Kalyoncu University"],
    ".hun.edu.tr": ["Hacettepe Üniversitesi", "Hacettepe University"],
    ".ibnhaldun.edu.tr": ["İbn Haldun Üniversitesi", "Ibn Haldun University"],
    ".ibu.edu.tr": ["Abant İzzet Baysal Üniversitesi", "Abant İzzet Baysal University"],
    ".ibun.edu.tr": ["İstanbul Bilgi Üniversitesi", "İstanbul Bilgi University"],
    ".std.idu.edu.tr": ["İzmir Demokrasi Üniversitesi", "Izmir Democracy University"],
    ".idu.edu.tr": ["İzmir Demokrasi Üniversitesi"],
    ".iesu.edu.tr": ["\ufeffİstanbul Esenyurt Üniversitesi"],
    ".ieu.edu.tr": ["İzmir Ekonomi Üniversitesi", "İzmir University of Economics"],
    ".igdir.edu.tr": ["Iğdır Üniversitesi", "Iğdır University"],
    ".ihu.edu.tr": ["Ibn Haldun University", "İbn Haldun Üniversitesi"],
    ".ikc.edu.tr": ["İzmir Kâtip Çelebi Üniversitesi", "İzmir Kâtip Çelebi University"],
    ".ogr.ikcu.edu.tr": [
        "İzmir Katip Çelebi Üniversitesi",
        "Izmir Katip Celebi University",
    ],
    ".ikcu.edu.tr": [
        "İzmir Katip Çelebi Üniversitesi",
        "Izmir Katip Celebi University",
    ],
    ".iku.edu.tr": ["Istanbul Kültür Üniversitesi", "Istanbul Kültür University"],
    ".inonu.edu.tr": ["İnönü Üniversitesi", "İnönü University"],
    ".isik.edu.tr": ["Işık Üniversitesi", "Işık University"],
    ".isikun.edu.tr": ["Işık Üniversitesi", "Işık University"],
    ".ismu.edu.tr": [
        "İstanbul Medeniyet Üniversitesi",
        "Istanbul Medeniyet University",
    ],
    ".isparta.edu.tr": [
        "Isparta Uygulamalı Bilimler Üniversitesi",
        "Isparta University of Applied Sciences",
    ],
    ".istanbul.edu.tr": ["İstanbul Üniversitesi", "İstanbul University"],
    ".istanbularel.edu.tr": ["Arel Üniversitesi", "Arel University"],
    ".istanbulbilim.edu.tr": [
        "İstanbul Bilim Üniversitesi",
        "İstanbul Bilim University",
    ],
    ".istanbulticaret.edu.tr": [
        "İstanbul Ticaret Üniversitesi",
        "Istanbul Commerce University",
    ],
    ".iste.edu.tr": [
        "İskenderun Teknik Üniversitesi",
        "İskenderun Technical University",
    ],
    ".istinye.edu.tr": ["İstinye Üniversitesi", "İstinye University"],
    ".iszu.edu.tr": [
        "İstanbul Sabahattin Zaim Üniversitesi",
        "İstanbul Sabahattin Zaim University",
    ],
    ".iticu.edu.tr": ["İstanbul Ticaret Üniversitesi", "İstanbul Ticaret University"],
    ".itu.edu.tr": ["İstanbul Teknik Üniversitesi", "İstanbul Technical University"],
    ".ogr.iu.edu.tr": [
        "İstanbul Universitesi",
        "Istanbul University - Student Spesific Mail Address Extensions",
    ],
    ".iuc.edu.tr": [
        "İstanbul Üniversitesi Cerrahpaşa",
        "Istanbul Universitesi Cerrahpasa",
    ],
    ".iyte.edu.tr": [
        "İzmir Yüksek Teknoloji Enstitüsü",
        "İzmir Institute of Technology",
    ],
    ".izmirekonomi.edu.tr": [
        "İzmir Ekonomi Üniversitesi",
        "İzmir University of Economics",
    ],
    ".izu.edu.tr": [
        "İstanbul Sabahattin Zaim Üniversitesi",
        "İstanbul Sabahattin Zaim University",
    ],
    ".kafkas.edu.tr": ["\ufeffKafkas Üniversitesi"],
    ".kapadokya.edu.tr": ["Kapadokya Üniversitesi"],
    ".karabuk.edu.tr": ["Karabük Üniversitesi", "Karabük University"],
    ".karaelmas.edu.tr": [
        "Zonguldak Karaelmas Üniversitesi",
        "Zonguldak Karaelmas University",
    ],
    ".karatay.edu.tr": ["KTO Karatay Üniversitesi", "KTO Karatay University"],
    ".karatekin.edu.tr": [
        "Çankırı Karatekin Üniversitesi",
        "Çankırı Karatekin University",
    ],
    ".kastamonu.edu.tr": ["Kastamonu Üniversitesi", "Kastamonu University"],
    ".kavram.edu.tr": ["İzmir Kavram Meslek Yüksekokulu"],
    ".kayseri.edu.tr": ["Kayseri Üniversitesi", "Kayseri Univercity"],
    ".kemerburgaz.edu.tr": [
        "İstanbul Kemerburgaz Üniversitesi",
        "İstanbul Kemerburgaz University",
    ],
    ".ogr.kent.edu.tr": ["İstanbul Kent Üniversitesi", "Istanbul KENT UNIVERSITY"],
    ".khas.edu.tr": ["Kadir Has Üniversitesi", "Kadir Has University"],
    ".kilis.edu.tr": ["Kilis 7 Aralık Üniversitesi", "Kilis 7 Aralık University"],
    ".kirklareli.edu.tr": ["Kırklareli Üniversitesi", "Kırklareli University"],
    ".kku.edu.tr": ["Kırıkkale Üniversitesi", "Kırıkkale University"],
    ".klu.edu.tr": ["Kırklareli Üniversitesi", "Kırklareli University"],
    ".kmu.edu.tr": [
        "Karamanoğlu Mehmetbey Üniversitesi",
        "Karamanoğlu Mehmetbey University",
    ],
    ".kocaeli.edu.tr": ["Kocaeli Üniversitesi", "Kocaeli University"],
    ".kocaelisaglik.edu.tr": [
        "Kocaeli Sağlık ve Teknoloji Üniversitesi",
        "Kocaeli Healt and Technology University",
    ],
    ".konya.edu.tr": ["Necmettin Erbakan Üniversitesi", "Necmettin Erbakan University"],
    ".ksbu.edu.tr": [
        "Kütahya Sağlık Bilimleri Üniversitesi",
        "Kütahya University of Health Sciences ",
    ],
    ".ksu.edu.tr": [
        "Kahramanmaraş Sütçü İmam Üniversitesi",
        "Kahramanmaraş Sütçü İmam University",
    ],
    ".ktu.edu.tr": ["Karadeniz Teknik Üniversitesi", "Karadeniz Technical University"],
    ".ktun.edu.tr": ["Konya Teknik Üniversitesi", "Konya Technical University"],
    ".ku.edu.tr": ["Koç Üniversitesi", "Koç University"],
    ".lefke.edu.tr": ["Lefke Avrupa Üniversitesi", "European University of Lefke"],
    ".maltepe.edu.tr": ["T.C. Maltepe Üniversitesi", "T.C. Maltepe University"],
    ".marmara.edu.tr": ["Marmara Üniversitesi", "Marmara University"],
    ".marun.edu.tr": ["Marmara University, Istanbul, TURKEY"],
    ".medeniyet.edu.tr": [
        "İstanbul Medeniyet Üniversitesi",
        "İstanbul Medeniyet University",
    ],
    ".medipol.edu.tr": ["İstanbul Medipol Üniversitesi", "İstanbul Medipol University"],
    ".mef.edu.tr": ["MEF Üniversitesi", "MEF University"],
    ".mehmetakif.edu.tr": [
        "T.C. Mehmet Akif Ersoy Üniversitesi",
        "T.C. Mehmet Akif Ersoy University",
    ],
    ".mersin.edu.tr": ["Mersin Üniversitesi", "Mersin University"],
    ".metu.edu.tr": [
        "Orta Doğu Teknik Üniversitesi",
        "Middle East Technical University",
    ],
    ".mku.edu.tr": ["Mustafa Kemal Üniversitesi", "Mustafa Kemal University"],
    ".msgsu.edu.tr": [
        "T.C. Mimar Sinan Güzel Sanatlar Üniversitesi",
        "T.C. Mimar Sinan Fine Arts University",
    ],
    ".msu.edu.tr": [
        "T.C. Mimar Sinan Güzel Sanatlar Üniversitesi",
        "T.C. Mimar Sinan Fine Arts University",
    ],
    ".mu.edu.tr": ["Muğla Sıtkı Koçman Üniversitesi", "Muğla Sıtkı Koçman University"],
    ".munzur.edu.tr": ["Munzur Üniversitesi", "Munzur University"],
    ".campus.netkent.edu.tr": [
        "Netkent Akdeniz Araştırma ve Bilim Üniversitesi",
        "Netkent Mediterranean Research and Science University",
    ],
    ".neu.edu.tr": ["Yakın Doğu Üniversitesi", "Near East University"],
    ".nevsehir.edu.tr": [
        "Nevşehir Hacı Bektaş Veli Üniversitesi",
        "Nevşehir Hacı Bektaş Veli University",
    ],
    ".nisantasi.edu.tr": ["Nişantaşı Üniversitesi", "Nişantaşı University"],
    ".nku.edu.tr": ["Namık Kemal Üniversitesi", "Namık Kemal University"],
    ".nny.edu.tr": [
        "T.C. Nuh Naci Yazgan Üniversitesi",
        "T.C. Nuh Naci Yazgan University",
    ],
    ".odtu.edu.tr": [
        "Orta Doğu Teknik Üniversitesi",
        "Middle East Technical University",
    ],
    ".odu.edu.tr": ["Ordu Üniversitesi", "Ordu University"],
    ".ogu.edu.tr": ["Osmangazi Üniversitesi", "Osmangazi University"],
    ".ohu.edu.tr": [
        "Niğde Ömer Halisdemir Üniversitesi",
        "Nigde Omer Halisdemir University",
    ],
    ".okan.edu.tr": ["Okan Üniversitesi", "Okan University"],
    ".omu.edu.tr": ["Ondokuz Mayıs Üniversitesi", "Ondokuz Mayıs University"],
    ".osmaniye.edu.tr": [
        "Osmaniye Korkut Ata Üniversitesi",
        "Osmaniye Korkut Ata University",
    ],
    ".ostimteknik.edu.tr": ["Ostim Teknik Üniversitesi", "Ostim Technical University"],
    ".ozal.edu.tr": [
        "Malatya Turgut Özal Üniversitesi",
        "Malatya Turgut Özal University",
    ],
    ".ozu.edu.tr": ["Özyeğin Üniversitesi", "Özyeğin University"],
    ".ozyegin.edu.tr": ["Özyeğin Üniversitesi", "Özyeğin University"],
    ".pa.edu.tr": ["Polis Akademisi", "Turkish National Police Academy"],
    ".pamukkale.edu.tr": ["Pamukkale Üniversitesi", "Pamukkale University"],
    ".pau.edu.tr": ["PAMUKKALE ÜNİVERSİTESİ", "PAMUKKALE UNIVERSITY"],
    ".pirireis.edu.tr": ["Pîrî Reis Üniversitesi", "Pîrî Reis University"],
    ".pru.edu.tr": ["Piri Reis Üniversitesi"],
    ".rdu.edu.tr": ["Rauf Denktas Universitesi", "Rauf Denktas University"],
    ".rumeli.edu.tr": [
        "T.C. İstanbul Rumeli Üniversitesi",
        "T.C. İstanbul Rumeli University",
    ],
    ".sabanciuniv.edu.tr": ["Sabancı Üniversitesi", "Sabancı University"],
    ".sakarya.edu.tr": ["Sakarya Üniversitesi", "Sakarya University"],
    ".samsun.edu.tr": ["Samsun University"],
    ".sanko.edu.tr": ["Sanko Üniversitesi", "Sanko University"],
    ".sau.edu.tr": ["Sakarya Üniversitesi", "Sakarya University"],
    ".sbu.edu.tr": ["Sağlık Bilimleri Üniversitesi", "University of Health Sciences"],
    ".sdu.edu.tr": ["Süleyman Demirel Üniversitesi", "Süleyman Demirel University"],
    ".sehir.edu.tr": ["İstanbul Şehir Üniversitesi", "İstanbul Şehir University"],
    ".selcuk.edu.tr": ["Selçuk Üniversitesi", "Selçuk University"],
    ".siirt.edu.tr": ["Siirt Üniversitesi", "Siirt University"],
    ".sinop.edu.tr": ["Sinop Üniversitesi", "Sinop University"],
    ".sirnak.edu.tr": ["Şırnak Üniversitesi", "Şırnak University"],
    ".subu.edu.tr": [
        "Sakarya Uygulama Bilimler Üniversitesi",
        "Sakarya University of Applied Sciences",
    ],
    ".tarsus.edu.tr": ["Tarsus Üniversitesi", "Tarsus University"],
    ".tau.edu.tr": ["Türk-Alman Üniversitesi", "Turkish-German University"],
    ".tedu.edu.tr": ["TED Üniversitesi", "TED University"],
    ".thk.edu.tr": [
        "Türk Hava Kurumu Üniversitesi",
        "University of Turkish Aeronautical Association",
    ],
    ".ticaret.edu.tr": [
        "Istanbul Ticaret Universitesi",
        "Istanbul Commerce University",
    ],
    ".toros.edu.tr": ["Toros Üniversitesi", "Toros University"],
    ".trakya.edu.tr": ["Trakya Üniversitesi", "Trakya University"],
    ".ufuk.edu.tr": ["Ufuk Üniversitesi", "Ufuk University"],
    ".uludag.edu.tr": ["Uludağ Üniversitesi", "Uludağ University", ".ogr"],
    ".usak.edu.tr": ["Uşak Üniversitesi", "Uşak University"],
    ".uskudar.edu.tr": ["Üsküdar Üniversitesi", "Üsküdar University"],
    ".yalova.edu.tr": ["Yalova Üniversitesi", "Yalova University"],
    ".yasar.edu.tr": ["Yaşar Üniversitesi", "Yaşar University"],
    ".ybu.edu.tr": [
        "Ankara Yıldırım Beyazıt Üniversitesi",
        "Ankara Yıldırım Beyazıt University",
    ],
    ".yeditepe.edu.tr": ["Yeditepe Üniversitesi", "Yeditepe University"],
    ".yeniyuzyil.edu.tr": [
        "İstanbul Yeni Yüzyıl Üniversitesi",
        "İstanbul Yeni Yüzyıl University",
    ],
    ".ogr.yesevi.edu.tr": [
        "Hoca Ahmet Yesevi Üniversitesi",
        "Akhmet Yassawi University",
    ],
    ".yildiz.edu.tr": ["Yıldız Teknik Üniversitesi", "Yıldız Technical University"],
    ".yiu.edu.tr": ["Yüksek İhtisas Üniversitesi", "Yüksek İhtisas University"],
    ".yuksekihtisasuniversitesi.edu.tr": [
        "Yüksek İhtisas Üniversitesi",
        "Yüksek İhtisas University",
    ],
    ".yyu.edu.tr": ["Yüzüncü Yıl Üniversitesi", "Yüzüncü Yıl University"],
    ".stu.acischools.k12.tr": ["Açı Lisesi", "Aci High School"],
    ".alkev.k12.tr": [
        "Alman Liseliler Kültür ve Eğitim Vakfı ALKEV Özel Okulları",
        "ALKEV Private Schools",
    ],
    ".ayseabla.k12.tr": ["Başkent Üniversitesi Özel Ayşeabla Anadolu Lisesi"],
    ".bahcesehir.k12.tr": ["\ufeffBahçeşehir Koleji", "Bahçeşehir College"],
    ".bjkkabatasvakfiokullari.k12.tr": [" BJK - Kabataş Vakfı Okulları"],
    ".bornovakoleji.k12.tr": ["bornovakoleji", " bornova college"],
    ".evrim.k12.tr": ["Özel Evrim Okulları"],
    ".fmvisik.k12.tr": ["Feyziye Mektepleri", "Feyziye Schools"],
    ".ihlaskoleji.k12.tr": ["İhlas Koleji", "İhlas College"],
    ".istek.k12.tr": ["İSTEK Antalya Okulları", "İSTEK Antalya College"],
    ".koc.k12.tr": ["Koç Okulu", "The Koç School"],
    ".maya.k12.tr": ["Maya School"],
    ".mayaokullari.k12.tr": ["Maya Okulları", "Maya Schools"],
    ".nds.k12.tr": ["Notre Dame de Sion Özel Fransız Lisesi"],
    ".odtugvo.k12.tr": ["ODTU GVO ÖZEL LİSESİ", "METU DFS PRIVATE HIGH SCHOOL"],
    ".robcol.k12.tr": ["American Robert College of Istanbul"],
    ".sanliurfaeml.k12.tr": [
        "Urfa Mesleki ve Teknik Anadolu Lisesi",
        "Urfa Vocational and Technical Anatolian HighSchool",
    ],
    ".sb.k12.tr": ["Özel Saint Benoît Fransız Lisesi"],
    ".sj.k12.tr": ["İstanbul Özel Saint-Joseph Fransız Lisesi"],
    ".sm.k12.tr": ["Saint Michel Fransız Lisesi"],
    ".sp.k12.tr": ["Saint Pulcherie Fransız Lisesi"],
    ".tedankara.k12.tr": ["TED Ankara Koleji", "Ted Ankara College Foundation Schools"],
    ".tedatakent.k12.tr": ["TED Atakent Koleji  ", "TED Atakent College"],
    ".terakki.k12.tr": ["Terakki Vakfı Okulları"],
    ".tevitol.k12.tr": ["TEV Inanc Turkes Ozel Lisesi"],
    ".uaa.k12.tr": ["Özel Üsküdar Amerikan Lisesi", "Uskudar American Academy"],
    ".ugurokullari.k12.tr": ["Ugur Okullari", "Ugur High schools"],
    ".yenilikciogrenme.k12.tr": ["Yenilikci Ogrenme Merkezi, Istanbul, Turkey"],
    ".usc.edu.tt": ["University of the Southern Caribbean"],
    ".utt.edu.tt": ["University of Trinidad and Tobago"],
    ".uwi.tt": ["University of the West Indies St. Augustine"],
    ".kcis.com.tw": [
        "Kang Chiao International School",
        "Kang Chiao International School",
    ],
    ".mail.aeust.edu.tw": [
        "亞東科技大學",
        "Asia Eastern University of Science and Technology ",
    ],
    ".live.asia.edu.tw": ["Asia University, Taiwan", "Asia University, Taiwan"],
    ".au.edu.tw": ["Aletheia University"],
    ".ccu.edu.tw": ["National Chung Cheng University"],
    ".cgu.edu.tw": ["Chang Gung University"],
    ".chgsh.chc.edu.tw": ["國立彰化女子高級中學", "National Changhua Girl's Senior High School"],
    ".chsh.chc.edu.tw": ["國立彰化高級中學", "National Changhua Senior High School"],
    ".chihlee.edu.tw": ["Chihlee University of Technology", "致理科技大學"],
    ".chu.edu.tw": ["Chung Hua University"],
    ".mailst.cjcu.edu.tw": ["Chang Jung Christian University"],
    ".cku.edu.tw": ["Ching Kuo Institue of Management &amp; Health"],
    ".cmu.edu.tw": ["中國醫藥大學", "China Medical University"],
    ".gm.cnu.edu.tw": ["嘉南藥理大學", "Chia Nan University of Pharmacy ＆ Science"],
    ".cpu.edu.tw": ["Central Police University"],
    ".csmu.edu.tw": ["CHUNG SHAN MEDICAL UNIVERSITY"],
    ".gcloud.csu.edu.tw": ["正修科技大學", "CHENG SHIU UNIVERSITY"],
    ".stu.ctu.edu.tw": ["建國科技大學", "Chienkuo Technology University"],
    ".cufa.edu.tw": ["崇右影藝科技大學", "CHUNGYU UNIVERSITY OF FILM AND ARTS"],
    ".stu.cute.edu.tw": ["中國科技大學", "China University of Technology"],
    ".cute.edu.tw": ["中國科技大學", "China University of Technology"],
    ".cycu.edu.tw": ["Chung Yuan Christian University"],
    ".cyut.edu.tw": ["Chao Yang University of Science and Technology"],
    ".dila.edu.tw": ["法鼓文理學院", "Dharma Drum Institute of Liberal Arts"],
    ".dyu.edu.tw": ["Da-Yeh University"],
    ".fcu.edu.tw": ["Feng Chia University"],
    ".mail.fgu.edu.tw": ["佛光大學", "Fo Guang University"],
    ".fju.edu.tw": ["Fu Jen Catholic University"],
    ".live.fy.edu.tw": ["輔英科技大學", "Fooyin University"],
    ".stu.hgsh.hc.edu.tw": ["国立新竹女子高级中学", "Hsinchu Girls Senior High School"],
    ".hcu.edu.tw": ["Hsuan Chuang University"],
    ".mail.hdut.edu.tw": ["宏國德霖科技大學", "Hungkuo Delin University of Technology"],
    ".student.hdut.edu.tw": ["宏國德霖科技大學", "Hungkuo Delin University of Technology"],
    ".hfu.edu.tw": ["Huafan University"],
    ".hk.edu.tw": ["弘光科技大學", "HungKuang University", "http://www.hk.edu.tw"],
    ".hust.edu.tw": ["修平科技大學", "Hsiuping University of Science and Technology"],
    ".ms.hwai.edu.tw": ["中華醫事科技大學", "Chung Hwa University of Medical Technology"],
    ".go.hwh.edu.tw": ["華夏科技大學", "Hwa Hsia University of Technology"],
    ".isu.edu.tw": ["I-Shou University"],
    ".just.edu.tw": ["景文科技大學", "JinWen University of Science & Technology"],
    ".kh.edu.tw": ["高雄市教育局", "Education Bureau, Kaohsiung City Government", ".group"],
    ".fssh.khc.edu.tw": ["國立鳳山高級中學", "National Feng-Shan Senior High School"],
    ".gm.kl.edu.tw": ["基隆市立銘傳國中", "Keelung Municipal Ming Chwan Junior High School"],
    ".kmu.edu.tw": ["高雄醫學大學", "Kaohsiung Medical University"],
    ".knu.edu.tw": ["開南大學", "Kainan University", "https://www.knu.edu.tw/"],
    ".ksu.edu.tw": ["Kun Shan University"],
    ".kuas.edu.tw": ["National Kaohsiung University of Applied Sciences"],
    ".mail.kyu.edu.tw": ["高苑科技大學", "Kao Yuan University"],
    ".stumail.kyu.edu.tw": ["高苑科技大學", "Kao Yuan University"],
    ".kyu.edu.tw": ["高苑科技大學", "Kao Yuan University"],
    ".lhu.edu.tw": ["LungHwa University of Science and Technology"],
    ".mail.lit.edu.tw": ["黎明技術學院", "lee ming institute of technology"],
    ".ltugmail.ltu.edu.tw": ["嶺東科技大學", "Ling Tung University"],
    ".stumail.ltu.edu.tw": ["嶺東科技大學", "Ling Tung University"],
    ".teamail.ltu.edu.tw": ["嶺東科技大學", "Ling Tung University"],
    ".mcu.edu.tw": ["Ming Chuan University"],
    ".mail.mcut.edu.tw": ["明志科技大學", "MING CHI UNIVERSITY OF TECHNOLOGY"],
    ".mail2.mcut.edu.tw": ["明志科技大學", "MING CHI UNIVERSITY OF TECHNOLOGY"],
    ".o365.mcut.edu.tw": ["明志科技大學", "MING CHI UNIVERSITY OF TECHNOLOGY"],
    ".go.meiho.edu.tw": ["美和科技大學", "MeiHo University"],
    ".ms.mingdao.edu.tw": ["明道高級中學", "Mingdao High School"],
    ".std.must.edu.tw": [
        "明新科技大學",
        "MUST(Minghsin University of Science and Technology)",
    ],
    ".nccu.edu.tw": ["National Chengchi University"],
    ".nchu.edu.tw": ["National Chung Hsing University, Taichung"],
    ".ncku.edu.tw": ["National Cheng Kung University"],
    ".ncnu.edu.tw": ["National Chi Nan University"],
    ".nctu.edu.tw": ["National Chiao Tung University"],
    ".ncu.edu.tw": ["National Central University"],
    ".ncue.edu.tw": ["National Changhua University of Education"],
    ".ncut.edu.tw": ["國立勤益科技大學", "National Chin-Yi University of Technology"],
    ".ncyu.edu.tw": ["National Chiayi University"],
    ".ndhu.edu.tw": ["National Dong Hwa University"],
    ".ndu.edu.tw": [
        "國防大學理工學院",
        "National Defense University Chung Cheng Institute of Technology",
    ],
    ".nfu.edu.tw": ["National Formosa University"],
    ".nhu.edu.tw": ["Nanhua University"],
    ".niu.edu.tw": ["National Ilan University"],
    ".nknu.edu.tw": ["National Kaohsiung Normal University"],
    ".nkust.edu.tw": [
        "國立高雄科技大學",
        "National Kaohsiung University of Science and Technology",
    ],
    ".nou.edu.tw": ["National Open University"],
    ".nptu.edu.tw": ["National Pingtung University"],
    ".ems.npu.edu.tw": ["國立澎湖科技大學", "National Penghu University"],
    ".gms.npu.edu.tw": [
        "國立澎湖科技大學",
        "National Penghu University of Science and Technology",
    ],
    ".npust.edu.tw": ["National Pingtung University of Science and Technology"],
    ".nqu.edu.tw": ["國立金門大學", "National Quemoy University"],
    ".nsysu.edu.tw": ["National Sun Yat-Sen University"],
    ".gm.ntcu.edu.tw": ["National Taichung University of Education"],
    ".ntcu.edu.tw": ["National Taichung University of Education"],
    ".nthu.edu.tw": ["National Tsinghua University"],
    ".ntnu.edu.tw": ["National Taiwan Normal University"],
    ".ntou.edu.tw": ["National Taiwan Ocean University"],
    ".apps.ntpc.edu.tw": ["五華國小", "wu hua elementary school", "apps.ntpc.edu.tw"],
    ".mail2.chshs.ntpc.edu.tw": [
        "新北市立中和高級中學",
        "New Taipei Municipal Zhonghe Senior High School",
    ],
    ".jdjh.ntpc.edu.tw": ["正德國中", "ZhengDe Junior high school"],
    ".ms.tcjh.ntpc.edu.tw": [
        "新北市立土城國民中學",
        "New Taipei Municipal Tucheng Junior High School",
    ],
    ".ntpu.edu.tw": ["National Taipei University"],
    ".gm.nttu.edu.tw": ["National Taitung University"],
    ".ms104.nttu.edu.tw": ["National Taitung University"],
    ".ms109.nttu.edu.tw": ["國立台東大學", "National Taitung University"],
    ".ntu.edu.tw": ["National Taiwan University"],
    ".ntub.edu.tw": ["國立臺北商業大學", "National Taipei University of Business"],
    ".ntue.edu.tw": ["國立台北教育大學", "national taipei university of education"],
    ".ntunhs.edu.tw": ["National Taipei University of Nursing and Health Sciences"],
    ".ntupes.edu.tw": ["國立臺灣體育運動大學", "National Taiwan University of Sport"],
    ".ntus.edu.tw": ["國立臺灣體育運動大學", "National Taiwan University of Sport"],
    ".ntust.edu.tw": ["National Taiwan University of Science and Technology"],
    ".ntut.edu.tw": ["National Taipei University of Technology"],
    ".nuk.edu.tw": ["National University of Kaohsiung"],
    ".nutc.edu.tw": [
        "國立臺中科技大學",
        "National Taichung University of Science and Technology",
    ],
    ".gm2.nutn.edu.tw": ["國立臺南大學", "National University of Tainan"],
    ".ps.nutn.edu.tw": [
        "國立臺南大學附設實驗國民小學",
        "National University of Tainan Affiliated Primary School",
    ],
    ".stumail.nutn.edu.tw": ["國立臺南大學", "National University of Tainan"],
    ".gm.nuu.edu.tw": ["國立聯合大學", "National United University"],
    ".nuu.edu.tw": ["國立聯合大學", "National United University"],
    ".nycu.edu.tw": ["National Yang Ming Chiao Tung University", "國立陽明交通大學"],
    ".ocu.edu.tw": ["僑光科技大學", "Oversea Chinese University"],
    ".mail.oit.edu.tw": ["亞東技術學院", "Oriental Institute of Technology"],
    ".ouk.edu.tw": ["Kaohsuing Open University"],
    ".pccu.edu.tw": ["Chinese Culture University"],
    ".mksh.phc.edu.tw": ["National Magong High School"],
    ".pu.edu.tw": ["Providence University"],
    ".school.saihs.edu.tw": [
        "臺北市立松山高級工農職業學校",
        "Songshan High School of Agriculture and Industry",
    ],
    ".scu.edu.tw": ["Soochow University"],
    ".shu.edu.tw": ["Shih Hsin University"],
    ".iis.sinica.edu.tw": [
        "中央研究院資訊科學研究所",
        "Institute of Information Science, Academia Sinica",
    ],
    ".stud.sju.edu.tw": ["聖約翰科技大學", "St. John's University"],
    ".stu.edu.tw": ["SHU-TE University"],
    ".stust.edu.tw": ["南台科技大學", "Southern Taiwan University of Science and Technology"],
    ".stut.edu.tw": ["Southern Taiwan University of Technology"],
    ".student.tajen.edu.tw": ["Tajen University"],
    ".cc.takming.edu.tw": ["德明財經科技大學", "Takming University of Science and Technology"],
    ".gs.takming.edu.tw": ["德明財經科技大學", "takming university of science and technology"],
    ".tas.edu.tw": ["Taipei American School"],
    ".ddjhs.tc.edu.tw": ["臺中市立大道國民中學", "Taichung Municipal Da-Dau Junior High School"],
    ".ms1.fhbes.tc.edu.tw": [
        "台中市私立明道普霖斯頓雙語小學",
        "Future-Heir Bilingual Elementary School",
    ],
    ".mdhs.tc.edu.tw": ["明德中學", "Ming-der senior high school"],
    ".st.tc.edu.tw": [
        "臺中市立光復國民中小學",
        "Taichung Municipal Kuang-Fu Junior high and Elementary School",
    ],
    ".tcfsh.tc.edu.tw": [
        "臺中市立臺中第一高級中等學校",
        "Taichung Municipal Taichung First Senior High School",
    ],
    ".tcivs.tc.edu.tw": [
        "臺中市立臺中工業高級中等學校",
        "Taichung Municipal Taichung Industrial High School",
    ],
    ".mail.tcvs.tc.edu.tw": [
        "臺中市立大甲工業高級中等學校",
        "Taichung Municipal Dajia Industrial Senior High School",
    ],
    ".gm.youth.tc.edu.tw": ["臺中市青年高級中學", "Youth Senior High School"],
    ".gms.tcu.edu.tw": ["Tzu Chi University"],
    ".tcu.edu.tw": ["Tzu Chi College of Medicine and Humanities"],
    ".ems.tcust.edu.tw": ["慈濟科技大學", "Tzu Chi University of Science and Technology"],
    ".thu.edu.tw": ["Tunghai University"],
    ".tku.edu.tw": ["Tamkang University"],
    ".tmu.edu.tw": ["臺北醫學大學", "TAIPEI MEDICAL UNIVERSITY"],
    ".csjhs.tn.edu.tw": ["臺南市立中山國民中學", "Jhongshan Junior High School"],
    ".nnkieh.tn.edu.tw": [
        "國立南科國際實驗高級中學",
        "National Nanke International Experimental High School",
    ],
    ".gm.ptivs.tn.edu.tw": ["國立台南高級工業職業學校", "National Tainan Industrial High School"],
    ".tnfsh.tn.edu.tw": ["Tainan First Senior High School"],
    ".stu.tnssh.tn.edu.tw": ["國立台南第二高級中學", "National Tainan Second Senior High School"],
    ".tnnua.edu.tw": ["Tainan National University of the Arts"],
    ".mail2u.tnu.edu.tw": ["東南科技大學", "TUNGNAN UNIVERSITY"],
    ".tnu.edu.tw": ["東南科技大學", "Tungnan University"],
    ".gmcc.tnua.edu.tw": ["Taipei Nation University of Arts"],
    ".gl.ck.tp.edu.tw": ["臺北市立建國高級中學", "Taipei Municipal Jianguo High School"],
    ".gafe.cksh.tp.edu.tw": ["臺北市立成功高級中學", "Taipei Municipal Chenggong High School"],
    ".st.fhjh.tp.edu.tw": ["臺北市私立復興實驗高級中學", "Taipei Fuhsing Private School"],
    ".ms2.hssh.tp.edu.tw": ["台北市立西松高級中學", "Taipei Municipal XiSong Senior High School"],
    ".mail.nihs.tp.edu.tw": ["Taipei Munucipal Nei-Hu Vocational High School"],
    ".tp.edu.tw": ["臺北市教育局"],
    ".im.tpcu.edu.tw": ["臺北城市科技大學", "Taipei City University of Science & Technology"],
    ".tpcu.edu.tw": ["台北城市科技大學", "Taipei City University of Science and Technology"],
    ".tpec.edu.tw": ["Taipei Physical Education College"],
    ".ttu.edu.tw": ["TaTung University "],
    ".tut.edu.tw": ["Tainan University of Technology"],
    ".twu.edu.tw": ["TransWorld University"],
    ".gm2.fxsh.tyc.edu.tw": ["振聲高中"],
    ".phsh.tyc.edu.tw": ["\ufeffPaul Hsu Senior High School"],
    ".uch.edu.tw": ["健行科技大學", "Chien Hsin University of Science and Technology"],
    ".g2.usc.edu.tw": ["實踐大學", "Shih Chien University"],
    ".utaipei.edu.tw": ["\ufeffUniversity of Taipei"],
    ".vnu.edu.tw": ["Vanung University"],
    ".st95.wzu.edu.tw": ["文藻外語大學", "Wenzao Ursuline University of Languages"],
    ".ydu.edu.tw": ["育達科技大學", "Yu Da University of Science and Technology  "],
    ".pjes.ylc.edu.tw": ["Pijiao National Primary School"],
    ".ym.edu.tw": ["National Yang Ming Medical College"],
    ".yuntech.edu.tw": ["National Yunlin University of Science and Technology"],
    ".yzu.edu.tw": ["Yuan Ze University"],
    ".ctschool.org.tw": ["臺北市運算思維實驗教育機構", "Taipei Computational Thinking School"],
    ".cycu.org.tw": ["Chung Yuan Christian University"],
    ".ntut.org.tw": ["NTUT", "National Taipei University of Technology"],
    ".yuntech.org.tw": [
        "國立雲林科技大學",
        "National Yunlin University of Science and Technology",
    ],
    ".almaktoum.ac.tz": ["Al-Maktoum College of Engineering and Technology"],
    ".dit.ac.tz": ["Dares Salaam Institute of Technology"],
    ".eastc.ac.tz": ["Eastern Africa Statistical Training Centre"],
    ".hkmu.ac.tz": ["Hubert Kairuki Memorial University"],
    ".iaa.ac.tz": ["Institute of Accountancy Arusha"],
    ".ilboru.ac.tz": ["Ilboru High School"],
    ".kcmc.ac.tz": ["Kilimanjaro Christian Medical College"],
    ".mmu.ac.tz": ["Mount Meru University"],
    ".mnma.ac.tz": ["Mwalimu Nyerere Memorial Academy"],
    ".muccobs.ac.tz": ["Moshi University College of Cooperative and Business Studies"],
    ".muchs.ac.tz": ["Muhimbili University of Health and Allied Sciences (MUHAS)"],
    ".mustnet.ac.tz": ["Mbeya University of Science and Technology"],
    ".mustudent.ac.tz": ["Mzumbe University (Chuo Kikuu Mzumbe)"],
    ".mzumbe.ac.tz": ["Mzumbe University (Chuo Kikuu Mzumbe)"],
    ".nm-aist.ac.tz": [
        "Nelson Mandela African Institution of Science and Technology",
        "Nelson Mandela African Institution of Science and Technology",
    ],
    ".openuniversity.ac.tz": ["Open University of Tanzania"],
    ".saut.ac.tz": ["St. Augustine University of Tanzania"],
    ".suanet.ac.tz": ["Sokoine University of Agriculture"],
    ".tumaini.ac.tz": ["Tumaini University - Iringa University College"],
    ".udom.ac.tz": ["University of Dodoma"],
    ".udsm.ac.tz": ["University of Dar Es Salaam"],
    ".uoi.ac.tz": ["University of Iringa", "University of Iringa"],
    ".phymly.ck.ua": ['Fyzyko-Matematycheskyy Lytsey "PHYMLY"', "PHYMLY"],
    ".stu.cn.ua": ["Chernihiv National University of Technology"],
    ".178.com.ua": ["Гімназія №178 міста Києва", "Gymnasium №178 of Kyiv"],
    ".knutd.com.ua": [
        "Київський національний університет технологій та дизайну",
        "Kyiv National University of Technologies and Design",
    ],
    ".lcdut.com.ua": [
        'Відокремлений структурний підрозділ Фаховий коледж телекомунікації та комп\'ютерних технологій Національного університету "Львівська політехніка"'
    ],
    ".lpml.com.ua": [
        "Львівський фізико-математичний ліцей",
        "Lviv Physics and Matematics lyceum",
    ],
    ".lutsk-ntu.com.ua": [
        "Луцький Національний Технічний Університет",
        "Lutsk National Technical University",
    ],
    ".sclnau.com.ua": [
        "Стрийський коледж Львівського національного аграрного університету",
        "Stryi College of Lviv National Agrarian University",
    ],
    ".sevntu.com.ua": ["Sevastopol National Technical University"],
    ".tnu.crimea.ua": ["Taurida National V.I.Vernadsky University"],
    ".chnu.cv.ua": ["Chernivci National University"],
    ".chtei-knteu.cv.ua": [
        "Чернівецький торговельно-економічний інститут",
        "Chernivtsi Institute of Trade and Economics",
    ],
    ".lyceum1.cv.ua": ["Чернівецький ліцей №1", "Chernivtsi Lyceum No 1"],
    ".dgma.donetsk.ua": [
        "Донбаська державна машинобудівна академія",
        "Donbas State Machine-Building Academy",
    ],
    ".dlit.dp.ua": [
        "Dnipro Lyceum of Information Technologies at DNU (LIT)",
        "Дніпровський ліцей інформаційних технологій при ДНУ (ЛІТ)",
    ],
    ".dnu.dp.ua": ["Dnepropetrovsk National University"],
    ".ef.dnulive.dp.ua": [
        "Дніпропетровський національний університет імені Олеся Гончара ",
        "Dnipropetrovsk national university Oles Honchar",
    ],
    ".ffeks.dnulive.dp.ua": [
        "Дніпропетровський національний університет імені Олеся Гончара ",
        "Dnipropetrovsk national university Oles Honchar",
    ],
    ".fpm.dnulive.dp.ua": [
        "Дніпропетровський національний університет імені Олеся Гончара ",
        "Dnipropetrovsk national university Oles Honchar",
    ],
    ".ftf.dnulive.dp.ua": [
        "Дніпропетровський національний університет імені Олеся Гончара ",
        "Dnipropetrovsk national university Oles Honchar",
    ],
    ".dsma.dp.ua": [
        'ДЗ "Дніпропетровська медична академія МОЗ України"',
        'State Establishment "Dnipropetrovsk Medical Academy of Health Ministry of Ukraine" (SE "DMA")',
    ],
    ".dstu.dp.ua": ["Dneprodzerzhinsk State Technical University"],
    ".umsf.dp.ua": [
        "Університет митної справи та фінансів",
        "University of Customs and Finance",
    ],
    ".bsmu.edu.ua": ["Bukovinian State Medical University"],
    ".cdu.edu.ua": [
        "The Bohdan Khmelnytsky National University of Cherkasy",
        "Черкаський національний університет імені Богдана Хмельницького",
    ],
    ".chdtu.edu.ua": [
        "Cherkasy State Technological University",
        "Черкаський Державний Технологічний Університет",
    ],
    ".chmnu.edu.ua": [
        "Чорноморський національний університет імені Петра Могили",
        "Petro Mohyla Black Sea National University",
    ],
    ".chnu.edu.ua": ["Chernivtsi National University"],
    ".cuspu.edu.ua": [
        "Центральноукраїнський державний педагогічний університет імені Володимира Винниченка",
        "Volodymyr Vynnychenko Central Ukrainian State Pedagogical University",
    ],
    ".diit.edu.ua": ["Dnepropetrovsk National University of Railway Transport"],
    ".ef.dnu.edu.ua": [
        "Дніпровський національний університет ім. Олеся Гончара",
        "Oles Honchar Dnipro National University",
    ],
    ".ffeks.dnu.edu.ua": [
        "Дніпровський національний університет імені Олеся Гончара",
        "Dnipro National University ",
    ],
    ".fpm.dnu.edu.ua": [
        "Дніпровський національний університет імені Олеся Гончара",
        "Dnipro National University ",
    ],
    ".ftf.dnu.edu.ua": [
        " Дніпровський національний університет імені Олеся Гончара",
        "Oles Honchar Dnipro National University",
    ],
    ".dnu.edu.ua": [
        "Дніпровський національний університет імені Олеся Гончара",
        "Dnipro National University ",
    ],
    ".donntu.edu.ua": ["Donetsk National Technical University"],
    ".donnu.edu.ua": ["Donetsk National University"],
    ".inbox.dsum.edu.ua": [
        "Donetsk State University of Management",
        "Донецкий Государственный Университет Управления",
    ],
    ".duan.edu.ua": [
        "Университет имени Альфреда Нобеля (Днепр,Украина)",
        "Alfred Nobel University",
    ],
    ".students.dut.edu.ua": [
        "Державний Університет Телекомунікацій ",
        "State University of Telecommunication",
    ],
    ".dut.edu.ua": [
        "Державний університет телекомунікацій",
        "State University of Telecommunications",
    ],
    ".hneu.edu.ua": ["Kharkiv National University of Economics"],
    ".ifnmu.edu.ua": [
        "Івано-Франківський національний медичний університет",
        "Ivano-Frankivsk National Medical University",
    ],
    ".istu.edu.ua": [
        "Міжнародний науково-технічний університет академіка Юрія Бугая",
        "Academician Yuriy Bugay International Scientific and Technical University",
    ],
    ".kart.edu.ua": [
        "The Ukrainian State University of Railway Transport",
        "The Ukrainian State University of Railway Transport",
    ],
    ".kau.edu.ua": [
        "Київський академічний університет (КАУ)",
        "KIYV ACADEMIC UNIVERSITY",
    ],
    ".kdpu.edu.ua": ["State Pedagogical University in Kryvyi Rih"],
    ".kdu.edu.ua": ["Kremenchuk Mykhailo Ostrohradskyi National University"],
    ".student.khai.edu.ua": [
        'Національний аерокосмічний університет ім. М.Є. Жуковського "Харківський авіаційний інститут"',
        'National Aerospace University "Kharkiv Aviation Institute", NAU "KhAI"',
    ],
    ".khmnu.edu.ua": [
        "Хмельницький національний університет",
        "Khmelnytsky National University",
    ],
    ".khpi.edu.ua": [
        "Харьковский политехнический институт",
        "Kharkiv Polytechnic Institute",
    ],
    ".kmu.edu.ua": ["Private higher educational establishment Kyiv Medical University"],
    ".kname.edu.ua": [
        "Харківський національний університет міського господарства імені О. М. Бекетова",
        "O.M. Beketov National University of Urban Economy in Kharkiv",
    ],
    ".kneu.edu.ua": [
        "Київський національний економічний університет імені Вадима Гетьмана",
        "Kyiv National Economic University named after Vadym Hetman",
    ],
    ".knlu.edu.ua": ["Kyiv National Linguistic University"],
    ".knmu.edu.ua": [
        "Kharkiv National Medical University",
        "Kharkiv National Medical University",
    ],
    ".knu.edu.ua": ["Kryvyi Rih National University"],
    ".knuba.edu.ua": ["Kiev National University of Construction and Architecture"],
    ".knutd.edu.ua": ["Kyiv National University of Technologies and Design"],
    ".knute.edu.ua": [
        "KYIV NATIONAL UNIVERSITY OF TRADE AND ECONOMICS",
        "Web-site: https://knute.edu.ua//",
        "old domain: knteu.kiev.ua",
    ],
    ".kpnu.edu.ua": [
        "Кам'янець-Подільський національний університет імені Івана Огієнка",
        "Kamianets-Podіlskyi National Ivan Ohiienko University",
    ],
    ".krok.edu.ua": ["KROK Economics and Law University"],
    ".krpd.edu.ua": [
        "Державний Університет Економіки і Технологій",
        "State University of Economics and Technology",
    ],
    ".ksu.edu.ua": ["Kiev Slavonic University"],
    ".kubg.edu.ua": [
        "Київський Університет імені Бориса Грінченка",
        "Borys Hrinchenko University of Kyiv",
    ],
    ".ldubgd.edu.ua": ["Lviv State University of Life Safety"],
    ".lnau.edu.ua": [
        "Львівський національний аграрний університет",
        "Lviv National Agrarian University",
    ],
    ".lntu.edu.ua": [
        "ЛУЦЬКИЙ НАЦІОНАЛЬНИЙ ТЕХНІЧНИЙ УНІВЕРСИТЕТ",
        "Lutsk National Technical University (Lutsk NTU)",
    ],
    ".lnu.edu.ua": [
        "Львівський національний університет імені Івана Франка",
        "Ivan Franko National University of Lviv",
    ],
    ".lp.edu.ua": ["Lviv Polytechnic National University"],
    ".luguniv.edu.ua": [
        "Луганський національний університет імені Тараса Шевченка",
        "Luhansk Taras Shevchenko National University",
    ],
    ".mkkm.edu.ua": ["МИКОЛАЇВСЬКИЙ ФАХОВИЙ КОЛЕДЖ КУЛЬТУРИ І МИСТЕЦТВ"],
    ".mnau.edu.ua": [
        "Николаевский национальный аграрный университет",
        "Mykolayiv National Agrarian University",
    ],
    ".nau.edu.ua": ["National Aviation Univesity"],
    ".nltu.edu.ua": [
        "Український національний лісотехнічний Університет",
        "UKRAINIAN NATIONAL FORESTRY UNIVERSITY",
    ],
    ".nlu.edu.ua": [
        "Національний юридичний університет імені Ярослава Мудрого",
        "Yaroslav Mudryi National Law University",
    ],
    ".nmetau.edu.ua": ["National Metallurgical Academy of Ukraine"],
    ".npu.edu.ua": ["National Pedagogical University M. Dragomanov "],
    ".it.nubip.edu.ua": [
        "Національний університет біоресурсів і природокористування України",
        "National University of Life and Environmental Sciences of Ukraine",
    ],
    ".nubip.edu.ua": [
        "Національний університет біоресурсів і природокористування України",
        "National University of Life and Environmental Sciences of Ukraine",
    ],
    ".nuft.edu.ua": [None],
    ".nung.edu.ua": [
        "Івано-Франківський національний технічний університет нафти і газу",
        "Ivano-Frankivsk National Technical University of Oil and Gas",
    ],
    ".nuos.edu.ua": [
        "\ufeffНаціональний Університет кораблебудування імені адмірала Макарова"
    ],
    ".nuph.edu.ua": [
        "Національний фармацевтичний університет",
        "National University of Pharmacy",
    ],
    ".nupp.edu.ua": [
        "Національний університет «Полтавська політехніка імені Юрія Кондратюка»",
        "The National University «Yuri Kondratyuk Poltava Polytechnic»",
    ],
    ".nuwm.edu.ua": [
        "Національний університет водного господарства та природокористування",
        "National University of Water Management and Environmental Sciences",
    ],
    ".oa.edu.ua": [
        'National University "Ostroh Academy"',
        'Національний університет "Острозька академія"',
    ],
    ".onaft.edu.ua": [
        "Одесская национальная академия пищевых технологий",
        "Odessa National Academy of Food Technologies",
    ],
    ".onat.edu.ua": [
        "ODESSA NATIONAL ACADEMY OF TELECOMMUNICATIONS named after O.S.POPOV",
        "ОДЕССКАЯ НАЦИОНАЛЬНАЯ АКАДЕМИЯ СВЯЗИ им. А.С.ПОПОВА",
    ],
    ".onmedu.edu.ua": ["Odessa National Medical University"],
    ".onu.edu.ua": ["Odessa National I.I. Mecnikov University"],
    ".onua.edu.ua": [
        'Національний університет "Одеська юридична академія"',
        "National University Odesa Law Academy",
    ],
    ".stud.op.edu.ua": ["Одесская Политехника", "Odessа Polytechnic State University"],
    ".pdpu.edu.ua": [
        "Південноукраїнський національний педагогічний університет імені К. Д. Ушинського"
    ],
    ".pntu.edu.ua": ["Poltava National Technical University"],
    ".pnu.edu.ua": [
        "Прикарпатський національний університет імені Василя Стефаника",
        "Vasyl Stefanyk Precarpathian National University",
    ],
    ".puet.edu.ua": ["Poltava University of Economics and Trade"],
    ".snu.edu.ua": ["East Ukrainian National University"],
    ".ssu.edu.ua": ["Сумський державний університет", "Sumy State University"],
    ".sumdu.edu.ua": ["Sumy State University"],
    ".tane.edu.ua": ["Ternopil Academy of National Economy"],
    ".tdmu.edu.ua": [
        "ТЕРНОПІЛЬСЬКИЙ НАЦІОНАЛЬНИЙ МЕДИЧНИЙ УНІВЕРСИТЕТ",
        "TERNOPIL NATIONAL MEDICAL UNIVERSITY",
    ],
    ".fizmat.tnpu.edu.ua": [
        "Фізико-математичний факультет Тернопільського педагогічного університету"
    ],
    ".tntu.edu.ua": [
        "Тернопільський національний технічний університет імені Івана Пулюя",
        "Ternopil Ivan Puluj National Technical University",
        "Web-site: https://tntu.edu.ua/",
    ],
    ".tnu.edu.ua": ["Таврический национальный университет имени В. И. Вернадского"],
    ".tsatu.edu.ua": [
        "Таврійський державний агротехнологічний університет",
        "Tavria State Agrotechnological University",
    ],
    ".ucu.edu.ua": ["Ukrainian Catholic University", "UCU"],
    ".udhtu.edu.ua": [
        "Украинский государственный Химико-Технологический университет",
        " Ukrainian State Chemical-Technological University",
    ],
    ".udpu.edu.ua": [
        "УМАНСЬКИЙ ДЕРЖАВНИЙ ПЕДАГОГІЧНИЙ УНІВЕРСИТЕТ імені Павла Тичини",
        "PAVLO TYCHYNA UMAN STATE Pedagogical University",
    ],
    ".ugi.edu.ua": [
        "Український Гуманітарний Інститут",
        "Ukrainian Institute of Arts and Sciences",
    ],
    ".uipa.edu.ua": ["Ukrainian Engineering Pedagogics Academy "],
    ".ukd.edu.ua": [None],
    ".ukma.edu.ua": [
        "Національний університет «Києво-Могилянська академія»",
        "National University of Kyiv-Mohyla Academy",
    ],
    ".univd.edu.ua": ["National University of Internal Affairs"],
    ".usmtu.edu.ua": ["National University of Shipbuilding"],
    ".uzhnu.edu.ua": ["Uzhhorod National University"],
    ".vnmu.edu.ua": ["Vinnitsa National Pirogov Medical University", "VNMU"],
    ".vntu.edu.ua": ["Vinnytsia National Technical University"],
    ".vnu.edu.ua": [
        "Волинський національний університет імені Лесі Українки",
        "Lesya Ukrainka Volyn National University",
    ],
    ".wunu.edu.ua": [
        "Західноукраїнський національний університет",
        "West Ukrainian National University",
    ],
    ".zieit.edu.ua": ["Zaporizhzhya Institute of Economics and Information Technology"],
    ".zntu.edu.ua": ["Zaporizhzhe National Technical University"],
    ".znu.edu.ua": ["Zaporizhzhe National University"],
    ".stu.zsea.edu.ua": [
        "Запорожский национальный университет",
        "Zaporizhzhia National University",
    ],
    ".zsmu.edu.ua": [
        "Запорізький державний медичний університет",
        "Zaporizhzhia State Medical University",
    ],
    ".student.ztu.edu.ua": [
        'Державний університет "Житомирська політехніка"',
        "Zhytomyr Polytechnic State University",
    ],
    ".ztu.edu.ua": [
        'Державний університет "Житомирська політехніка"',
        "Zhytomyr Polytechnic State University",
    ],
    ".zu.edu.ua": [
        "Житомирський державний університет імені Івана Франка",
        "Zhytomyr Ivan Franko State University",
    ],
    ".comp-sc.if.ua": [
        "Прикарпатський національний університет імені Василя Стефаника"
    ],
    ".ifdtung.if.ua": ["Ivano-Frankivsk National University of Oli and Gas"],
    ".pu.if.ua": ["Precarpathian University"],
    ".school16.if.ua": ["Ivano-Frankovsk secondary school No 16"],
    ".school3.if.ua": ["School 3 of Ivano-Frankovsk, Ukraine"],
    ".e-u.in.ua": [
        'Приватний вищий навчальний заклад "Європейський Університет"',
        'Privatniy vischiy navchalniy zaklad "Evropeyskiy Universitet"',
    ],
    ".kpi.in.ua": ["National Technical University (Kiev Politechnical Institute)"],
    ".mschool5.in.ua": ["\ufeffСпециализированная школа №5 Мариуполь"],
    ".karazin.ua": ["V. N. Karazin Kharkov National University"],
    ".khadi.kharkov.ua": ["Kharkiv State Transport Technical University"],
    ".kpi.kharkov.ua": [
        "National Technical University (Kharkiv Polytechnical Institute)"
    ],
    ".ksmu.kharkov.ua": ["Kharkiv State Medical University"],
    ".kstuca.kharkov.ua": [
        "Kharkiv State Technical University of Construction and Architecture"
    ],
    ".kture.kharkov.ua": ["Kharkiv National University of Radio Electronics"],
    ".ukrfa.kharkov.ua": ["Ukrainian Academy of Pharmacy"],
    ".univer.kharkov.ua": ["Kharkiv National University"],
    ".university.kherson.ua": ["Kherson State University"],
    ".iao.kiev.ua": [
        'International Center "Institute of applied optics" NAS of Ukraine'
    ],
    ".kemk.kiev.ua": ["Kiev Electromechanical College"],
    ".kmrf.kiev.ua": [
        "Коледж морського і річкового флоту Державного університету інфраструктури та технологій",
        "College of Marine and River Fleet of State University of Infrastructure and Technologies",
    ],
    ".kneu.kiev.ua": ["Kiev National Economic University"],
    ".knteu.kiev.ua": ["Kyiv National University of Trade and Economics"],
    ".naiau.kiev.ua": [
        "Національна академія внутрішніх справ",
        "National academy of internal affairs",
    ],
    ".nauu.kiev.ua": ["National Agricultural University"],
    ".ortlyceum.kiev.ua": ["Educational Complex 141 ORT"],
    ".sch3.kiev.ua": ["Спеціалізована школа №3", "Specialized school #3"],
    ".socosvita.kiev.ua": [
        "Academy of Labour, Social Relations and Tourism",
        "Academy of Labour, Social Relations and Tourism",
    ],
    ".tl-kpi.kiev.ua": ["Технічний ліцей НТУУ “КПІ”"],
    ".ukma.kiev.ua": ["National University of Kiev-Mohyla Academy"],
    ".unicyb.kiev.ua": [
        "Cybernetics Faculty, National Taras Shevchenko University of Kiev"
    ],
    ".univ.kiev.ua": ["National Taras Shevchenko University of Kiev"],
    ".usuft.kiev.ua": ["National University of Food Technologies"],
    ".khnu.km.ua": [
        "Khmelnitsky National University",
        "Хмельницький Національний Університет",
    ],
    ".kneu.ua": ["Kyiv National Economic University named after Vadym Hetman (KNEU)"],
    ".knu.ua": ["Taras Shevchenko National University of Kyiv"],
    ".kpi.ua": ["National Technical University (Kiev Politechnical Institute)"],
    ".kntu.kr.ua": ["Central Ukrainian National Technical University"],
    ".kspu.kr.ua": ["Kirovograd State Pedagogical University"],
    ".ptu16.kr.ua": [
        "Професійно-технічне училище №16 м. Мала Виска",
        "Vocational school №16 Mala Vyska",
    ],
    ".ksu.ks.ua": ["Kherson State University", "Херсонський державний університет"],
    ".university.ks.ua": ["Kherson State University"],
    ".lnau.lg.ua": ["Lugansk National Agrarian University"],
    ".lpnu.ua": ["Lviv Polytechnic National University"],
    ".gymnasia21.lutsk.ua": ["Lutsk Gymnasium #  21 after Mikhail Kravchuk "],
    ".forest.lviv.ua": ["Ukrainian National Forestry University"],
    ".lute.lviv.ua": ["Lviv University of Trade and Economics"],
    ".meduniv.lviv.ua": ["Lviv Medical University", "Lviv National Medical Univeristy"],
    ".nltu.lviv.ua": ["Ukrainian National Forestry University"],
    ".school3.mk.ua": ["\ufeffМиколаївська загальноосвітня школа І-ІІІ ступенів №3"],
    ".kkz.net.ua": [
        "Kiev collage of communications",
        "KKC",
        "Київський колледж зв'язку",
        "ККЗ",
        "Киевский колледж связи",
        "ККС",
    ],
    ".kntu.net.ua": ["Kherson National Technical University"],
    ".univ.net.ua": ["Taras Shevchenko National University of Kyiv"],
    ".nmu.ua": ["Bogomolets National Medical University"],
    ".nure.ua": ["Kharkiv National University Radioelectronics, Ukraine"],
    ".ma.odessa.ua": ["Odessa National Maritime Academy"],
    ".onu.odessa.ua": ["Odessa National I.I. Mecnikov University"],
    ".osmu.odessa.ua": ["Odessa National Marine University"],
    ".rl.odessa.ua": ["Ришельевский лицей", "Richelieu Lyceum"],
    ".opu.ua": ["Odessa national polytechnic university"],
    ".intec.org.ua": ["International Economy Department PSACEA"],
    ".kse.org.ua": ["Kiev School Of Economics"],
    ".mdpu.org.ua": [
        "Мелітопольський державний педагогічний університет імені Богдана Хмельницького",
        "Bogdan Khmelnitsky Melitopol State Pedagogical University",
    ],
    ".nmu.org.ua": ["National Mining University"],
    ".ogasa.org.ua": ["Odessa State Academy of Civil Engeneering and Architecture"],
    ".ztkolegium.org.ua": ["Житомирський міський колегіум", "Zhytomyr City Collegium"],
    ".polytechnic.poltava.ua": [
        "PPC NTU 'KhPI'",
        "Poltava Polytechnic College by National Technical University 'Kharkiv Polytechnical Institute'",
    ],
    ".sh44.pp.ua": ["Secondary school 44, Kam'yanske"],
    ".regi.rovno.ua": [
        "International University of Economics and Humanities named after academician Stepan Demianchuk"
    ],
    ".elitar.rv.ua": ['"Elitar" High School'],
    ".sau.sumy.ua": ["Sumy National Agrarian University"],
    ".tk.te.ua": [
        "Technical college of Ternopil Ivan Puluj National Technical University"
    ],
    ".unit.ua": ["UNIT Factory"],
    ".univ.uzhgorod.ua": ["Uzhgorod National University"],
    ".vnmu.vn.ua": ["National Pirogov Memorial Medical University"],
    ".econom.zp.ua": ["Zaporizhzhya Institute of Economics and Information Technology"],
    ".zgia.zp.ua": ["Zaporizhzhya State Engineering Academy"],
    ".zhatk.zt.ua": ["Zhytomyr Agrotechnical College"],
    ".bugemauniv.ac.ug": ["Bugema University"],
    ".busitema.ac.ug": ["Busitema University"],
    ".students.cavendish.ac.ug": ["Cavendish Uniniversity Uganda"],
    ".ciu.ac.ug": ["Clarke International University"],
    ".gu.ac.ug": ["Gulu University"],
    ".iuiu.ac.ug": ["Islamic University in Uganda"],
    ".kab.ac.ug": ["Kabale University"],
    ".kiu.ac.ug": ["Kampala International University"],
    ".ku.ac.ug": ["Kampala University"],
    ".kyu.ac.ug": ["Kyambogo University"],
    ".mak.ac.ug": ["Makerere University"],
    ".mmu.ac.ug": ["Mountains of the Moon University"],
    ".mru.ac.ug": ["Mutesa 1 Royal University"],
    ".mubs.ac.ug": ["Makerere University Business School"],
    ".muni.ac.ug": ["Muni University"],
    ".must.ac.ug": ["Mbarara University of Science and Technology"],
    ".ndejjeuniversity.ac.ug": ["Ndejje University"],
    ".nkumbauniversity.ac.ug": ["Nkumba University"],
    ".ucu.ac.ug": ["Uganda Christian University"],
    ".umu.ac.ug": ["Uganda Martyr's University"],
    ".student.utamu.ac.ug": [
        "Uganda Technology and Management University",
        "Uganda Technology and Management University",
    ],
    ".abdn.ac.uk": ["University of Aberdeen"],
    ".aber.ac.uk": ["Prifysgol Aberystwyth University"],
    ".abertay.ac.uk": ["University of Abertay Dundee"],
    ".activatelearning.ac.uk": [
        "Activate Learning - Banbury and Bicester College, City of Oxford College & Reading College"
    ],
    ".ada.ac.uk": ["Ada. National College for Digital Skills"],
    ".anglia.ac.uk": ["Anglia Ruskin University"],
    ".arts.ac.uk": ["University of the Arts London"],
    ".aru.ac.uk": ["Anglia Ruskin University"],
    ".aston.ac.uk": ["Aston University"],
    ".ayrshire.ac.uk": ["Ayrshire College"],
    ".bangor.ac.uk": ["Prifysgol Bangor University"],
    ".bath.ac.uk": ["University of Bath"],
    ".bbk.ac.uk": ["Birkbeck College, University of London"],
    ".bcom.ac.uk": ["British College of Osteopathic Medicine"],
    ".bcu.ac.uk": ["Birmingham City University"],
    ".beds.ac.uk": ["University of Bedfordshire"],
    ".bham.ac.uk": ["University of Birmingham"],
    ".bmet.ac.uk": ["Birmingham Metropolitan College"],
    ".bournemouth.ac.uk": ["Bournemouth University"],
    ".brad.ac.uk": ["University of Bradford"],
    ".bris.ac.uk": ["University of Bristol"],
    ".bristol.ac.uk": ["University of Bristol"],
    ".brookes.ac.uk": ["Oxford Brookes University"],
    ".brooklands.ac.uk": ["Brooklands College"],
    ".brunel.ac.uk": ["Brunel University Uxbridge"],
    ".bton.ac.uk": ["University of Brighton"],
    ".buck.ac.uk": ["University of Buckingham"],
    ".bucks.ac.uk": ["Buckinghamshire New University"],
    ".burycollege.ac.uk": ["Bury College"],
    ".caledonian.ac.uk": ["Glasgow Caledonian University"],
    ".cam.ac.uk": ["University of Cambridge"],
    ".cambria.ac.uk": ["+ Coleg Cambria"],
    ".canterbury.ac.uk": ["Canterbury Christ Church University"],
    ".cardiff.ac.uk": ["Cardiff University"],
    ".cardiffmet.ac.uk": [
        "Cardiff Metropolitan University",
        "Prifysgol Metropolitan Caerdydd",
    ],
    ".chester.ac.uk": ["University of Chester"],
    ".city.ac.uk": ["City University"],
    ".student.cityofbristol.ac.uk": ["City of Bristol College"],
    ".coleggwent.ac.uk": ["Coleg Gwent"],
    ".collyers.ac.uk": ["The College of Richard Collyer"],
    ".confetti.ac.uk": ["Confetti Institute of Creative Technologies"],
    ".cornwall.ac.uk": ["Cornwall College"],
    ".courtauld.ac.uk": ["Courtauld Institute of Art, University of London"],
    ".coventry.ac.uk": ["Coventry University"],
    ".cranfield.ac.uk": ["Cranfield University"],
    ".derby.ac.uk": ["University of Derby"],
    ".dmu.ac.uk": ["De Montfort University Leicester"],
    ".dundee.ac.uk": ["University of Dundee"],
    ".dur.ac.uk": ["University of Durham"],
    ".sms.ed.ac.uk": ["University of Edinburgh"],
    ".ed.ac.uk": ["University of Edinburgh"],
    ".go.edgehill.ac.uk": ["Edge Hill University"],
    ".edgehill.ac.uk": ["Edge Hill University"],
    ".esc.ac.uk": ["East Surrey College"],
    ".escg.ac.uk": ["East Sussex College Group"],
    ".eselondon.ac.uk": ["European School of Economics"],
    ".essex.ac.uk": ["University of Essex"],
    ".ex.ac.uk": ["University of Exeter"],
    ".exeter.ac.uk": ["University of Exeter"],
    ".student.gbmc.ac.uk": [
        "Greater Brighton Metropolitan College (GB MET) for Students."
    ],
    ".gcal.ac.uk": ["Glasgow Caledonian University"],
    ".gcu.ac.uk": ["Glasgow Caledonian University"],
    ".student.gla.ac.uk": ["University of Glasgow"],
    ".gla.ac.uk": ["University of Glasgow"],
    ".glam.ac.uk": ["University of Glamorgan"],
    ".glasgowclyde.ac.uk": ["Glasgow Clyde College"],
    ".gllm.ac.uk": ["\ufeffGrŵp Llandrillo Menai"],
    ".glos.ac.uk": ["University of Gloucestershire"],
    ".gold.ac.uk": ["Goldsmiths College, University of London"],
    ".gre.ac.uk": ["University of Greenwich"],
    ".gsa.ac.uk": ["Glasgow School of Art"],
    ".herts.ac.uk": ["University of Hertfordshire"],
    ".heythrop.ac.uk": ["Heythrop College, University of London"],
    ".hope.ac.uk": ["Liverpool Hope University College"],
    ".howcollege.ac.uk": ["Heart Of Worcestershire College"],
    ".hud.ac.uk": ["University of Huddersfield"],
    ".hull.ac.uk": ["University of Hull"],
    ".hw.ac.uk": ["Heriot-Watt University"],
    ".ic.ac.uk": ["Imperial College London", "Imperial College School of Medicine"],
    ".imperial.ac.uk": ["Imperial College London"],
    ".ioe.ac.uk": ["Institute of Education, University of London"],
    ".kcl.ac.uk": ["King's College London, University of London"],
    ".kedst.ac.uk": ["King Edward VI College"],
    ".keele.ac.uk": ["Keele University"],
    ".kent.ac.uk": ["University of Kent"],
    ".kingston.ac.uk": ["Kingston University"],
    ".knowsleycollege.ac.uk": ["Knowsley College"],
    ".lamp.ac.uk": ["University of Wales, Lampeter"],
    ".lancs.ac.uk": ["University of Lancaster"],
    ".lboro.ac.uk": ["Loughborough University"],
    ".le.ac.uk": ["University of Leicester"],
    ".leeds.ac.uk": ["University of Leeds"],
    ".student.leedsbeckett.ac.uk": ["Leeds Beckett University"],
    ".lgu.ac.uk": ["London Guildhall University"],
    ".lincoln.ac.uk": ["University of Lincoln"],
    ".linst.ac.uk": [
        "Camberwell College of Arts",
        "Central Saint Martins College of Art &amp; Design",
        "Chelsea College of Art and Design",
    ],
    ".liv-coll.ac.uk": ["The City of Liverpool College"],
    ".liv.ac.uk": ["University of Liverpool"],
    ".liverpool.ac.uk": ["University of Liverpool"],
    ".livjm.ac.uk": ["Liverpool John Moores University"],
    ".ljmu.ac.uk": ["Liverpool John Moores University"],
    ".lmu.ac.uk": ["Leeds Metropolitan University"],
    ".lon.ac.uk": [
        "British Institute in Paris, University of London",
        "London Business School",
        "University of London",
    ],
    ".student.london.ac.uk": ["University of London"],
    ".londonmet.ac.uk": ["London Metropolitan University"],
    ".longroad.ac.uk": [],
    ".lsbu.ac.uk": ["London South Bank University"],
    ".lse.ac.uk": [
        "London School of Economics and Political Science, University of London"
    ],
    ".lshtm.ac.uk": [
        "London School of Hygiene &amp; Tropical Medicine, University of London"
    ],
    ".man.ac.uk": ["University of Manchester"],
    ".manchester.ac.uk": ["University of Manchester"],
    ".mdx.ac.uk": ["Middlesex University"],
    ".mmu.ac.uk": ["The Manchester Metropolitan University"],
    ".lms.mrc.ac.uk": [
        "MRC London institute of Medical Sciences (Imperial College London)"
    ],
    ".napier.ac.uk": ["Napier University"],
    ".ncl.ac.uk": [
        "Newcastle University, Medicine Malaysia ",
        "University of Newcastle-upon-Tyne",
        '"Newcastle Univeristy" ',
    ],
    ".nescol.ac.uk": ["North East Scotland College"],
    ".newcollege.ac.uk": ["New College Swindon"],
    ".newport.ac.uk": ["University of Wales, Newport"],
    ".students.nhc.ac.uk": ["North Hertfordshire College"],
    ".northampton.ac.uk": ["University of Northampton"],
    ".northlindsey.ac.uk": ["North Lindsey College"],
    ".nottingham.ac.uk": ["University of Nottingham"],
    ".ntu.ac.uk": ["Nottingham Trent University"],
    ".open.ac.uk": ["Open University"],
    ".ou.ac.uk": ["The Open University"],
    ".kellogg.ox.ac.uk": ["Kellogg College"],
    ".worc.ox.ac.uk": ["Worcester College, University of Oxford"],
    ".ox.ac.uk": ["University of Oxford"],
    ".paisley.ac.uk": ["University of Paisley"],
    ".peterborough.ac.uk": ["Peterborough Regional College"],
    ".pirbright.ac.uk": ["The Pirbright Institute"],
    ".plymouth.ac.uk": ["University of Plymouth"],
    ".port.ac.uk": ["University of Portsmouth"],
    ".portsmouth-college.ac.uk": ["Portsmouth College"],
    ".primarygoal.ac.uk": ["Primary Goal"],
    ".student.qmc.ac.uk": ["Queen Mary's College"],
    ".qmul.ac.uk": ["Queen Mary, University of London"],
    ".qmw.ac.uk": ["Queen Mary and Westfield College, University of London"],
    ".qub.ac.uk": ["The Queen's University Belfast"],
    ".ram.ac.uk": ["Royal Academy of Music, University of London"],
    ".rca.ac.uk": ["Royal College of Art"],
    ".rcm.ac.uk": ["Royal College of Music, University of London"],
    ".rdg.ac.uk": ["University of Reading"],
    ".rfi.ac.uk": ["The Rosalind Franklin Institute"],
    ".rgu.ac.uk": ["The Robert Gordon University"],
    ".rhbnc.ac.uk": ["Royal Holloway and Bedford New College"],
    ".rhul.ac.uk": ["Royal Holloway, University of London"],
    ".richmond.ac.uk": [
        "Richmond University - The American International University in London"
    ],
    ".roehampton.ac.uk": ["Roehampton University of Surrey"],
    ".salford.ac.uk": ["University of Salford"],
    ".sas.ac.uk": [
        "Institue of Historical Research, University of London",
        "Institute of Advanced Legal Studies, University of London",
        "Institute of Classical Studies, University of London",
        "Institute of Commonwealth Studies, University of London",
        "Institute of Germanic Studies, University of London",
        "Institute of Latin American Studies, University of London",
        "Warburg Institute, University of London",
    ],
    ".sghms.ac.uk": ["Saint George's Hospital Medical School, University of London"],
    ".sgscol.ac.uk": ["South Gloucestershire and Stroud College"],
    ".shef.ac.uk": ["University of Sheffield"],
    ".shrewsbury.ac.uk": ["Shrewsbury Colleges Group"],
    ".shu.ac.uk": ["Sheffield Hallam University"],
    ".smu.ac.uk": ["Swansea Metropolitan University"],
    ".soas.ac.uk": ["School of Oriental and African Studies, University of London"],
    ".solent.ac.uk": ["Southampton Solent University"],
    ".somerset.ac.uk": [
        "Taunton and Bridgwater College, Somerset, UK.",
        "University of Somerset.",
        "http://www.somerset.ac.uk/",
        "http://www.somerset.ac.uk/courses/lbw622t-hm1-bsc-hons-computing-internet-technologies-3-years.html",
    ],
    ".soton.ac.uk": ["University of Southampton"],
    ".southport.ac.uk": ["Southport College"],
    ".southwales.ac.uk": ["University of South Wales"],
    ".ssees.ac.uk": [
        "School of Slavonic and East European Studies, University of London"
    ],
    ".ssfc.ac.uk": ["Shrewsbury Colleges Group"],
    ".st-and.ac.uk": ["University of St. Andrews"],
    ".st-patricks.ac.uk": ["St.Patrick's International College, London"],
    ".staffs.ac.uk": ["Staffordshire University"],
    ".stamford.ac.uk": ["New College Stamford"],
    ".stephenson.ac.uk": ["Stephenson College"],
    ".stephensoncoll.ac.uk": ["Stephenson College"],
    ".stir.ac.uk": ["University of Stirling"],
    ".strath.ac.uk": [
        "University of Strathclyde",
        "uka tarsadia university,bardoli",
        "Pune university (INDIA)",
    ],
    ".sunderland.ac.uk": ["University of Sunderland"],
    ".surrey.ac.uk": ["University of Surrey"],
    ".sussex.ac.uk": ["University of Sussex"],
    ".swan.ac.uk": ["University of Wales, Swansea"],
    ".swansea.ac.uk": ["Swansea University"],
    ".tcm.ac.uk": ["Trinity College of Music"],
    ".tees.ac.uk": ["University of Teesside"],
    ".trinity-cm.ac.uk": ["Trinity College Carmarthen"],
    ".trurocollege.ac.uk": ["Truro College"],
    ".tvu.ac.uk": ["Thames Valley University"],
    ".uca.ac.uk": ["University for the Creative Arts"],
    ".ucl.ac.uk": ["University College London, University of London"],
    ".uclan.ac.uk": ["University of Central Lancashire"],
    ".ucs.ac.uk": ["University Campus Suffolk"],
    ".uea.ac.uk": ["University of East Anglia"],
    ".uel.ac.uk": ["University of East London"],
    ".ukc.ac.uk": [
        "Brussels School of International Studies",
        "University of Kent at Canterbury",
    ],
    ".ulst.ac.uk": ["University of Ulster"],
    ".umds.ac.uk": ["United Medical and Dental Schools, University of London"],
    ".unl.ac.uk": ["University of North London"],
    ".unn.ac.uk": ["University of Northumbria at Newcastle"],
    ".uwe.ac.uk": ["University of the West of England, Bristol"],
    ".uwic.ac.uk": ["University of Wales Institute, Cardiff"],
    ".wales.ac.uk": ["University of Wales"],
    ".warwick.ac.uk": ["University of Warwick"],
    ".warwickshire.ac.uk": ["Warwickshire College Group"],
    ".student.westherts.ac.uk": ["West Herts College, Watford"],
    ".westminster.ac.uk": ["University of Westminster"],
    ".wimbledon.ac.uk": ["Wimbledon School of Art"],
    ".wlc.ac.uk": ["West London College"],
    ".wlv.ac.uk": ["University of Wolverhampton"],
    ".woking.ac.uk": ["Woking College"],
    ".worc.ac.uk": ["University of Worcester"],
    ".worthing.ac.uk": ["Worthing College"],
    ".york.ac.uk": ["University of York"],
    ".yorksj.ac.uk": ["York St John University"],
    ".hbk.acesmat.uk": ["Hinchingbrooke School", "Hinchingbrooke School"],
    ".adamsgs.uk": ["Haberdashers' Adams"],
    ".avonvalleyschool.uk": ["The Avon Valley School"],
    ".clf.uk": ["Cabot Learning Federation"],
    ".agsb.co.uk": ["Altrincham Grammar School for Boys"],
    ".albanyacademy.co.uk": ["Albany Academy"],
    ".archapprentices.co.uk": ["Arch Apprentices"],
    ".ashville.co.uk": ["Ashville College"],
    ".barrbeaconschool.co.uk": ["Barr Beacon School", "Barr Beacon School"],
    ".bb-hs.co.uk": ["Blythe Bridge High School", "Blythe Bridge High School"],
    ".bedmod.co.uk": ["Bedford Modern School"],
    ".beverleyj6.co.uk": ["Beverley Joint Sixth Form"],
    ".bexleygs.co.uk": ["Bexley Grammar School"],
    ".biddulphhigh.co.uk": ["Biddulph High School"],
    ".boa-academy.co.uk": ["Birmingham Ormiston Academy"],
    ".bolnoreschool.co.uk": ["Bolnore Village Primary School"],
    ".bostongrammarschool.co.uk": ["Boston Grammar School"],
    ".calday.co.uk": ["Calday Grange Grammar School"],
    ".caludoncastle.co.uk": ["Caludon Castle"],
    ".cardinalallen.co.uk": ["Cardinal Allen Catholic High School"],
    ".cardinalnewman.co.uk": ["Cardinal Newman Roman Catholic Comprehensive School"],
    ".cedarsupper.co.uk": ["Cedars Upper School"],
    ".chesterfieldhigh.co.uk": ["Chesterfield High School"],
    ".cliftonhigh.co.uk": ["Clifton High School"],
    ".clrchs.co.uk": ["Cardinal Langley RC High School & Sixth Form College"],
    ".cowbridgecomprehensiveschool.co.uk": [
        "Cowbridge Comprehensive School Sixth Form"
    ],
    ".cowbridgecs.co.uk": ["Cowbridge Comprehensive School Sixth Form"],
    ".crgs.co.uk": ["Colchester Royal Grammar School"],
    ".cvms.co.uk": ["The Cardinal Vaughan Memorial School"],
    ".derbymanufacturingutc.co.uk": ["Derby Manufacturing UTC, Derby, UK"],
    ".eastlondonscienceschool.co.uk": ["East London Science School Sixth Form"],
    ".ebbwfawr.co.uk": ["Ebbw Fawr Learning Community", "Ebbw Fawr Learning Community"],
    ".edgbarrowschool.co.uk": ["Edgbarrow School"],
    ".elam.co.uk": ["East London Arts and Music"],
    ".ewellcastle.co.uk": ["Ewell Castle School"],
    ".hallifordschool.co.uk": ["Halliford School"],
    ".heathfieldcc.co.uk": ["Heathfield Community College "],
    ".heckgrammar.co.uk": ["Heckmondwike Grammar School"],
    ".hitchinboys.co.uk": ["Hitchin Boys' Academy"],
    ".holmfirthhigh.co.uk": ["Holmfirth High School"],
    ".horizoncc.co.uk": ["Horizon Community College"],
    ".hppc.co.uk": ["Hurstpierpoint College"],
    ".hswv.co.uk": ["Highfields School"],
    ".ilford-school.co.uk": ["Ilford Grammar School"],
    ".ilkleygs.co.uk": ["Ilkley Grammar School"],
    ".interhigh.co.uk": ["InterHigh Education", "InterHigh School", "InterHigh"],
    ".iscaexeter.co.uk": ["Isca Academy "],
    ".ivesheadschool.co.uk": ["Iveshead School"],
    ".kennetschool.co.uk": ["Kennet School, Thatcham"],
    ".kingschester.co.uk": ["The King's School, Chester"],
    ".kingsolomonhigh.co.uk": ["Kantor King Solomon High School"],
    ".kirkbiekendal.co.uk": ["Kirkbie Kendal School"],
    ".kirkhamgrammar.co.uk": ["Kirkham Grammar School"],
    ".latymer.co.uk": ["Latymer School - Sixth Form"],
    ".limt.co.uk": ["London Institute of Management and Technology"],
    ".lincolnutc.co.uk": ["Lincoln UTC"],
    ".lsclondon.co.uk": ["London School of Commerce", "London School of Commerce"],
    ".maynard.co.uk": ["Maynard School"],
    ".meole.co.uk": ["Meole Brace School Science College"],
    ".meolscophighschool.co.uk": ["Meols Cop High School"],
    ".mmhs.co.uk": ["Matthew Moss"],
    ".mynsb.co.uk": ["Northampton School For Boys"],
    ".myton.co.uk": [
        "Myton School",
        "https://www.mytonschool.co.uk/",
        "https://www.mytonschool.co.uk/sixth-form/welcome-myton-sixth-form/",
        "https://www.mytonschool.co.uk/sixth-form/courses/computer-science-level/",
        "https://www.mytonschool.co.uk/sixth-form/courses/information-technology/",
        "https://www.mytonschool.co.uk/staff-by-department/",
    ],
    ".newhallstudent.co.uk": ["New Hall School"],
    ".nottinghamhigh.co.uk": ["Nottingham High School"],
    ".oatforge.co.uk": ["Ormiston Forge Academy"],
    ".perse.co.uk": ["The Perse School, Cambridge"],
    ".philipshigh.co.uk": ["Philips High School"],
    ".poolehigh.co.uk": ["Poole High School"],
    ".prioryacademies.co.uk": ["The Priory Academy"],
    ".qerdp.co.uk": ["Queen Elizabeth's School, Barnet"],
    ".reading-school.co.uk": ["Reading Grammar School"],
    ".rgsg.co.uk": ["Royal Grammar School, Guildford"],
    ".rhymneycomprehensive.co.uk": ["Rhymney Comprehensive School"],
    ".roundhayschool.co.uk": ["Roundhay School"],
    ".saintsa.co.uk": ["Saint Augustine's Catholic High School"],
    ".students.salegrammar.co.uk": ["Sale Grammar School"],
    ".salegrammar.co.uk": ["Sale Grammar School"],
    ".scarboroughcollege.co.uk": ["Scarborough College"],
    ".shepshedlearning.co.uk": ["Iveshead School"],
    ".sheringhamhigh.co.uk": ["Sheringham High School"],
    ".sheringhamsixthform.co.uk": ["Sheringham Sixth Form College"],
    ".sirhenryfloyd.co.uk": [
        "Sir Henry Floyd Grammar School",
        "https://www.sirhenryfloyd.co.uk/curriculum/curriculum-key-stage/",
    ],
    ".sphcs.co.uk": ["St Philip Howard Sixth Form"],
    ".staldhelms-academy.co.uk": ["St Aldhelm's Academy"],
    ".stjos.co.uk": ["St. Joseph's College"],
    ".stowe.co.uk": ["Stowe School"],
    ".tbgs.co.uk": ["Torquay Boys' Grammar School"],
    ".theangmeringschool.co.uk": ["The Angmering School"],
    ".thecotswoldschool.co.uk": ["The Cotswold School"],
    ".thefarnboroughacademy.co.uk": ["The Farnborough Academy"],
    ".thekingsschool.co.uk": ["The Kings School Gloucester"],
    ".theurswickschool.co.uk": ["The Urswick School"],
    ".thorpehouse.co.uk": ["thorpe house school"],
    ".tqacademy.co.uk": ["Torquay Academy"],
    ".uptonhigh.co.uk": ["Upton-by-Chester High School"],
    ".utc-silverstone.co.uk": ["Silverstone UTC"],
    ".utcw.co.uk": ["UTC Warrington"],
    ".verulamschool.co.uk": ["Verulam School"],
    ".weston.co.uk": ["Weston College"],
    ".wg6.co.uk": ["Wilmington Grammar Schools Sixth Form"],
    ".windsorsixth.co.uk": ["Windsor High School and Sixth Form, Halesowen"],
    ".woacademy.co.uk": ["Wodensborough Ormiston Academy"],
    ".wolfreton.co.uk": ["Wolfreton School and Sixth Form College"],
    ".wsnl.co.uk": ["Worksop College"],
    ".wycliffe.co.uk": ["Wycliffe College"],
    ".Kingsworcester.org.uk": ["King's School Worcester", "@kingsworcester.org.uk"],
    ".Ksw.org.uk": ["King's School Worcester", "@ksw.org.uk"],
    ".abingdon.org.uk": ["Abingdon School"],
    ".alleyns.org.uk": ["Alleyn's School"],
    ".ashlawn.org.uk": ["Ashlawn School"],
    ".bclschool.org.uk": ["Beis Chinuch Lebonos Girls School"],
    ".bcs.org.uk": ["British Computer Society"],
    ".beauchamp.org.uk": ["Beauchamp college"],
    ".beauchampcity.org.uk": ["Beauchamp City Sixth Form"],
    ".bedfordschool.org.uk": ["Bedford School"],
    ".beechencliff.org.uk": [
        "Beechen Cliff School",
        "@beechencliff.org.uk",
        "School offers A-Level in Computer Science",
    ],
    ".berkeleygreenutc.org.uk": ["SGS Berkeley Green UTC", "@berkeleygreenutc.org.uk"],
    ".carmelstudent.bhcet.org.uk": ["Carmel College", "Carmel College"],
    ".bicestertechstudio.org.uk": ["Bicester Technology Studio"],
    ".bl6.org.uk": ["Brine Leas Sixth Form", "BL6"],
    ".blandfordschool.org.uk": ["The Blandford School"],
    ".bluecoatstudent.org.uk": ["The Liverpool Blue Coat School"],
    ".bradfieldcollege.org.uk": ["Bradfield College"],
    ".bramptonmanor.org.uk": ["Brampton Manor Academy"],
    ".brgsmail.org.uk": ["Bacup and Rawtenstall Grammar School"],
    ".bristolfreeschool.org.uk": ["Bristol Free School"],
    ".bucksgfl.org.uk": ["Bucks Grid for Learning"],
    ".carmel.org.uk": ["Carmel RC College"],
    ".chartereastdulwich.org.uk": ["The Charter School East Dulwich"],
    ".charterhouse.org.uk": ["Charterhouse"],
    ".chichesterfreeschool.org.uk": ["Chichester Free School"],
    ".christofidelis.org.uk": ["Catholic High School, Chester"],
    ".clevedonschool.org.uk": ["Clevedon School"],
    ".collegiateacademy.org.uk": ["Shireland Collegiate Academy"],
    ".cooperscoborn.org.uk": ["The Coopers' Company and Coborn School"],
    ".cotswold-chine.org.uk": ["Cotswold Chine School"],
    ".edu.creweutc.org.uk": ["Crewe UTC"],
    ".dartfordgrammarschool.org.uk": [
        "Dartford Grammar School ",
        "Dartford Grammar School ",
    ],
    ".discoveryschool.org.uk": ["Discovery School"],
    ".dulwich.org.uk": ["Dulwich College"],
    ".durhamjohnston.org.uk": ["Durham Johnston Comprehensive School"],
    ".ealingfields.org.uk": ["Ealing Fields High School"],
    ".edinburghacademy.org.uk": ["The Edinburgh Academy"],
    ".epsomcollege.org.uk": ["Epsom College"],
    ".esf-schools.org.uk": ["Emmanuel Schools Foundation"],
    ".etoncollege.org.uk": ["Eton College"],
    ".stjohns.excalibur.org.uk": ["St John's Marlborough", "St John's Marlborough"],
    ".forest.org.uk": ["Forest School London"],
    ".gordanoschool.org.uk": ["Gordano School"],
    ".gsal.org.uk": ["The Grammar School at Leeds"],
    ".gsm.org.uk": ["Greenwich School of Management\u200e"],
    ".habsboys.org.uk": ["Haberdashers' Aske's Boys' School"],
    ".hanleycastlehs.org.uk": ["Hanley Castle High School"],
    ".harrisdulwichgirls.org.uk": ["harris girls' academy east dulwich"],
    ".highgateschool.org.uk": ["Highgate School, UK"],
    ".ivesheadschool.org.uk": ["Iveshead School"],
    ".kaa.org.uk": ["Kensington Aldridge Academy"],
    ".kcs.org.uk": ["King's College School Wimbledon"],
    ".kegs.org.uk": ["King Edward VI Grammar School", "King Edward VI Grammar School"],
    ".kgs.org.uk": ["Kingston Grammar School"],
    ".kingsburyhigh.org.uk": ["Kingsbury High School"],
    ".kingsdalefoundationschool.org.uk": ["Kingsdale Foundation School"],
    ".kscs.org.uk": ["Ken Stimpson Community School"],
    ".ksnmail.ksn.org.uk": ["Kenilworth School and Sixth Form"],
    ".ksn.org.uk": ["Kenilworth School and Sixth Form"],
    ".landau-forte.org.uk": ["Landau Forte College Derby"],
    ".lat16.org.uk": ["Longfield Academy "],
    ".lccm.org.uk": ["London College of Creative Media"],
    ".lfatsf.org.uk": ["Landau Forte Academy Tamworth Sixth Form"],
    ".littleheath.org.uk": ["Little Heath School"],
    ".eleve.lyceefrancais.org.uk": ["Lycee Francais Charles de Gaulle"],
    ".maslearner.org.uk": ["Mascalls academy"],
    ".mhchs.org.uk": ["Mill Hill County High Scool"],
    ".millhill.org.uk": ["Mill Hill School"],
    ".mtsn.org.uk": ["Merchant Taylors' School"],
    ".nbacademy.org.uk": ["North Birmingham Academy"],
    ".ndhs.org.uk": ["Notre Dame High School", "@ndhs.org.uk"],
    ".nlcs.org.uk": ["North London Collegiate School"],
    ".novalis-trust.org.uk": ["Novalis Trust"],
    ".nsix.org.uk": ["Hellesdon High School & Sixth Form Centre"],
    ".olchfa.org.uk": ["Olchfa"],
    ".oundleschool.org.uk": ["Oundle School"],
    ".parksidefederation.org.uk": ["Cambridge Academy for Science and Technology"],
    ".penrice.org.uk": ["Penrice Accademy"],
    ".petcheyacademy.org.uk": ["The Petchey Academy"],
    ".plymstockschool.org.uk": ["Plymstock School"],
    ".q3academy.org.uk": ["q3 academy"],
    ".qegsss.org.uk": ["Queen Elizabeth Grammar School"],
    ".qes.org.uk": ["Queen Elizabeth School"],
    ".rawlinsacademy.org.uk": ["Rawlins Academy", "@rawlinsacademy.org.uk"],
    ".rgsw.org.uk": ["Royal Grammar School Worcester"],
    ".rmgs.org.uk": ["Rainham Mark Grammar School", "rainhammark.com"],
    ".rochester-college.org.uk": ["Rochester Independent College"],
    ".rsat.org.uk": ["Royston Schools' Academy Trust"],
    ".rwba.org.uk": ["Royal Wootton Bassett Academy"],
    ".student.s6f.org.uk": ["Scarborough Sixth Form College"],
    ".s6f.org.uk": ["Scarborough Sixth Form College"],
    ".sandhurstschool.org.uk": ["Sandhurst School"],
    ".savremena.org.uk": ["Savremena Gimnazija"],
    ".sbeschool.org.uk": ["Shenley Brook End School"],
    ".sbllearning.org.uk": ["Sir Bernard Lovell Academy"],
    ".shiplake.org.uk": ["Shiplake College"],
    ".shrewsbury.org.uk": ["Shrewsbury School"],
    ".shsb.org.uk": ["Southend High School for Boys"],
    ".sidcot.org.uk": ["Sidcot School"],
    ".smwca.org.uk": [
        "St. Margaret Ward Catholic Academy",
        "http://www.stmargaretward.co.uk/ [check bottom of page]",
    ],
    ".southhunsley.org.uk": ["South Hunsley School"],
    ".st-ambrosecollege.org.uk": ["St Ambrose College"],
    ".stbens.org.uk": [
        "St Benedict's School Ealing",
        "54 Eaton Rise",
        "Ealing",
        "London ",
        "W5 2ES",
    ],
    ".steds.org.uk": [None],
    ".stmaryschesterfield.org.uk": [
        "St Marys Catholic High School and Sixth form (Chesterfield)",
        "https://www.st-maryshigh.derbyshire.sch.uk",
        "@stmaryschesterfield.org.uk",
    ],
    ".stpaulsschool.org.uk": ["St Pauls School"],
    ".solihull.tgacademy.org.uk": ["Tudor Grange Academy Solihull"],
    ".thekingsacademy.org.uk": ["The King's Academy"],
    ".thomasestley.org.uk": ["Thomas Estley Community College"],
    ".tscacademy.org.uk": ["The Samworth Church Academy"],
    ".ucs.org.uk": ["University College School"],
    ".uhs.org.uk": ["Uxbridge High School"],
    ".utcderby.org.uk": ["UTC Derby Pride Park"],
    ".utcn.org.uk": ["University Technical College Norfolk"],
    ".utcreading.org.uk": ["UTC Reading"],
    ".utcsheffield.org.uk": ["The Sheffield UTC Academy Trust"],
    ".uvhs.org.uk": ["Ulverston Victoria High School"],
    ".valeacademy.org.uk": ["The Vale Academy"],
    ".invicta.viat.org.uk": ["invicta grammar school"],
    ".student.waylandacademy.org.uk": ["Wayland Academy Norfolk"],
    ".wellingtoncollege.org.uk": ["Wellington College"],
    ".westminster.org.uk": ["Westminster School"],
    ".william-morris.org.uk": ["William Morris College"],
    ".greatwyrley.windsoracademytrust.org.uk": ["Great Wyrley Academy"],
    ".wmgacademy.org.uk": ["WMG Academy for Young Engineers"],
    ".Dovergramboys.Kent.sch.uk": [
        "format - username@dovergramboys.kent.sch.uk",
        "Dover grammar school for boys, kent, uk",
    ],
    ".judd.Kent.sch.uk": [
        "The Judd School, Tonbridge, Kent, UK",
        "format - username@judd.kent.sch.uk",
    ],
    ".poltair.cornwall.sch.uk": ["Poltair School"],
    ".mountbatten.hants.sch.uk": ["The Mountbatten School"],
    ".rickmansworth.herts.sch.uk": ["Rickmansworth School, Croxley Green"],
    ".mgs.kent.sch.uk": [
        "Maidstone grammar school, Kent, UK",
        "format - username@mgs.kent.sch.uk",
    ],
    ".hodgson.lancs.sch.uk": ["Hodgson Academy"],
    ".millfield.lancs.sch.uk": ["Millfield Science & Performing Arts College"],
    ".st-aidans.lancs.sch.uk": ["St Aidans Church of England High School"],
    ".mhsg.manchester.sch.uk": ["Manchester High School For Girls"],
    ".ermysteds.n-yorks.sch.uk": ["Ermysted's Grammar School"],
    ".aan.norfolk.sch.uk": ["Attleborough Academy Norfolk"],
    ".ccs.northants.sch.uk": ["Caroline Chisholm School"],
    ".nsb.northants.sch.uk": ["Northampton School For Boys"],
    ".poolehigh.poole.sch.uk": ["Poole High School"],
    ".claremont.surrey.sch.uk": ["Claremont Fan Court School"],
    ".stjohns.surrey.sch.uk": ["St John's School. Leatherhead, Surrey"],
    ".cheam.sutton.sch.uk": ["Cheam High School"],
    ".southbromsgrove.worcs.sch.uk": ["South Bromsgrove High"],
    ".tgs.starmat.uk": ["Tadcaster Grammar School"],
    ".innopolis.university": ["Innopolis University"],
    ".rudn.university": ["RUDN University"],
    ".satbayev.university": ["Satbayev University"],
    ".sit.university": ["Schaffhausen Institute of Technology"],
    ".uit.university": [
        "Université Internationale de Tunis - UIT | UIT",
        "https://univ-internationale.com/fr",
    ],
    ".ahschools.us": ["Anoka-Hennepin School District"],
    ".madisoncity.k12.al.us": [
        "James Clemens High School",
        "Bob Jones High School",
        "Liberty Middle School",
        "Discovery Middle School",
    ],
    ".mtnbrook.k12.al.us": ["Mountain Brook High School", "Mountain Brook Junior High"],
    ".pickens.k12.al.us": ["Pickens County School District"],
    ".k12.andoverma.us": ["Andover Public Schools"],
    ".apsva.us": ["Washington-Liberty High School", "Arlington Career Center"],
    ".args.us": ["Appomattox Regional Governor's School"],
    ".bubblers.us": ["South Middleton School District"],
    ".clovisusd.k12.ca.us": ["Clovis Unified School District", "cusd.com"],
    ".khsd.k12.ca.us": ["Kern High School District"],
    ".sbcusd.k12.ca.us": [
        "San Bernardino City Unified School District",
        "San Bernardino City USD",
    ],
    ".vcpusd.k12.ca.us": ["Valley Center-Pauma Unified"],
    ".jeffco.k12.co.us": ["Jefferson County Public Schools"],
    ".cpsd.us": ["Cambridge Rindge and Latin School"],
    ".bethel.k12.ct.us": ["Bethel Public Schools"],
    ".newtown.k12.ct.us": ["Newtown High School"],
    ".appo.k12.de.us": ["Appoquinimink High School"],
    ".colonial.k12.de.us": ["William Penn High School"],
    ".student.ecisd.us": ["Edinburg North High School"],
    ".nassau.k12.fl.us": ["Fernandina Beach Middle School"],
    ".pasco.k12.fl.us": ["Pasco County Schools"],
    ".stjohns.k12.fl.us": ["Creekside High School"],
    ".fuom.us": ["Florida University of Medicine"],
    ".cherokee.k12.ga.us": ["Cherokee County School District"],
    ".forsyth.k12.ga.us": ["Forsyth County School District"],
    ".heard.k12.ga.us": ["Heard County School District"],
    ".henry.k12.ga.us": ["Henry County School District"],
    ".students.rockdale.k12.ga.us": ["Salem High School"],
    ".greenvilleschools.us": ["Greer High School"],
    ".hartlandschools.us": ["Hartland Consolidated Schools"],
    ".hasd.us": ["Halifax Area School District"],
    ".kaimukims.k12.hi.us": ["Kaimuki Middle School"],
    ".notes.k12.hi.us": ["Hawaii State Department of Education", ".group"],
    ".ames.k12.ia.us": ["Ames Community School District"],
    ".g.bettendorf.k12.ia.us": ["Bettendorf High School"],
    ".cr.k12.ia.us": ["Cedar Rapids Community School District"],
    ".davenport.k12.ia.us": ["West High School"],
    ".north-scott.k12.ia.us": ["North Community School District"],
    ".rvc.cc.il.us": ["Rock Valley College"],
    ".auburn.k12.il.us": ["Auburn High School"],
    ".batesville.k12.in.us": ["Batesville High School"],
    ".ccs.k12.in.us": ["Clay middle school", "Clay middle school"],
    ".clay.k12.in.us": ["Clay Community Schools"],
    ".elkhart.k12.in.us": ["Elkhart Community Schools"],
    ".gws.k12.in.us": ["Greenwood Middle School"],
    ".hse.k12.in.us": ["Hamilton Southeastern High School"],
    ".mvcsc.k12.in.us": ["Mount Vernon High School"],
    ".ngsc.k12.in.us": ["Princeton Community High School"],
    ".phm.k12.in.us": ["Penn Harris Maddison School Corporation"],
    ".warren.k12.in.us": ["MSD Warren Township Schools"],
    ".jdragonmail.us": ["Johnston High School"],
    ".jeffcoschools.us": ["Jefferson County Public Schools"],
    ".stu.boone.kyschools.us": ["Boone County Schools"],
    ".stu.campbell.kyschools.us": ["Campbell County Schools"],
    ".campbell.kyschools.us": ["Campbell County Schools"],
    ".stu.fayette.kyschools.us": ["Fayette County Public Schools"],
    ".fayette.kyschools.us": ["Bryan Station High School"],
    ".stu.hardin.kyschools.us": ["Hardin County Schools"],
    ".stu.jefferson.kyschools.us": ["Jefferson County Public Schools"],
    ".jessamine.kyschools.us": ["West Jessamine High School"],
    ".stu.scott.kyschools.us": ["Scott County Schools"],
    ".duxbury.k12.ma.us": ["Duxbury Public Schools"],
    ".lynnfield.k12.ma.us": ["Lynnfield Public Schools / Lynnfield High School"],
    ".newton.k12.ma.us": ["Newton South High School", ".group"],
    ".north-reading.k12.ma.us": [
        "North Reading Public Schools / North Reading High School"
    ],
    ".norwood.k12.ma.us": ["Norwood High School"],
    ".student.plymouth.k12.ma.us": ["Plymouth Public Schools"],
    ".reading.k12.ma.us": ["Reading Public Schools / Reading Memorial High School"],
    ".shrewsbury.k12.ma.us": ["Shrewsbury Public Schools / Shrewsbury High School"],
    ".wayland.k12.ma.us": ["Wayland High School"],
    ".sch.ci.lexington.ma.us": ["Lexington High School"],
    ".students.kent.k12.md.us": ["Kent County High School"],
    ".aaps.k12.mi.us": ["Pioneer High School - Ann Arbor"],
    ".clarkston.k12.mi.us": ["Clarkston Community Schools"],
    ".cvs.k12.mi.us": ["Chippewa Valley Schools"],
    ".haslett.k12.mi.us": ["Haslett High School"],
    ".rochester.k12.mi.us": [
        "Rochester Community School District",
        "Rochester Community Schools",
    ],
    ".roseville.k12.mi.us": ["Roseville High School"],
    ".troy.k12.mi.us": [
        "Troy Community School District",
        "Troy Community Schools",
        "Troy Public School District",
    ],
    ".edenpr.k12.mn.us": ["Eden Prairie School District - Teacher Email"],
    ".isd2142.k12.mn.us": ["St. Louis County Schools"],
    ".gapps.sartell.k12.mn.us": [
        "Sartell-St. Stephen ISD 748 (Google Apps for Education)"
    ],
    ".sartell.k12.mn.us": ["Sartell-St. Stephen ISD 748 (Teacher Email)"],
    ".stpaul.k12.mn.us": ["Highland Park Senior High"],
    ".eastbuchanan.k12.mo.us": ["East Buchanan C1"],
    ".monett.k12.mo.us": ["Monnett Schools"],
    ".smithville.k12.mo.us": ["Smithville Schools"],
    ".wrightcity.k12.mo.us": ["Wright City School District"],
    ".gfps.k12.mt.us": ["Great Falls Public School District"],
    ".sacoschools.k12.mt.us": ["Saco Public School District"],
    ".mtsdstudent.us": [
        "Montgomery High School ",
        "Montgomery Township School District",
        "Montgomery High",
        "Montgomery ",
    ],
    ".mycod.us": ["College of the Desert"],
    ".myhalifax.us": ["Halifax Area School District"],
    ".student.myscps.us": [
        "Seminole County Public Schools",
        "https://www.scps.k12.fl.us/",
        "The emails for students that are in schools in Seminole County are ID@student.myscps.us",
    ],
    ".students.abss.k12.nc.us": ["Alamance-Burlington School System - Student Emails"],
    ".abss.k12.nc.us": ["Alamance-Burlington School System - Teacher Emails"],
    ".lee.k12.nc.us": ["Lee County Schools"],
    ".k12.nd.us": ["Jamestown High School"],
    ".nicolet.us": ["Nicolet High School"],
    ".brrsd.k12.nj.us": ["Bridgewater Raritan School District, NJ"],
    ".dvrhs.k12.nj.us": ["Delaware Valley Regional High School"],
    ".edison.k12.nj.us": ["Edison Public School District"],
    ".ewrsd.k12.nj.us": ["Hightstown High School"],
    ".ns.greenwich.k12.nj.us": ["Greenwich Township School District", ".group"],
    ".gtps.k12.nj.us": ["Galloway Township Public Schools"],
    ".mahwah.k12.nj.us": ["Mahwah Public School District"],
    ".nps.k12.nj.us": ["Newark Public Schools District"],
    ".paramus.k12.nj.us": ["Paramus Public School District"],
    ".ramsey.k12.nj.us": ["Ramsey Public School District"],
    ".ridgewood.k12.nj.us": ["Ridgewood High School"],
    ".students.somsd.k12.nj.us": [
        "South Orange Maplewood School District Student Domain",
        ".group",
    ],
    ".summit.k12.nj.us": ["Summit High School"],
    ".commack.k12.ny.us": ["Commack High School"],
    ".comsewogue.k12.ny.us": ["Comsewogue School District"],
    ".icsd.k12.ny.us": ["Ithaca City School District"],
    ".lvcsd.k12.ny.us": ["Locust Valley Middle School", "Locust Valley Middle School"],
    ".newpaltz.k12.ny.us": ["New Paltz High School"],
    ".northport.k12.ny.us": ["Northport High School"],
    ".syosset.k12.ny.us": ["Syosset High School", "Syosset Central School District"],
    ".wfsd.k12.ny.us": ["William Floyd High School", "William Floyd School District"],
    ".ashland-city.k12.oh.us": ["Ashland City Schools"],
    ".norman.k12.ok.us": ["Norman Public Schools"],
    ".cascade.k12.or.us": ["Cascade School District"],
    ".hsd.k12.or.us": ["Hillsboro School District"],
    ".loswego.k12.or.us": ["Lake Oswego School District", "LOSD"],
    ".student.orecity.k12.or.us": ["Oregon City School District", "OCSD"],
    ".orecity.k12.or.us": ["Oregon City School District", "OCSD"],
    ".stu.ortrail.k12.or.us": ["Sandy High School"],
    ".iwms.wlwv.k12.or.us": ["Wood Middle School"],
    ".basd.k12.pa.us": ["Beaver Area School District"],
    ".franklinregional.k12.pa.us": ["Franklin Regional School District"],
    ".gmsd.k12.pa.us": ["Governor Mifflin School District"],
    ".hpsd.k12.pa.us": ["Hanover Public School District"],
    ".indians.k12.pa.us": ["Shamokin Area High School"],
    ".wilmington.k12.pa.us": ["Wilmington Area School District"],
    ".wssd.k12.pa.us": ["West Shore School District"],
    ".pausd.us": ["Palo Alto Unified School District"],
    ".pusd.us": ["Pasadena High School", "Pasadena High School"],
    ".rcs-k12.us": [
        "Rochester Community School District",
        "Rochester Community Schools",
    ],
    ".rentonschools.us": ["Renton School District"],
    ".clover.k12.sc.us": ["Clover School District"],
    ".gssm.k12.sc.us": ["South Carolina Governor's School for Science and Mathematics"],
    ".k12.sd.us": ["Brookings High School"],
    ".smusd.us": ["San Marino Unified School District"],
    ".tri-county.us": ["Tri-County Regional Vocational Technical High School"],
    ".austin.cc.tx.us": ["Austin Community College"],
    ".davis.k12.ut.us": ["Davis School District"],
    ".bedford.k12.va.us": [
        "Forest Middle School",
        "http://bedfordfms.sharpschool.net/",
        ".group",
    ],
    ".harrisonburg.k12.va.us": [
        "Harrisonburg High School",
        "https://harrisonburg.k12.va.us/hhs/",
        ".group",
    ],
    ".nn.k12.va.us": ["Newport News Public Schools", ".group"],
    ".salem.k12.va.us": ["Salem High School"],
    ".students.wcps.k12.va.us": ["Skyline High School"],
    ".westfordk12.us": ["Westford Academy"],
    ".bonduel.k12.wi.us": ["Bonduel School District"],
    ".hudson.k12.wi.us": ["Hudson"],
    ".madison.k12.wi.us": ["James Madison Memorial High School", "Madison, WI  USA"],
    ".students.mcpasd.k12.wi.us": ["Middleton High School"],
    ".randomlake.k12.wi.us": ["Random Lake School District"],
    ".shorewood.k12.wi.us": ["Shorewood School District"],
    ".waukesha.k12.wi.us": ["School District of Waukesha"],
    ".k12.wv.us": ["South Branch Career & Technical Center"],
    ".yorkuniversity.us": ["York University"],
    ".docente.ceibal.edu.uy": [
        "Administracion Nacional de Educacion Publica - Plan Ceibal"
    ],
    ".estudiante.ceibal.edu.uy": ["Plan Ceibal"],
    ".claeh.edu.uy": [
        "Insituto Universitario - Centro Latinoamericano de Economia Humana - IU Claeh"
    ],
    ".fcien.edu.uy": ["Facultad de Ciencias"],
    ".fic.edu.uy": [
        "Facultad de Información y Comunicación, Universidad de la República."
    ],
    ".fing.edu.uy": [
        "Facultad de Ingeniería, Universidad de la República",
        "https://www.fing.edu.uy/",
    ],
    ".ort.edu.uy": ["Universidad ORT Uruguay"],
    ".psico.edu.uy": ["Facultad de Psicología UDELAR", "psico.edu.uy"],
    ".rau.edu.uy": ["Universidad de la República"],
    ".seciu.edu.uy": ["Universidad de la Republica", "University of the Republic"],
    ".alumnos.seminario.edu.uy": ["Colegio Seminario"],
    ".ucu.edu.uy": ["Universidad Católica del Uruguay"],
    ".ude.edu.uy": ["Universidad de la Empresa (UDE)"],
    ".udelar.edu.uy": ["Universidad de la República", ".group"],
    ".um.edu.uy": ["Universidad de Montevideo"],
    ".utec.edu.uy": [
        "UTEC (Universidad Tecnológica del Uruguay)",
        "UTEC (Technological University of Uruguay)",
    ],
    ".adu.uz": ["Andijon Davlat Universiteti", "Andizhan State University"],
    ".akfauniversity.uz": ["Akfa University"],
    ".fdu.uz": ["Fergana state university"],
    ".gubkin.uz": ["National University of Oil and Gas «Gubkin University»"],
    ".ibs.uz": ["International Business School Kelajak ILMI"],
    ".iiau.uz": ["International Islamic Academy of Uzbekistan"],
    ".inha.uz": ["Inha University in Tashkent"],
    ".iut.uz": ["Inha University in Tashkent"],
    ".jbnuu.uz": [
        "  MIRZO ULUG‘BEK NOMIDAGI O‘ZBEKISTON MILLIY UNIVERSITETI JIZZAX FILIALI",
        "  JIZZAKH BRANCH OF NATIONAL UNIVERSITY OF UZBEKISTAN NAMED AFTER MIRZO ULUGBEK",
    ],
    ".jspi.uz": [
        "Jizzax davlat pedagogika instituti",
        "Jizzakh State Pedadogical Institute",
    ],
    ".kiuf.uz": ["Korean International University in Ferghana"],
    ".mdis.uz": ["Management Development Institute of Singapore, Tashkent"],
    ".msu.uz": [
        "Lomonosov Moscow State University in Tashkent",
        "Moscow State University in Tashkent",
    ],
    ".namdu.uz": ["Namangan davlat universiteti", "Namangan State University"],
    ".ndki.uz": ["Navoiy Davlat Konchilik Instituti", "Navoi State Mining Institute"],
    ".nuu.uz": ["National University of Uzbekistan"],
    ".pharmi.uz": ["Tashkent Pharmaceutical Institute"],
    ".polito.uz": ["Turin Polytechnic University in Tashkent"],
    ".qarshidu.uz": ["Qarshi davlat universiteti", "Qarshi State University"],
    ".qdpi.uz": ["Kokand State Pedagogical Institute"],
    ".qmii.uz": ["Karshi Engineering Economic Institute"],
    ".samdchti.uz": ["Samarkand State Institute of Foreign Languages"],
    ".samdu.uz": ["Samarkand State University"],
    ".samgasi.uz": ["Samarkand State Architectural and Civil Engineering Institute"],
    ".tatuff.uz": ["Tashkent University of Information Technologies, Ferghana branch"],
    ".tayi.uz": ["Tashkent Automobile and Roads Institute"],
    ".tcti.uz": ["Tashkent Chemical Technological Institute"],
    ".tdpu.uz": [
        "Toshkent Davlat Pedagogika Universiteti",
        "Tashkent State Pedagogical University",
    ],
    ".tdtu.uz": [
        "Tashkent State Technical University",
        "Ташкентский Государственный Технический Университет",
        "Toshkent Davlat Texnika Universiteti",
    ],
    ".teamuni.uz": ["TEAM University"],
    ".tfi.uz": ["Tashkent School of Finance"],
    ".tiiamekb.uz": [
        "Karshi branch of the Tashkent Institute of Irrigation and Agricultural Mechanization Engineers"
    ],
    ".tiim.uz": ["Tashkent Institute of Irrigation and Melioration"],
    ".tiu.uz": ["Tashkent Islam University"],
    ".tma.uz": ["Tashkent Medical Academy"],
    ".tsue.uz": ["Tashkent State University of Economics"],
    ".tsul.uz": [
        "Ташкентский государственный юридический университет",
        "Tashkent State University of Law",
    ],
    ".tuit.uz": ["Tashkent University of Information Technologies"],
    ".tuitkf.uz": ["Karshi Branch of Tashkent University of Information Technologies"],
    ".ubtuit.uz": ["TATU Urgnch filiali", "Urgench branch of TUIT"],
    ".urdu.uz": ["Urganch Davlat Universiteti", "Urgench State University"],
    ".uwed.uz": ["University of World Economy &amp; Diplomacy"],
    ".uzpak.uz": ["Namangan Engineering-Pedagogical Institute"],
    ".uzswlu.uz": ["Uzbek State World Languages University"],
    ".wiut.uz": ["Westminster International University in Tashkent"],
    ".ytit.uz": [
        "Yeoju Technical Institute in Tashkent",
        "Yeoju Technical Institute in Tashkent",
    ],
    ".iutamaracay.com.ve": [
        "Instituto Universitario de tecnología de Administración Industrial"
    ],
    ".uba.edu.ve": ["Universidad Bicentenaria de Aragua"],
    ".ubv.edu.ve": ["Universidad Bolivariana de Venezuela"],
    ".uc.edu.ve": ["Universidad de Carabobo"],
    ".ucab.edu.ve": ["Universidad Católica Andres Bello"],
    ".ucat.edu.ve": ["Universidad Católica del Táchira"],
    ".ucla.edu.ve": ["Universidad Centro Occidental Lisandro Alvarado"],
    ".uft.edu.ve": ["Universidad Fermin Toro"],
    ".una.edu.ve": ["Universidad Nacional Abierta"],
    ".unefa.edu.ve": ["Universidad Nacional Experimental de la Fuerza Armada"],
    ".unellez.edu.ve": [
        "Universidad Nacional Experimental de los Llanos Occidentales Ezequiel Zamora"
    ],
    ".unerg.edu.ve": ["Universidad Nacional Experimental Romulo Gallegos"],
    ".unermb.edu.ve": ["Universidad Nacional Experimental Rafael Maria Baralt"],
    ".unesur.edu.ve": [
        "Universidad Nacional Experimental Sur del Lago Jesús Maria Semprum"
    ],
    ".unica.edu.ve": ["Universidad Católica Cecilio Acosta"],
    ".unimet.edu.ve": ["Universidad Metropolitana"],
    ".unitec.edu.ve": ["Universidad Tecnológica del Centro"],
    ".uvm.edu.ve": ["Universidad Valle del Momboy"],
    ".www.ucv.ve": ["Universidad Central de Venezuela"],
    ".ucv.ve": ["Universidad Central de Venezuela"],
    ".www.ula.ve": ["Universidad de Los Andes"],
    ".ula.ve": ["Universidad de Los Andes"],
    ".www.usb.ve": ["Universidad Simón Bolivar"],
    ".usb.ve": ["Simón Bolívar University"],
    ".hlscc.edu.vg": ["H. Lavity Stoutt Community College"],
    ".fpt.aptech.ac.vn": ["FPT Aptech", "FPT Aptech"],
    ".apcs.vn": ["Advanced Program in Computer Science - University of Science HCMC"],
    ".aptech.vn": ["Hanoi-Aptech Computer Education"],
    ".datapot.vn": [
        "https://datapot.edu.vn/",
        "Datapot is an educational institute that provides data science courses for Universities and Companies in Vietnam.",
    ],
    ".actvn.edu.vn": ["Academy of cryptography techniques of VietNam"],
    ".agu.edu.vn": ["An Giang University"],
    ".aptechlearning.edu.vn": [
        "Aprotrain-Aptech",
        "Aprotrain-Aptech",
        "Website: https://aptechvietnam.com.vn/",
        "Facebook: https://www.facebook.com/aptechvietnam.com.vn",
        "Wiki: https://vi.wikipedia.org/wiki/Aptech",
        "My student email: quyen.nh.404@aptechlearning.edu.vn",
    ],
    ".arena.edu.vn": ["FPT Arena Multimedia Education"],
    ".bacgiang.edu.vn": [
        "BacGiang Specialized Upper Secondary School",
        "Website: http://thptchuyen.bacgiang.edu.vn/",
    ],
    ".bafu.edu.vn": [
        "TRƯỜNG ĐẠI HỌC NÔNG - LÂM BẮC GIANG",
        "BAC GIANG AGRICULTURE AND FORESTRY UNIVERSITY",
    ],
    ".bav.edu.vn": ["Học viện Ngân Hàng", "Banking Academy of Vietnam"],
    ".bctech.edu.vn": [
        "Trường Cao đẳng Kỹ thuật Công nghệ Bà Rịa - Vũng Tàu",
        "BCTECH",
    ],
    ".bdu.edu.vn": ["Binh Duong University"],
    ".bkacad.edu.vn": ["Học viện Công nghệ BKACAD", "BKACAD Academy of Technology"],
    ".bkc.edu.vn": ["CAO DANG BACH KHOA SAI GON (BKC)", "BACH KHOA SAI GON COLLEGE"],
    ".ms.blu.edu.vn": ["Trường Đại Học Bạc Liêu", "Bac Lieu University"],
    ".st.buh.edu.vn": [
        "Đại học ngân hàng thành phố Hồ Chí Minh",
        "Banking University of Ho Chi Minh city",
    ],
    ".buh.edu.vn": ["Trường Đại Học Ngân Hàng TPHCM", "Banking University TPHCM"],
    ".bvu.edu.vn": ["Ba Ria - Vung Tau University"],
    ".c3lqdon-khanhhoa.edu.vn": [
        "Trung Học Phổ Thông Lê Quý Đôn Khánh Hoà",
        "Le Quy Don High School for gitfted",
    ],
    ".cantho.edu.vn": [
        "Sở GD&ĐT Cần Thơ",
        "Department of Education and Training of Can Tho City",
    ],
    ".caothang.edu.vn": ["Cao Đẳng Kĩ Thuật Cao Thắng"],
    ".cdythadong.edu.vn": ["Cao đẳng Y tế Hà Đông", "HA DONG MEDICAL COLLEGE"],
    ".cis.edu.vn": ["Canadian International School Viet Nam"],
    ".cofer.edu.vn": [
        "Cao đẳng Kinh Tế Đối Ngoại",
        "College of Foreign Economy and Relations",
    ],
    ".cta.edu.vn": [
        "TRƯỜNG TRUNG CẤP CÔNG NGHỆ & QUẢN TRỊ KINH DOANH HÀ NỘI",
        "HANOI COLLEGE OF TECHNOLOGY AND BUSINESS ADMINSTRATION",
    ],
    ".ctd.edu.vn": [
        "Cao Đẳng Kinh Tế Kỹ Thuật Thủ Đức",
        "Thu Duc Economic and Technical College",
    ],
    ".cth.edu.vn": ["Con Tu Hoc", "CTH Edu"],
    ".ctu.edu.vn": ["Can-Tho University"],
    ".student.ctuet.edu.vn": [
        "Trường Đại học Kỹ thuật - Công nghệ Cần Thơ",
        "Can Tho University of Technology",
    ],
    ".ctuet.edu.vn": [
        "Trường Đại học Kỹ thuật - Công nghệ Cần Thơ",
        "Can Tho University of Technology",
    ],
    ".student.ctump.edu.vn": ["Can Tho University of Medicine and Pharmacy"],
    ".dainam.edu.vn": ["Đại Học Đại Nam", "\x08Dai Nam University"],
    ".daivietsaigon.edu.vn": ["Trường Cao đẳng Đại Việt Sài Gòn"],
    ".danavtc.edu.vn": ["Danang Vocational Training College"],
    ".datapot.edu.vn": [
        "https://datapot.edu.vn/",
        "Datapot is an educational institute that provides data science courses for Universities and Companies in Vietnam.",
    ],
    ".dau.edu.vn": ["Đại học kiến trúc Đà Nẵng", "DANANG ARCHITECTURE UNIVERSITY"],
    ".dhcnhn.edu.vn": ["Đại học Công Nghiệp Hà Nội", "Hanoi University of Industry"],
    ".sv.dla.edu.vn": [
        "Đại học Kinh tế Công nghiệp Long An",
        "Long An University of Economics and Industry",
    ],
    ".dlu.edu.vn": ["University of Da Lat"],
    ".donga.edu.vn": ["\ufeffĐại Học Đông Á", "Dong A University"],
    ".dtu.edu.vn": ["Duy Tan University"],
    ".due.edu.vn": ["Đại học kinh tế Đà Nẵng", "Da Nang University of Economics"],
    ".dut.edu.vn": ["Da Nang University of Technology and Science"],
    ".duytan.edu.vn": ["Trường Đại học Duy Tân", "Duy Tan university"],
    ".eaut.edu.vn": [
        "Trường Đại Học Công Nghệ Đông Á, Hà Nội, Việt Nam",
        "East Asia University of Technology, Hanoi, VietNam",
    ],
    ".edisonschools.edu.vn": ["Edison Schools Ecopark", "Edison Schools Ecopark"],
    ".eiu.edu.vn": [
        "Eastern International University",
        "Eastern International University",
    ],
    ".fe.edu.vn": ["FPT University"],
    ".apcs.fitus.edu.vn": ["VNUHCM - University of Science"],
    ".flss.edu.vn": [
        "Trường Trung Học Phổ Thông Chuyên Ngoại Ngữ",
        "Foreign language special school",
    ],
    ".fpt.edu.vn": ["FPT University"],
    ".ftu.edu.vn": ["Đại học Ngoại Thương", "Foreign Trade University"],
    ".student.fulbright.edu.vn": ["Fulbright University Vietnam"],
    ".fulbright.edu.vn": ["Fulbright University Vietnam"],
    ".funix.edu.vn": ["FUNiX Online University"],
    ".student.hactech.edu.vn": [
        "Cao dang nghe Bach Khoa Ha Noi",
        "Hanoi Vocational College Of Technology",
    ],
    ".hanu.edu.vn": ["Ha Noi University"],
    ".hau.edu.vn": ["Hanoi University of Architecture"],
    ".haugiang.edu.vn": ["Department of Education and Training of Hau Giang Province"],
    ".haui.edu.vn": [" Đại học Công Nghiệp Hà Nội", "Hanoi University of Industry"],
    ".hcc2.edu.vn": [
        "Cao đẳng xây dựng Thành phố Hồ Chí Minh",
        "Ho Chi Minh City Construction College",
    ],
    ".hce.edu.vn": ["Hue College of Economics"],
    ".hcmiu.edu.vn": ["International University Ho Chi Minh City"],
    ".hcmuaf.edu.vn": ["Ho Chi Minh City University of Agriculture and Forestry"],
    ".hcmuarc.edu.vn": ["Ho Chi Minh City University of Architecture"],
    ".hcmue.edu.vn": [
        "Trường Đại học Sư Phạm TP.HCM",
        "Ho Chi Minh City University of Education",
    ],
    ".hcmulaw.edu.vn": ["Ho Chi Minh City University of Law"],
    ".sv.hcmunre.edu.vn": ["Dai Hoc Tai Nguyen va Moi Truong TPHCM"],
    ".hcmuns.edu.vn": ["Ho Chi Minh City University of Natural Sciences"],
    ".student.hcmup.edu.vn": [
        "Đại Học Sư Phạm Thành Phố Hồ Chí Minh",
        "Ho Chi Minh City University of Pedagogy",
    ],
    ".hcmupeda.edu.vn": ["Ho Chi Minh City University of Pedagogics"],
    ".hcmus.edu.vn": ["Ho Chi Minh University of Science"],
    ".hcmussh.edu.vn": [
        "Ho Chi Minh City University of Social Sciences and Humanities"
    ],
    ".hcmut.edu.vn": ["Ho Chi Minh City University of Technology"],
    ".hcmute.edu.vn": ["University of Technical Education Ho Chi Minh City"],
    ".hcmutrans.edu.vn": ["Ho Chi Minh City University of Transport"],
    ".hdu.edu.vn": ["Hong Duc University"],
    ".student.hlu.edu.vn": ["Đại học luật Hà Nội", "Hanoi Law University"],
    ".hmu.edu.vn": ["Hanoi Medical University"],
    ".hnue.edu.vn": ["Hanoi National University of Education"],
    ".hoasen.edu.vn": ["Hoa Sen University"],
    ".hou.edu.vn": ["Hanoi Open University"],
    ".hpmu.edu.vn": [
        "Đại học Y Dược Hải Phòng",
        "Hai Phong University of Medicine and Pharmacy",
    ],
    ".hpu2.edu.vn": ["Dai Hoc Su Pham Ha Noi", "Hanoi Pedagogical University 2"],
    ".htt.edu.vn": [
        "Trường Cao Đẳng Công nghệ và Thương Mại Hà Nội",
        "Hanoi College of Technology and Trading",
    ],
    ".hu.edu.vn": ["Ha Tinh University", "Ha Tinh University"],
    ".hua.edu.vn": ["Hanoi University of Agriculture"],
    ".huaf.edu.vn": ["Hue University of Agriculture and Forestry "],
    ".hubt.edu.vn": ["Hanoi University of Business and Technology"],
    ".huc.edu.vn": ["Hanoi University of Culture"],
    ".students.hueic.edu.vn": [
        "TRƯỜNG CAO ĐẲNG CÔNG NGHIỆP HUẾ",
        "HUE INDUSTRIAL COLLEGE",
    ],
    ".huemed-univ.edu.vn": ["Hue University of Medicine and Pharmacy"],
    ".hueuni.edu.vn": ["Hue University"],
    ".hufi.edu.vn": ["Ho Chi Minh City University of Food Industry"],
    ".st.huflit.edu.vn": [
        "Trường Đại Học Ngoại Ngữ - Tin Học TP.HCM",
        "Ho Chi Minh City University of Foreign Languages and Information Technology",
    ],
    ".humg.edu.vn": ["Hanoi University of Mining and Geology"],
    ".hunre.edu.vn": [
        "Đại học Tài nguyên và Môi trường Hà Nội",
        "Hanoi University of Natural Resources and Environment",
    ],
    ".hup.edu.vn": ["Trường Đại học Dược Hà Nội", "Ha Noi University of Pharmacy"],
    ".huph.edu.vn": [
        "TRƯỜNG ĐẠI HỌC Y TẾ CÔNG CỘNG",
        "HANOI UNIVERSITY OF PUBLIC HEALTH",
    ],
    ".hus.edu.vn": ["Hanoi University of Science"],
    ".husc.edu.vn": ["Trường Đại học Khoa học Huế", "Hue University Of Sciences"],
    ".hust.edu.vn": ["Hanoi University of Science and Technology"],
    ".hut.edu.vn": ["Hanoi University of Technology"],
    ".hutech.edu.vn": ["University of Technology"],
    ".hvnh.edu.vn": ["Học Viện Ngân Hàng", "Banking Academy"],
    ".hvtc.edu.vn": ["Học Viện Tài Chính", "Academy Of Finance"],
    ".hvu.edu.vn": ["\ufeffTrường đại học Hùng Vương", "Hung Vuong University"],
    ".hwru.edu.vn": ["Water Resources University"],
    ".ibm.edu.vn": [
        "Viện quản lý kinh doanh quốc tế",
        "International Business Management Institute",
    ],
    ".ictu.edu.vn": [
        "TRƯỜNG ĐẠI HỌC CÔNG NGHỆ THÔNG TIN VÀ TRUYỀN THÔNG",
        "THAI NGUYEN UNIVERSITY UNIVERSITY OF INFORMATION AND COMMUNICATION TECHNOLOGY",
    ],
    ".iei.edu.vn": [
        "VIET NAM INTERNATIONAL UNIVERSITY HOCHIMINH CITY - INTERNATIONAL EDUCATION INSTITUTE"
    ],
    ".ikids.edu.vn": ["International Kids"],
    ".student.isb.edu.vn": [
        "Viện đào tạo quốc tế - Trường Đại học Kinh tế Thành phố Hồ Chí Minh",
        "International School of Business - University of Economics, Ho Chi Minh city, Viet Nam",
    ],
    ".ispace.edu.vn": [
        "Trường Cao đẳng An ninh mạng iSPACE",
        "iSPACE vocational training college",
    ],
    ".itc.edu.vn": [
        "\ufeffcao đẳng công nghệ thông tin",
        "information technology collecge",
    ],
    ".ittc.edu.vn": [
        "Trường đại học công nghiệp thực phẩm Thành Phố Hồ Chí Minh",
        "HCMC University of Food Industry",
    ],
    ".student.iuh.edu.vn": [
        "Đại học Công nghiệp Thành phố Hồ Chí Minh",
        "Industrial University of Ho Chi Minh City",
    ],
    ".ict.jvn.edu.vn": ["John Von Neumann Institute"],
    ".khanhhoa.edu.vn": ["Trường THPT Nguyễn Văn Trỗi", "Nguyen Van Troi High School"],
    ".ktkt-haiduong.edu.vn": ["Hai Duong University of  Economics and Technology"],
    ".ldxh.edu.vn": [
        "Đại học Lao động - Xã hội cơ sở 2",
        "University of Labour Social Affairs 2",
    ],
    ".lhu.edu.vn": ["Đại học Lạc Hồng", "Lac Hong University"],
    ".lomonoxop.edu.vn": [
        "Trường THCS và THPT M.V.Lômônôxốp",
        "M.V Lomonosov secondary and high school",
    ],
    ".lqdtu.edu.vn": [
        "Le Quy Don Technical University",
        "Le Quy Don Technical University",
    ],
    ".lsts.edu.vn": ["Trường Đinh Thiện Lý", "Lawrence S.Ting School"],
    ".mku.edu.vn": ["Đại học Cửu Long", "Mekong University"],
    ".ndun.edu.vn": [
        "Trường Đại học Điều dưỡng Nam Định",
        "Nam Dinh University of Nursing",
    ],
    ".neu.edu.vn": ["Hanoi National Economics University"],
    ".nttu.edu.vn": ["Trường Đại học Nguyễn Tất Thành", "Nguyen Tat Thanh University"],
    ".ntu-hn.edu.vn": ["Đại học Nguyễn Trãi", "Nguyen Trai University"],
    ".ntu.edu.vn": ["Trường Đại học Nha Trang", "Nha Trang University"],
    ".nuce.edu.vn": ["National University of Civil Engineering"],
    ".ou.edu.vn": ["Ho Chi Minh City Open University"],
    ".oude.edu.vn": ["Trường Đại Học Mở thành phố Hồ Chí Minh"],
    ".pace.edu.vn": ["PACE Institute of Management "],
    ".penphy.edu.vn": ["Trường THCS Thuận Hưng"],
    ".phenikaa-uni.edu.vn": ["Phenikaa university", "Phenikaa university"],
    ".phuocbinh.edu.vn": ["Trường Đại Học Phước Bình", "Phuoc Binh University"],
    ".pnt.edu.vn": [
        "Trường Đại học Y khoa Phạm Ngọc Thạch",
        "Pham Ngoc Thach University of Medicine (PNTU)",
    ],
    ".ptit.edu.vn": ["Posts & Telecommunications Institude of Technology"],
    ".ptithcm.edu.vn": [
        "Học viện Công nghệ Bưu chính viễn thông",
        "Posts and Telecommunications Institute of Technology",
    ],
    ".pvu.edu.vn": ["Trường Đại Học Dầu Khí Việt Nam", "Petrovietnam University"],
    ".qui.edu.vn": ["Quang Ninh University of Industry"],
    ".quochocquynhon.edu.vn": ["Quoc Hoc Quy Nhon"],
    ".rmit.edu.vn": ["RMIT International University Vietnam"],
    ".saigontech.edu.vn": ["Saigontech"],
    ".sgu.edu.vn": ["Saigon University"],
    ".ssis.edu.vn": ["SAIGON SOUTH INTERNATIONAL SCHOOL"],
    ".student.stu.edu.vn": [
        "Đại học công nghệ Sài Gòn",
        "Saigon Technology University",
    ],
    ".taynguyenuni.edu.vn": ["Tay Nguyen University"],
    ".tckt.edu.vn": [
        "Dai Hoc Tai Chinh Ke Toan",
        "University Of Finance and Accountancy",
    ],
    ".tcu.edu.vn": ["Đại Học Thông tin Liên Lạc", "University Communications"],
    ".tdc.edu.vn": ["Thu Duc College of Technology"],
    ".tdmu.edu.vn": ["Thu Dau Mot University"],
    ".tdt.edu.vn": ["Ton Duc Thang University"],
    ".student.tdtu.edu.vn": ["Đại Học Tôn Đức Thắng", "Ton Duc Thang University"],
    ".tdtu.edu.vn": ["Ton Duc Thang University"],
    ".tdu.edu.vn": ["Tay Do University"],
    ".teky.edu.vn": [
        "Teky Holdings Young Technology Education JSc",
        "Teky Holdings Young Technology Education JSc",
    ],
    ".tgu.edu.vn": ["Tien Giang University", "Tien Giang University"],
    ".thanglong.edu.vn": ["Thang Long University"],
    ".thcs-nguyentrai.edu.vn": ["THCS Nguyễn Trãi"],
    ".thcsthuanhung.edu.vn": ["Trường THCS Thuận Hưng"],
    ".thpt-baria-brvt.edu.vn": ["THPT Bà Rịa", "Ba Ria High School"],
    ".thptchuyenthainguyen.edu.vn": [
        "Trung học phổ thông chuyên Thái Nguyên",
        "Thai Nguyen gifted high school",
    ],
    ".thpthahuytaphatinh.edu.vn": ["Truong THPT Ha Huy Tap", "Ha Huy Tap High School "],
    ".thptkhuongdinh.edu.vn": ["THPT Khương Đình", "Khuong Dinh Highschool"],
    ".thptlythaito.edu.vn": ["THPT Ly Thai To", "Ly Thai To High School"],
    ".thptsontra.edu.vn": ["THPT Sơn Trà", "Son Tra High School"],
    ".thpt-aldong.thuathienhue.edu.vn": ["An Luong Dong High School"],
    ".tkh.edu.vn": ["Trường trung học phổ thông Thanh Khê, Đà Nẵng City, VietNam"],
    ".tlu.edu.vn": ["Đại học thủy lợi Hà Nội", "Water Resources University"],
    ".tmu.edu.vn": ["Đại học Thương Mại", "Vietnam University of Commerce"],
    ".tnut.edu.vn": [
        "Đại Học Kỹ Thuật Công Nghiệp Thái Nguyên",
        "Thai Nguyen University of technology",
    ],
    ".topica.edu.vn": ["Tổ hợp Công nghệ giáo dục Topica"],
    ".tranvanbayst.edu.vn": ["Trần Văn Bảy"],
    ".ttn.edu.vn": ["Đại học Tây Nguyên", "Tay Nguyen University"],
    ".std.ttu.edu.vn": ["Tan Tao University", "Tan Tao University"],
    ".tuaf.edu.vn": ["Thainguyen University of Agriculture and Forestry"],
    ".tvu.edu.vn": ["Đại học Trà Vinh", "Tra Vinh University"],
    ".uah.edu.vn": [
        "Đại Học Kiến Trúc Ho Chi Minh City",
        "University of Architecture Ho Chi Minh City",
    ],
    ".ud.edu.vn": ["University of Da Nang"],
    ".uef.edu.vn": [
        "Trường Đại học Kinh tế - Tài chính thành phố Hồ Chí Minh",
        "Ho Chi Minh City University of Economics and Finance - UEF",
    ],
    ".ueh.edu.vn": ["Ho Chi Minh City University of Economics"],
    ".st.uel.edu.vn": [
        "Trường Đại học Kinh tế - Luật",
        "University of Economics and Law",
    ],
    ".sv.ufm.edu.vn": ["University of finance - marketing"],
    ".uit.edu.vn": ["University of Information Technology Ho Chi Minh City"],
    ".ump.edu.vn": [
        "University of Medicine and Pharmacy at Ho Chi Minh City",
        "University of Medicine and Pharmacy at Ho Chi Minh City",
    ],
    ".uneti.edu.vn": ["Kinh tế kỹ thuật công nghiệp Hà Nội", "Uneti University"],
    ".upt.edu.vn": ["Đại học Phan Thiết", "University of Phan Thiet"],
    ".uschool.edu.vn": ["Trường Trung Cấp Công Nghệ Tân Tiến"],
    ".sv.ussh.edu.vn": [
        "DAI HOC KHOA HOC XA HOI VA NHAN VAN, DAI HOC QUOC GIA HA NOI",
        "University of Social Sciences and Humanities, VNU Hanoi",
    ],
    ".st.usth.edu.vn": ["University of Science and Technology of Hanoi"],
    ".usth.edu.vn": ["University of Science and Technology of Hanoi"],
    ".ut.edu.vn": [
        "\ufeffTrường đại học Giao thông vận tải thành phố Hồ Chí Minh",
        "Ho Chi Minh City University of Transport",
    ],
    ".utb.edu.vn": ["Tay Bac University", "Tay Bac University"],
    ".st.utc.edu.vn": ["University of Transport and Communication", "www.utc.edu.vn"],
    ".utc.edu.vn": ["University of Transport and Communications"],
    ".st.utc2.edu.vn": [
        "University of Transport and Communications – Campus in Ho Chi Minh City",
        "www.utc2.edu.vn",
    ],
    ".utehy.edu.vn": [
        "Trường Đại học Sư phạm Kĩ thuật Hưng Yên",
        "Hung Yen University of Technology and Education",
    ],
    ".utm.edu.vn": [
        "Trường Đại học Công nghệ và Quản lý Hữu Nghị",
        "Hanoi University Of Technology and Management",
    ],
    ".utt.edu.vn": ["University Of Transport Technology"],
    ".vaa.edu.vn": ["Ministry of Transport Vietnam Aviation Academy"],
    ".vcam.edu.vn": [
        "Trường cao đẳng cơ khí nông nghiệp",
        "Vocational college of agricultural mecanics",
    ],
    ".student.vgu.edu.vn": ["Đại học Việt Đức", "Vietnamese German University"],
    ".vhu.edu.vn": ["Van Hien University"],
    ".vimaru.edu.vn": ["Vietnam Maritime University"],
    ".vinhuni.edu.vn": ["Vinh University"],
    ".vinuni.edu.vn": ["VinUniversity", "VinUniversity"],
    ".vlute.edu.vn": [
        "Đại học Sư Phạm Kỹ Thuật Vĩnh Long",
        "Vinh Long University of Technology and Education",
    ],
    ".vmmu.edu.vn": ["Vietnam Military Medical University"],
    ".vnu.edu.vn": ["Vietnam National University Hanoi"],
    ".vnua.edu.vn": [
        "Học viện Nông nghiệp Việt Nam",
        "Vietnam National University of Agriculture",
    ],
    ".vnuhcm.edu.vn": ["Vietnam National University Ho Chi Minh City"],
    ".vnuk.edu.vn": [
        "Viện Nghiên cứu và Đào tạo Việt Anh",
        "The VNUK Institute for Research and Executive Education",
    ],
    ".vtc.edu.vn": ["VTC INFORMATION TECHNOLOGY AND DESIGN ACADEMY", "VTC ACADEMY"],
    ".wellspring.edu.vn": [
        "trường Phổ thông Song Ngữ Liên cấp Wellspring",
        "Wellspring International Bilingual School",
    ],
    ".yds.edu.vn": ["Ho Chi Minh City University of Medicine and Pharmacy"],
    ".hiu.vn": [
        "Hong Bang International University",
        "Hong Bang International University",
    ],
    ".itrithuc.vn": [
        "Digital Vietnamese Knowledge System Project of the Ministry of Science and Technology of Vietnam"
    ],
    ".udn.vn": ["Danang College Of Technology"],
    ".vanlanguni.vn": ["Van Lang University"],
    ".vnn.vn": [
        "Ho Chi Minh City University of Foreign Languages and Information Technology"
    ],
    ".coltech.vnu.vn": ["Vietnam National University Hanoi"],
    ".ucode.world": ["UNIT Factory ucode"],
    ".nus.edu.ws": ["National University of Samoa"],
    ".adenuniversity.edu.ye": ["University of Aden"],
    ".eman-univ.edu.ye": ["Al-Eman University"],
    ".hoduniv.edu.ye": ["Hodeidah University"],
    ".hust.edu.ye": ["Hadhramout University of Science and Technology "],
    ".su.edu.ye": ["Sana'a University"],
    ".akademia.ac.za": ["Akademia MSW"],
    ".cput.ac.za": ["Cape Peninsula University of Technology"],
    ".cut.ac.za": ["Central University of Technology, Free State"],
    ".myuct.ac.za": ["University of Cape Town"],
    ".nmmu.ac.za": ["Nelson Mandela Metropolitan University"],
    ".nwu.ac.za": ["North-West University"],
    ".my.richfield.ac.za": ["Richfied Graduate Institute of Technology"],
    ".ru.ac.za": ["Rhodes University"],
    ".sun.ac.za": ["University of Stellenbosch"],
    ".tut.ac.za": ["Tshwane University of Technology"],
    ".uct.ac.za": ["University of Cape Town"],
    ".ufh.ac.za": ["University of Fort Hare"],
    ".uj.ac.za": ["University of Johannesburg"],
    ".ukzn.ac.za": ["University of KwaZulu-Natal"],
    ".ul.ac.za": ["University of Limpopo"],
    ".mylife.unisa.ac.za": ["University of South Africa"],
    ".unisa.ac.za": ["University of South Africa"],
    ".univen.ac.za": ["University of Venda"],
    ".uniwest.ac.za": ["University of North West"],
    ".uovs.ac.za": ["University of the Free State"],
    ".up.ac.za": ["University of Pretoria"],
    ".uwc.ac.za": ["University of the Western Cape"],
    ".uzulu.ac.za": ["University of Zululand"],
    ".vut.ac.za": ["Vaal University of Technology"],
    ".wits.ac.za": ["University of Witwatersrand"],
    ".wsu.ac.za": ["Walter Sisulu University for Technology and Science"],
    ".akademiastudente.co.za": ["Akademia MSW"],
    ".birnamcollege.co.za": ["Birnam College"],
    ".boston.co.za": ["Boston College"],
    ".ctucareer.co.za": ["CTU Training Solutions"],
    ".damelin.co.za": ["Damelin - Pretoria City Campus"],
    ".dsk.co.za": [
        "Deutsche Internationale Schule Kapstadt",
        "German International School Cape Town",
    ],
    ".educationgroup.co.za": ["CTI Education Group"],
    ".gibs.co.za": ["Gordon Institute of Business Science"],
    ".kloofhigh.co.za": ["Kloof High School"],
    ".lsdc.co.za": ["Leseding Computer Systems", "Leseding Skills Development Centre"],
    ".students.mancosa.co.za": ["Mancosa University"],
    ".myboston.co.za": ["Boston College"],
    ".sabje.co.za": ["King David Victory Park"],
    ".sthenrys.co.za": ["St Henry's Marist College"],
    ".stjohnschool.co.za": ["St John's College"],
    ".stjohnscollege.co.za": ["St John's College", "St John's College"],
    ".tuks.co.za": ["University of Pretoria"],
    ".vcconnect.co.za": ["Varsity College "],
    ".vegaconnect.co.za": ["Vega institute of Education"],
    ".virtualwindow.co.za": ["Open Window", "Open Window"],
    ".wethinkcode.co.za": ["WeThinkCode_"],
    ".bishops.org.za": ["Bishops Diocesan College"],
    ".mu.ac.zm": ["Mulungushi University"],
    ".unilus.ac.zm": ["University of Lusaka"],
    ".zambianopenuniversity.ac.zm": ["Zambian Open University"],
    ".cbu.edu.zm": ["Copperbelt University"],
    ".www.unza.zm": ["University of Zambia"],
    ".unza.zm": ["University of Zambia"],
    ".cut.ac.zw": ["Chinhoyi University of Technology"],
    ".msu.ac.zw": ["Midlands State University"],
    ".nust.ac.zw": ["National University of Science and Technology Bulawayo"],
    ".solusi.ac.zw": ["Solusi University"],
    ".uz.ac.zw": ["University of Zimbabwe"],
}
